﻿using System;
using System.Runtime.InteropServices;
using System.Threading;
using HeuristicLab.Common; // required for parameters collection
using HeuristicLab.Core; // required for parameters collection
using HeuristicLab.Data; // IntValue, ...
using HeuristicLab.Optimization; // BasicAlgorithm
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Problems.DataAnalysis;
using HeuristicLab.Random; // MersenneTwister

namespace PGE {
  // each HL item needs to have a name and a description (BasicAlgorithm is an Item)
  // The name and description of items is shown in the GUI
  [Item(Name = "Priorizied Grammar Enumeration (PGE)", Description = "Priorizied grammar enumeration algorithm. Worm, T. and Chiu K., 'Prioritized Grammar Enumeration: Symbolic Regression by Dynamic Programming'. GECCO 2013")]

  // If the algorithm should be shown in the "New..." dialog it must be creatable. Entries in the new dialog are grouped to categories and ordered by priorities
  [Creatable(Category = CreatableAttribute.Categories.Algorithms, Priority = 999)]

  [StorableClass] // for persistence (storing your algorithm to a files or transfer to HeuristicLab.Hive)
  public unsafe class PGE : BasicAlgorithm {

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern void addTestData(IntPtr indepNames, IntPtr depndNames, IntPtr matrix, int nEntries);

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern void addTrainData(IntPtr indepNames, IntPtr depndNames, IntPtr matrix, int nEntries);

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern void initSearch(int maxGen, int pgeRptEpoch, int pgeRptCount, int pgeArchiveCap, int peelCnt, int evalrCount, double zeroEpsilon, IntPtr initMethod, IntPtr growMethod, int sortType);

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern void initTreeParams(IntPtr Roots, IntPtr Nodes, IntPtr NonTrig, IntPtr Leafs, IntPtr UsableVars, int UsableVarsN, int MaxSize, int MinSize, int MaxDepth, int MinDepth);

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern void initProblem(IntPtr Name, int MaxIter, double HitRatio, int SearchVar, IntPtr ProblemTypeString, int numProcs);

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern void stepW();

    [DllImport("go-pge.dll", CharSet = CharSet.Ansi, CallingConvention = CallingConvention.StdCall)]
    public static extern IntPtr getStepResult(out Int64 nobestpush, out Int64 bestnewminerr, out Int64 bestlen1, out Int64 bestlen2, out Int64 testscore, out IntPtr coeff, out Int64 nCoeff);

    public override Type ProblemType { get { return typeof(RegressionProblem); } }
    public new RegressionProblem Problem { get { return (RegressionProblem)base.Problem; } }

    #region parameters
    // If an algorithm has parameters then we usually also add properties to access these parameters.
    // This is not strictly required but considered good shape.
    private IFixedValueParameter<IntValue> MaxIterationsParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["MaxIterations"]; }
    }
    public int MaxIterations {
      get { return MaxIterationsParameter.Value.Value; }
      set { MaxIterationsParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> nUsableVarsParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["nUsableVars"]; }
    }
    public int nUsableVars {
      get { return nUsableVarsParameter.Value.Value; }
      set { nUsableVarsParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> MaxGenParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["MaxGen"]; }
    }
    public int MaxGen {
      get { return MaxGenParameter.Value.Value; }
      set { MaxGenParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> EvalrCountParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["EvalrCount"]; }
    }
    public int EvalrCount {
      get { return EvalrCountParameter.Value.Value; }
      set { EvalrCountParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> MaxSizeParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["MaxSize"]; }
    }
    public int MaxSize {
      get { return MaxSizeParameter.Value.Value; }
      set { MaxSizeParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> MinSizeParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["MinSize"]; }
    }
    public int MinSize {
      get { return MinSizeParameter.Value.Value; }
      set { MinSizeParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> MaxDepthParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["MaxDepth"]; }
    }
    public int MaxDepth {
      get { return MaxDepthParameter.Value.Value; }
      set { MaxDepthParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> SearchVarParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["SearchVar"]; }
    }
    public int SearchVar {
      get { return SearchVarParameter.Value.Value; }
      set { SearchVarParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> MinDepthParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["MinDepth"]; }
    }
    public int MinDepth {
      get { return MinDepthParameter.Value.Value; }
      set { MinDepthParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> PgeRptEpochParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["PgeRptEpoch"]; }
    }
    public int PgeRptEpoch {
      get { return PgeRptEpochParameter.Value.Value; }
      set { PgeRptEpochParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> PgeRptCountParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["PgeRptCount"]; }
    }
    public int PgeRptCount {
      get { return PgeRptCountParameter.Value.Value; }
      set { PgeRptCountParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> PgeArchiveCapParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["PgeArchiveCap"]; }
    }
    public int PgeArchiveCap {
      get { return PgeArchiveCapParameter.Value.Value; }
      set { PgeArchiveCapParameter.Value.Value = value; }
    }

    private IFixedValueParameter<IntValue> PeelCntParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["PeelCnt"]; }
    }
    public int PeelCnt {
      get { return PeelCntParameter.Value.Value; }
      set { PeelCntParameter.Value.Value = value; }
    }

    private IFixedValueParameter<DoubleValue> ZeroEpsilonParameter {
      get { return (IFixedValueParameter<DoubleValue>)Parameters["ZeroEpsilon"]; }
    }
    public double ZeroEpsilon {
      get { return ZeroEpsilonParameter.Value.Value; }
      set { ZeroEpsilonParameter.Value.Value = value; }
    }

    private IFixedValueParameter<DoubleValue> HitRatioParameter {
      get { return (IFixedValueParameter<DoubleValue>)Parameters["HitRatio"]; }
    }
    public double HitRatio {
      get { return HitRatioParameter.Value.Value; }
      set { HitRatioParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> IndependedNamesParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["IndependedNames"]; }
    }
    public string IndependedNames {
      get { return IndependedNamesParameter.Value.Value; }
      set { IndependedNamesParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> DependedNamesParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["DependedNames"]; }
    }
    public string DependedNames {
      get { return DependedNamesParameter.Value.Value; }
      set { DependedNamesParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> InitMethodParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["InitMethod"]; }
    }
    public string InitMethod {
      get { return InitMethodParameter.Value.Value; }
      set { InitMethodParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> GrowMethodParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["GrowMethod"]; }
    }
    public string GrowMethod {
      get { return GrowMethodParameter.Value.Value; }
      set { GrowMethodParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> RootsParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["Roots"]; }
    }
    public string Roots {
      get { return RootsParameter.Value.Value; }
      set { RootsParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> NodesParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["Nodes"]; }
    }
    public string Nodes {
      get { return NodesParameter.Value.Value; }
      set { NodesParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> NonTrigParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["NonTrig"]; }
    }
    public string NonTrig {
      get { return NonTrigParameter.Value.Value; }
      set { NonTrigParameter.Value.Value = value; }
    }

    private IFixedValueParameter<StringValue> LeafsParameter {
      get { return (IFixedValueParameter<StringValue>)Parameters["Leafs"]; }
    }
    public string Leafs {
      get { return LeafsParameter.Value.Value; }
      set { LeafsParameter.Value.Value = value; }
    }
    #endregion

    // createable items must have a default ctor
    public PGE() {
      // algorithm parameters are shown in the GUI
      Parameters.Add(new FixedValueParameter<IntValue>("MaxIterations", new IntValue(50)));
      Parameters.Add(new FixedValueParameter<IntValue>("SearchVar", new IntValue(0)));
      Parameters.Add(new FixedValueParameter<IntValue>("MinDepth", new IntValue(1)));
      Parameters.Add(new FixedValueParameter<IntValue>("MaxDepth", new IntValue(6)));
      Parameters.Add(new FixedValueParameter<IntValue>("MinSize", new IntValue(4)));
      Parameters.Add(new FixedValueParameter<IntValue>("MaxSize", new IntValue(50)));
      Parameters.Add(new FixedValueParameter<IntValue>("EvalrCount", new IntValue(2)));
      Parameters.Add(new FixedValueParameter<IntValue>("PeelCnt", new IntValue(3)));
      Parameters.Add(new FixedValueParameter<IntValue>("PgeArchiveCap", new IntValue(256)));
      Parameters.Add(new FixedValueParameter<IntValue>("PgeRptCount", new IntValue(20)));
      Parameters.Add(new FixedValueParameter<IntValue>("PgeRptEpoch", new IntValue(1)));
      Parameters.Add(new FixedValueParameter<IntValue>("MaxGen", new IntValue(200)));
      Parameters.Add(new FixedValueParameter<IntValue>("nUsableVars", new IntValue(5)));

      Parameters.Add(new FixedValueParameter<StringValue>("IndependedNames", new StringValue("x y z v w")));
      Parameters.Add(new FixedValueParameter<StringValue>("DependedNames", new StringValue("f(xs)")));
      Parameters.Add(new FixedValueParameter<StringValue>("InitMethod", new StringValue("method1")));
      Parameters.Add(new FixedValueParameter<StringValue>("GrowMethod", new StringValue("method1")));

      Parameters.Add(new FixedValueParameter<StringValue>("Roots", new StringValue("Add")));
      Parameters.Add(new FixedValueParameter<StringValue>("Nodes", new StringValue("Add Mul")));
      Parameters.Add(new FixedValueParameter<StringValue>("NonTrig", new StringValue("Add Mul")));
      Parameters.Add(new FixedValueParameter<StringValue>("Leafs", new StringValue("Var ConstantF")));

      Parameters.Add(new FixedValueParameter<DoubleValue>("ZeroEpsilon", new DoubleValue(0.00001)));
      Parameters.Add(new FixedValueParameter<DoubleValue>("HitRatio", new DoubleValue(0.01)));
    }

    // Persistence uses this ctor to improve deserialization efficiency.
    // If we would use the default ctor instead this would completely initialize the object (e.g. creating parameters)
    // even though the data is later overwritten by the stored data.
    [StorableConstructor]
    public PGE(bool deserializing) : base(deserializing) { }

    // Each clonable item must have a cloning ctor (deep cloning, the cloner is used to handle cyclic object references)
    public PGE(PGE original, Cloner cloner) : base(original, cloner) {
      // Don't forget to call the cloning ctor of the base class
      // TODO: if this class has fields then they need to be cloned here
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new PGE(this, cloner);
    }

    protected override void Run(CancellationToken cancellationToken) {

      Environment.SetEnvironmentVariable("GOGC", "off");
      Environment.SetEnvironmentVariable("GODEBUG", "cgocheck=0");
      Environment.SetEnvironmentVariable("CGO_ENABLED", "1");

      //Parameter
      int MaxIter = MaxIterations;
      string indepNames = IndependedNames;
      string depndNames = DependedNames;
      
      int nTrainData = 200;   //Woher ?
      int nTestData = 2000;   //Woher ?

      //Constants
      int SortType = 0;
      string ProblemTypeString = "benchmark";
      int NumProcs = 12;
      string Name = "Korns_02";

      //Calcs
      int indepLen = indepNames.Split(' ').Length;
      int depLen = depndNames.Split(' ').Length;

      IntPtr TrainData = GetTrainData(indepLen, depLen, nTrainData);
      IntPtr TestData = GetTestData(indepLen, depLen, nTestData);

      IntPtr CindepNames = Marshal.StringToHGlobalAnsi(indepNames);
      IntPtr CdepndNames = Marshal.StringToHGlobalAnsi(depndNames);

      IntPtr CinitMethod = Marshal.StringToHGlobalAnsi(InitMethod);
      IntPtr CgrowMethod = Marshal.StringToHGlobalAnsi(GrowMethod);

      IntPtr Croots = Marshal.StringToHGlobalAnsi(Roots);
      IntPtr Cnodes = Marshal.StringToHGlobalAnsi(Nodes);
      IntPtr CnonTrig = Marshal.StringToHGlobalAnsi(NonTrig);
      IntPtr Cleafs = Marshal.StringToHGlobalAnsi(Leafs);

      IntPtr Cname = Marshal.StringToHGlobalAnsi(Name);
      IntPtr CproblemTypeString = Marshal.StringToHGlobalAnsi(ProblemTypeString);


      Console.WriteLine("AddTrainData");
      addTestData(CindepNames, CdepndNames, TestData, nTestData);

      Console.WriteLine("AddTestData");
      addTrainData(CindepNames, CdepndNames, TrainData, nTrainData);

      IntPtr UsableVars = GetUsableVars(nUsableVars);

      Console.WriteLine("InitSearch");
      initSearch(MaxGen, PgeRptEpoch, PgeRptCount, PgeArchiveCap, PeelCnt, EvalrCount, ZeroEpsilon, CinitMethod, CgrowMethod, SortType);

      Console.WriteLine("InitTree");
      initTreeParams(Croots, Cnodes, CnonTrig, Cleafs, UsableVars, nUsableVars, MaxSize, MinSize, MaxDepth, MinDepth);

      Console.WriteLine("InitProblem");
      initProblem(Cname, MaxIter, HitRatio, SearchVar, CproblemTypeString, NumProcs);

      Console.WriteLine("Finished Init");

      var curItersItem = new IntValue();

      double[] coeffmem = new double[nUsableVars];
      IntPtr Coeff = Marshal.AllocHGlobal(sizeof(Double) * nUsableVars);
      Marshal.Copy(coeffmem, 0, Coeff, nUsableVars);

      for (int iter = 1; iter <= MaxIter; iter++) {
        curItersItem.Value = iter;

        Console.WriteLine("Step " + iter);
        stepW();

        for (int iPeel = 0; iPeel < PeelCnt; iPeel++) {
          Int64 nobestpush = 0; //bool
          Int64 bestnewminerr = 0;  //bool
          Int64 bestlen1 = 0; 
          Int64 bestlen2 = 0;
          Int64 nCoeff = 0;
          Int64 TestScore = 0;

          IntPtr eqn = getStepResult(out nobestpush, out bestnewminerr, out bestlen1, out bestlen2, out TestScore, out Coeff, out nCoeff);

          string eqnStr = Marshal.PtrToStringAnsi(eqn);

          if (nobestpush == 1) 
          {
            Console.WriteLine("No best push");
          } else {
            Console.WriteLine("Push/Pop (" + bestlen1 + "," + bestlen2 + ") " + eqnStr);

            for (int iCoeff = 0; iCoeff < nCoeff; iCoeff++) {
              //Marshal.Re
              //Console.WriteLine(" Coeff " + Marshal.ReadFloatPtr(Coeff, iCoeff * sizeof());
            }

            var curItersResult = new Result("Iteration " + iter + " " + iPeel, curItersItem);

            var bestQualityItem = new StringValue(eqnStr);
            var bestQualityResult = new Result("Best quality " + iter + " " + iPeel, bestQualityItem);
            Results.Add(curItersResult);
            Results.Add(bestQualityResult);

            if (bestnewminerr == 1)
            {
              Console.WriteLine("Best New Min Error");
            }
          }
          //Marshal.FreeHGlobal(eqn);
        }

        if (cancellationToken.IsCancellationRequested) break;
      }
      Marshal.FreeHGlobal(Coeff);
      //Marshal.FreeHGlobal(UsableVars);
      //Marshal.FreeHGlobal(CproblemTypeString);
      //Marshal.FreeHGlobal(Cname);
      Results.Add(new Result("Execution time", new TimeSpanValue(this.ExecutionTime)));
    }

    public override bool SupportsPause {
      get { return false; }
    }

    private static IntPtr GetUsableVars(int n) {
      Int64[] UV = new Int64[n];

      for (int i = 0; i < n; i++) {
        UV[i] = i;
      }

      IntPtr UsableVars = Marshal.AllocHGlobal(sizeof(Int64) * n);
      Marshal.Copy(UV, 0, UsableVars, n);

      return UsableVars;
    }

    private static IntPtr GetTestData(int indepLen, int depLen, int n) {
      int nCulm = indepLen + depLen;

      double[] val = new double[n * nCulm];

      val[0 * nCulm + 0] = 35.528360;
      val[0 * nCulm + 1] = -4.871221;
      val[0 * nCulm + 2] = 46.703853;
      val[0 * nCulm + 3] = -29.730475;
      val[0 * nCulm + 4] = -34.723734;
      val[0 * nCulm + 5] = 4.946698;
      val[1 * nCulm + 0] = -44.231504;
      val[1 * nCulm + 1] = 31.425053;
      val[1 * nCulm + 2] = -9.415432;
      val[1 * nCulm + 3] = -9.818755;
      val[1 * nCulm + 4] = 20.340236;
      val[1 * nCulm + 5] = 5.257956;
      val[2 * nCulm + 0] = -40.145913;
      val[2 * nCulm + 1] = 45.154614;
      val[2 * nCulm + 2] = 42.652329;
      val[2 * nCulm + 3] = 40.513300;
      val[2 * nCulm + 4] = -6.647631;
      val[2 * nCulm + 5] = -60.768387;
      val[3 * nCulm + 0] = 9.327007;
      val[3 * nCulm + 1] = -18.137567;
      val[3 * nCulm + 2] = 14.513202;
      val[3 * nCulm + 3] = -17.981328;
      val[3 * nCulm + 4] = 5.462345;
      val[3 * nCulm + 5] = -31.068418;
      val[4 * nCulm + 0] = -4.363941;
      val[4 * nCulm + 1] = 18.585630;
      val[4 * nCulm + 2] = -0.690409;
      val[4 * nCulm + 3] = 5.057848;
      val[4 * nCulm + 4] = 44.249465;
      val[4 * nCulm + 5] = 2.759126;
      val[5 * nCulm + 0] = 47.763236;
      val[5 * nCulm + 1] = 31.592286;
      val[5 * nCulm + 2] = 15.907035;
      val[5 * nCulm + 3] = -23.423081;
      val[5 * nCulm + 4] = 22.478740;
      val[5 * nCulm + 5] = 1.950184;
      val[6 * nCulm + 0] = -16.278202;
      val[6 * nCulm + 1] = 0.457686;
      val[6 * nCulm + 2] = 7.556504;
      val[6 * nCulm + 3] = 49.812207;
      val[6 * nCulm + 4] = -33.444801;
      val[6 * nCulm + 5] = -6.884534;
      val[7 * nCulm + 0] = -21.929718;
      val[7 * nCulm + 1] = 9.888507;
      val[7 * nCulm + 2] = 39.572147;
      val[7 * nCulm + 3] = 37.355059;
      val[7 * nCulm + 4] = -27.468348;
      val[7 * nCulm + 5] = -7.910990;
      val[8 * nCulm + 0] = 6.923541;
      val[8 * nCulm + 1] = 47.218019;
      val[8 * nCulm + 2] = -23.564647;
      val[8 * nCulm + 3] = 29.891087;
      val[8 * nCulm + 4] = -17.401192;
      val[8 * nCulm + 5] = -20.744603;
      val[9 * nCulm + 0] = -6.079671;
      val[9 * nCulm + 1] = 40.411034;
      val[9 * nCulm + 2] = 16.110523;
      val[9 * nCulm + 3] = 3.818028;
      val[9 * nCulm + 4] = 33.173629;
      val[9 * nCulm + 5] = 6.540762;
      val[10 * nCulm + 0] = 2.433467;
      val[10 * nCulm + 1] = 33.095144;
      val[10 * nCulm + 2] = -31.086298;
      val[10 * nCulm + 3] = 10.811361;
      val[10 * nCulm + 4] = 21.595160;
      val[10 * nCulm + 5] = 9.853644;
      val[11 * nCulm + 0] = -27.518072;
      val[11 * nCulm + 1] = -11.172010;
      val[11 * nCulm + 2] = 13.336483;
      val[11 * nCulm + 3] = -48.294798;
      val[11 * nCulm + 4] = 46.019746;
      val[11 * nCulm + 5] = -5.886423;
      val[12 * nCulm + 0] = -28.788139;
      val[12 * nCulm + 1] = 4.910058;
      val[12 * nCulm + 2] = 31.899783;
      val[12 * nCulm + 3] = 6.013857;
      val[12 * nCulm + 4] = -30.175800;
      val[12 * nCulm + 5] = -1.483510;
      val[13 * nCulm + 0] = 32.637495;
      val[13 * nCulm + 1] = -8.530306;
      val[13 * nCulm + 2] = -32.110986;
      val[13 * nCulm + 3] = 42.021517;
      val[13 * nCulm + 4] = 10.915009;
      val[13 * nCulm + 5] = 14.753585;
      val[14 * nCulm + 0] = 31.581582;
      val[14 * nCulm + 1] = -48.123516;
      val[14 * nCulm + 2] = 31.768625;
      val[14 * nCulm + 3] = -20.749623;
      val[14 * nCulm + 4] = -30.174653;
      val[14 * nCulm + 5] = 11.033754;
      val[15 * nCulm + 0] = 48.635034;
      val[15 * nCulm + 1] = -41.733060;
      val[15 * nCulm + 2] = 43.430440;
      val[15 * nCulm + 3] = 12.684023;
      val[15 * nCulm + 4] = 5.875879;
      val[15 * nCulm + 5] = -23.170547;
      val[16 * nCulm + 0] = 26.762238;
      val[16 * nCulm + 1] = 36.340173;
      val[16 * nCulm + 2] = -24.894535;
      val[16 * nCulm + 3] = -5.605376;
      val[16 * nCulm + 4] = 36.334468;
      val[16 * nCulm + 5] = 4.233858;
      val[17 * nCulm + 0] = 25.145521;
      val[17 * nCulm + 1] = 44.853054;
      val[17 * nCulm + 2] = -18.334141;
      val[17 * nCulm + 3] = 11.881314;
      val[17 * nCulm + 4] = 42.381077;
      val[17 * nCulm + 5] = 6.566382;
      val[18 * nCulm + 0] = -42.357660;
      val[18 * nCulm + 1] = -34.882176;
      val[18 * nCulm + 2] = 9.183237;
      val[18 * nCulm + 3] = 41.599486;
      val[18 * nCulm + 4] = 24.184490;
      val[18 * nCulm + 5] = 1.544697;
      val[19 * nCulm + 0] = 31.441787;
      val[19 * nCulm + 1] = 48.275494;
      val[19 * nCulm + 2] = -39.676964;
      val[19 * nCulm + 3] = -47.630359;
      val[19 * nCulm + 4] = -37.095302;
      val[19 * nCulm + 5] = 0.147681;
      val[20 * nCulm + 0] = -9.078921;
      val[20 * nCulm + 1] = 3.086811;
      val[20 * nCulm + 2] = -11.123847;
      val[20 * nCulm + 3] = 39.136046;
      val[20 * nCulm + 4] = 24.015646;
      val[20 * nCulm + 5] = 8.551861;
      val[21 * nCulm + 0] = 8.938696;
      val[21 * nCulm + 1] = 25.506630;
      val[21 * nCulm + 2] = -38.311138;
      val[21 * nCulm + 3] = 23.266212;
      val[21 * nCulm + 4] = -5.712827;
      val[21 * nCulm + 5] = -40.180486;
      val[22 * nCulm + 0] = -18.358330;
      val[22 * nCulm + 1] = 18.708014;
      val[22 * nCulm + 2] = 20.158104;
      val[22 * nCulm + 3] = 17.582586;
      val[22 * nCulm + 4] = 26.496756;
      val[22 * nCulm + 5] = 6.712888;
      val[23 * nCulm + 0] = -40.845049;
      val[23 * nCulm + 1] = 16.105598;
      val[23 * nCulm + 2] = -21.861983;
      val[23 * nCulm + 3] = -37.737274;
      val[23 * nCulm + 4] = -3.292133;
      val[23 * nCulm + 5] = 31.331399;
      val[24 * nCulm + 0] = 22.053264;
      val[24 * nCulm + 1] = -48.597474;
      val[24 * nCulm + 2] = -10.793461;
      val[24 * nCulm + 3] = -12.317774;
      val[24 * nCulm + 4] = -11.489620;
      val[24 * nCulm + 5] = 25.325013;
      val[25 * nCulm + 0] = 28.810041;
      val[25 * nCulm + 1] = 12.362830;
      val[25 * nCulm + 2] = 34.864708;
      val[25 * nCulm + 3] = -38.338879;
      val[25 * nCulm + 4] = -19.963826;
      val[25 * nCulm + 5] = 6.388804;
      val[26 * nCulm + 0] = -13.726681;
      val[26 * nCulm + 1] = -32.693687;
      val[26 * nCulm + 2] = 1.424195;
      val[26 * nCulm + 3] = 49.941958;
      val[26 * nCulm + 4] = -39.189710;
      val[26 * nCulm + 5] = -1.853246;
      val[27 * nCulm + 0] = 28.699196;
      val[27 * nCulm + 1] = -18.398672;
      val[27 * nCulm + 2] = 0.406712;
      val[27 * nCulm + 3] = -0.615911;
      val[27 * nCulm + 4] = -11.365699;
      val[27 * nCulm + 5] = 8.148771;
      val[28 * nCulm + 0] = 13.695322;
      val[28 * nCulm + 1] = -48.136951;
      val[28 * nCulm + 2] = -11.304375;
      val[28 * nCulm + 3] = 26.090905;
      val[28 * nCulm + 4] = 2.903962;
      val[28 * nCulm + 5] = -35.704112;
      val[29 * nCulm + 0] = 28.122320;
      val[29 * nCulm + 1] = 29.630938;
      val[29 * nCulm + 2] = 1.473437;
      val[29 * nCulm + 3] = 20.488026;
      val[29 * nCulm + 4] = 4.256546;
      val[29 * nCulm + 5] = 55.962924;
      val[30 * nCulm + 0] = 21.349854;
      val[30 * nCulm + 1] = -18.637162;
      val[30 * nCulm + 2] = -14.268497;
      val[30 * nCulm + 3] = -31.914547;
      val[30 * nCulm + 4] = 15.384353;
      val[30 * nCulm + 5] = -15.323341;
      val[31 * nCulm + 0] = 37.202180;
      val[31 * nCulm + 1] = 48.541654;
      val[31 * nCulm + 2] = 28.150913;
      val[31 * nCulm + 3] = -46.647159;
      val[31 * nCulm + 4] = 6.642921;
      val[31 * nCulm + 5] = 1.579900;
      val[32 * nCulm + 0] = 11.625904;
      val[32 * nCulm + 1] = 6.261292;
      val[32 * nCulm + 2] = 12.131636;
      val[32 * nCulm + 3] = 47.100012;
      val[32 * nCulm + 4] = 39.270637;
      val[32 * nCulm + 5] = 6.661697;
      val[33 * nCulm + 0] = 25.024361;
      val[33 * nCulm + 1] = 37.679028;
      val[33 * nCulm + 2] = -7.650179;
      val[33 * nCulm + 3] = 48.974379;
      val[33 * nCulm + 4] = 24.085848;
      val[33 * nCulm + 5] = 17.259064;
      val[34 * nCulm + 0] = 44.479407;
      val[34 * nCulm + 1] = -48.149421;
      val[34 * nCulm + 2] = -9.159622;
      val[34 * nCulm + 3] = 37.585855;
      val[34 * nCulm + 4] = -34.028905;
      val[34 * nCulm + 5] = 1.699365;
      val[35 * nCulm + 0] = -23.217244;
      val[35 * nCulm + 1] = -33.755328;
      val[35 * nCulm + 2] = -44.506854;
      val[35 * nCulm + 3] = -9.446730;
      val[35 * nCulm + 4] = -20.946523;
      val[35 * nCulm + 5] = 9.992467;
      val[36 * nCulm + 0] = 20.498148;
      val[36 * nCulm + 1] = 23.946338;
      val[36 * nCulm + 2] = -12.326101;
      val[36 * nCulm + 3] = -41.438722;
      val[36 * nCulm + 4] = -24.071705;
      val[36 * nCulm + 5] = 3.669610;
      val[37 * nCulm + 0] = -49.225602;
      val[37 * nCulm + 1] = -14.846652;
      val[37 * nCulm + 2] = -49.269253;
      val[37 * nCulm + 3] = 10.369623;
      val[37 * nCulm + 4] = -0.362401;
      val[37 * nCulm + 5] = 58.704599;
      val[38 * nCulm + 0] = -44.643757;
      val[38 * nCulm + 1] = 32.995880;
      val[38 * nCulm + 2] = 2.446568;
      val[38 * nCulm + 3] = 41.109934;
      val[38 * nCulm + 4] = 27.491094;
      val[38 * nCulm + 5] = 12.989314;
      val[39 * nCulm + 0] = 49.850966;
      val[39 * nCulm + 1] = 42.217249;
      val[39 * nCulm + 2] = -4.624295;
      val[39 * nCulm + 3] = 7.329174;
      val[39 * nCulm + 4] = -27.297762;
      val[39 * nCulm + 5] = -8.361171;
      val[40 * nCulm + 0] = -17.481092;
      val[40 * nCulm + 1] = 12.278468;
      val[40 * nCulm + 2] = -4.274719;
      val[40 * nCulm + 3] = -3.615732;
      val[40 * nCulm + 4] = -31.171145;
      val[40 * nCulm + 5] = -1.085435;
      val[41 * nCulm + 0] = 22.960608;
      val[41 * nCulm + 1] = 38.356352;
      val[41 * nCulm + 2] = -25.734419;
      val[41 * nCulm + 3] = -17.655855;
      val[41 * nCulm + 4] = -33.421799;
      val[41 * nCulm + 5] = -2.701690;
      val[42 * nCulm + 0] = -21.446723;
      val[42 * nCulm + 1] = 42.373999;
      val[42 * nCulm + 2] = -22.616840;
      val[42 * nCulm + 3] = 0.835362;
      val[42 * nCulm + 4] = 6.720630;
      val[42 * nCulm + 5] = 30.662314;
      val[43 * nCulm + 0] = 23.687616;
      val[43 * nCulm + 1] = 9.768459;
      val[43 * nCulm + 2] = 35.949458;
      val[43 * nCulm + 3] = 14.113278;
      val[43 * nCulm + 4] = 36.087448;
      val[43 * nCulm + 5] = 3.362397;
      val[44 * nCulm + 0] = 20.106260;
      val[44 * nCulm + 1] = 38.749315;
      val[44 * nCulm + 2] = 33.136025;
      val[44 * nCulm + 3] = 30.203761;
      val[44 * nCulm + 4] = 8.958134;
      val[44 * nCulm + 5] = 36.663690;
      val[45 * nCulm + 0] = 40.776733;
      val[45 * nCulm + 1] = 19.764579;
      val[45 * nCulm + 2] = 49.428173;
      val[45 * nCulm + 3] = 19.250109;
      val[45 * nCulm + 4] = 35.462320;
      val[45 * nCulm + 5] = 5.437486;
      val[46 * nCulm + 0] = -38.224729;
      val[46 * nCulm + 1] = -3.571152;
      val[46 * nCulm + 2] = 44.471931;
      val[46 * nCulm + 3] = -27.022834;
      val[46 * nCulm + 4] = 38.045670;
      val[46 * nCulm + 5] = -3.576255;
      val[47 * nCulm + 0] = 43.991443;
      val[47 * nCulm + 1] = -42.670215;
      val[47 * nCulm + 2] = 46.203837;
      val[47 * nCulm + 3] = -20.480101;
      val[47 * nCulm + 4] = -29.549564;
      val[47 * nCulm + 5] = 10.345598;
      val[48 * nCulm + 0] = 48.694184;
      val[48 * nCulm + 1] = -29.017415;
      val[48 * nCulm + 2] = -24.777402;
      val[48 * nCulm + 3] = -28.672447;
      val[48 * nCulm + 4] = 42.347441;
      val[48 * nCulm + 5] = -6.218214;
      val[49 * nCulm + 0] = 22.734711;
      val[49 * nCulm + 1] = 9.134362;
      val[49 * nCulm + 2] = -45.765629;
      val[49 * nCulm + 3] = -49.239662;
      val[49 * nCulm + 4] = 2.754691;
      val[49 * nCulm + 5] = -68.682174;
      val[50 * nCulm + 0] = 43.624176;
      val[50 * nCulm + 1] = -47.168824;
      val[50 * nCulm + 2] = -10.160528;
      val[50 * nCulm + 3] = 35.809148;
      val[50 * nCulm + 4] = 25.372053;
      val[50 * nCulm + 5] = -1.889227;
      val[51 * nCulm + 0] = 44.829327;
      val[51 * nCulm + 1] = -35.898795;
      val[51 * nCulm + 2] = -44.393419;
      val[51 * nCulm + 3] = 33.841096;
      val[51 * nCulm + 4] = -41.914180;
      val[51 * nCulm + 5] = 0.462374;
      val[52 * nCulm + 0] = -3.177271;
      val[52 * nCulm + 1] = 35.154468;
      val[52 * nCulm + 2] = 4.688212;
      val[52 * nCulm + 3] = -38.328239;
      val[52 * nCulm + 4] = -46.773169;
      val[52 * nCulm + 5] = 0.551178;
      val[53 * nCulm + 0] = -7.717706;
      val[53 * nCulm + 1] = 6.440085;
      val[53 * nCulm + 2] = 0.350683;
      val[53 * nCulm + 3] = -23.181969;
      val[53 * nCulm + 4] = -5.245842;
      val[53 * nCulm + 5] = 15.336233;
      val[54 * nCulm + 0] = 13.694506;
      val[54 * nCulm + 1] = -33.507271;
      val[54 * nCulm + 2] = 48.904668;
      val[54 * nCulm + 3] = 44.624490;
      val[54 * nCulm + 4] = -31.218447;
      val[54 * nCulm + 5] = -1.455590;
      val[55 * nCulm + 0] = -24.449808;
      val[55 * nCulm + 1] = -7.294553;
      val[55 * nCulm + 2] = -21.486307;
      val[55 * nCulm + 3] = -4.131200;
      val[55 * nCulm + 4] = -29.788284;
      val[55 * nCulm + 5] = 2.045542;
      val[56 * nCulm + 0] = -9.604205;
      val[56 * nCulm + 1] = 7.149284;
      val[56 * nCulm + 2] = -10.838312;
      val[56 * nCulm + 3] = 14.106871;
      val[56 * nCulm + 4] = -6.061187;
      val[56 * nCulm + 5] = -16.369467;
      val[57 * nCulm + 0] = 20.853542;
      val[57 * nCulm + 1] = -21.416190;
      val[57 * nCulm + 2] = 37.634071;
      val[57 * nCulm + 3] = -5.470358;
      val[57 * nCulm + 4] = -0.515474;
      val[57 * nCulm + 5] = 247.115278;
      val[58 * nCulm + 0] = 22.221456;
      val[58 * nCulm + 1] = -6.901826;
      val[58 * nCulm + 2] = 36.376966;
      val[58 * nCulm + 3] = -0.601854;
      val[58 * nCulm + 4] = -47.546903;
      val[58 * nCulm + 5] = 0.976997;
      val[59 * nCulm + 0] = 8.948948;
      val[59 * nCulm + 1] = 4.747224;
      val[59 * nCulm + 2] = -26.928305;
      val[59 * nCulm + 3] = -5.815919;
      val[59 * nCulm + 4] = -13.078944;
      val[59 * nCulm + 5] = 0.616766;
      val[60 * nCulm + 0] = 47.264144;
      val[60 * nCulm + 1] = -5.086315;
      val[60 * nCulm + 2] = 28.819372;
      val[60 * nCulm + 3] = -39.642417;
      val[60 * nCulm + 4] = -40.886102;
      val[60 * nCulm + 5] = 5.408190;
      val[61 * nCulm + 0] = 24.253016;
      val[61 * nCulm + 1] = -24.736786;
      val[61 * nCulm + 2] = -6.537728;
      val[61 * nCulm + 3] = -23.167072;
      val[61 * nCulm + 4] = -45.722913;
      val[61 * nCulm + 5] = 5.189109;
      val[62 * nCulm + 0] = 47.386536;
      val[62 * nCulm + 1] = -23.397793;
      val[62 * nCulm + 2] = 12.564403;
      val[62 * nCulm + 3] = -7.063417;
      val[62 * nCulm + 4] = -13.763249;
      val[62 * nCulm + 5] = 10.705946;
      val[63 * nCulm + 0] = 26.223282;
      val[63 * nCulm + 1] = 24.926964;
      val[63 * nCulm + 2] = 15.226702;
      val[63 * nCulm + 3] = -48.688516;
      val[63 * nCulm + 4] = -35.044726;
      val[63 * nCulm + 5] = 3.439366;
      val[64 * nCulm + 0] = 9.476523;
      val[64 * nCulm + 1] = 35.668197;
      val[64 * nCulm + 2] = -10.866593;
      val[64 * nCulm + 3] = -21.655157;
      val[64 * nCulm + 4] = 23.052394;
      val[64 * nCulm + 5] = 3.107289;
      val[65 * nCulm + 0] = -3.486875;
      val[65 * nCulm + 1] = -19.304899;
      val[65 * nCulm + 2] = 37.245118;
      val[65 * nCulm + 3] = 16.475326;
      val[65 * nCulm + 4] = 14.365895;
      val[65 * nCulm + 5] = -0.702299;
      val[66 * nCulm + 0] = -3.227466;
      val[66 * nCulm + 1] = -42.376506;
      val[66 * nCulm + 2] = -45.514607;
      val[66 * nCulm + 3] = 2.401739;
      val[66 * nCulm + 4] = -14.968617;
      val[66 * nCulm + 5] = 12.870707;
      val[67 * nCulm + 0] = -9.933772;
      val[67 * nCulm + 1] = 29.618509;
      val[67 * nCulm + 2] = -23.898111;
      val[67 * nCulm + 3] = -38.743953;
      val[67 * nCulm + 4] = -27.342771;
      val[67 * nCulm + 5] = 1.809714;
      val[68 * nCulm + 0] = -49.450663;
      val[68 * nCulm + 1] = -19.636583;
      val[68 * nCulm + 2] = 44.906862;
      val[68 * nCulm + 3] = -22.468233;
      val[68 * nCulm + 4] = -4.904886;
      val[68 * nCulm + 5] = 40.862165;
      val[69 * nCulm + 0] = 16.582867;
      val[69 * nCulm + 1] = 4.586003;
      val[69 * nCulm + 2] = -0.015822;
      val[69 * nCulm + 3] = 40.995652;
      val[69 * nCulm + 4] = 46.187249;
      val[69 * nCulm + 5] = 4.901271;
      val[70 * nCulm + 0] = -40.860306;
      val[70 * nCulm + 1] = 5.445730;
      val[70 * nCulm + 2] = -6.638337;
      val[70 * nCulm + 3] = -23.874837;
      val[70 * nCulm + 4] = -22.309552;
      val[70 * nCulm + 5] = 4.140034;
      val[71 * nCulm + 0] = 15.879872;
      val[71 * nCulm + 1] = 42.559344;
      val[71 * nCulm + 2] = 7.289614;
      val[71 * nCulm + 3] = -26.419555;
      val[71 * nCulm + 4] = -3.894523;
      val[71 * nCulm + 5] = -19.386011;
      val[72 * nCulm + 0] = 23.538496;
      val[72 * nCulm + 1] = 48.867719;
      val[72 * nCulm + 2] = 30.326464;
      val[72 * nCulm + 3] = -21.893482;
      val[72 * nCulm + 4] = 6.113702;
      val[72 * nCulm + 5] = 21.113917;
      val[73 * nCulm + 0] = 23.557567;
      val[73 * nCulm + 1] = -15.455347;
      val[73 * nCulm + 2] = -0.423738;
      val[73 * nCulm + 3] = -28.697410;
      val[73 * nCulm + 4] = 25.099511;
      val[73 * nCulm + 5] = -8.096446;
      val[74 * nCulm + 0] = -21.042354;
      val[74 * nCulm + 1] = -37.968199;
      val[74 * nCulm + 2] = 15.716314;
      val[74 * nCulm + 3] = 35.793711;
      val[74 * nCulm + 4] = 16.908572;
      val[74 * nCulm + 5] = -0.378720;
      val[75 * nCulm + 0] = 7.754070;
      val[75 * nCulm + 1] = -24.084660;
      val[75 * nCulm + 2] = 13.114959;
      val[75 * nCulm + 3] = 20.308576;
      val[75 * nCulm + 4] = 46.589000;
      val[75 * nCulm + 5] = -0.153641;
      val[76 * nCulm + 0] = -25.057191;
      val[76 * nCulm + 1] = 24.170220;
      val[76 * nCulm + 2] = -14.393548;
      val[76 * nCulm + 3] = 11.832110;
      val[76 * nCulm + 4] = 16.313423;
      val[76 * nCulm + 5] = 10.676062;
      val[77 * nCulm + 0] = -1.831074;
      val[77 * nCulm + 1] = -33.255007;
      val[77 * nCulm + 2] = -35.792276;
      val[77 * nCulm + 3] = -7.682652;
      val[77 * nCulm + 4] = -17.457361;
      val[77 * nCulm + 5] = 11.329707;
      val[78 * nCulm + 0] = -9.816107;
      val[78 * nCulm + 1] = -1.713383;
      val[78 * nCulm + 2] = 36.848173;
      val[78 * nCulm + 3] = -41.860561;
      val[78 * nCulm + 4] = -4.708257;
      val[78 * nCulm + 5] = 44.036020;
      val[79 * nCulm + 0] = 12.299103;
      val[79 * nCulm + 1] = 33.829870;
      val[79 * nCulm + 2] = 20.894889;
      val[79 * nCulm + 3] = 31.654511;
      val[79 * nCulm + 4] = -31.606185;
      val[79 * nCulm + 5] = -9.576922;
      val[80 * nCulm + 0] = 4.319071;
      val[80 * nCulm + 1] = -23.339792;
      val[80 * nCulm + 2] = 2.130224;
      val[80 * nCulm + 3] = -30.841159;
      val[80 * nCulm + 4] = 22.973177;
      val[80 * nCulm + 5] = -10.933301;
      val[81 * nCulm + 0] = -24.458385;
      val[81 * nCulm + 1] = 9.974797;
      val[81 * nCulm + 2] = 39.743155;
      val[81 * nCulm + 3] = 8.291920;
      val[81 * nCulm + 4] = 1.078545;
      val[81 * nCulm + 5] = 80.395817;
      val[82 * nCulm + 0] = -49.624526;
      val[82 * nCulm + 1] = -47.716226;
      val[82 * nCulm + 2] = 20.659994;
      val[82 * nCulm + 3] = -19.696016;
      val[82 * nCulm + 4] = -17.109552;
      val[82 * nCulm + 5] = 18.879502;
      val[83 * nCulm + 0] = -26.237244;
      val[83 * nCulm + 1] = -8.749226;
      val[83 * nCulm + 2] = -43.134346;
      val[83 * nCulm + 3] = -42.949560;
      val[83 * nCulm + 4] = -46.291986;
      val[83 * nCulm + 5] = 5.516176;
      val[84 * nCulm + 0] = 6.969518;
      val[84 * nCulm + 1] = -14.618834;
      val[84 * nCulm + 2] = -8.016899;
      val[84 * nCulm + 3] = -26.321655;
      val[84 * nCulm + 4] = -49.696358;
      val[84 * nCulm + 5] = 4.129380;
      val[85 * nCulm + 0] = 14.258762;
      val[85 * nCulm + 1] = -1.384557;
      val[85 * nCulm + 2] = -15.034249;
      val[85 * nCulm + 3] = 28.949634;
      val[85 * nCulm + 4] = 36.006668;
      val[85 * nCulm + 5] = 3.853626;
      val[86 * nCulm + 0] = -2.724900;
      val[86 * nCulm + 1] = 45.740424;
      val[86 * nCulm + 2] = 46.249019;
      val[86 * nCulm + 3] = 45.931435;
      val[86 * nCulm + 4] = -29.721854;
      val[86 * nCulm + 5] = -14.369139;
      val[87 * nCulm + 0] = -16.703865;
      val[87 * nCulm + 1] = -34.510913;
      val[87 * nCulm + 2] = -5.081524;
      val[87 * nCulm + 3] = -40.914338;
      val[87 * nCulm + 4] = -10.518541;
      val[87 * nCulm + 5] = 34.171290;
      val[88 * nCulm + 0] = 3.129790;
      val[88 * nCulm + 1] = -47.555798;
      val[88 * nCulm + 2] = -35.853946;
      val[88 * nCulm + 3] = 4.236100;
      val[88 * nCulm + 4] = 0.605950;
      val[88 * nCulm + 5] = -338.158464;
      val[89 * nCulm + 0] = -34.028876;
      val[89 * nCulm + 1] = -11.640962;
      val[89 * nCulm + 2] = 4.522454;
      val[89 * nCulm + 3] = 20.139186;
      val[89 * nCulm + 4] = -24.385317;
      val[89 * nCulm + 5] = -1.419555;
      val[90 * nCulm + 0] = -13.665711;
      val[90 * nCulm + 1] = -11.400059;
      val[90 * nCulm + 2] = 11.406201;
      val[90 * nCulm + 3] = -17.841880;
      val[90 * nCulm + 4] = 32.254835;
      val[90 * nCulm + 5] = -4.061197;
      val[91 * nCulm + 0] = 32.741459;
      val[91 * nCulm + 1] = -49.357318;
      val[91 * nCulm + 2] = 46.805177;
      val[91 * nCulm + 3] = 45.501080;
      val[91 * nCulm + 4] = 38.695724;
      val[91 * nCulm + 5] = -0.241702;
      val[92 * nCulm + 0] = -42.293576;
      val[92 * nCulm + 1] = 6.884586;
      val[92 * nCulm + 2] = 34.026221;
      val[92 * nCulm + 3] = -48.975078;
      val[92 * nCulm + 4] = 15.655857;
      val[92 * nCulm + 5] = -12.495482;
      val[93 * nCulm + 0] = 7.435389;
      val[93 * nCulm + 1] = 30.672450;
      val[93 * nCulm + 2] = -44.811398;
      val[93 * nCulm + 3] = 0.963430;
      val[93 * nCulm + 4] = -7.195041;
      val[93 * nCulm + 5] = -20.581995;
      val[94 * nCulm + 0] = 31.064021;
      val[94 * nCulm + 1] = 2.687043;
      val[94 * nCulm + 2] = 3.715509;
      val[94 * nCulm + 3] = -9.436163;
      val[94 * nCulm + 4] = -10.888385;
      val[94 * nCulm + 5] = 3.163937;
      val[95 * nCulm + 0] = -21.082316;
      val[95 * nCulm + 1] = -42.128078;
      val[95 * nCulm + 2] = 37.898867;
      val[95 * nCulm + 3] = -4.682767;
      val[95 * nCulm + 4] = -19.657958;
      val[95 * nCulm + 5] = 11.501330;
      val[96 * nCulm + 0] = -24.957593;
      val[96 * nCulm + 1] = -23.718414;
      val[96 * nCulm + 2] = 19.882175;
      val[96 * nCulm + 3] = 7.690245;
      val[96 * nCulm + 4] = 13.860430;
      val[96 * nCulm + 5] = -5.243616;
      val[97 * nCulm + 0] = -6.439776;
      val[97 * nCulm + 1] = -49.183332;
      val[97 * nCulm + 2] = -12.805784;
      val[97 * nCulm + 3] = 6.406326;
      val[97 * nCulm + 4] = -12.514083;
      val[97 * nCulm + 5] = 16.409998;
      val[98 * nCulm + 0] = 2.480177;
      val[98 * nCulm + 1] = 39.635811;
      val[98 * nCulm + 2] = -35.724279;
      val[98 * nCulm + 3] = -31.339854;
      val[98 * nCulm + 4] = -47.634832;
      val[98 * nCulm + 5] = -0.594345;
      val[99 * nCulm + 0] = 1.398948;
      val[99 * nCulm + 1] = -15.005140;
      val[99 * nCulm + 2] = -6.818858;
      val[99 * nCulm + 3] = -30.931452;
      val[99 * nCulm + 4] = -39.045508;
      val[99 * nCulm + 5] = 5.798712;
      val[100 * nCulm + 0] = 43.550074;
      val[100 * nCulm + 1] = 33.092609;
      val[100 * nCulm + 2] = -28.262749;
      val[100 * nCulm + 3] = -35.081116;
      val[100 * nCulm + 4] = 43.610330;
      val[100 * nCulm + 5] = 0.014173;
      val[101 * nCulm + 0] = 30.547786;
      val[101 * nCulm + 1] = 23.418513;
      val[101 * nCulm + 2] = -1.609904;
      val[101 * nCulm + 3] = -30.399608;
      val[101 * nCulm + 4] = -4.563246;
      val[101 * nCulm + 5] = 7.471303;
      val[102 * nCulm + 0] = -9.181064;
      val[102 * nCulm + 1] = 13.634785;
      val[102 * nCulm + 2] = -41.395662;
      val[102 * nCulm + 3] = -33.930746;
      val[102 * nCulm + 4] = -41.451675;
      val[102 * nCulm + 5] = 2.547579;
      val[103 * nCulm + 0] = 19.366580;
      val[103 * nCulm + 1] = -30.106892;
      val[103 * nCulm + 2] = 7.106395;
      val[103 * nCulm + 3] = -0.190433;
      val[103 * nCulm + 4] = 24.366839;
      val[103 * nCulm + 5] = -5.655348;
      val[104 * nCulm + 0] = 36.461059;
      val[104 * nCulm + 1] = 21.204388;
      val[104 * nCulm + 2] = -24.830439;
      val[104 * nCulm + 3] = -44.877366;
      val[104 * nCulm + 4] = 25.786800;
      val[104 * nCulm + 5] = -4.115328;
      val[105 * nCulm + 0] = -5.900049;
      val[105 * nCulm + 1] = -48.969820;
      val[105 * nCulm + 2] = -2.660046;
      val[105 * nCulm + 3] = 2.305450;
      val[105 * nCulm + 4] = 13.708213;
      val[105 * nCulm + 5] = -15.882824;
      val[106 * nCulm + 0] = -18.923890;
      val[106 * nCulm + 1] = 0.824398;
      val[106 * nCulm + 2] = -36.828456;
      val[106 * nCulm + 3] = 31.408096;
      val[106 * nCulm + 4] = -5.349304;
      val[106 * nCulm + 5] = -28.290932;
      val[107 * nCulm + 0] = -27.776742;
      val[107 * nCulm + 1] = 28.016213;
      val[107 * nCulm + 2] = 24.618123;
      val[107 * nCulm + 3] = -35.708760;
      val[107 * nCulm + 4] = -13.669891;
      val[107 * nCulm + 5] = 2.893619;
      val[108 * nCulm + 0] = 13.101249;
      val[108 * nCulm + 1] = -18.890416;
      val[108 * nCulm + 2] = -16.174317;
      val[108 * nCulm + 3] = -32.882701;
      val[108 * nCulm + 4] = -2.657869;
      val[108 * nCulm + 5] = 92.431467;
      val[109 * nCulm + 0] = -44.221338;
      val[109 * nCulm + 1] = -9.981088;
      val[109 * nCulm + 2] = 47.789894;
      val[109 * nCulm + 3] = 4.153571;
      val[109 * nCulm + 4] = -20.193740;
      val[109 * nCulm + 5] = 1.595947;
      val[110 * nCulm + 0] = -30.839975;
      val[110 * nCulm + 1] = 28.530758;
      val[110 * nCulm + 2] = 4.848159;
      val[110 * nCulm + 3] = 33.434213;
      val[110 * nCulm + 4] = 12.094500;
      val[110 * nCulm + 5] = 24.480763;
      val[111 * nCulm + 0] = 49.884458;
      val[111 * nCulm + 1] = 48.593309;
      val[111 * nCulm + 2] = -29.275654;
      val[111 * nCulm + 3] = 18.363806;
      val[111 * nCulm + 4] = -6.305884;
      val[111 * nCulm + 5] = -50.029466;
      val[112 * nCulm + 0] = -44.117652;
      val[112 * nCulm + 1] = -49.741851;
      val[112 * nCulm + 2] = 14.411291;
      val[112 * nCulm + 3] = 47.744249;
      val[112 * nCulm + 4] = 13.014156;
      val[112 * nCulm + 5] = -0.496541;
      val[113 * nCulm + 0] = 21.132357;
      val[113 * nCulm + 1] = 37.459431;
      val[113 * nCulm + 2] = -1.285848;
      val[113 * nCulm + 3] = -18.435056;
      val[113 * nCulm + 4] = 41.423187;
      val[113 * nCulm + 5] = 2.403872;
      val[114 * nCulm + 0] = -0.882001;
      val[114 * nCulm + 1] = 43.726166;
      val[114 * nCulm + 2] = 25.322809;
      val[114 * nCulm + 3] = 38.829921;
      val[114 * nCulm + 4] = -34.379555;
      val[114 * nCulm + 5] = -11.136217;
      val[115 * nCulm + 0] = 17.404120;
      val[115 * nCulm + 1] = -30.965013;
      val[115 * nCulm + 2] = 13.402123;
      val[115 * nCulm + 3] = -36.131357;
      val[115 * nCulm + 4] = -4.141418;
      val[115 * nCulm + 5] = 76.916178;
      val[116 * nCulm + 0] = -36.816032;
      val[116 * nCulm + 1] = 26.643700;
      val[116 * nCulm + 2] = 15.478956;
      val[116 * nCulm + 3] = -16.514253;
      val[116 * nCulm + 4] = -40.706414;
      val[116 * nCulm + 5] = -0.947850;
      val[117 * nCulm + 0] = -38.240012;
      val[117 * nCulm + 1] = 21.963062;
      val[117 * nCulm + 2] = 21.670177;
      val[117 * nCulm + 3] = 20.936598;
      val[117 * nCulm + 4] = 14.828873;
      val[117 * nCulm + 5] = 13.923447;
      val[118 * nCulm + 0] = 44.584508;
      val[118 * nCulm + 1] = 22.012247;
      val[118 * nCulm + 2] = 26.145569;
      val[118 * nCulm + 3] = 19.728123;
      val[118 * nCulm + 4] = -26.023627;
      val[118 * nCulm + 5] = -7.361989;
      val[119 * nCulm + 0] = -30.794624;
      val[119 * nCulm + 1] = -41.564487;
      val[119 * nCulm + 2] = -34.905154;
      val[119 * nCulm + 3] = -6.105418;
      val[119 * nCulm + 4] = 31.126793;
      val[119 * nCulm + 5] = -7.018981;
      val[120 * nCulm + 0] = -2.102463;
      val[120 * nCulm + 1] = 21.254787;
      val[120 * nCulm + 2] = 32.737852;
      val[120 * nCulm + 3] = 45.692753;
      val[120 * nCulm + 4] = -4.568577;
      val[120 * nCulm + 5] = -69.131868;
      val[121 * nCulm + 0] = -34.871646;
      val[121 * nCulm + 1] = 20.515308;
      val[121 * nCulm + 2] = -29.440257;
      val[121 * nCulm + 3] = 35.195008;
      val[121 * nCulm + 4] = 26.322363;
      val[121 * nCulm + 5] = 10.247926;
      val[122 * nCulm + 0] = -3.628587;
      val[122 * nCulm + 1] = -23.467687;
      val[122 * nCulm + 2] = -21.574275;
      val[122 * nCulm + 3] = 31.974390;
      val[122 * nCulm + 4] = 20.947985;
      val[122 * nCulm + 5] = 2.152145;
      val[123 * nCulm + 0] = -14.911893;
      val[123 * nCulm + 1] = 47.872004;
      val[123 * nCulm + 2] = 4.949202;
      val[123 * nCulm + 3] = 11.737480;
      val[123 * nCulm + 4] = -2.761668;
      val[123 * nCulm + 5] = -101.937096;
      val[124 * nCulm + 0] = -9.502522;
      val[124 * nCulm + 1] = -15.651980;
      val[124 * nCulm + 2] = 5.514257;
      val[124 * nCulm + 3] = -8.997872;
      val[124 * nCulm + 4] = -30.041068;
      val[124 * nCulm + 5] = 4.113882;
      val[125 * nCulm + 0] = 25.380335;
      val[125 * nCulm + 1] = 31.587509;
      val[125 * nCulm + 2] = 23.326507;
      val[125 * nCulm + 3] = -15.534498;
      val[125 * nCulm + 4] = -8.131066;
      val[125 * nCulm + 5] = -9.114931;
      val[126 * nCulm + 0] = -37.652538;
      val[126 * nCulm + 1] = -32.170090;
      val[126 * nCulm + 2] = -6.131287;
      val[126 * nCulm + 3] = 5.130782;
      val[126 * nCulm + 4] = 14.774754;
      val[126 * nCulm + 5] = -8.432483;
      val[127 * nCulm + 0] = -43.096617;
      val[127 * nCulm + 1] = -49.414742;
      val[127 * nCulm + 2] = 39.835500;
      val[127 * nCulm + 3] = -25.984746;
      val[127 * nCulm + 4] = 42.101157;
      val[127 * nCulm + 5] = -8.246986;
      val[128 * nCulm + 0] = -0.611531;
      val[128 * nCulm + 1] = -12.142211;
      val[128 * nCulm + 2] = -46.830207;
      val[128 * nCulm + 3] = 38.846153;
      val[128 * nCulm + 4] = -48.396052;
      val[128 * nCulm + 5] = -2.381756;
      val[129 * nCulm + 0] = 3.071373;
      val[129 * nCulm + 1] = -41.674637;
      val[129 * nCulm + 2] = -26.167887;
      val[129 * nCulm + 3] = 4.972088;
      val[129 * nCulm + 4] = 2.350694;
      val[129 * nCulm + 5] = -73.673888;
      val[130 * nCulm + 0] = -6.993953;
      val[130 * nCulm + 1] = -47.092616;
      val[130 * nCulm + 2] = -9.490670;
      val[130 * nCulm + 3] = -34.646157;
      val[130 * nCulm + 4] = -9.719257;
      val[130 * nCulm + 5] = 40.037247;
      val[131 * nCulm + 0] = 39.424480;
      val[131 * nCulm + 1] = -4.994261;
      val[131 * nCulm + 2] = -31.253109;
      val[131 * nCulm + 3] = -18.735930;
      val[131 * nCulm + 4] = -14.341305;
      val[131 * nCulm + 5] = 8.062126;
      val[132 * nCulm + 0] = 25.019085;
      val[132 * nCulm + 1] = -36.087492;
      val[132 * nCulm + 2] = 5.024567;
      val[132 * nCulm + 3] = 29.011883;
      val[132 * nCulm + 4] = -38.376901;
      val[132 * nCulm + 5] = 1.102692;
      val[133 * nCulm + 0] = 38.553376;
      val[133 * nCulm + 1] = -45.840815;
      val[133 * nCulm + 2] = 16.503604;
      val[133 * nCulm + 3] = -32.790838;
      val[133 * nCulm + 4] = 15.729653;
      val[133 * nCulm + 5] = -23.431668;
      val[134 * nCulm + 0] = -23.091254;
      val[134 * nCulm + 1] = -48.521290;
      val[134 * nCulm + 2] = -48.968690;
      val[134 * nCulm + 3] = 45.788765;
      val[134 * nCulm + 4] = -5.450778;
      val[134 * nCulm + 5] = 2.602863;
      val[135 * nCulm + 0] = -5.848259;
      val[135 * nCulm + 1] = 30.073850;
      val[135 * nCulm + 2] = 4.554760;
      val[135 * nCulm + 3] = -22.581901;
      val[135 * nCulm + 4] = -8.256578;
      val[135 * nCulm + 5] = -4.064986;
      val[136 * nCulm + 0] = -31.006468;
      val[136 * nCulm + 1] = 28.117267;
      val[136 * nCulm + 2] = -0.286420;
      val[136 * nCulm + 3] = -41.357586;
      val[136 * nCulm + 4] = 45.714213;
      val[136 * nCulm + 5] = -1.140927;
      val[137 * nCulm + 0] = -16.655982;
      val[137 * nCulm + 1] = 36.179863;
      val[137 * nCulm + 2] = -40.347313;
      val[137 * nCulm + 3] = -39.897071;
      val[137 * nCulm + 4] = 16.356239;
      val[137 * nCulm + 5] = -0.845723;
      val[138 * nCulm + 0] = 1.260278;
      val[138 * nCulm + 1] = 43.384909;
      val[138 * nCulm + 2] = 28.853535;
      val[138 * nCulm + 3] = 1.822572;
      val[138 * nCulm + 4] = 17.047024;
      val[138 * nCulm + 5] = 12.782459;
      val[139 * nCulm + 0] = -46.135585;
      val[139 * nCulm + 1] = -33.940578;
      val[139 * nCulm + 2] = -42.054018;
      val[139 * nCulm + 3] = 29.376585;
      val[139 * nCulm + 4] = -42.201320;
      val[139 * nCulm + 5] = 0.741901;
      val[140 * nCulm + 0] = -23.434763;
      val[140 * nCulm + 1] = 3.134125;
      val[140 * nCulm + 2] = 17.448455;
      val[140 * nCulm + 3] = -4.449407;
      val[140 * nCulm + 4] = -43.936540;
      val[140 * nCulm + 5] = 0.371697;
      val[141 * nCulm + 0] = 48.618659;
      val[141 * nCulm + 1] = -41.163868;
      val[141 * nCulm + 2] = 11.199225;
      val[141 * nCulm + 3] = 36.382946;
      val[141 * nCulm + 4] = 4.365240;
      val[141 * nCulm + 5] = -4.954067;
      val[142 * nCulm + 0] = -15.945478;
      val[142 * nCulm + 1] = 33.101308;
      val[142 * nCulm + 2] = 48.420155;
      val[142 * nCulm + 3] = -21.363580;
      val[142 * nCulm + 4] = -35.866936;
      val[142 * nCulm + 5] = -1.319019;
      val[143 * nCulm + 0] = 37.412265;
      val[143 * nCulm + 1] = 48.523273;
      val[143 * nCulm + 2] = 32.247621;
      val[143 * nCulm + 3] = 34.679138;
      val[143 * nCulm + 4] = -41.482858;
      val[143 * nCulm + 5] = -9.263674;
      val[144 * nCulm + 0] = -27.894960;
      val[144 * nCulm + 1] = -3.364058;
      val[144 * nCulm + 2] = -15.230366;
      val[144 * nCulm + 3] = -47.560113;
      val[144 * nCulm + 4] = 16.737958;
      val[144 * nCulm + 5] = -14.170865;
      val[145 * nCulm + 0] = 23.668927;
      val[145 * nCulm + 1] = 28.865987;
      val[145 * nCulm + 2] = 4.308100;
      val[145 * nCulm + 3] = 34.143985;
      val[145 * nCulm + 4] = -10.150779;
      val[145 * nCulm + 5] = -29.151705;
      val[146 * nCulm + 0] = -15.512597;
      val[146 * nCulm + 1] = -15.988540;
      val[146 * nCulm + 2] = 17.505765;
      val[146 * nCulm + 3] = 20.069254;
      val[146 * nCulm + 4] = -8.250706;
      val[146 * nCulm + 5] = -2.111058;
      val[147 * nCulm + 0] = 45.687341;
      val[147 * nCulm + 1] = -18.938904;
      val[147 * nCulm + 2] = -48.070824;
      val[147 * nCulm + 3] = 24.741702;
      val[147 * nCulm + 4] = -17.903354;
      val[147 * nCulm + 5] = -1.304158;
      val[148 * nCulm + 0] = -44.869441;
      val[148 * nCulm + 1] = 11.773720;
      val[148 * nCulm + 2] = -28.495845;
      val[148 * nCulm + 3] = -37.334651;
      val[148 * nCulm + 4] = -46.906245;
      val[148 * nCulm + 5] = 2.809367;
      val[149 * nCulm + 0] = -46.900402;
      val[149 * nCulm + 1] = 29.198138;
      val[149 * nCulm + 2] = -47.193063;
      val[149 * nCulm + 3] = -19.219267;
      val[149 * nCulm + 4] = -3.432453;
      val[149 * nCulm + 5] = -13.530805;
      val[150 * nCulm + 0] = 13.989772;
      val[150 * nCulm + 1] = 48.221195;
      val[150 * nCulm + 2] = -41.535637;
      val[150 * nCulm + 3] = -45.326655;
      val[150 * nCulm + 4] = 27.755023;
      val[150 * nCulm + 5] = 0.723634;
      val[151 * nCulm + 0] = -9.629799;
      val[151 * nCulm + 1] = -38.053209;
      val[151 * nCulm + 2] = -14.789716;
      val[151 * nCulm + 3] = 24.923062;
      val[151 * nCulm + 4] = -13.451829;
      val[151 * nCulm + 5] = 4.850142;
      val[152 * nCulm + 0] = 5.279669;
      val[152 * nCulm + 1] = -28.209321;
      val[152 * nCulm + 2] = -25.311902;
      val[152 * nCulm + 3] = 1.021831;
      val[152 * nCulm + 4] = 17.786724;
      val[152 * nCulm + 5] = -7.005028;
      val[153 * nCulm + 0] = -32.371438;
      val[153 * nCulm + 1] = 25.303067;
      val[153 * nCulm + 2] = 13.991072;
      val[153 * nCulm + 3] = -42.339760;
      val[153 * nCulm + 4] = 47.126497;
      val[153 * nCulm + 5] = -1.481147;
      val[154 * nCulm + 0] = -9.718846;
      val[154 * nCulm + 1] = -41.660814;
      val[154 * nCulm + 2] = 35.978853;
      val[154 * nCulm + 3] = 31.229102;
      val[154 * nCulm + 4] = -24.557570;
      val[154 * nCulm + 5] = 2.240654;
      val[155 * nCulm + 0] = -29.288371;
      val[155 * nCulm + 1] = 39.004733;
      val[155 * nCulm + 2] = 38.089737;
      val[155 * nCulm + 3] = 32.398365;
      val[155 * nCulm + 4] = -35.741109;
      val[155 * nCulm + 5] = -9.226189;
      val[156 * nCulm + 0] = -14.024048;
      val[156 * nCulm + 1] = -14.428512;
      val[156 * nCulm + 2] = 22.219510;
      val[156 * nCulm + 3] = 7.063608;
      val[156 * nCulm + 4] = 19.127931;
      val[156 * nCulm + 5] = -1.592494;
      val[157 * nCulm + 0] = -0.842393;
      val[157 * nCulm + 1] = -4.877269;
      val[157 * nCulm + 2] = 29.046473;
      val[157 * nCulm + 3] = -6.687082;
      val[157 * nCulm + 4] = 7.567007;
      val[157 * nCulm + 5] = -7.003762;
      val[158 * nCulm + 0] = 15.667673;
      val[158 * nCulm + 1] = 25.737861;
      val[158 * nCulm + 2] = 25.141237;
      val[158 * nCulm + 3] = -28.385593;
      val[158 * nCulm + 4] = 21.935135;
      val[158 * nCulm + 5] = -0.341348;
      val[159 * nCulm + 0] = 35.539184;
      val[159 * nCulm + 1] = 4.760232;
      val[159 * nCulm + 2] = 31.143043;
      val[159 * nCulm + 3] = -22.904169;
      val[159 * nCulm + 4] = 3.476748;
      val[159 * nCulm + 5] = -24.471616;
      val[160 * nCulm + 0] = -11.550112;
      val[160 * nCulm + 1] = -20.203455;
      val[160 * nCulm + 2] = 13.559179;
      val[160 * nCulm + 3] = -26.706641;
      val[160 * nCulm + 4] = 46.200103;
      val[160 * nCulm + 5] = -4.576074;
      val[161 * nCulm + 0] = 20.500718;
      val[161 * nCulm + 1] = -45.889666;
      val[161 * nCulm + 2] = 27.169604;
      val[161 * nCulm + 3] = 34.501727;
      val[161 * nCulm + 4] = -26.258506;
      val[161 * nCulm + 5] = 2.282779;
      val[162 * nCulm + 0] = -28.997610;
      val[162 * nCulm + 1] = -16.879906;
      val[162 * nCulm + 2] = -40.709283;
      val[162 * nCulm + 3] = 1.457602;
      val[162 * nCulm + 4] = 5.375165;
      val[162 * nCulm + 5] = -13.350774;
      val[163 * nCulm + 0] = 16.169828;
      val[163 * nCulm + 1] = -16.304500;
      val[163 * nCulm + 2] = 25.895408;
      val[163 * nCulm + 3] = 48.152661;
      val[163 * nCulm + 4] = 17.402073;
      val[163 * nCulm + 5] = 8.892644;
      val[164 * nCulm + 0] = -1.374745;
      val[164 * nCulm + 1] = -39.125799;
      val[164 * nCulm + 2] = -46.506124;
      val[164 * nCulm + 3] = 28.928484;
      val[164 * nCulm + 4] = 14.480216;
      val[164 * nCulm + 5] = -3.103327;
      val[165 * nCulm + 0] = -31.038563;
      val[165 * nCulm + 1] = 19.521662;
      val[165 * nCulm + 2] = -17.799239;
      val[165 * nCulm + 3] = 38.633773;
      val[165 * nCulm + 4] = 31.729334;
      val[165 * nCulm + 5] = 8.905539;
      val[166 * nCulm + 0] = -49.071893;
      val[166 * nCulm + 1] = -22.678060;
      val[166 * nCulm + 2] = -15.529151;
      val[166 * nCulm + 3] = 25.646927;
      val[166 * nCulm + 4] = 49.686322;
      val[166 * nCulm + 5] = 0.512827;
      val[167 * nCulm + 0] = -16.338600;
      val[167 * nCulm + 1] = 33.206569;
      val[167 * nCulm + 2] = 24.789427;
      val[167 * nCulm + 3] = -32.438795;
      val[167 * nCulm + 4] = 31.931362;
      val[167 * nCulm + 5] = 0.343811;
      val[168 * nCulm + 0] = 21.691318;
      val[168 * nCulm + 1] = -30.389387;
      val[168 * nCulm + 2] = 35.414630;
      val[168 * nCulm + 3] = 6.447783;
      val[168 * nCulm + 4] = 39.930003;
      val[168 * nCulm + 5] = -2.608056;
      val[169 * nCulm + 0] = -45.157293;
      val[169 * nCulm + 1] = -40.719644;
      val[169 * nCulm + 2] = -35.685371;
      val[169 * nCulm + 3] = 38.386706;
      val[169 * nCulm + 4] = -5.742416;
      val[169 * nCulm + 5] = 2.152984;
      val[170 * nCulm + 0] = 34.729677;
      val[170 * nCulm + 1] = -43.783916;
      val[170 * nCulm + 2] = -31.406706;
      val[170 * nCulm + 3] = 22.318330;
      val[170 * nCulm + 4] = 30.878071;
      val[170 * nCulm + 5] = -3.060483;
      val[171 * nCulm + 0] = 16.239294;
      val[171 * nCulm + 1] = 36.240438;
      val[171 * nCulm + 2] = -47.082238;
      val[171 * nCulm + 3] = -35.408836;
      val[171 * nCulm + 4] = -38.197466;
      val[171 * nCulm + 5] = 0.126950;
      val[172 * nCulm + 0] = 7.479325;
      val[172 * nCulm + 1] = -3.691349;
      val[172 * nCulm + 2] = 9.658200;
      val[172 * nCulm + 3] = -41.314286;
      val[172 * nCulm + 4] = 27.618829;
      val[172 * nCulm + 5] = -7.483096;
      val[173 * nCulm + 0] = 9.986665;
      val[173 * nCulm + 1] = 27.813943;
      val[173 * nCulm + 2] = 20.799102;
      val[173 * nCulm + 3] = -45.640156;
      val[173 * nCulm + 4] = 13.123725;
      val[173 * nCulm + 5] = -6.199379;
      val[174 * nCulm + 0] = -23.233393;
      val[174 * nCulm + 1] = -2.878587;
      val[174 * nCulm + 2] = -26.590913;
      val[174 * nCulm + 3] = -45.662378;
      val[174 * nCulm + 4] = -28.394530;
      val[174 * nCulm + 5] = 8.321719;
      val[175 * nCulm + 0] = -40.444116;
      val[175 * nCulm + 1] = -9.553089;
      val[175 * nCulm + 2] = -40.874071;
      val[175 * nCulm + 3] = -18.378917;
      val[175 * nCulm + 4] = 19.419976;
      val[175 * nCulm + 5] = -6.578015;
      val[176 * nCulm + 0] = -34.815767;
      val[176 * nCulm + 1] = -46.023439;
      val[176 * nCulm + 2] = -48.127445;
      val[176 * nCulm + 3] = 39.076861;
      val[176 * nCulm + 4] = 5.046006;
      val[176 * nCulm + 5] = -6.286137;
      val[177 * nCulm + 0] = 24.294525;
      val[177 * nCulm + 1] = -47.813894;
      val[177 * nCulm + 2] = -38.656220;
      val[177 * nCulm + 3] = 42.237391;
      val[177 * nCulm + 4] = -12.966308;
      val[177 * nCulm + 5] = 2.265695;
      val[178 * nCulm + 0] = -30.943927;
      val[178 * nCulm + 1] = -44.323706;
      val[178 * nCulm + 2] = -31.908126;
      val[178 * nCulm + 3] = 19.081289;
      val[178 * nCulm + 4] = -28.017909;
      val[178 * nCulm + 5] = 4.494443;
      val[179 * nCulm + 0] = -49.956102;
      val[179 * nCulm + 1] = 40.486653;
      val[179 * nCulm + 2] = 42.180388;
      val[179 * nCulm + 3] = -31.521490;
      val[179 * nCulm + 4] = 17.964475;
      val[179 * nCulm + 5] = 2.592168;
      val[180 * nCulm + 0] = -27.275347;
      val[180 * nCulm + 1] = -13.081401;
      val[180 * nCulm + 2] = -49.182118;
      val[180 * nCulm + 3] = 17.094685;
      val[180 * nCulm + 4] = -9.098394;
      val[180 * nCulm + 5] = -1.857864;
      val[181 * nCulm + 0] = 38.052794;
      val[181 * nCulm + 1] = 42.051838;
      val[181 * nCulm + 2] = 12.038898;
      val[181 * nCulm + 3] = 1.817068;
      val[181 * nCulm + 4] = 29.404630;
      val[181 * nCulm + 5] = 7.291682;
      val[182 * nCulm + 0] = -49.806917;
      val[182 * nCulm + 1] = -16.870849;
      val[182 * nCulm + 2] = 16.354173;
      val[182 * nCulm + 3] = 24.651683;
      val[182 * nCulm + 4] = 31.320060;
      val[182 * nCulm + 5] = 1.405901;
      val[183 * nCulm + 0] = -19.997279;
      val[183 * nCulm + 1] = 43.123240;
      val[183 * nCulm + 2] = 48.990484;
      val[183 * nCulm + 3] = 29.673581;
      val[183 * nCulm + 4] = 20.889766;
      val[183 * nCulm + 5] = 16.724757;
      val[184 * nCulm + 0] = 16.768696;
      val[184 * nCulm + 1] = 41.208839;
      val[184 * nCulm + 2] = -21.426025;
      val[184 * nCulm + 3] = -32.066990;
      val[184 * nCulm + 4] = 18.134085;
      val[184 * nCulm + 5] = 2.616193;
      val[185 * nCulm + 0] = -8.179186;
      val[185 * nCulm + 1] = -19.690883;
      val[185 * nCulm + 2] = 49.757267;
      val[185 * nCulm + 3] = 25.092677;
      val[185 * nCulm + 4] = 34.139146;
      val[185 * nCulm + 5] = 0.978949;
      val[186 * nCulm + 0] = -2.908266;
      val[186 * nCulm + 1] = -45.683536;
      val[186 * nCulm + 2] = 32.171820;
      val[186 * nCulm + 3] = -44.285814;
      val[186 * nCulm + 4] = -48.842374;
      val[186 * nCulm + 5] = 8.948965;
      val[187 * nCulm + 0] = -28.500108;
      val[187 * nCulm + 1] = -6.622222;
      val[187 * nCulm + 2] = 8.395633;
      val[187 * nCulm + 3] = 46.176870;
      val[187 * nCulm + 4] = -41.355422;
      val[187 * nCulm + 5] = -4.297226;
      val[188 * nCulm + 0] = -31.094657;
      val[188 * nCulm + 1] = 2.240545;
      val[188 * nCulm + 2] = -44.204119;
      val[188 * nCulm + 3] = -43.472745;
      val[188 * nCulm + 4] = -22.419401;
      val[188 * nCulm + 5] = 8.935217;
      val[189 * nCulm + 0] = -37.712643;
      val[189 * nCulm + 1] = -31.554005;
      val[189 * nCulm + 2] = -4.901441;
      val[189 * nCulm + 3] = 24.515158;
      val[189 * nCulm + 4] = 24.980712;
      val[189 * nCulm + 5] = -1.103717;
      val[190 * nCulm + 0] = 32.086527;
      val[190 * nCulm + 1] = 22.513213;
      val[190 * nCulm + 2] = -41.673711;
      val[190 * nCulm + 3] = 23.579535;
      val[190 * nCulm + 4] = -21.898555;
      val[190 * nCulm + 5] = -9.732865;
      val[191 * nCulm + 0] = -9.290769;
      val[191 * nCulm + 1] = -45.170337;
      val[191 * nCulm + 2] = -45.146092;
      val[191 * nCulm + 3] = 38.789748;
      val[191 * nCulm + 4] = -20.458474;
      val[191 * nCulm + 5] = 1.706232;
      val[192 * nCulm + 0] = -14.222150;
      val[192 * nCulm + 1] = -12.206623;
      val[192 * nCulm + 2] = -17.763889;
      val[192 * nCulm + 3] = -6.180379;
      val[192 * nCulm + 4] = 0.674522;
      val[192 * nCulm + 5] = -128.797299;
      val[193 * nCulm + 0] = -47.566020;
      val[193 * nCulm + 1] = 47.928049;
      val[193 * nCulm + 2] = -9.414480;
      val[193 * nCulm + 3] = -47.267866;
      val[193 * nCulm + 4] = 46.385886;
      val[193 * nCulm + 5] = 0.297367;
      val[194 * nCulm + 0] = -13.947501;
      val[194 * nCulm + 1] = -14.509712;
      val[194 * nCulm + 2] = 31.356248;
      val[194 * nCulm + 3] = 11.109890;
      val[194 * nCulm + 4] = -47.289614;
      val[194 * nCulm + 5] = 0.570297;
      val[195 * nCulm + 0] = 38.751045;
      val[195 * nCulm + 1] = -29.349896;
      val[195 * nCulm + 2] = -14.978894;
      val[195 * nCulm + 3] = -39.349540;
      val[195 * nCulm + 4] = 24.552447;
      val[195 * nCulm + 5] = -13.014193;
      val[196 * nCulm + 0] = -3.007064;
      val[196 * nCulm + 1] = 3.291518;
      val[196 * nCulm + 2] = -37.880691;
      val[196 * nCulm + 3] = 9.969862;
      val[196 * nCulm + 4] = -3.783733;
      val[196 * nCulm + 5] = -16.359580;
      val[197 * nCulm + 0] = 18.728730;
      val[197 * nCulm + 1] = -24.774580;
      val[197 * nCulm + 2] = -10.924127;
      val[197 * nCulm + 3] = 11.582486;
      val[197 * nCulm + 4] = -15.870275;
      val[197 * nCulm + 5] = 4.164562;
      val[198 * nCulm + 0] = -5.920270;
      val[198 * nCulm + 1] = 0.992561;
      val[198 * nCulm + 2] = 6.686068;
      val[198 * nCulm + 3] = -11.149967;
      val[198 * nCulm + 4] = 10.843666;
      val[198 * nCulm + 5] = -4.203776;
      val[199 * nCulm + 0] = 27.086982;
      val[199 * nCulm + 1] = -15.017474;
      val[199 * nCulm + 2] = -43.078149;
      val[199 * nCulm + 3] = -28.044457;
      val[199 * nCulm + 4] = 15.714160;
      val[199 * nCulm + 5] = -12.740879;
      val[200 * nCulm + 0] = 12.447539;
      val[200 * nCulm + 1] = -20.564272;
      val[200 * nCulm + 2] = -47.851676;
      val[200 * nCulm + 3] = -31.682727;
      val[200 * nCulm + 4] = -45.093650;
      val[200 * nCulm + 5] = 5.714197;
      val[201 * nCulm + 0] = -0.839724;
      val[201 * nCulm + 1] = 38.463070;
      val[201 * nCulm + 2] = 46.068366;
      val[201 * nCulm + 3] = -27.652451;
      val[201 * nCulm + 4] = 33.191320;
      val[201 * nCulm + 5] = 1.771676;
      val[202 * nCulm + 0] = -28.911983;
      val[202 * nCulm + 1] = -2.285120;
      val[202 * nCulm + 2] = 7.638261;
      val[202 * nCulm + 3] = 15.105357;
      val[202 * nCulm + 4] = 1.516875;
      val[202 * nCulm + 5] = 40.234901;
      val[203 * nCulm + 0] = 29.796075;
      val[203 * nCulm + 1] = 13.743895;
      val[203 * nCulm + 2] = -46.530772;
      val[203 * nCulm + 3] = -44.616628;
      val[203 * nCulm + 4] = -0.141868;
      val[203 * nCulm + 5] = 1030.280535;
      val[204 * nCulm + 0] = -16.889078;
      val[204 * nCulm + 1] = 13.671181;
      val[204 * nCulm + 2] = 20.330303;
      val[204 * nCulm + 3] = -44.759454;
      val[204 * nCulm + 4] = -44.913151;
      val[204 * nCulm + 5] = 3.506349;
      val[205 * nCulm + 0] = -34.485197;
      val[205 * nCulm + 1] = -41.618641;
      val[205 * nCulm + 2] = -15.275459;
      val[205 * nCulm + 3] = 25.751367;
      val[205 * nCulm + 4] = 3.929892;
      val[205 * nCulm + 5] = -18.881235;
      val[206 * nCulm + 0] = 8.888629;
      val[206 * nCulm + 1] = 25.226704;
      val[206 * nCulm + 2] = -49.193068;
      val[206 * nCulm + 3] = -46.104888;
      val[206 * nCulm + 4] = 6.756430;
      val[206 * nCulm + 5] = -14.396571;
      val[207 * nCulm + 0] = -46.362268;
      val[207 * nCulm + 1] = -12.971501;
      val[207 * nCulm + 2] = -34.938176;
      val[207 * nCulm + 3] = -36.631014;
      val[207 * nCulm + 4] = 21.552086;
      val[207 * nCulm + 5] = -10.663852;
      val[208 * nCulm + 0] = 9.922507;
      val[208 * nCulm + 1] = -22.061613;
      val[208 * nCulm + 2] = -19.577368;
      val[208 * nCulm + 3] = 5.770240;
      val[208 * nCulm + 4] = 3.257661;
      val[208 * nCulm + 5] = -23.441122;
      val[209 * nCulm + 0] = 45.064516;
      val[209 * nCulm + 1] = -29.289439;
      val[209 * nCulm + 2] = 28.572220;
      val[209 * nCulm + 3] = -26.844169;
      val[209 * nCulm + 4] = -46.849213;
      val[209 * nCulm + 5] = 5.901367;
      val[210 * nCulm + 0] = -7.674163;
      val[210 * nCulm + 1] = -16.995684;
      val[210 * nCulm + 2] = -19.769985;
      val[210 * nCulm + 3] = 24.334989;
      val[210 * nCulm + 4] = 40.093941;
      val[210 * nCulm + 5] = 1.096450;
      val[211 * nCulm + 0] = -7.641304;
      val[211 * nCulm + 1] = 32.678291;
      val[211 * nCulm + 2] = -44.537780;
      val[211 * nCulm + 3] = 37.757548;
      val[211 * nCulm + 4] = -43.471068;
      val[211 * nCulm + 5] = -7.439384;
      val[212 * nCulm + 0] = -38.795407;
      val[212 * nCulm + 1] = -24.432247;
      val[212 * nCulm + 2] = -9.691534;
      val[212 * nCulm + 3] = 16.310355;
      val[212 * nCulm + 4] = 22.543038;
      val[212 * nCulm + 5] = -1.475343;
      val[213 * nCulm + 0] = 20.642318;
      val[213 * nCulm + 1] = -39.689869;
      val[213 * nCulm + 2] = 29.641559;
      val[213 * nCulm + 3] = -7.576230;
      val[213 * nCulm + 4] = -11.213547;
      val[213 * nCulm + 5] = 20.181421;
      val[214 * nCulm + 0] = 32.167965;
      val[214 * nCulm + 1] = 42.751688;
      val[214 * nCulm + 2] = -39.087863;
      val[214 * nCulm + 3] = -30.877662;
      val[214 * nCulm + 4] = -15.014854;
      val[214 * nCulm + 5] = -3.513208;
      val[215 * nCulm + 0] = -35.477391;
      val[215 * nCulm + 1] = 16.098318;
      val[215 * nCulm + 2] = 27.264124;
      val[215 * nCulm + 3] = -26.812239;
      val[215 * nCulm + 4] = 7.825843;
      val[215 * nCulm + 5] = -6.250140;
      val[216 * nCulm + 0] = -32.266559;
      val[216 * nCulm + 1] = -26.386659;
      val[216 * nCulm + 2] = 2.659178;
      val[216 * nCulm + 3] = -21.125687;
      val[216 * nCulm + 4] = -28.981039;
      val[216 * nCulm + 5] = 7.989962;
      val[217 * nCulm + 0] = 4.607950;
      val[217 * nCulm + 1] = 31.799644;
      val[217 * nCulm + 2] = 30.417573;
      val[217 * nCulm + 3] = 42.451414;
      val[217 * nCulm + 4] = -46.422325;
      val[217 * nCulm + 5] = -7.340819;
      val[218 * nCulm + 0] = -16.414346;
      val[218 * nCulm + 1] = 12.013091;
      val[218 * nCulm + 2] = -39.037704;
      val[218 * nCulm + 3] = -0.558077;
      val[218 * nCulm + 4] = -1.931583;
      val[218 * nCulm + 5] = -27.840441;
      val[219 * nCulm + 0] = 9.900201;
      val[219 * nCulm + 1] = -33.585599;
      val[219 * nCulm + 2] = -33.039607;
      val[219 * nCulm + 3] = -41.402752;
      val[219 * nCulm + 4] = 33.797383;
      val[219 * nCulm + 5] = -10.272140;
      val[220 * nCulm + 0] = 0.860906;
      val[220 * nCulm + 1] = 40.998941;
      val[220 * nCulm + 2] = -16.871718;
      val[220 * nCulm + 3] = -14.077032;
      val[220 * nCulm + 4] = 20.503082;
      val[220 * nCulm + 5] = 6.445181;
      val[221 * nCulm + 0] = 3.539397;
      val[221 * nCulm + 1] = 36.601419;
      val[221 * nCulm + 2] = 43.236396;
      val[221 * nCulm + 3] = -33.245991;
      val[221 * nCulm + 4] = -45.056181;
      val[221 * nCulm + 5] = -0.122501;
      val[222 * nCulm + 0] = 39.708311;
      val[222 * nCulm + 1] = -38.828464;
      val[222 * nCulm + 2] = 12.479149;
      val[222 * nCulm + 3] = -4.890169;
      val[222 * nCulm + 4] = 18.000710;
      val[222 * nCulm + 5] = -11.265928;
      val[223 * nCulm + 0] = -44.984978;
      val[223 * nCulm + 1] = -48.115463;
      val[223 * nCulm + 2] = -19.251061;
      val[223 * nCulm + 3] = 18.477493;
      val[223 * nCulm + 4] = -32.115306;
      val[223 * nCulm + 5] = 4.598210;
      val[224 * nCulm + 0] = -19.616117;
      val[224 * nCulm + 1] = 46.935031;
      val[224 * nCulm + 2] = -36.375836;
      val[224 * nCulm + 3] = -45.377215;
      val[224 * nCulm + 4] = 13.322479;
      val[224 * nCulm + 5] = 0.783475;
      val[225 * nCulm + 0] = 18.402860;
      val[225 * nCulm + 1] = -3.314831;
      val[225 * nCulm + 2] = 17.339130;
      val[225 * nCulm + 3] = -12.556318;
      val[225 * nCulm + 4] = -38.590001;
      val[225 * nCulm + 5] = 2.176707;
      val[226 * nCulm + 0] = -41.959604;
      val[226 * nCulm + 1] = 40.377964;
      val[226 * nCulm + 2] = 5.902485;
      val[226 * nCulm + 3] = 8.509506;
      val[226 * nCulm + 4] = 43.648605;
      val[226 * nCulm + 5] = 5.531445;
      val[227 * nCulm + 0] = -38.036350;
      val[227 * nCulm + 1] = 22.393926;
      val[227 * nCulm + 2] = -41.305061;
      val[227 * nCulm + 3] = -39.188937;
      val[227 * nCulm + 4] = 40.985487;
      val[227 * nCulm + 5] = -1.709623;
      val[228 * nCulm + 0] = 2.207198;
      val[228 * nCulm + 1] = -0.989460;
      val[228 * nCulm + 2] = 35.346984;
      val[228 * nCulm + 3] = -45.217180;
      val[228 * nCulm + 4] = -28.260464;
      val[228 * nCulm + 5] = 7.969131;
      val[229 * nCulm + 0] = -12.299673;
      val[229 * nCulm + 1] = -9.332269;
      val[229 * nCulm + 2] = 34.706720;
      val[229 * nCulm + 3] = -9.334532;
      val[229 * nCulm + 4] = 24.272594;
      val[229 * nCulm + 5] = -3.410163;
      val[230 * nCulm + 0] = -23.756771;
      val[230 * nCulm + 1] = 28.963214;
      val[230 * nCulm + 2] = 25.198638;
      val[230 * nCulm + 3] = 5.203145;
      val[230 * nCulm + 4] = -48.233545;
      val[230 * nCulm + 5] = -3.122869;
      val[231 * nCulm + 0] = 6.026126;
      val[231 * nCulm + 1] = -31.116879;
      val[231 * nCulm + 2] = 24.206032;
      val[231 * nCulm + 3] = 2.825283;
      val[231 * nCulm + 4] = 7.034265;
      val[231 * nCulm + 5] = -18.807319;
      val[232 * nCulm + 0] = 44.777993;
      val[232 * nCulm + 1] = 4.331892;
      val[232 * nCulm + 2] = -13.081849;
      val[232 * nCulm + 3] = -32.350618;
      val[232 * nCulm + 4] = -23.599361;
      val[232 * nCulm + 5] = 5.849727;
      val[233 * nCulm + 0] = 36.455680;
      val[233 * nCulm + 1] = -37.224595;
      val[233 * nCulm + 2] = -22.135561;
      val[233 * nCulm + 3] = -49.697953;
      val[233 * nCulm + 4] = 4.897944;
      val[233 * nCulm + 5] = -83.771246;
      val[234 * nCulm + 0] = 39.924636;
      val[234 * nCulm + 1] = 31.492666;
      val[234 * nCulm + 2] = -10.903168;
      val[234 * nCulm + 3] = -39.815916;
      val[234 * nCulm + 4] = 35.632750;
      val[234 * nCulm + 5] = -0.875632;
      val[235 * nCulm + 0] = -17.617174;
      val[235 * nCulm + 1] = 8.517872;
      val[235 * nCulm + 2] = 40.019605;
      val[235 * nCulm + 3] = 31.778960;
      val[235 * nCulm + 4] = 17.374647;
      val[235 * nCulm + 5] = 11.207969;
      val[236 * nCulm + 0] = 0.868819;
      val[236 * nCulm + 1] = 17.437513;
      val[236 * nCulm + 2] = -3.191250;
      val[236 * nCulm + 3] = -30.771930;
      val[236 * nCulm + 4] = 46.531275;
      val[236 * nCulm + 5] = -1.126426;
      val[237 * nCulm + 0] = 30.222816;
      val[237 * nCulm + 1] = -29.489734;
      val[237 * nCulm + 2] = 44.504028;
      val[237 * nCulm + 3] = -43.353579;
      val[237 * nCulm + 4] = 8.602195;
      val[237 * nCulm + 5] = -39.851825;
      val[238 * nCulm + 0] = -17.523769;
      val[238 * nCulm + 1] = 38.967166;
      val[238 * nCulm + 2] = 32.649754;
      val[238 * nCulm + 3] = -11.268243;
      val[238 * nCulm + 4] = 12.879016;
      val[238 * nCulm + 5] = 10.409989;
      val[239 * nCulm + 0] = 49.510573;
      val[239 * nCulm + 1] = 32.761884;
      val[239 * nCulm + 2] = 12.718593;
      val[239 * nCulm + 3] = -36.166939;
      val[239 * nCulm + 4] = -43.545313;
      val[239 * nCulm + 5] = 0.600126;
      val[240 * nCulm + 0] = 19.485389;
      val[240 * nCulm + 1] = 49.069051;
      val[240 * nCulm + 2] = -46.655478;
      val[240 * nCulm + 3] = 5.527247;
      val[240 * nCulm + 4] = -30.588690;
      val[240 * nCulm + 5] = -8.218301;
      val[241 * nCulm + 0] = -23.933598;
      val[241 * nCulm + 1] = 36.840979;
      val[241 * nCulm + 2] = -0.944837;
      val[241 * nCulm + 3] = 42.754680;
      val[241 * nCulm + 4] = -23.884370;
      val[241 * nCulm + 5] = -15.544031;
      val[242 * nCulm + 0] = 4.088387;
      val[242 * nCulm + 1] = -8.391707;
      val[242 * nCulm + 2] = -26.227068;
      val[242 * nCulm + 3] = 39.420651;
      val[242 * nCulm + 4] = 22.800288;
      val[242 * nCulm + 5] = 6.671600;
      val[243 * nCulm + 0] = 40.990888;
      val[243 * nCulm + 1] = 32.849618;
      val[243 * nCulm + 2] = 23.952013;
      val[243 * nCulm + 3] = -11.180330;
      val[243 * nCulm + 4] = -3.128280;
      val[243 * nCulm + 5] = -32.557333;
      val[244 * nCulm + 0] = -22.927051;
      val[244 * nCulm + 1] = -4.536857;
      val[244 * nCulm + 2] = -39.931181;
      val[244 * nCulm + 3] = 29.958531;
      val[244 * nCulm + 4] = -22.537585;
      val[244 * nCulm + 5] = -5.109048;
      val[245 * nCulm + 0] = 20.063770;
      val[245 * nCulm + 1] = -29.182132;
      val[245 * nCulm + 2] = 18.598923;
      val[245 * nCulm + 3] = 25.057252;
      val[245 * nCulm + 4] = 10.343920;
      val[245 * nCulm + 5] = -1.657528;
      val[246 * nCulm + 0] = -4.143965;
      val[246 * nCulm + 1] = -41.251320;
      val[246 * nCulm + 2] = -45.078139;
      val[246 * nCulm + 3] = -32.634641;
      val[246 * nCulm + 4] = -38.880116;
      val[246 * nCulm + 5] = 9.225006;
      val[247 * nCulm + 0] = 16.701613;
      val[247 * nCulm + 1] = 35.688556;
      val[247 * nCulm + 2] = 13.021984;
      val[247 * nCulm + 3] = -29.736110;
      val[247 * nCulm + 4] = -8.203237;
      val[247 * nCulm + 5] = -3.204609;
      val[248 * nCulm + 0] = 45.716302;
      val[248 * nCulm + 1] = 17.506888;
      val[248 * nCulm + 2] = -46.710731;
      val[248 * nCulm + 3] = -13.362243;
      val[248 * nCulm + 4] = -24.674212;
      val[248 * nCulm + 5] = -0.565081;
      val[249 * nCulm + 0] = -44.628499;
      val[249 * nCulm + 1] = 3.211047;
      val[249 * nCulm + 2] = 2.098856;
      val[249 * nCulm + 3] = -23.391167;
      val[249 * nCulm + 4] = -26.180102;
      val[249 * nCulm + 5] = 3.878543;
      val[250 * nCulm + 0] = -26.132741;
      val[250 * nCulm + 1] = -37.745592;
      val[250 * nCulm + 2] = -22.376180;
      val[250 * nCulm + 3] = 5.318299;
      val[250 * nCulm + 4] = 27.123631;
      val[250 * nCulm + 5] = -5.428873;
      val[251 * nCulm + 0] = 17.091398;
      val[251 * nCulm + 1] = -37.679444;
      val[251 * nCulm + 2] = 39.222314;
      val[251 * nCulm + 3] = 21.636114;
      val[251 * nCulm + 4] = 15.734750;
      val[251 * nCulm + 5] = -4.596161;
      val[252 * nCulm + 0] = 4.429716;
      val[252 * nCulm + 1] = -48.136771;
      val[252 * nCulm + 2] = -26.445795;
      val[252 * nCulm + 3] = 39.085469;
      val[252 * nCulm + 4] = 19.739452;
      val[252 * nCulm + 5] = -1.940416;
      val[253 * nCulm + 0] = 37.950138;
      val[253 * nCulm + 1] = 24.508727;
      val[253 * nCulm + 2] = -14.137249;
      val[253 * nCulm + 3] = 40.999491;
      val[253 * nCulm + 4] = 40.007093;
      val[253 * nCulm + 5] = 7.980432;
      val[254 * nCulm + 0] = 35.933734;
      val[254 * nCulm + 1] = -16.421357;
      val[254 * nCulm + 2] = 4.267536;
      val[254 * nCulm + 3] = 16.606724;
      val[254 * nCulm + 4] = 45.939332;
      val[254 * nCulm + 5] = 0.249099;
      val[255 * nCulm + 0] = -30.642514;
      val[255 * nCulm + 1] = 34.046926;
      val[255 * nCulm + 2] = -18.184904;
      val[255 * nCulm + 3] = 0.638986;
      val[255 * nCulm + 4] = 39.494380;
      val[255 * nCulm + 5] = 4.387047;
      val[256 * nCulm + 0] = 41.857131;
      val[256 * nCulm + 1] = 16.896772;
      val[256 * nCulm + 2] = -22.656939;
      val[256 * nCulm + 3] = -48.838134;
      val[256 * nCulm + 4] = -47.730361;
      val[256 * nCulm + 5] = 3.397567;
      val[257 * nCulm + 0] = 35.056359;
      val[257 * nCulm + 1] = -43.151221;
      val[257 * nCulm + 2] = 20.510408;
      val[257 * nCulm + 3] = 7.913342;
      val[257 * nCulm + 4] = -36.542526;
      val[257 * nCulm + 5] = 4.794343;
      val[258 * nCulm + 0] = -37.888358;
      val[258 * nCulm + 1] = -48.902415;
      val[258 * nCulm + 2] = 33.202150;
      val[258 * nCulm + 3] = -30.709216;
      val[258 * nCulm + 4] = 23.323868;
      val[258 * nCulm + 5] = -15.926342;
      val[259 * nCulm + 0] = 30.433232;
      val[259 * nCulm + 1] = 21.596785;
      val[259 * nCulm + 2] = 6.347126;
      val[259 * nCulm + 3] = -41.100288;
      val[259 * nCulm + 4] = 37.234895;
      val[259 * nCulm + 5] = -2.249303;
      val[260 * nCulm + 0] = 36.547112;
      val[260 * nCulm + 1] = -7.201609;
      val[260 * nCulm + 2] = 7.794308;
      val[260 * nCulm + 3] = 24.948051;
      val[260 * nCulm + 4] = 33.172685;
      val[260 * nCulm + 5] = 2.762199;
      val[261 * nCulm + 0] = 30.183518;
      val[261 * nCulm + 1] = -38.306208;
      val[261 * nCulm + 2] = 33.321667;
      val[261 * nCulm + 3] = 6.771856;
      val[261 * nCulm + 4] = -45.523046;
      val[261 * nCulm + 5] = 3.508836;
      val[262 * nCulm + 0] = 10.612417;
      val[262 * nCulm + 1] = -30.567554;
      val[262 * nCulm + 2] = 20.170745;
      val[262 * nCulm + 3] = 18.758639;
      val[262 * nCulm + 4] = 39.137612;
      val[262 * nCulm + 5] = -1.198179;
      val[263 * nCulm + 0] = -33.194422;
      val[263 * nCulm + 1] = -39.864520;
      val[263 * nCulm + 2] = 37.312183;
      val[263 * nCulm + 3] = 28.165824;
      val[263 * nCulm + 4] = -30.869284;
      val[263 * nCulm + 5] = 2.023816;
      val[264 * nCulm + 0] = -42.791360;
      val[264 * nCulm + 1] = -12.711105;
      val[264 * nCulm + 2] = 40.563052;
      val[264 * nCulm + 3] = -9.150890;
      val[264 * nCulm + 4] = -34.748064;
      val[264 * nCulm + 5] = 3.208011;
      val[265 * nCulm + 0] = -35.090848;
      val[265 * nCulm + 1] = 32.852131;
      val[265 * nCulm + 2] = -37.801019;
      val[265 * nCulm + 3] = 38.994638;
      val[265 * nCulm + 4] = -32.552075;
      val[265 * nCulm + 5] = -10.217098;
      val[266 * nCulm + 0] = -42.097893;
      val[266 * nCulm + 1] = 4.495506;
      val[266 * nCulm + 2] = 30.197858;
      val[266 * nCulm + 3] = 40.070580;
      val[266 * nCulm + 4] = 29.875853;
      val[266 * nCulm + 5] = 7.290757;
      val[267 * nCulm + 0] = -25.547549;
      val[267 * nCulm + 1] = -43.840424;
      val[267 * nCulm + 2] = -42.969559;
      val[267 * nCulm + 3] = -45.346222;
      val[267 * nCulm + 4] = 27.815896;
      val[267 * nCulm + 5] = -14.946578;
      val[268 * nCulm + 0] = -0.289187;
      val[268 * nCulm + 1] = 34.173065;
      val[268 * nCulm + 2] = -15.526205;
      val[268 * nCulm + 3] = -36.770939;
      val[268 * nCulm + 4] = 44.680864;
      val[268 * nCulm + 5] = -0.045210;
      val[269 * nCulm + 0] = 35.653839;
      val[269 * nCulm + 1] = 1.218984;
      val[269 * nCulm + 2] = -9.884294;
      val[269 * nCulm + 3] = 26.296329;
      val[269 * nCulm + 4] = 37.602473;
      val[269 * nCulm + 5] = 3.693579;
      val[270 * nCulm + 0] = 39.929473;
      val[270 * nCulm + 1] = -23.718484;
      val[270 * nCulm + 2] = 10.925441;
      val[270 * nCulm + 3] = 46.931578;
      val[270 * nCulm + 4] = -23.579721;
      val[270 * nCulm + 5] = -4.429738;
      val[271 * nCulm + 0] = 33.439911;
      val[271 * nCulm + 1] = 25.441859;
      val[271 * nCulm + 2] = 35.008732;
      val[271 * nCulm + 3] = 2.829145;
      val[271 * nCulm + 4] = 40.264007;
      val[271 * nCulm + 5] = 3.553467;
      val[272 * nCulm + 0] = 35.090918;
      val[272 * nCulm + 1] = 20.206437;
      val[272 * nCulm + 2] = -6.052123;
      val[272 * nCulm + 3] = -4.467555;
      val[272 * nCulm + 4] = 47.223374;
      val[272 * nCulm + 5] = 1.807553;
      val[273 * nCulm + 0] = 35.885358;
      val[273 * nCulm + 1] = 35.990094;
      val[273 * nCulm + 2] = -46.651915;
      val[273 * nCulm + 3] = 31.690881;
      val[273 * nCulm + 4] = -8.897501;
      val[273 * nCulm + 5] = -35.775235;
      val[274 * nCulm + 0] = 17.982225;
      val[274 * nCulm + 1] = 26.383972;
      val[274 * nCulm + 2] = -48.574056;
      val[274 * nCulm + 3] = -23.836027;
      val[274 * nCulm + 4] = 4.990014;
      val[274 * nCulm + 5] = 2.646882;
      val[275 * nCulm + 0] = -9.211478;
      val[275 * nCulm + 1] = -16.950535;
      val[275 * nCulm + 2] = -39.215764;
      val[275 * nCulm + 3] = 11.878583;
      val[275 * nCulm + 4] = 22.580273;
      val[275 * nCulm + 5] = -0.833195;
      val[276 * nCulm + 0] = 24.465498;
      val[276 * nCulm + 1] = -7.803562;
      val[276 * nCulm + 2] = -24.344552;
      val[276 * nCulm + 3] = 28.713044;
      val[276 * nCulm + 4] = 49.261273;
      val[276 * nCulm + 5] = 2.239115;
      val[277 * nCulm + 0] = -5.122486;
      val[277 * nCulm + 1] = 9.368722;
      val[277 * nCulm + 2] = -46.023339;
      val[277 * nCulm + 3] = -9.413490;
      val[277 * nCulm + 4] = 24.104048;
      val[277 * nCulm + 5] = 0.221209;
      val[278 * nCulm + 0] = 37.812547;
      val[278 * nCulm + 1] = -12.394576;
      val[278 * nCulm + 2] = 17.042301;
      val[278 * nCulm + 3] = 25.506614;
      val[278 * nCulm + 4] = 25.981504;
      val[278 * nCulm + 5] = 2.618763;
      val[279 * nCulm + 0] = 6.937082;
      val[279 * nCulm + 1] = 12.189792;
      val[279 * nCulm + 2] = -21.009848;
      val[279 * nCulm + 3] = -5.859278;
      val[279 * nCulm + 4] = -28.173594;
      val[279 * nCulm + 5] = -0.833565;
      val[280 * nCulm + 0] = 38.953538;
      val[280 * nCulm + 1] = -40.621183;
      val[280 * nCulm + 2] = 46.949183;
      val[280 * nCulm + 3] = 12.800628;
      val[280 * nCulm + 4] = 21.521007;
      val[280 * nCulm + 5] = -5.888857;
      val[281 * nCulm + 0] = 32.998316;
      val[281 * nCulm + 1] = -38.013746;
      val[281 * nCulm + 2] = -17.901507;
      val[281 * nCulm + 3] = -8.239805;
      val[281 * nCulm + 4] = -14.046895;
      val[281 * nCulm + 5] = 15.815898;
      val[282 * nCulm + 0] = -18.011702;
      val[282 * nCulm + 1] = -42.988835;
      val[282 * nCulm + 2] = 11.486206;
      val[282 * nCulm + 3] = 6.317532;
      val[282 * nCulm + 4] = -23.819856;
      val[282 * nCulm + 5] = 7.517093;
      val[283 * nCulm + 0] = 19.848710;
      val[283 * nCulm + 1] = -21.475686;
      val[283 * nCulm + 2] = -7.258073;
      val[283 * nCulm + 3] = 20.820421;
      val[283 * nCulm + 4] = -0.041552;
      val[283 * nCulm + 5] = 74.872992;
      val[284 * nCulm + 0] = -13.835679;
      val[284 * nCulm + 1] = 46.040633;
      val[284 * nCulm + 2] = -9.557578;
      val[284 * nCulm + 3] = 9.938728;
      val[284 * nCulm + 4] = 4.858622;
      val[284 * nCulm + 5] = 54.765827;
      val[285 * nCulm + 0] = 23.351299;
      val[285 * nCulm + 1] = -27.394782;
      val[285 * nCulm + 2] = 0.391710;
      val[285 * nCulm + 3] = 16.900327;
      val[285 * nCulm + 4] = -27.623004;
      val[285 * nCulm + 5] = 2.028275;
      val[286 * nCulm + 0] = 3.134516;
      val[286 * nCulm + 1] = -32.694501;
      val[286 * nCulm + 2] = 25.995702;
      val[286 * nCulm + 3] = 14.299655;
      val[286 * nCulm + 4] = 36.532652;
      val[286 * nCulm + 5] = -2.153318;
      val[287 * nCulm + 0] = -24.448076;
      val[287 * nCulm + 1] = 49.378716;
      val[287 * nCulm + 2] = -22.671254;
      val[287 * nCulm + 3] = -36.222379;
      val[287 * nCulm + 4] = -2.753746;
      val[287 * nCulm + 5] = -22.384040;
      val[288 * nCulm + 0] = -46.488634;
      val[288 * nCulm + 1] = 49.988369;
      val[288 * nCulm + 2] = 38.559344;
      val[288 * nCulm + 3] = 23.131205;
      val[288 * nCulm + 4] = 6.282093;
      val[288 * nCulm + 5] = 55.322996;
      val[289 * nCulm + 0] = 6.658037;
      val[289 * nCulm + 1] = 42.115447;
      val[289 * nCulm + 2] = 7.324068;
      val[289 * nCulm + 3] = 1.993439;
      val[289 * nCulm + 4] = -6.067497;
      val[289 * nCulm + 5] = -34.179913;
      val[290 * nCulm + 0] = -3.532612;
      val[290 * nCulm + 1] = 21.708963;
      val[290 * nCulm + 2] = 22.217354;
      val[290 * nCulm + 3] = 10.149175;
      val[290 * nCulm + 4] = 31.752143;
      val[290 * nCulm + 5] = 4.979134;
      val[291 * nCulm + 0] = -14.804544;
      val[291 * nCulm + 1] = 13.485654;
      val[291 * nCulm + 2] = 31.260951;
      val[291 * nCulm + 3] = 36.438900;
      val[291 * nCulm + 4] = -10.896441;
      val[291 * nCulm + 5] = -21.456857;
      val[292 * nCulm + 0] = 16.822358;
      val[292 * nCulm + 1] = 37.524491;
      val[292 * nCulm + 2] = -25.158511;
      val[292 * nCulm + 3] = -31.283331;
      val[292 * nCulm + 4] = 41.884928;
      val[292 * nCulm + 5] = 0.935301;
      val[293 * nCulm + 0] = 47.240918;
      val[293 * nCulm + 1] = 0.534291;
      val[293 * nCulm + 2] = -29.641658;
      val[293 * nCulm + 3] = -4.180775;
      val[293 * nCulm + 4] = -7.579916;
      val[293 * nCulm + 5] = 2.507073;
      val[294 * nCulm + 0] = 21.404307;
      val[294 * nCulm + 1] = 41.451890;
      val[294 * nCulm + 2] = 16.441352;
      val[294 * nCulm + 3] = -2.700668;
      val[294 * nCulm + 4] = 19.868153;
      val[294 * nCulm + 5] = 9.461983;
      val[295 * nCulm + 0] = -42.295634;
      val[295 * nCulm + 1] = -31.349028;
      val[295 * nCulm + 2] = -3.822083;
      val[295 * nCulm + 3] = 23.187816;
      val[295 * nCulm + 4] = -39.749933;
      val[295 * nCulm + 5] = 1.201819;
      val[296 * nCulm + 0] = 3.392785;
      val[296 * nCulm + 1] = -35.639850;
      val[296 * nCulm + 2] = -14.328486;
      val[296 * nCulm + 3] = 44.535298;
      val[296 * nCulm + 4] = 0.734222;
      val[296 * nCulm + 5] = 57.576551;
      val[297 * nCulm + 0] = 5.394015;
      val[297 * nCulm + 1] = 8.840627;
      val[297 * nCulm + 2] = 37.984521;
      val[297 * nCulm + 3] = 44.967450;
      val[297 * nCulm + 4] = 34.722173;
      val[297 * nCulm + 5] = 7.565127;
      val[298 * nCulm + 0] = 13.028874;
      val[298 * nCulm + 1] = 43.865677;
      val[298 * nCulm + 2] = -28.833755;
      val[298 * nCulm + 3] = -20.740945;
      val[298 * nCulm + 4] = 6.806923;
      val[298 * nCulm + 5] = 16.310256;
      val[299 * nCulm + 0] = -47.693790;
      val[299 * nCulm + 1] = -33.007777;
      val[299 * nCulm + 2] = -3.481512;
      val[299 * nCulm + 3] = 25.740063;
      val[299 * nCulm + 4] = -11.090258;
      val[299 * nCulm + 5] = 3.331867;
      val[300 * nCulm + 0] = -12.319788;
      val[300 * nCulm + 1] = 47.039343;
      val[300 * nCulm + 2] = 10.387818;
      val[300 * nCulm + 3] = -13.657311;
      val[300 * nCulm + 4] = -49.070933;
      val[300 * nCulm + 5] = -2.989998;
      val[301 * nCulm + 0] = -26.599629;
      val[301 * nCulm + 1] = 35.329833;
      val[301 * nCulm + 2] = -16.155463;
      val[301 * nCulm + 3] = -46.379789;
      val[301 * nCulm + 4] = 36.506438;
      val[301 * nCulm + 5] = -1.202710;
      val[302 * nCulm + 0] = -19.883331;
      val[302 * nCulm + 1] = 11.165496;
      val[302 * nCulm + 2] = -20.150443;
      val[302 * nCulm + 3] = 37.768140;
      val[302 * nCulm + 4] = -20.454214;
      val[302 * nCulm + 5] = -11.093789;
      val[303 * nCulm + 0] = 5.106337;
      val[303 * nCulm + 1] = -33.957613;
      val[303 * nCulm + 2] = -24.481129;
      val[303 * nCulm + 3] = -11.499347;
      val[303 * nCulm + 4] = -30.434780;
      val[303 * nCulm + 5] = 7.299640;
      val[304 * nCulm + 0] = -23.249461;
      val[304 * nCulm + 1] = -42.071106;
      val[304 * nCulm + 2] = 3.822619;
      val[304 * nCulm + 3] = -33.009501;
      val[304 * nCulm + 4] = -38.755108;
      val[304 * nCulm + 5] = 9.399928;
      val[305 * nCulm + 0] = -42.702599;
      val[305 * nCulm + 1] = -23.791935;
      val[305 * nCulm + 2] = -6.107674;
      val[305 * nCulm + 3] = 8.300237;
      val[305 * nCulm + 4] = -9.105469;
      val[305 * nCulm + 5] = 8.283114;
      val[306 * nCulm + 0] = -42.844675;
      val[306 * nCulm + 1] = -10.229801;
      val[306 * nCulm + 2] = -42.444436;
      val[306 * nCulm + 3] = 34.738833;
      val[306 * nCulm + 4] = -48.379505;
      val[306 * nCulm + 5] = -2.167904;
      val[307 * nCulm + 0] = 48.646883;
      val[307 * nCulm + 1] = 23.224615;
      val[307 * nCulm + 2] = -33.168815;
      val[307 * nCulm + 3] = 42.266601;
      val[307 * nCulm + 4] = 6.680548;
      val[307 * nCulm + 5] = 46.632148;
      val[308 * nCulm + 0] = -8.423063;
      val[308 * nCulm + 1] = 42.157117;
      val[308 * nCulm + 2] = -38.493015;
      val[308 * nCulm + 3] = -20.688488;
      val[308 * nCulm + 4] = 41.974276;
      val[308 * nCulm + 5] = 2.650963;
      val[309 * nCulm + 0] = 0.444406;
      val[309 * nCulm + 1] = 25.251302;
      val[309 * nCulm + 2] = -35.155325;
      val[309 * nCulm + 3] = 21.598030;
      val[309 * nCulm + 4] = 39.842807;
      val[309 * nCulm + 5] = 5.795710;
      val[310 * nCulm + 0] = -11.657649;
      val[310 * nCulm + 1] = 28.219586;
      val[310 * nCulm + 2] = -48.218263;
      val[310 * nCulm + 3] = -39.696874;
      val[310 * nCulm + 4] = -38.004669;
      val[310 * nCulm + 5] = 1.659452;
      val[311 * nCulm + 0] = -48.141780;
      val[311 * nCulm + 1] = 26.142578;
      val[311 * nCulm + 2] = 34.356167;
      val[311 * nCulm + 3] = 7.569572;
      val[311 * nCulm + 4] = -34.824932;
      val[311 * nCulm + 5] = -4.352086;
      val[312 * nCulm + 0] = -5.910057;
      val[312 * nCulm + 1] = 36.014787;
      val[312 * nCulm + 2] = 4.166706;
      val[312 * nCulm + 3] = -33.058694;
      val[312 * nCulm + 4] = -44.048507;
      val[312 * nCulm + 5] = -0.087654;
      val[313 * nCulm + 0] = 21.991898;
      val[313 * nCulm + 1] = -1.167690;
      val[313 * nCulm + 2] = -40.898282;
      val[313 * nCulm + 3] = -31.773391;
      val[313 * nCulm + 4] = -46.167104;
      val[313 * nCulm + 5] = 3.607321;
      val[314 * nCulm + 0] = -49.833252;
      val[314 * nCulm + 1] = 9.574234;
      val[314 * nCulm + 2] = 39.668875;
      val[314 * nCulm + 3] = 34.475162;
      val[314 * nCulm + 4] = 33.383911;
      val[314 * nCulm + 5] = 6.475538;
      val[315 * nCulm + 0] = 10.526442;
      val[315 * nCulm + 1] = 21.333937;
      val[315 * nCulm + 2] = -30.774815;
      val[315 * nCulm + 3] = -34.326194;
      val[315 * nCulm + 4] = 43.050039;
      val[315 * nCulm + 5] = -1.198493;
      val[316 * nCulm + 0] = -5.568443;
      val[316 * nCulm + 1] = 9.482243;
      val[316 * nCulm + 2] = 43.227999;
      val[316 * nCulm + 3] = 31.262521;
      val[316 * nCulm + 4] = 4.453552;
      val[316 * nCulm + 5] = 43.534429;
      val[317 * nCulm + 0] = 30.821205;
      val[317 * nCulm + 1] = -6.688914;
      val[317 * nCulm + 2] = -13.869452;
      val[317 * nCulm + 3] = 20.097096;
      val[317 * nCulm + 4] = -27.745211;
      val[317 * nCulm + 5] = -2.057436;
      val[318 * nCulm + 0] = -2.717954;
      val[318 * nCulm + 1] = -25.617909;
      val[318 * nCulm + 2] = 37.859446;
      val[318 * nCulm + 3] = -17.565940;
      val[318 * nCulm + 4] = 26.364768;
      val[318 * nCulm + 5] = -7.522905;
      val[319 * nCulm + 0] = 2.145537;
      val[319 * nCulm + 1] = 24.978836;
      val[319 * nCulm + 2] = 9.331667;
      val[319 * nCulm + 3] = 15.901714;
      val[319 * nCulm + 4] = -10.461801;
      val[319 * nCulm + 5] = -18.265980;
      val[320 * nCulm + 0] = 1.049014;
      val[320 * nCulm + 1] = -0.161696;
      val[320 * nCulm + 2] = 44.534907;
      val[320 * nCulm + 3] = -7.115367;
      val[320 * nCulm + 4] = 11.417357;
      val[320 * nCulm + 5] = -2.786877;
      val[321 * nCulm + 0] = -47.846598;
      val[321 * nCulm + 1] = 5.784740;
      val[321 * nCulm + 2] = -7.676608;
      val[321 * nCulm + 3] = 3.888179;
      val[321 * nCulm + 4] = -41.692100;
      val[321 * nCulm + 5] = -0.868173;
      val[322 * nCulm + 0] = -24.652286;
      val[322 * nCulm + 1] = -40.439872;
      val[322 * nCulm + 2] = -23.023828;
      val[322 * nCulm + 3] = -11.826117;
      val[322 * nCulm + 4] = 30.241430;
      val[322 * nCulm + 5] = -7.950577;
      val[323 * nCulm + 0] = 6.821344;
      val[323 * nCulm + 1] = 46.420381;
      val[323 * nCulm + 2] = -34.231119;
      val[323 * nCulm + 3] = -16.631281;
      val[323 * nCulm + 4] = -41.142755;
      val[323 * nCulm + 5] = -3.197134;
      val[324 * nCulm + 0] = -44.778938;
      val[324 * nCulm + 1] = -22.186795;
      val[324 * nCulm + 2] = 17.398548;
      val[324 * nCulm + 3] = 3.673368;
      val[324 * nCulm + 4] = -20.249256;
      val[324 * nCulm + 5] = 4.557578;
      val[325 * nCulm + 0] = 16.308813;
      val[325 * nCulm + 1] = -3.210289;
      val[325 * nCulm + 2] = 9.531200;
      val[325 * nCulm + 3] = -2.888908;
      val[325 * nCulm + 4] = -4.227838;
      val[325 * nCulm + 5] = 7.058438;
      val[326 * nCulm + 0] = 40.249278;
      val[326 * nCulm + 1] = 7.915993;
      val[326 * nCulm + 2] = -44.221190;
      val[326 * nCulm + 3] = 43.472278;
      val[326 * nCulm + 4] = -45.069022;
      val[326 * nCulm + 5] = -5.167007;
      val[327 * nCulm + 0] = -30.300756;
      val[327 * nCulm + 1] = 49.462337;
      val[327 * nCulm + 2] = 6.112003;
      val[327 * nCulm + 3] = 11.112061;
      val[327 * nCulm + 4] = 36.797027;
      val[327 * nCulm + 5] = 8.021902;
      val[328 * nCulm + 0] = -42.756803;
      val[328 * nCulm + 1] = -11.552689;
      val[328 * nCulm + 2] = -5.259769;
      val[328 * nCulm + 3] = -44.989276;
      val[328 * nCulm + 4] = 41.445795;
      val[328 * nCulm + 5] = -6.227397;
      val[329 * nCulm + 0] = -35.205070;
      val[329 * nCulm + 1] = 47.716059;
      val[329 * nCulm + 2] = -35.087479;
      val[329 * nCulm + 3] = 18.726909;
      val[329 * nCulm + 4] = 13.472096;
      val[329 * nCulm + 5] = 23.574304;
      val[330 * nCulm + 0] = 16.554476;
      val[330 * nCulm + 1] = -34.863756;
      val[330 * nCulm + 2] = 17.644788;
      val[330 * nCulm + 3] = 45.176059;
      val[330 * nCulm + 4] = -29.231342;
      val[330 * nCulm + 5] = -1.439837;
      val[331 * nCulm + 0] = -1.188721;
      val[331 * nCulm + 1] = 31.863831;
      val[331 * nCulm + 2] = -8.412890;
      val[331 * nCulm + 3] = 27.881830;
      val[331 * nCulm + 4] = 39.598736;
      val[331 * nCulm + 5] = 7.371544;
      val[332 * nCulm + 0] = 28.311651;
      val[332 * nCulm + 1] = -19.319549;
      val[332 * nCulm + 2] = -33.537256;
      val[332 * nCulm + 3] = 20.490837;
      val[332 * nCulm + 4] = -6.932356;
      val[332 * nCulm + 5] = -0.569743;
      val[333 * nCulm + 0] = 4.799849;
      val[333 * nCulm + 1] = 32.035546;
      val[333 * nCulm + 2] = 37.186097;
      val[333 * nCulm + 3] = 32.504836;
      val[333 * nCulm + 4] = -47.501741;
      val[333 * nCulm + 5] = -6.201157;
      val[334 * nCulm + 0] = 45.300507;
      val[334 * nCulm + 1] = -33.316240;
      val[334 * nCulm + 2] = 42.468724;
      val[334 * nCulm + 3] = 49.263669;
      val[334 * nCulm + 4] = 39.020376;
      val[334 * nCulm + 5] = 2.164489;
      val[335 * nCulm + 0] = -10.627047;
      val[335 * nCulm + 1] = -48.412919;
      val[335 * nCulm + 2] = 3.688972;
      val[335 * nCulm + 3] = 25.750004;
      val[335 * nCulm + 4] = -27.101609;
      val[335 * nCulm + 5] = 4.188109;
      val[336 * nCulm + 0] = 1.220831;
      val[336 * nCulm + 1] = 26.745342;
      val[336 * nCulm + 2] = 0.475714;
      val[336 * nCulm + 3] = 48.086616;
      val[336 * nCulm + 4] = 34.275289;
      val[336 * nCulm + 5] = 10.564110;
      val[337 * nCulm + 0] = 34.673967;
      val[337 * nCulm + 1] = -35.856625;
      val[337 * nCulm + 2] = -6.086415;
      val[337 * nCulm + 3] = 43.462051;
      val[337 * nCulm + 4] = 31.183492;
      val[337 * nCulm + 5] = 1.384425;
      val[338 * nCulm + 0] = 21.616239;
      val[338 * nCulm + 1] = 41.839382;
      val[338 * nCulm + 2] = -45.433602;
      val[338 * nCulm + 3] = -32.036035;
      val[338 * nCulm + 4] = 26.458206;
      val[338 * nCulm + 5] = 1.983804;
      val[339 * nCulm + 0] = -17.106164;
      val[339 * nCulm + 1] = 13.516404;
      val[339 * nCulm + 2] = 38.444276;
      val[339 * nCulm + 3] = -14.635611;
      val[339 * nCulm + 4] = -16.432486;
      val[339 * nCulm + 5] = 0.552384;
      val[340 * nCulm + 0] = 49.833634;
      val[340 * nCulm + 1] = -35.031256;
      val[340 * nCulm + 2] = 32.277198;
      val[340 * nCulm + 3] = 19.548917;
      val[340 * nCulm + 4] = -15.734107;
      val[340 * nCulm + 5] = 4.887593;
      val[341 * nCulm + 0] = 34.592950;
      val[341 * nCulm + 1] = -1.902962;
      val[341 * nCulm + 2] = -12.606441;
      val[341 * nCulm + 3] = -33.449135;
      val[341 * nCulm + 4] = -17.493003;
      val[341 * nCulm + 5] = 9.795725;
      val[342 * nCulm + 0] = 13.251714;
      val[342 * nCulm + 1] = 34.280703;
      val[342 * nCulm + 2] = -49.214349;
      val[342 * nCulm + 3] = 40.112786;
      val[342 * nCulm + 4] = 43.224765;
      val[342 * nCulm + 5] = 8.376468;
      val[343 * nCulm + 0] = -44.686647;
      val[343 * nCulm + 1] = 28.075024;
      val[343 * nCulm + 2] = -4.009596;
      val[343 * nCulm + 3] = 17.829573;
      val[343 * nCulm + 4] = 4.594595;
      val[343 * nCulm + 5] = 47.520728;
      val[344 * nCulm + 0] = -47.566101;
      val[344 * nCulm + 1] = -30.005851;
      val[344 * nCulm + 2] = -1.052475;
      val[344 * nCulm + 3] = -1.648075;
      val[344 * nCulm + 4] = -47.542098;
      val[344 * nCulm + 5] = 3.381493;
      val[345 * nCulm + 0] = -9.305153;
      val[345 * nCulm + 1] = 28.033869;
      val[345 * nCulm + 2] = -37.863974;
      val[345 * nCulm + 3] = -17.869513;
      val[345 * nCulm + 4] = 27.109818;
      val[345 * nCulm + 5] = 2.004681;
      val[346 * nCulm + 0] = 35.883737;
      val[346 * nCulm + 1] = -0.238621;
      val[346 * nCulm + 2] = -42.493580;
      val[346 * nCulm + 3] = -36.492473;
      val[346 * nCulm + 4] = 4.863622;
      val[346 * nCulm + 5] = -35.517129;
      val[347 * nCulm + 0] = 12.285171;
      val[347 * nCulm + 1] = -19.873332;
      val[347 * nCulm + 2] = 49.925324;
      val[347 * nCulm + 3] = 37.618881;
      val[347 * nCulm + 4] = -43.563224;
      val[347 * nCulm + 5] = -1.698131;
      val[348 * nCulm + 0] = 28.867847;
      val[348 * nCulm + 1] = -10.532170;
      val[348 * nCulm + 2] = 4.383734;
      val[348 * nCulm + 3] = -6.201767;
      val[348 * nCulm + 4] = -49.853171;
      val[348 * nCulm + 5] = 1.818812;
      val[349 * nCulm + 0] = 27.252415;
      val[349 * nCulm + 1] = -11.715180;
      val[349 * nCulm + 2] = -27.924649;
      val[349 * nCulm + 3] = 6.714906;
      val[349 * nCulm + 4] = -46.002044;
      val[349 * nCulm + 5] = 0.744498;
      val[350 * nCulm + 0] = 0.960737;
      val[350 * nCulm + 1] = 44.927352;
      val[350 * nCulm + 2] = -2.049607;
      val[350 * nCulm + 3] = 44.060516;
      val[350 * nCulm + 4] = 49.066870;
      val[350 * nCulm + 5] = 8.814392;
      val[351 * nCulm + 0] = 26.336982;
      val[351 * nCulm + 1] = 18.807892;
      val[351 * nCulm + 2] = 26.977451;
      val[351 * nCulm + 3] = -15.642771;
      val[351 * nCulm + 4] = -15.960735;
      val[351 * nCulm + 5] = -0.708652;
      val[352 * nCulm + 0] = -6.812334;
      val[352 * nCulm + 1] = 46.733904;
      val[352 * nCulm + 2] = -9.251701;
      val[352 * nCulm + 3] = 31.911994;
      val[352 * nCulm + 4] = 18.071709;
      val[352 * nCulm + 5] = 20.828896;
      val[353 * nCulm + 0] = 23.991528;
      val[353 * nCulm + 1] = 36.293321;
      val[353 * nCulm + 2] = 1.584917;
      val[353 * nCulm + 3] = 6.638102;
      val[353 * nCulm + 4] = 3.910374;
      val[353 * nCulm + 5] = 52.196574;
      val[354 * nCulm + 0] = 14.167869;
      val[354 * nCulm + 1] = -47.859297;
      val[354 * nCulm + 2] = -24.634578;
      val[354 * nCulm + 3] = 0.455617;
      val[354 * nCulm + 4] = -25.096218;
      val[354 * nCulm + 5] = 9.170687;
      val[355 * nCulm + 0] = 10.689865;
      val[355 * nCulm + 1] = 41.240632;
      val[355 * nCulm + 2] = 40.853704;
      val[355 * nCulm + 3] = -45.106963;
      val[355 * nCulm + 4] = -25.573335;
      val[355 * nCulm + 5] = 0.945614;
      val[356 * nCulm + 0] = -5.971378;
      val[356 * nCulm + 1] = 39.252962;
      val[356 * nCulm + 2] = -31.110736;
      val[356 * nCulm + 3] = 38.634542;
      val[356 * nCulm + 4] = 1.185100;
      val[356 * nCulm + 5] = 311.315460;
      val[357 * nCulm + 0] = -38.371483;
      val[357 * nCulm + 1] = 5.142786;
      val[357 * nCulm + 2] = 30.414605;
      val[357 * nCulm + 3] = -27.456149;
      val[357 * nCulm + 4] = 12.851137;
      val[357 * nCulm + 5] = -7.988462;
      val[358 * nCulm + 0] = -5.253059;
      val[358 * nCulm + 1] = -14.968073;
      val[358 * nCulm + 2] = 49.788036;
      val[358 * nCulm + 3] = -2.739196;
      val[358 * nCulm + 4] = -47.567079;
      val[358 * nCulm + 5] = 1.992025;
      val[359 * nCulm + 0] = 10.469039;
      val[359 * nCulm + 1] = 25.592694;
      val[359 * nCulm + 2] = -6.278877;
      val[359 * nCulm + 3] = 46.264567;
      val[359 * nCulm + 4] = -41.142182;
      val[359 * nCulm + 5] = -8.037047;
      val[360 * nCulm + 0] = 32.624084;
      val[360 * nCulm + 1] = -28.820747;
      val[360 * nCulm + 2] = -9.594895;
      val[360 * nCulm + 3] = 39.917208;
      val[360 * nCulm + 4] = -47.511208;
      val[360 * nCulm + 5] = -0.875492;
      val[361 * nCulm + 0] = -28.611375;
      val[361 * nCulm + 1] = 41.193520;
      val[361 * nCulm + 2] = 21.105885;
      val[361 * nCulm + 3] = 47.715933;
      val[361 * nCulm + 4] = 26.569137;
      val[361 * nCulm + 5] = 16.069358;
      val[362 * nCulm + 0] = 22.358432;
      val[362 * nCulm + 1] = -38.322089;
      val[362 * nCulm + 2] = 32.746950;
      val[362 * nCulm + 3] = -21.582083;
      val[362 * nCulm + 4] = -8.787720;
      val[362 * nCulm + 5] = 32.496211;
      val[363 * nCulm + 0] = -45.738335;
      val[363 * nCulm + 1] = 5.427143;
      val[363 * nCulm + 2] = -3.937337;
      val[363 * nCulm + 3] = 42.052699;
      val[363 * nCulm + 4] = 49.024234;
      val[363 * nCulm + 5] = 4.814221;
      val[364 * nCulm + 0] = -45.734674;
      val[364 * nCulm + 1] = -5.601682;
      val[364 * nCulm + 2] = 30.833695;
      val[364 * nCulm + 3] = -28.808031;
      val[364 * nCulm + 4] = 2.171599;
      val[364 * nCulm + 5] = -74.771266;
      val[365 * nCulm + 0] = -9.398593;
      val[365 * nCulm + 1] = 7.174845;
      val[365 * nCulm + 2] = -10.931720;
      val[365 * nCulm + 3] = -2.678637;
      val[365 * nCulm + 4] = 36.211396;
      val[365 * nCulm + 5] = 0.817717;
      val[366 * nCulm + 0] = 14.314698;
      val[366 * nCulm + 1] = 35.031987;
      val[366 * nCulm + 2] = 35.238838;
      val[366 * nCulm + 3] = 14.907811;
      val[366 * nCulm + 4] = 4.613710;
      val[366 * nCulm + 5] = 51.464631;
      val[367 * nCulm + 0] = -20.776043;
      val[367 * nCulm + 1] = 27.285225;
      val[367 * nCulm + 2] = 1.807528;
      val[367 * nCulm + 3] = 30.740577;
      val[367 * nCulm + 4] = 3.754172;
      val[367 * nCulm + 5] = 73.390072;
      val[368 * nCulm + 0] = -23.532923;
      val[368 * nCulm + 1] = -20.653508;
      val[368 * nCulm + 2] = 20.534509;
      val[368 * nCulm + 3] = 35.855304;
      val[368 * nCulm + 4] = -27.403782;
      val[368 * nCulm + 5] = -2.395739;
      val[369 * nCulm + 0] = -40.067235;
      val[369 * nCulm + 1] = -23.728076;
      val[369 * nCulm + 2] = 29.100213;
      val[369 * nCulm + 3] = -21.966670;
      val[369 * nCulm + 4] = 24.623206;
      val[369 * nCulm + 5] = -8.553928;
      val[370 * nCulm + 0] = 5.862941;
      val[370 * nCulm + 1] = -9.000407;
      val[370 * nCulm + 2] = 48.421541;
      val[370 * nCulm + 3] = 47.642604;
      val[370 * nCulm + 4] = -38.418902;
      val[370 * nCulm + 5] = -4.530844;
      val[371 * nCulm + 0] = -30.163168;
      val[371 * nCulm + 1] = -44.917582;
      val[371 * nCulm + 2] = 28.320812;
      val[371 * nCulm + 3] = 43.075613;
      val[371 * nCulm + 4] = 20.934906;
      val[371 * nCulm + 5] = -0.186465;
      val[372 * nCulm + 0] = 41.448846;
      val[372 * nCulm + 1] = -2.779273;
      val[372 * nCulm + 2] = 39.346187;
      val[372 * nCulm + 3] = 9.602602;
      val[372 * nCulm + 4] = -36.395595;
      val[372 * nCulm + 5] = -0.657390;
      val[373 * nCulm + 0] = 9.495560;
      val[373 * nCulm + 1] = 48.168810;
      val[373 * nCulm + 2] = -19.205517;
      val[373 * nCulm + 3] = 4.008766;
      val[373 * nCulm + 4] = 48.533041;
      val[373 * nCulm + 5] = 5.318778;
      val[374 * nCulm + 0] = -1.582864;
      val[374 * nCulm + 1] = -14.358835;
      val[374 * nCulm + 2] = -22.511663;
      val[374 * nCulm + 3] = -24.442259;
      val[374 * nCulm + 4] = 35.701055;
      val[374 * nCulm + 5] = -4.914344;
      val[375 * nCulm + 0] = 35.534398;
      val[375 * nCulm + 1] = -17.108274;
      val[375 * nCulm + 2] = -2.648908;
      val[375 * nCulm + 3] = -14.267956;
      val[375 * nCulm + 4] = -39.947724;
      val[375 * nCulm + 5] = 3.947713;
      val[376 * nCulm + 0] = -41.069884;
      val[376 * nCulm + 1] = -0.172489;
      val[376 * nCulm + 2] = -22.334615;
      val[376 * nCulm + 3] = -40.605360;
      val[376 * nCulm + 4] = -8.624777;
      val[376 * nCulm + 5] = 22.609148;
      val[377 * nCulm + 0] = 27.615158;
      val[377 * nCulm + 1] = -22.331738;
      val[377 * nCulm + 2] = 22.098561;
      val[377 * nCulm + 3] = -26.281884;
      val[377 * nCulm + 4] = -26.236557;
      val[377 * nCulm + 5] = 9.000376;
      val[378 * nCulm + 0] = -33.069253;
      val[378 * nCulm + 1] = -14.361642;
      val[378 * nCulm + 2] = 43.913604;
      val[378 * nCulm + 3] = -37.930159;
      val[378 * nCulm + 4] = 48.323612;
      val[378 * nCulm + 5] = -4.892020;
      val[379 * nCulm + 0] = -24.688110;
      val[379 * nCulm + 1] = 17.130842;
      val[379 * nCulm + 2] = -8.137613;
      val[379 * nCulm + 3] = 17.406398;
      val[379 * nCulm + 4] = -20.008139;
      val[379 * nCulm + 5] = -7.940488;
      val[380 * nCulm + 0] = 28.821985;
      val[380 * nCulm + 1] = -29.565039;
      val[380 * nCulm + 2] = -23.794606;
      val[380 * nCulm + 3] = 11.846063;
      val[380 * nCulm + 4] = -35.736880;
      val[380 * nCulm + 5] = 2.576870;
      val[381 * nCulm + 0] = -35.321478;
      val[381 * nCulm + 1] = 30.707172;
      val[381 * nCulm + 2] = 41.478090;
      val[381 * nCulm + 3] = 12.497635;
      val[381 * nCulm + 4] = 7.256645;
      val[381 * nCulm + 5] = 28.411448;
      val[382 * nCulm + 0] = -18.939946;
      val[382 * nCulm + 1] = -5.715253;
      val[382 * nCulm + 2] = 16.980544;
      val[382 * nCulm + 3] = -31.063011;
      val[382 * nCulm + 4] = -28.231022;
      val[382 * nCulm + 5] = 6.396400;
      val[383 * nCulm + 0] = -48.487913;
      val[383 * nCulm + 1] = -40.512323;
      val[383 * nCulm + 2] = 2.058212;
      val[383 * nCulm + 3] = -15.772624;
      val[383 * nCulm + 4] = 17.886804;
      val[383 * nCulm + 5] = -14.664523;
      val[384 * nCulm + 0] = 33.671160;
      val[384 * nCulm + 1] = 7.864521;
      val[384 * nCulm + 2] = 30.277675;
      val[384 * nCulm + 3] = 26.689957;
      val[384 * nCulm + 4] = -47.551573;
      val[384 * nCulm + 5] = -3.209589;
      val[385 * nCulm + 0] = -4.189388;
      val[385 * nCulm + 1] = -35.693225;
      val[385 * nCulm + 2] = -22.022702;
      val[385 * nCulm + 3] = 36.100174;
      val[385 * nCulm + 4] = 22.426883;
      val[385 * nCulm + 5] = 0.315889;
      val[386 * nCulm + 0] = 32.436221;
      val[386 * nCulm + 1] = 43.133766;
      val[386 * nCulm + 2] = -45.492111;
      val[386 * nCulm + 3] = 11.163782;
      val[386 * nCulm + 4] = -7.120568;
      val[386 * nCulm + 5] = -35.863807;
      val[387 * nCulm + 0] = -44.542618;
      val[387 * nCulm + 1] = 37.938762;
      val[387 * nCulm + 2] = 0.969751;
      val[387 * nCulm + 3] = -40.704644;
      val[387 * nCulm + 4] = 12.233404;
      val[387 * nCulm + 5] = -0.840172;
      val[388 * nCulm + 0] = 27.256676;
      val[388 * nCulm + 1] = 12.380689;
      val[388 * nCulm + 2] = -23.049290;
      val[388 * nCulm + 3] = -48.539918;
      val[388 * nCulm + 4] = -26.285799;
      val[388 * nCulm + 5] = 6.741261;
      val[389 * nCulm + 0] = 47.122503;
      val[389 * nCulm + 1] = 27.079566;
      val[389 * nCulm + 2] = -11.268811;
      val[389 * nCulm + 3] = -26.453982;
      val[389 * nCulm + 4] = -13.939124;
      val[389 * nCulm + 5] = 0.017570;
      val[390 * nCulm + 0] = 16.918033;
      val[390 * nCulm + 1] = 20.430868;
      val[390 * nCulm + 2] = -41.447769;
      val[390 * nCulm + 3] = -47.560185;
      val[390 * nCulm + 4] = -33.138953;
      val[390 * nCulm + 5] = 4.104959;
      val[391 * nCulm + 0] = -23.227957;
      val[391 * nCulm + 1] = 35.689089;
      val[391 * nCulm + 2] = 24.204762;
      val[391 * nCulm + 3] = -39.044517;
      val[391 * nCulm + 4] = 25.068816;
      val[391 * nCulm + 5] = -0.403551;
      val[392 * nCulm + 0] = -9.154837;
      val[392 * nCulm + 1] = -30.117670;
      val[392 * nCulm + 2] = 14.623403;
      val[392 * nCulm + 3] = -2.941902;
      val[392 * nCulm + 4] = 26.848115;
      val[392 * nCulm + 5] = -5.598416;
      val[393 * nCulm + 0] = 7.395542;
      val[393 * nCulm + 1] = -41.772028;
      val[393 * nCulm + 2] = 11.549124;
      val[393 * nCulm + 3] = -46.899727;
      val[393 * nCulm + 4] = -42.535719;
      val[393 * nCulm + 5] = 10.097306;
      val[394 * nCulm + 0] = -16.023279;
      val[394 * nCulm + 1] = -17.412236;
      val[394 * nCulm + 2] = -30.547128;
      val[394 * nCulm + 3] = 35.823728;
      val[394 * nCulm + 4] = -31.683171;
      val[394 * nCulm + 5] = -2.520600;
      val[395 * nCulm + 0] = 13.968079;
      val[395 * nCulm + 1] = -39.348584;
      val[395 * nCulm + 2] = -47.751883;
      val[395 * nCulm + 3] = 10.976922;
      val[395 * nCulm + 4] = -0.477018;
      val[395 * nCulm + 5] = 281.755006;
      val[396 * nCulm + 0] = 13.557532;
      val[396 * nCulm + 1] = 21.540879;
      val[396 * nCulm + 2] = 23.295520;
      val[396 * nCulm + 3] = 46.301179;
      val[396 * nCulm + 4] = 45.064939;
      val[396 * nCulm + 5] = 7.355696;
      val[397 * nCulm + 0] = 12.664234;
      val[397 * nCulm + 1] = 12.693059;
      val[397 * nCulm + 2] = 17.690263;
      val[397 * nCulm + 3] = -2.490209;
      val[397 * nCulm + 4] = -46.269527;
      val[397 * nCulm + 5] = -0.813743;
      val[398 * nCulm + 0] = -25.296552;
      val[398 * nCulm + 1] = 17.090846;
      val[398 * nCulm + 2] = 49.472109;
      val[398 * nCulm + 3] = 11.802621;
      val[398 * nCulm + 4] = -26.029189;
      val[398 * nCulm + 5] = -5.024194;
      val[399 * nCulm + 0] = 39.534035;
      val[399 * nCulm + 1] = -27.544027;
      val[399 * nCulm + 2] = 40.270449;
      val[399 * nCulm + 3] = 28.300271;
      val[399 * nCulm + 4] = -4.923829;
      val[399 * nCulm + 5] = -0.496986;
      val[400 * nCulm + 0] = 37.642640;
      val[400 * nCulm + 1] = -41.888010;
      val[400 * nCulm + 2] = -15.953100;
      val[400 * nCulm + 3] = -1.926471;
      val[400 * nCulm + 4] = 28.751531;
      val[400 * nCulm + 5] = -6.983130;
      val[401 * nCulm + 0] = 1.647141;
      val[401 * nCulm + 1] = -14.666067;
      val[401 * nCulm + 2] = -6.182840;
      val[401 * nCulm + 3] = 21.663988;
      val[401 * nCulm + 4] = -22.924149;
      val[401 * nCulm + 5] = -1.214917;
      val[402 * nCulm + 0] = 12.725952;
      val[402 * nCulm + 1] = 9.139888;
      val[402 * nCulm + 2] = 39.435091;
      val[402 * nCulm + 3] = 40.854101;
      val[402 * nCulm + 4] = 21.566322;
      val[402 * nCulm + 5] = 11.202581;
      val[403 * nCulm + 0] = 46.143929;
      val[403 * nCulm + 1] = 29.751338;
      val[403 * nCulm + 2] = -17.864873;
      val[403 * nCulm + 3] = 34.263580;
      val[403 * nCulm + 4] = 49.771025;
      val[403 * nCulm + 5] = 6.317959;
      val[404 * nCulm + 0] = 28.392883;
      val[404 * nCulm + 1] = 32.895050;
      val[404 * nCulm + 2] = 23.846666;
      val[404 * nCulm + 3] = 29.485051;
      val[404 * nCulm + 4] = -12.330722;
      val[404 * nCulm + 5] = -23.715542;
      val[405 * nCulm + 0] = -31.229185;
      val[405 * nCulm + 1] = -5.981037;
      val[405 * nCulm + 2] = -14.768809;
      val[405 * nCulm + 3] = 22.377615;
      val[405 * nCulm + 4] = -40.749687;
      val[405 * nCulm + 5] = -1.674566;
      val[406 * nCulm + 0] = -13.083821;
      val[406 * nCulm + 1] = 39.215851;
      val[406 * nCulm + 2] = -42.609437;
      val[406 * nCulm + 3] = 15.792883;
      val[406 * nCulm + 4] = -2.874385;
      val[406 * nCulm + 5] = -90.354469;
      val[407 * nCulm + 0] = -42.351373;
      val[407 * nCulm + 1] = -45.711009;
      val[407 * nCulm + 2] = -28.793775;
      val[407 * nCulm + 3] = 41.297028;
      val[407 * nCulm + 4] = 12.289023;
      val[407 * nCulm + 5] = -1.470123;
      val[408 * nCulm + 0] = -34.115428;
      val[408 * nCulm + 1] = -6.829246;
      val[408 * nCulm + 2] = 29.462298;
      val[408 * nCulm + 3] = 13.546585;
      val[408 * nCulm + 4] = -20.530551;
      val[408 * nCulm + 5] = -1.318687;
      val[409 * nCulm + 0] = -10.856958;
      val[409 * nCulm + 1] = 47.701870;
      val[409 * nCulm + 2] = -21.584852;
      val[409 * nCulm + 3] = 10.678235;
      val[409 * nCulm + 4] = 29.799976;
      val[409 * nCulm + 5] = 9.502910;
      val[410 * nCulm + 0] = 13.984909;
      val[410 * nCulm + 1] = 11.175129;
      val[410 * nCulm + 2] = 31.084702;
      val[410 * nCulm + 3] = -13.855932;
      val[410 * nCulm + 4] = -3.422970;
      val[410 * nCulm + 5] = 3.937053;
      val[411 * nCulm + 0] = 20.882704;
      val[411 * nCulm + 1] = -17.432956;
      val[411 * nCulm + 2] = 47.652488;
      val[411 * nCulm + 3] = 33.337480;
      val[411 * nCulm + 4] = -22.639860;
      val[411 * nCulm + 5] = -3.095171;
      val[412 * nCulm + 0] = -9.436220;
      val[412 * nCulm + 1] = -45.704007;
      val[412 * nCulm + 2] = 48.046593;
      val[412 * nCulm + 3] = -41.767405;
      val[412 * nCulm + 4] = -33.707121;
      val[412 * nCulm + 5] = 12.513201;
      val[413 * nCulm + 0] = 36.226936;
      val[413 * nCulm + 1] = 36.364364;
      val[413 * nCulm + 2] = 19.255279;
      val[413 * nCulm + 3] = -2.006469;
      val[413 * nCulm + 4] = -49.565817;
      val[413 * nCulm + 5] = -3.051039;
      val[414 * nCulm + 0] = 12.437792;
      val[414 * nCulm + 1] = 38.149495;
      val[414 * nCulm + 2] = -43.901264;
      val[414 * nCulm + 3] = -16.841625;
      val[414 * nCulm + 4] = -8.462406;
      val[414 * nCulm + 5] = -11.688272;
      val[415 * nCulm + 0] = 36.224330;
      val[415 * nCulm + 1] = -17.662708;
      val[415 * nCulm + 2] = 23.893099;
      val[415 * nCulm + 3] = -37.159486;
      val[415 * nCulm + 4] = 7.634872;
      val[415 * nCulm + 5] = -33.757699;
      val[416 * nCulm + 0] = -31.594783;
      val[416 * nCulm + 1] = 17.584087;
      val[416 * nCulm + 2] = 34.273503;
      val[416 * nCulm + 3] = 41.009404;
      val[416 * nCulm + 4] = 7.855828;
      val[416 * nCulm + 5] = 35.534048;
      val[417 * nCulm + 0] = 5.934766;
      val[417 * nCulm + 1] = -11.332017;
      val[417 * nCulm + 2] = 44.605065;
      val[417 * nCulm + 3] = -31.378185;
      val[417 * nCulm + 4] = 41.098657;
      val[417 * nCulm + 5] = -4.688935;
      val[418 * nCulm + 0] = -9.402039;
      val[418 * nCulm + 1] = -7.213078;
      val[418 * nCulm + 2] = 4.418249;
      val[418 * nCulm + 3] = 13.105952;
      val[418 * nCulm + 4] = -17.617161;
      val[418 * nCulm + 5] = -1.353282;
      val[419 * nCulm + 0] = 25.801145;
      val[419 * nCulm + 1] = -44.085858;
      val[419 * nCulm + 2] = -34.799528;
      val[419 * nCulm + 3] = -15.532916;
      val[419 * nCulm + 4] = 28.341090;
      val[419 * nCulm + 5] = -9.727116;
      val[420 * nCulm + 0] = 18.327336;
      val[420 * nCulm + 1] = -45.871714;
      val[420 * nCulm + 2] = 38.517606;
      val[420 * nCulm + 3] = 31.306921;
      val[420 * nCulm + 4] = -18.449525;
      val[420 * nCulm + 5] = 3.966683;
      val[421 * nCulm + 0] = 10.978901;
      val[421 * nCulm + 1] = -46.182447;
      val[421 * nCulm + 2] = 42.293921;
      val[421 * nCulm + 3] = -23.736700;
      val[421 * nCulm + 4] = -12.326957;
      val[421 * nCulm + 5] = 27.077716;
      val[422 * nCulm + 0] = 38.150216;
      val[422 * nCulm + 1] = 31.669645;
      val[422 * nCulm + 2] = 27.154542;
      val[422 * nCulm + 3] = -38.203090;
      val[422 * nCulm + 4] = 13.191029;
      val[422 * nCulm + 5] = -2.114394;
      val[423 * nCulm + 0] = 24.154720;
      val[423 * nCulm + 1] = 22.361742;
      val[423 * nCulm + 2] = 2.712887;
      val[423 * nCulm + 3] = 21.098261;
      val[423 * nCulm + 4] = 6.121481;
      val[423 * nCulm + 5] = 33.834725;
      val[424 * nCulm + 0] = 16.868353;
      val[424 * nCulm + 1] = 7.579116;
      val[424 * nCulm + 2] = -20.270456;
      val[424 * nCulm + 3] = 21.905328;
      val[424 * nCulm + 4] = 16.518465;
      val[424 * nCulm + 5] = 8.678709;
      val[425 * nCulm + 0] = -13.077807;
      val[425 * nCulm + 1] = -32.792175;
      val[425 * nCulm + 2] = -11.668363;
      val[425 * nCulm + 3] = -22.234274;
      val[425 * nCulm + 4] = 8.905037;
      val[425 * nCulm + 5] = -29.018450;
      val[426 * nCulm + 0] = 45.311311;
      val[426 * nCulm + 1] = -45.679495;
      val[426 * nCulm + 2] = 28.232306;
      val[426 * nCulm + 3] = -32.343089;
      val[426 * nCulm + 4] = 41.113054;
      val[426 * nCulm + 5] = -8.752716;
      val[427 * nCulm + 0] = -2.353576;
      val[427 * nCulm + 1] = -49.502867;
      val[427 * nCulm + 2] = -29.240270;
      val[427 * nCulm + 3] = 49.265759;
      val[427 * nCulm + 4] = -44.275626;
      val[427 * nCulm + 5] = 0.255348;
      val[428 * nCulm + 0] = -34.466684;
      val[428 * nCulm + 1] = 5.629261;
      val[428 * nCulm + 2] = 47.179924;
      val[428 * nCulm + 3] = -28.358249;
      val[428 * nCulm + 4] = 2.472351;
      val[428 * nCulm + 5] = -43.284814;
      val[429 * nCulm + 0] = -30.245062;
      val[429 * nCulm + 1] = 32.238289;
      val[429 * nCulm + 2] = -22.722007;
      val[429 * nCulm + 3] = 27.691515;
      val[429 * nCulm + 4] = -5.601289;
      val[429 * nCulm + 5] = -50.413298;
      val[430 * nCulm + 0] = 26.662604;
      val[430 * nCulm + 1] = -22.293680;
      val[430 * nCulm + 2] = 10.496682;
      val[430 * nCulm + 3] = 34.181418;
      val[430 * nCulm + 4] = 14.672185;
      val[430 * nCulm + 5] = 4.065054;
      val[431 * nCulm + 0] = 49.263416;
      val[431 * nCulm + 1] = 49.237446;
      val[431 * nCulm + 2] = 29.717575;
      val[431 * nCulm + 3] = 5.834744;
      val[431 * nCulm + 4] = -20.550001;
      val[431 * nCulm + 5] = -12.454916;
      val[432 * nCulm + 0] = 32.401687;
      val[432 * nCulm + 1] = -14.286553;
      val[432 * nCulm + 2] = -24.378337;
      val[432 * nCulm + 3] = 43.073325;
      val[432 * nCulm + 4] = -30.005475;
      val[432 * nCulm + 5] = -4.311084;
      val[433 * nCulm + 0] = 1.483177;
      val[433 * nCulm + 1] = -22.755090;
      val[433 * nCulm + 2] = -7.586445;
      val[433 * nCulm + 3] = -38.673323;
      val[433 * nCulm + 4] = -28.702452;
      val[433 * nCulm + 5] = 10.360185;
      val[434 * nCulm + 0] = 8.803692;
      val[434 * nCulm + 1] = 23.357891;
      val[434 * nCulm + 2] = -48.016242;
      val[434 * nCulm + 3] = -22.345705;
      val[434 * nCulm + 4] = -20.463321;
      val[434 * nCulm + 5] = -0.004127;
      val[435 * nCulm + 0] = -5.567998;
      val[435 * nCulm + 1] = 15.678959;
      val[435 * nCulm + 2] = -35.570133;
      val[435 * nCulm + 3] = 24.252756;
      val[435 * nCulm + 4] = 20.376047;
      val[435 * nCulm + 5] = 9.506094;
      val[436 * nCulm + 0] = 25.953252;
      val[436 * nCulm + 1] = -4.118454;
      val[436 * nCulm + 2] = -32.216914;
      val[436 * nCulm + 3] = -47.606009;
      val[436 * nCulm + 4] = 13.509931;
      val[436 * nCulm + 5] = -17.892159;
      val[437 * nCulm + 0] = 32.654350;
      val[437 * nCulm + 1] = -38.012972;
      val[437 * nCulm + 2] = 16.200535;
      val[437 * nCulm + 3] = 10.994330;
      val[437 * nCulm + 4] = -47.284324;
      val[437 * nCulm + 5] = 2.934665;
      val[438 * nCulm + 0] = -16.679267;
      val[438 * nCulm + 1] = 38.680929;
      val[438 * nCulm + 2] = -1.291991;
      val[438 * nCulm + 3] = -23.017754;
      val[438 * nCulm + 4] = 43.995069;
      val[438 * nCulm + 5] = 1.915167;
      val[439 * nCulm + 0] = 0.374771;
      val[439 * nCulm + 1] = 48.944746;
      val[439 * nCulm + 2] = -0.269527;
      val[439 * nCulm + 3] = 20.192703;
      val[439 * nCulm + 4] = -47.833779;
      val[439 * nCulm + 5] = -6.611412;
      val[440 * nCulm + 0] = 10.411358;
      val[440 * nCulm + 1] = 12.464942;
      val[440 * nCulm + 2] = -25.427580;
      val[440 * nCulm + 3] = 7.415057;
      val[440 * nCulm + 4] = 2.465432;
      val[440 * nCulm + 5] = 38.397202;
      val[441 * nCulm + 0] = 20.409602;
      val[441 * nCulm + 1] = -49.298019;
      val[441 * nCulm + 2] = 43.928446;
      val[441 * nCulm + 3] = 5.295687;
      val[441 * nCulm + 4] = 32.473669;
      val[441 * nCulm + 5] = -6.183741;
      val[442 * nCulm + 0] = 43.854384;
      val[442 * nCulm + 1] = 20.712713;
      val[442 * nCulm + 2] = 14.386806;
      val[442 * nCulm + 3] = -16.958584;
      val[442 * nCulm + 4] = -45.295919;
      val[442 * nCulm + 5] = -0.162299;
      val[443 * nCulm + 0] = 30.838889;
      val[443 * nCulm + 1] = -40.232018;
      val[443 * nCulm + 2] = -0.938085;
      val[443 * nCulm + 3] = -43.317369;
      val[443 * nCulm + 4] = -45.944262;
      val[443 * nCulm + 5] = 8.837541;
      val[444 * nCulm + 0] = 26.905072;
      val[444 * nCulm + 1] = -46.212552;
      val[444 * nCulm + 2] = 42.882220;
      val[444 * nCulm + 3] = 13.338415;
      val[444 * nCulm + 4] = 36.199749;
      val[444 * nCulm + 5] = -4.068490;
      val[445 * nCulm + 0] = -8.079051;
      val[445 * nCulm + 1] = -38.702940;
      val[445 * nCulm + 2] = -27.917890;
      val[445 * nCulm + 3] = 4.585247;
      val[445 * nCulm + 4] = 3.087636;
      val[445 * nCulm + 5] = -52.072275;
      val[446 * nCulm + 0] = -22.121870;
      val[446 * nCulm + 1] = -9.293773;
      val[446 * nCulm + 2] = -8.622371;
      val[446 * nCulm + 3] = 37.634874;
      val[446 * nCulm + 4] = 29.413530;
      val[446 * nCulm + 5] = 4.790754;
      val[447 * nCulm + 0] = -38.265504;
      val[447 * nCulm + 1] = 42.830260;
      val[447 * nCulm + 2] = 17.097393;
      val[447 * nCulm + 3] = -34.688464;
      val[447 * nCulm + 4] = -35.993217;
      val[447 * nCulm + 5] = -0.840697;
      val[448 * nCulm + 0] = 5.021401;
      val[448 * nCulm + 1] = -41.968750;
      val[448 * nCulm + 2] = -22.836475;
      val[448 * nCulm + 3] = -16.560942;
      val[448 * nCulm + 4] = 38.699767;
      val[448 * nCulm + 5] = -6.928714;
      val[449 * nCulm + 0] = 30.564933;
      val[449 * nCulm + 1] = 22.620754;
      val[449 * nCulm + 2] = -24.439974;
      val[449 * nCulm + 3] = -47.584611;
      val[449 * nCulm + 4] = 5.391647;
      val[449 * nCulm + 5] = -21.685799;
      val[450 * nCulm + 0] = -42.741159;
      val[450 * nCulm + 1] = 2.422718;
      val[450 * nCulm + 2] = 14.317912;
      val[450 * nCulm + 3] = 11.273591;
      val[450 * nCulm + 4] = 36.453400;
      val[450 * nCulm + 5] = 2.008413;
      val[451 * nCulm + 0] = -7.977571;
      val[451 * nCulm + 1] = 9.773275;
      val[451 * nCulm + 2] = 11.619415;
      val[451 * nCulm + 3] = 27.800479;
      val[451 * nCulm + 4] = -19.662153;
      val[451 * nCulm + 5] = -8.815251;
      val[452 * nCulm + 0] = 12.866322;
      val[452 * nCulm + 1] = 18.278449;
      val[452 * nCulm + 2] = 2.541752;
      val[452 * nCulm + 3] = -43.432721;
      val[452 * nCulm + 4] = -41.322044;
      val[452 * nCulm + 5] = 3.111357;
      val[453 * nCulm + 0] = 27.353939;
      val[453 * nCulm + 1] = 1.401357;
      val[453 * nCulm + 2] = -47.717539;
      val[453 * nCulm + 3] = -29.785514;
      val[453 * nCulm + 4] = -11.081283;
      val[453 * nCulm + 5] = 12.354198;
      val[454 * nCulm + 0] = 10.761286;
      val[454 * nCulm + 1] = -28.632085;
      val[454 * nCulm + 2] = 49.876020;
      val[454 * nCulm + 3] = 19.678186;
      val[454 * nCulm + 4] = 45.298087;
      val[454 * nCulm + 5] = -0.705620;
      val[455 * nCulm + 0] = -33.448264;
      val[455 * nCulm + 1] = 0.571788;
      val[455 * nCulm + 2] = 24.052037;
      val[455 * nCulm + 3] = 18.330902;
      val[455 * nCulm + 4] = -22.197342;
      val[455 * nCulm + 5] = -3.800786;
      val[456 * nCulm + 0] = -6.919171;
      val[456 * nCulm + 1] = 10.684364;
      val[456 * nCulm + 2] = 16.448804;
      val[456 * nCulm + 3] = 14.313034;
      val[456 * nCulm + 4] = -37.171140;
      val[456 * nCulm + 5] = -2.953142;
      val[457 * nCulm + 0] = 15.185095;
      val[457 * nCulm + 1] = -36.247508;
      val[457 * nCulm + 2] = -27.212847;
      val[457 * nCulm + 3] = 22.889271;
      val[457 * nCulm + 4] = -19.772948;
      val[457 * nCulm + 5] = 3.427752;
      val[458 * nCulm + 0] = -19.778257;
      val[458 * nCulm + 1] = 18.538869;
      val[458 * nCulm + 2] = 34.444992;
      val[458 * nCulm + 3] = 42.536258;
      val[458 * nCulm + 4] = -23.191365;
      val[458 * nCulm + 5] = -12.235370;
      val[459 * nCulm + 0] = 17.308717;
      val[459 * nCulm + 1] = 10.668544;
      val[459 * nCulm + 2] = -40.714483;
      val[459 * nCulm + 3] = -39.389803;
      val[459 * nCulm + 4] = -1.414639;
      val[459 * nCulm + 5] = 96.330356;
      val[460 * nCulm + 0] = 3.195156;
      val[460 * nCulm + 1] = -1.164179;
      val[460 * nCulm + 2] = -7.855851;
      val[460 * nCulm + 3] = -49.567417;
      val[460 * nCulm + 4] = 27.660126;
      val[460 * nCulm + 5] = -8.451434;
      val[461 * nCulm + 0] = -7.245047;
      val[461 * nCulm + 1] = 49.360397;
      val[461 * nCulm + 2] = -3.040752;
      val[461 * nCulm + 3] = -27.382629;
      val[461 * nCulm + 4] = 36.566189;
      val[461 * nCulm + 5] = 3.074926;
      val[462 * nCulm + 0] = 40.755142;
      val[462 * nCulm + 1] = -24.437080;
      val[462 * nCulm + 2] = -3.118026;
      val[462 * nCulm + 3] = 13.981609;
      val[462 * nCulm + 4] = 30.564312;
      val[462 * nCulm + 5] = -1.389183;
      val[463 * nCulm + 0] = 46.013163;
      val[463 * nCulm + 1] = 46.053582;
      val[463 * nCulm + 2] = 42.721163;
      val[463 * nCulm + 3] = -26.576255;
      val[463 * nCulm + 4] = 48.487522;
      val[463 * nCulm + 5] = 2.131369;
      val[464 * nCulm + 0] = -31.472066;
      val[464 * nCulm + 1] = 3.902999;
      val[464 * nCulm + 2] = 35.113329;
      val[464 * nCulm + 3] = -7.940067;
      val[464 * nCulm + 4] = -42.834466;
      val[464 * nCulm + 5] = 0.676108;
      val[465 * nCulm + 0] = -1.085725;
      val[465 * nCulm + 1] = 40.738664;
      val[465 * nCulm + 2] = -0.989071;
      val[465 * nCulm + 3] = 40.876853;
      val[465 * nCulm + 4] = 31.514569;
      val[465 * nCulm + 5] = 12.488249;
      val[466 * nCulm + 0] = -3.995586;
      val[466 * nCulm + 1] = 35.795382;
      val[466 * nCulm + 2] = 18.054987;
      val[466 * nCulm + 3] = -31.402351;
      val[466 * nCulm + 4] = -33.567981;
      val[466 * nCulm + 5] = -0.389450;
      val[467 * nCulm + 0] = -19.822920;
      val[467 * nCulm + 1] = 35.342413;
      val[467 * nCulm + 2] = -47.823385;
      val[467 * nCulm + 3] = -14.011685;
      val[467 * nCulm + 4] = 43.870783;
      val[467 * nCulm + 5] = 2.531428;
      val[468 * nCulm + 0] = 32.762806;
      val[468 * nCulm + 1] = -47.142847;
      val[468 * nCulm + 2] = 12.719354;
      val[468 * nCulm + 3] = 42.564460;
      val[468 * nCulm + 4] = 38.074819;
      val[468 * nCulm + 5] = -0.339170;
      val[469 * nCulm + 0] = 43.717617;
      val[469 * nCulm + 1] = -10.404850;
      val[469 * nCulm + 2] = -29.594559;
      val[469 * nCulm + 3] = -24.307841;
      val[469 * nCulm + 4] = 36.721026;
      val[469 * nCulm + 5] = -4.244459;
      val[470 * nCulm + 0] = -32.308667;
      val[470 * nCulm + 1] = -37.012657;
      val[470 * nCulm + 2] = -15.112714;
      val[470 * nCulm + 3] = 6.690037;
      val[470 * nCulm + 4] = 39.659438;
      val[470 * nCulm + 5] = -3.388989;
      val[471 * nCulm + 0] = -9.011591;
      val[471 * nCulm + 1] = 45.007360;
      val[471 * nCulm + 2] = -41.183435;
      val[471 * nCulm + 3] = 0.862117;
      val[471 * nCulm + 4] = 36.618377;
      val[471 * nCulm + 5] = 6.159141;
      val[472 * nCulm + 0] = 38.665581;
      val[472 * nCulm + 1] = -32.311316;
      val[472 * nCulm + 2] = 17.435639;
      val[472 * nCulm + 3] = -40.594147;
      val[472 * nCulm + 4] = -30.235627;
      val[472 * nCulm + 5] = 11.643220;
      val[473 * nCulm + 0] = 38.775477;
      val[473 * nCulm + 1] = 47.145217;
      val[473 * nCulm + 2] = 25.570504;
      val[473 * nCulm + 3] = 22.535049;
      val[473 * nCulm + 4] = -3.337558;
      val[473 * nCulm + 5] = -98.590723;
      val[474 * nCulm + 0] = 47.112467;
      val[474 * nCulm + 1] = -47.461208;
      val[474 * nCulm + 2] = 2.332619;
      val[474 * nCulm + 3] = 4.620657;
      val[474 * nCulm + 4] = 5.713203;
      val[474 * nCulm + 5] = -35.262982;
      val[475 * nCulm + 0] = -4.844292;
      val[475 * nCulm + 1] = -14.782705;
      val[475 * nCulm + 2] = 45.718344;
      val[475 * nCulm + 3] = 13.119604;
      val[475 * nCulm + 4] = -20.817026;
      val[475 * nCulm + 5] = 0.608153;
      val[476 * nCulm + 0] = -7.250462;
      val[476 * nCulm + 1] = 1.167082;
      val[476 * nCulm + 2] = 48.362909;
      val[476 * nCulm + 3] = 29.390849;
      val[476 * nCulm + 4] = 22.523349;
      val[476 * nCulm + 5] = 6.651819;
      val[477 * nCulm + 0] = 32.047579;
      val[477 * nCulm + 1] = -13.776425;
      val[477 * nCulm + 2] = -42.780349;
      val[477 * nCulm + 3] = 13.407682;
      val[477 * nCulm + 4] = 41.251006;
      val[477 * nCulm + 5] = 0.187689;
      val[478 * nCulm + 0] = -8.652571;
      val[478 * nCulm + 1] = -27.716639;
      val[478 * nCulm + 2] = 17.749998;
      val[478 * nCulm + 3] = -27.988861;
      val[478 * nCulm + 4] = -12.006279;
      val[478 * nCulm + 5] = 22.191233;
      val[479 * nCulm + 0] = 2.273395;
      val[479 * nCulm + 1] = -15.243535;
      val[479 * nCulm + 2] = -38.734594;
      val[479 * nCulm + 3] = 21.954121;
      val[479 * nCulm + 4] = -33.004139;
      val[479 * nCulm + 5] = -0.732408;
      val[480 * nCulm + 0] = 35.592442;
      val[480 * nCulm + 1] = -19.801353;
      val[480 * nCulm + 2] = -30.625924;
      val[480 * nCulm + 3] = 20.904005;
      val[480 * nCulm + 4] = -1.958371;
      val[480 * nCulm + 5] = -2.435081;
      val[481 * nCulm + 0] = 24.496873;
      val[481 * nCulm + 1] = -23.485271;
      val[481 * nCulm + 2] = 23.737137;
      val[481 * nCulm + 3] = 18.825676;
      val[481 * nCulm + 4] = -9.097762;
      val[481 * nCulm + 5] = 2.654268;
      val[482 * nCulm + 0] = -39.323062;
      val[482 * nCulm + 1] = -48.245449;
      val[482 * nCulm + 2] = -22.887001;
      val[482 * nCulm + 3] = -43.273164;
      val[482 * nCulm + 4] = -23.264854;
      val[482 * nCulm + 5] = 18.849850;
      val[483 * nCulm + 0] = 44.895857;
      val[483 * nCulm + 1] = 48.210888;
      val[483 * nCulm + 2] = -25.169217;
      val[483 * nCulm + 3] = -18.567151;
      val[483 * nCulm + 4] = 14.985239;
      val[483 * nCulm + 5] = 9.593460;
      val[484 * nCulm + 0] = 5.695909;
      val[484 * nCulm + 1] = -31.096204;
      val[484 * nCulm + 2] = -1.339624;
      val[484 * nCulm + 3] = -17.910253;
      val[484 * nCulm + 4] = 23.768983;
      val[484 * nCulm + 5] = -9.529101;
      val[485 * nCulm + 0] = 2.549382;
      val[485 * nCulm + 1] = 33.205652;
      val[485 * nCulm + 2] = 18.937511;
      val[485 * nCulm + 3] = -6.338266;
      val[485 * nCulm + 4] = 30.071141;
      val[485 * nCulm + 5] = 4.459048;
      val[486 * nCulm + 0] = -49.090456;
      val[486 * nCulm + 1] = -41.993657;
      val[486 * nCulm + 2] = 20.051406;
      val[486 * nCulm + 3] = -10.423468;
      val[486 * nCulm + 4] = 24.781727;
      val[486 * nCulm + 5] = -9.781721;
      val[487 * nCulm + 0] = 22.943025;
      val[487 * nCulm + 1] = 29.284722;
      val[487 * nCulm + 2] = 34.309223;
      val[487 * nCulm + 3] = -13.484836;
      val[487 * nCulm + 4] = -37.516252;
      val[487 * nCulm + 5] = -1.763433;
      val[488 * nCulm + 0] = -42.678634;
      val[488 * nCulm + 1] = 15.940386;
      val[488 * nCulm + 2] = 0.521505;
      val[488 * nCulm + 3] = -13.911082;
      val[488 * nCulm + 4] = -24.834581;
      val[488 * nCulm + 5] = -0.156774;
      val[489 * nCulm + 0] = 32.724336;
      val[489 * nCulm + 1] = 31.408467;
      val[489 * nCulm + 2] = 6.003756;
      val[489 * nCulm + 3] = 23.778495;
      val[489 * nCulm + 4] = -13.786532;
      val[489 * nCulm + 5] = -18.717353;
      val[490 * nCulm + 0] = -49.714829;
      val[490 * nCulm + 1] = 46.848975;
      val[490 * nCulm + 2] = 30.308812;
      val[490 * nCulm + 3] = -47.774824;
      val[490 * nCulm + 4] = -25.018241;
      val[490 * nCulm + 5] = 0.405166;
      val[491 * nCulm + 0] = -4.183584;
      val[491 * nCulm + 1] = 27.017197;
      val[491 * nCulm + 2] = -30.627127;
      val[491 * nCulm + 3] = -26.346057;
      val[491 * nCulm + 4] = -39.591432;
      val[491 * nCulm + 5] = 0.149762;
      val[492 * nCulm + 0] = 13.843139;
      val[492 * nCulm + 1] = 22.575428;
      val[492 * nCulm + 2] = -27.447492;
      val[492 * nCulm + 3] = -11.596849;
      val[492 * nCulm + 4] = 17.001740;
      val[492 * nCulm + 5] = 3.286468;
      val[493 * nCulm + 0] = -8.216378;
      val[493 * nCulm + 1] = 47.917151;
      val[493 * nCulm + 2] = 35.443915;
      val[493 * nCulm + 3] = 47.595498;
      val[493 * nCulm + 4] = 38.290933;
      val[493 * nCulm + 5] = 12.036795;
      val[494 * nCulm + 0] = -40.666925;
      val[494 * nCulm + 1] = 33.797109;
      val[494 * nCulm + 2] = 11.661781;
      val[494 * nCulm + 3] = 8.580168;
      val[494 * nCulm + 4] = 43.259425;
      val[494 * nCulm + 5] = 4.866811;
      val[495 * nCulm + 0] = 28.581186;
      val[495 * nCulm + 1] = 5.948098;
      val[495 * nCulm + 2] = -49.117432;
      val[495 * nCulm + 3] = -43.949232;
      val[495 * nCulm + 4] = -21.809682;
      val[495 * nCulm + 5] = 8.477348;
      val[496 * nCulm + 0] = -30.513813;
      val[496 * nCulm + 1] = -9.003258;
      val[496 * nCulm + 2] = 18.008067;
      val[496 * nCulm + 3] = -23.253890;
      val[496 * nCulm + 4] = -31.936195;
      val[496 * nCulm + 5] = 5.010902;
      val[497 * nCulm + 0] = -49.881149;
      val[497 * nCulm + 1] = -6.906307;
      val[497 * nCulm + 2] = -36.365803;
      val[497 * nCulm + 3] = -19.333601;
      val[497 * nCulm + 4] = -12.566632;
      val[497 * nCulm + 5] = 10.113494;
      val[498 * nCulm + 0] = 8.456555;
      val[498 * nCulm + 1] = -1.942146;
      val[498 * nCulm + 2] = 31.670896;
      val[498 * nCulm + 3] = -45.426666;
      val[498 * nCulm + 4] = 25.886009;
      val[498 * nCulm + 5] = -8.431527;
      val[499 * nCulm + 0] = -33.399665;
      val[499 * nCulm + 1] = 37.101858;
      val[499 * nCulm + 2] = -46.869503;
      val[499 * nCulm + 3] = 27.559308;
      val[499 * nCulm + 4] = -44.789336;
      val[499 * nCulm + 5] = -6.603387;
      val[500 * nCulm + 0] = -15.848049;
      val[500 * nCulm + 1] = 2.908859;
      val[500 * nCulm + 2] = 28.399526;
      val[500 * nCulm + 3] = 45.008972;
      val[500 * nCulm + 4] = 32.568614;
      val[500 * nCulm + 5] = 7.194100;
      val[501 * nCulm + 0] = -41.215973;
      val[501 * nCulm + 1] = -32.373265;
      val[501 * nCulm + 2] = 8.235515;
      val[501 * nCulm + 3] = -17.830544;
      val[501 * nCulm + 4] = -30.964346;
      val[501 * nCulm + 5] = 7.904354;
      val[502 * nCulm + 0] = -21.056543;
      val[502 * nCulm + 1] = -20.425345;
      val[502 * nCulm + 2] = -21.314695;
      val[502 * nCulm + 3] = -14.271426;
      val[502 * nCulm + 4] = 49.509340;
      val[502 * nCulm + 5] = -3.087180;
      val[503 * nCulm + 0] = 39.661160;
      val[503 * nCulm + 1] = 40.695702;
      val[503 * nCulm + 2] = -30.240180;
      val[503 * nCulm + 3] = -25.150320;
      val[503 * nCulm + 4] = -10.398701;
      val[503 * nCulm + 5] = -6.846025;
      val[504 * nCulm + 0] = -5.502985;
      val[504 * nCulm + 1] = -25.815633;
      val[504 * nCulm + 2] = 6.903734;
      val[504 * nCulm + 3] = -33.253482;
      val[504 * nCulm + 4] = -45.519070;
      val[504 * nCulm + 5] = 6.372345;
      val[505 * nCulm + 0] = 48.545288;
      val[505 * nCulm + 1] = -20.839605;
      val[505 * nCulm + 2] = 20.124559;
      val[505 * nCulm + 3] = 49.886950;
      val[505 * nCulm + 4] = -9.949050;
      val[505 * nCulm + 5] = -13.589487;
      val[506 * nCulm + 0] = -11.690628;
      val[506 * nCulm + 1] = 30.248906;
      val[506 * nCulm + 2] = 26.148459;
      val[506 * nCulm + 3] = 27.173097;
      val[506 * nCulm + 4] = 46.255747;
      val[506 * nCulm + 5] = 6.105972;
      val[507 * nCulm + 0] = -11.358074;
      val[507 * nCulm + 1] = 28.994162;
      val[507 * nCulm + 2] = 41.114177;
      val[507 * nCulm + 3] = 20.487705;
      val[507 * nCulm + 4] = 5.909246;
      val[507 * nCulm + 5] = 39.865206;
      val[508 * nCulm + 0] = 13.446244;
      val[508 * nCulm + 1] = 13.093919;
      val[508 * nCulm + 2] = -5.623901;
      val[508 * nCulm + 3] = -1.299951;
      val[508 * nCulm + 4] = 22.337666;
      val[508 * nCulm + 5] = 2.729132;
      val[509 * nCulm + 0] = -40.828624;
      val[509 * nCulm + 1] = -18.088410;
      val[509 * nCulm + 2] = 22.554763;
      val[509 * nCulm + 3] = 28.932425;
      val[509 * nCulm + 4] = 27.522497;
      val[509 * nCulm + 5] = 2.094959;
      val[510 * nCulm + 0] = 25.512120;
      val[510 * nCulm + 1] = 42.045103;
      val[510 * nCulm + 2] = -25.074839;
      val[510 * nCulm + 3] = -29.839606;
      val[510 * nCulm + 4] = 49.415553;
      val[510 * nCulm + 5] = 1.399119;
      val[511 * nCulm + 0] = 39.994821;
      val[511 * nCulm + 1] = -49.626090;
      val[511 * nCulm + 2] = 29.746893;
      val[511 * nCulm + 3] = -14.384037;
      val[511 * nCulm + 4] = -27.695277;
      val[511 * nCulm + 5] = 11.169817;
      val[512 * nCulm + 0] = -24.773032;
      val[512 * nCulm + 1] = 39.750318;
      val[512 * nCulm + 2] = 6.999094;
      val[512 * nCulm + 3] = -34.089169;
      val[512 * nCulm + 4] = -7.256369;
      val[512 * nCulm + 5] = -3.462771;
      val[513 * nCulm + 0] = 45.400475;
      val[513 * nCulm + 1] = 17.605074;
      val[513 * nCulm + 2] = 17.653798;
      val[513 * nCulm + 3] = 37.191047;
      val[513 * nCulm + 4] = -24.708053;
      val[513 * nCulm + 5] = -10.267319;
      val[514 * nCulm + 0] = 6.343615;
      val[514 * nCulm + 1] = 37.458311;
      val[514 * nCulm + 2] = -44.019096;
      val[514 * nCulm + 3] = 11.423129;
      val[514 * nCulm + 4] = -39.615055;
      val[514 * nCulm + 5] = -5.610511;
      val[515 * nCulm + 0] = -4.755578;
      val[515 * nCulm + 1] = -42.103136;
      val[515 * nCulm + 2] = -38.363153;
      val[515 * nCulm + 3] = 25.342717;
      val[515 * nCulm + 4] = -31.186731;
      val[515 * nCulm + 5] = 2.773795;
      val[516 * nCulm + 0] = -17.217024;
      val[516 * nCulm + 1] = -9.065800;
      val[516 * nCulm + 2] = 0.534267;
      val[516 * nCulm + 3] = -48.593442;
      val[516 * nCulm + 4] = -22.188962;
      val[516 * nCulm + 5] = 12.529828;
      val[517 * nCulm + 0] = -42.141104;
      val[517 * nCulm + 1] = -36.495409;
      val[517 * nCulm + 2] = -5.878156;
      val[517 * nCulm + 3] = 17.554042;
      val[517 * nCulm + 4] = 19.349102;
      val[517 * nCulm + 5] = -4.403590;
      val[518 * nCulm + 0] = 39.022342;
      val[518 * nCulm + 1] = -31.511316;
      val[518 * nCulm + 2] = 11.151756;
      val[518 * nCulm + 3] = 31.220992;
      val[518 * nCulm + 4] = -28.406738;
      val[518 * nCulm + 5] = 0.278376;
      val[519 * nCulm + 0] = -17.376880;
      val[519 * nCulm + 1] = -4.209594;
      val[519 * nCulm + 2] = -18.131018;
      val[519 * nCulm + 3] = -33.994879;
      val[519 * nCulm + 4] = 40.210773;
      val[519 * nCulm + 5] = -4.267166;
      val[520 * nCulm + 0] = -39.186450;
      val[520 * nCulm + 1] = -35.152336;
      val[520 * nCulm + 2] = 21.048604;
      val[520 * nCulm + 3] = 18.460386;
      val[520 * nCulm + 4] = 26.065831;
      val[520 * nCulm + 5] = -2.801116;
      val[521 * nCulm + 0] = -3.644742;
      val[521 * nCulm + 1] = 13.673820;
      val[521 * nCulm + 2] = -45.925341;
      val[521 * nCulm + 3] = -11.710930;
      val[521 * nCulm + 4] = -30.610686;
      val[521 * nCulm + 5] = -0.073522;
      val[522 * nCulm + 0] = 0.250144;
      val[522 * nCulm + 1] = -35.260155;
      val[522 * nCulm + 2] = -4.482076;
      val[522 * nCulm + 3] = -31.903261;
      val[522 * nCulm + 4] = -3.325688;
      val[522 * nCulm + 5] = 95.821300;
      val[523 * nCulm + 0] = -15.616658;
      val[523 * nCulm + 1] = -30.359689;
      val[523 * nCulm + 2] = 0.800772;
      val[523 * nCulm + 3] = 2.857505;
      val[523 * nCulm + 4] = -20.969759;
      val[523 * nCulm + 5] = 6.437845;
      val[524 * nCulm + 0] = -38.740457;
      val[524 * nCulm + 1] = 47.258482;
      val[524 * nCulm + 2] = 32.864956;
      val[524 * nCulm + 3] = 47.442671;
      val[524 * nCulm + 4] = -4.877530;
      val[524 * nCulm + 5] = -91.671465;
      val[525 * nCulm + 0] = -30.849134;
      val[525 * nCulm + 1] = 6.461062;
      val[525 * nCulm + 2] = 18.052321;
      val[525 * nCulm + 3] = -26.116541;
      val[525 * nCulm + 4] = 18.854025;
      val[525 * nCulm + 5] = -4.704540;
      val[526 * nCulm + 0] = 38.301616;
      val[526 * nCulm + 1] = 38.531395;
      val[526 * nCulm + 2] = -44.610809;
      val[526 * nCulm + 3] = -17.315456;
      val[526 * nCulm + 4] = 2.919875;
      val[526 * nCulm + 5] = 34.622603;
      val[527 * nCulm + 0] = -10.186746;
      val[527 * nCulm + 1] = -31.343834;
      val[527 * nCulm + 2] = 6.680552;
      val[527 * nCulm + 3] = 27.991328;
      val[527 * nCulm + 4] = -45.464220;
      val[527 * nCulm + 5] = 0.579033;
      val[528 * nCulm + 0] = -8.636613;
      val[528 * nCulm + 1] = -30.339337;
      val[528 * nCulm + 2] = 4.311068;
      val[528 * nCulm + 3] = -48.598542;
      val[528 * nCulm + 4] = -26.254983;
      val[528 * nCulm + 5] = 14.461176;
      val[529 * nCulm + 0] = -6.370354;
      val[529 * nCulm + 1] = -33.090320;
      val[529 * nCulm + 2] = 21.597775;
      val[529 * nCulm + 3] = 38.326461;
      val[529 * nCulm + 4] = -35.320407;
      val[529 * nCulm + 5] = -0.471702;
      val[530 * nCulm + 0] = 9.264929;
      val[530 * nCulm + 1] = 42.589053;
      val[530 * nCulm + 2] = 18.326017;
      val[530 * nCulm + 3] = -9.548592;
      val[530 * nCulm + 4] = 29.582229;
      val[530 * nCulm + 5] = 5.516671;
      val[531 * nCulm + 0] = 9.041143;
      val[531 * nCulm + 1] = 9.190825;
      val[531 * nCulm + 2] = -13.491743;
      val[531 * nCulm + 3] = -6.777292;
      val[531 * nCulm + 4] = -32.691723;
      val[531 * nCulm + 5] = -0.119448;
      val[532 * nCulm + 0] = -6.636281;
      val[532 * nCulm + 1] = -40.015288;
      val[532 * nCulm + 2] = 12.133710;
      val[532 * nCulm + 3] = 23.914473;
      val[532 * nCulm + 4] = -30.064150;
      val[532 * nCulm + 5] = 2.764930;
      val[533 * nCulm + 0] = 1.087478;
      val[533 * nCulm + 1] = -0.628721;
      val[533 * nCulm + 2] = 28.557501;
      val[533 * nCulm + 3] = 6.569388;
      val[533 * nCulm + 4] = -17.196942;
      val[533 * nCulm + 5] = -1.405125;
      val[534 * nCulm + 0] = -30.501999;
      val[534 * nCulm + 1] = 38.247000;
      val[534 * nCulm + 2] = -46.777203;
      val[534 * nCulm + 3] = 21.956805;
      val[534 * nCulm + 4] = 49.453926;
      val[534 * nCulm + 5] = 5.992226;
      val[535 * nCulm + 0] = 17.367607;
      val[535 * nCulm + 1] = 21.338188;
      val[535 * nCulm + 2] = -39.520579;
      val[535 * nCulm + 3] = 12.646369;
      val[535 * nCulm + 4] = -17.386535;
      val[535 * nCulm + 5] = -9.022001;
      val[536 * nCulm + 0] = -43.104488;
      val[536 * nCulm + 1] = -39.636729;
      val[536 * nCulm + 2] = -22.873433;
      val[536 * nCulm + 3] = -6.985769;
      val[536 * nCulm + 4] = 25.647651;
      val[536 * nCulm + 5] = -8.374290;
      val[537 * nCulm + 0] = -10.046487;
      val[537 * nCulm + 1] = 14.361708;
      val[537 * nCulm + 2] = -4.859637;
      val[537 * nCulm + 3] = 12.479943;
      val[537 * nCulm + 4] = 32.484391;
      val[537 * nCulm + 5] = 4.141124;
      val[538 * nCulm + 0] = -34.159813;
      val[538 * nCulm + 1] = 39.288677;
      val[538 * nCulm + 2] = -29.079996;
      val[538 * nCulm + 3] = 44.363892;
      val[538 * nCulm + 4] = -36.491139;
      val[538 * nCulm + 5] = -10.620730;
      val[539 * nCulm + 0] = 17.282191;
      val[539 * nCulm + 1] = -26.811596;
      val[539 * nCulm + 2] = -35.633056;
      val[539 * nCulm + 3] = 45.336303;
      val[539 * nCulm + 4] = -12.376100;
      val[539 * nCulm + 5] = -6.854915;
      val[540 * nCulm + 0] = -17.956537;
      val[540 * nCulm + 1] = 26.044572;
      val[540 * nCulm + 2] = 5.872286;
      val[540 * nCulm + 3] = -43.176314;
      val[540 * nCulm + 4] = -26.793185;
      val[540 * nCulm + 5] = 3.256525;
      val[541 * nCulm + 0] = -45.481510;
      val[541 * nCulm + 1] = -32.082378;
      val[541 * nCulm + 2] = -6.890937;
      val[541 * nCulm + 3] = 27.071312;
      val[541 * nCulm + 4] = 17.802328;
      val[541 * nCulm + 5] = -1.102356;
      val[542 * nCulm + 0] = 15.616143;
      val[542 * nCulm + 1] = 18.065638;
      val[542 * nCulm + 2] = 23.462649;
      val[542 * nCulm + 3] = -38.861081;
      val[542 * nCulm + 4] = 8.234307;
      val[542 * nCulm + 5] = -11.723860;
      val[543 * nCulm + 0] = 26.784805;
      val[543 * nCulm + 1] = 23.761961;
      val[543 * nCulm + 2] = -36.684365;
      val[543 * nCulm + 3] = 14.393981;
      val[543 * nCulm + 4] = 8.563009;
      val[543 * nCulm + 5] = 21.321277;
      val[544 * nCulm + 0] = 17.800666;
      val[544 * nCulm + 1] = -13.030476;
      val[544 * nCulm + 2] = -39.631812;
      val[544 * nCulm + 3] = 22.646913;
      val[544 * nCulm + 4] = -0.438138;
      val[544 * nCulm + 5] = -103.659199;
      val[545 * nCulm + 0] = 1.407073;
      val[545 * nCulm + 1] = 8.346657;
      val[545 * nCulm + 2] = 41.850112;
      val[545 * nCulm + 3] = -46.604468;
      val[545 * nCulm + 4] = -43.253259;
      val[545 * nCulm + 5] = 4.416667;
      val[546 * nCulm + 0] = 41.278201;
      val[546 * nCulm + 1] = 40.172408;
      val[546 * nCulm + 2] = -2.669238;
      val[546 * nCulm + 3] = 31.050964;
      val[546 * nCulm + 4] = -39.092934;
      val[546 * nCulm + 5] = -8.393654;
      val[547 * nCulm + 0] = 0.318234;
      val[547 * nCulm + 1] = 47.308189;
      val[547 * nCulm + 2] = 12.313051;
      val[547 * nCulm + 3] = -3.895872;
      val[547 * nCulm + 4] = 26.149458;
      val[547 * nCulm + 5] = 8.088097;
      val[548 * nCulm + 0] = -46.899174;
      val[548 * nCulm + 1] = 38.708552;
      val[548 * nCulm + 2] = -14.062643;
      val[548 * nCulm + 3] = -40.169792;
      val[548 * nCulm + 4] = -45.443161;
      val[548 * nCulm + 5] = 0.382202;
      val[549 * nCulm + 0] = 10.927540;
      val[549 * nCulm + 1] = 14.304542;
      val[549 * nCulm + 2] = -41.207258;
      val[549 * nCulm + 3] = -15.789553;
      val[549 * nCulm + 4] = 3.128021;
      val[549 * nCulm + 5] = -2.017124;
      val[550 * nCulm + 0] = -27.475680;
      val[550 * nCulm + 1] = 8.523118;
      val[550 * nCulm + 2] = -2.054744;
      val[550 * nCulm + 3] = -48.275524;
      val[550 * nCulm + 4] = 18.274735;
      val[550 * nCulm + 5] = -10.066258;
      val[551 * nCulm + 0] = -4.300417;
      val[551 * nCulm + 1] = 21.144821;
      val[551 * nCulm + 2] = 44.726409;
      val[551 * nCulm + 3] = -22.174829;
      val[551 * nCulm + 4] = -46.409625;
      val[551 * nCulm + 5] = 0.335051;
      val[552 * nCulm + 0] = 47.815614;
      val[552 * nCulm + 1] = 45.338585;
      val[552 * nCulm + 2] = -13.303217;
      val[552 * nCulm + 3] = 7.694001;
      val[552 * nCulm + 4] = -22.224571;
      val[552 * nCulm + 5] = -11.064747;
      val[553 * nCulm + 0] = -12.494360;
      val[553 * nCulm + 1] = -15.976667;
      val[553 * nCulm + 2] = 8.287695;
      val[553 * nCulm + 3] = 2.313782;
      val[553 * nCulm + 4] = -37.276480;
      val[553 * nCulm + 5] = 1.964901;
      val[554 * nCulm + 0] = 46.203822;
      val[554 * nCulm + 1] = 47.553833;
      val[554 * nCulm + 2] = 6.693840;
      val[554 * nCulm + 3] = 11.396861;
      val[554 * nCulm + 4] = 45.322415;
      val[554 * nCulm + 5] = 6.386629;
      val[555 * nCulm + 0] = 39.726203;
      val[555 * nCulm + 1] = -33.693480;
      val[555 * nCulm + 2] = -8.627694;
      val[555 * nCulm + 3] = 32.141918;
      val[555 * nCulm + 4] = -30.389507;
      val[555 * nCulm + 5] = 0.471664;
      val[556 * nCulm + 0] = 35.889810;
      val[556 * nCulm + 1] = 11.706135;
      val[556 * nCulm + 2] = 13.467656;
      val[556 * nCulm + 3] = 44.622416;
      val[556 * nCulm + 4] = -5.995477;
      val[556 * nCulm + 5] = -44.240490;
      val[557 * nCulm + 0] = -47.061939;
      val[557 * nCulm + 1] = -43.895379;
      val[557 * nCulm + 2] = 25.462592;
      val[557 * nCulm + 3] = -14.457294;
      val[557 * nCulm + 4] = -41.521211;
      val[557 * nCulm + 5] = 6.882086;
      val[558 * nCulm + 0] = -27.846189;
      val[558 * nCulm + 1] = 38.359611;
      val[558 * nCulm + 2] = -27.744351;
      val[558 * nCulm + 3] = 6.484043;
      val[558 * nCulm + 4] = 40.384902;
      val[558 * nCulm + 5] = 5.485924;
      val[559 * nCulm + 0] = -32.101936;
      val[559 * nCulm + 1] = -30.537805;
      val[559 * nCulm + 2] = -12.198337;
      val[559 * nCulm + 3] = 37.226217;
      val[559 * nCulm + 4] = 27.868404;
      val[559 * nCulm + 5] = 1.365999;
      val[560 * nCulm + 0] = 47.106805;
      val[560 * nCulm + 1] = 43.882019;
      val[560 * nCulm + 2] = 40.425721;
      val[560 * nCulm + 3] = -12.745882;
      val[560 * nCulm + 4] = -20.020621;
      val[560 * nCulm + 5] = -7.131296;
      val[561 * nCulm + 0] = -3.658838;
      val[561 * nCulm + 1] = 29.339319;
      val[561 * nCulm + 2] = 6.667105;
      val[561 * nCulm + 3] = -48.893131;
      val[561 * nCulm + 4] = -46.433418;
      val[561 * nCulm + 5] = 2.223278;
      val[562 * nCulm + 0] = -1.470766;
      val[562 * nCulm + 1] = -27.046863;
      val[562 * nCulm + 2] = -23.681152;
      val[562 * nCulm + 3] = 14.148225;
      val[562 * nCulm + 4] = 7.022365;
      val[562 * nCulm + 5] = -8.464158;
      val[563 * nCulm + 0] = 49.671786;
      val[563 * nCulm + 1] = -18.826282;
      val[563 * nCulm + 2] = 16.192050;
      val[563 * nCulm + 3] = 29.884089;
      val[563 * nCulm + 4] = 46.298396;
      val[563 * nCulm + 5] = 1.360499;
      val[564 * nCulm + 0] = -44.403821;
      val[564 * nCulm + 1] = 33.636506;
      val[564 * nCulm + 2] = 8.361386;
      val[564 * nCulm + 3] = 35.280102;
      val[564 * nCulm + 4] = -8.892982;
      val[564 * nCulm + 5] = -36.451204;
      val[565 * nCulm + 0] = -18.392209;
      val[565 * nCulm + 1] = -25.783868;
      val[565 * nCulm + 2] = 26.320625;
      val[565 * nCulm + 3] = 43.782269;
      val[565 * nCulm + 4] = 43.256130;
      val[565 * nCulm + 5] = 2.199488;
      val[566 * nCulm + 0] = -6.914692;
      val[566 * nCulm + 1] = -28.184287;
      val[566 * nCulm + 2] = 14.225672;
      val[566 * nCulm + 3] = -13.475972;
      val[566 * nCulm + 4] = -38.167572;
      val[566 * nCulm + 5] = 5.396477;
      val[567 * nCulm + 0] = -38.415658;
      val[567 * nCulm + 1] = 18.998468;
      val[567 * nCulm + 2] = 20.621761;
      val[567 * nCulm + 3] = -13.893298;
      val[567 * nCulm + 4] = -41.017297;
      val[567 * nCulm + 5] = -0.359129;
      val[568 * nCulm + 0] = 5.288672;
      val[568 * nCulm + 1] = 16.604577;
      val[568 * nCulm + 2] = -12.973557;
      val[568 * nCulm + 3] = -0.826124;
      val[568 * nCulm + 4] = 4.555705;
      val[568 * nCulm + 5] = 16.623661;
      val[569 * nCulm + 0] = -28.707561;
      val[569 * nCulm + 1] = 25.429911;
      val[569 * nCulm + 2] = 15.406346;
      val[569 * nCulm + 3] = 3.275672;
      val[569 * nCulm + 4] = -14.939611;
      val[569 * nCulm + 5] = -8.864821;
      val[570 * nCulm + 0] = -4.924096;
      val[570 * nCulm + 1] = 14.042483;
      val[570 * nCulm + 2] = 49.378201;
      val[570 * nCulm + 3] = -44.596269;
      val[570 * nCulm + 4] = 16.494226;
      val[570 * nCulm + 5] = -8.537993;
      val[571 * nCulm + 0] = 2.949657;
      val[571 * nCulm + 1] = 6.798205;
      val[571 * nCulm + 2] = -14.930121;
      val[571 * nCulm + 3] = 10.281614;
      val[571 * nCulm + 4] = 27.822503;
      val[571 * nCulm + 5] = 3.135723;
      val[572 * nCulm + 0] = -44.604565;
      val[572 * nCulm + 1] = 4.007442;
      val[572 * nCulm + 2] = -38.628469;
      val[572 * nCulm + 3] = -1.204383;
      val[572 * nCulm + 4] = 30.108099;
      val[572 * nCulm + 5] = 0.670672;
      val[573 * nCulm + 0] = -11.047765;
      val[573 * nCulm + 1] = -38.441161;
      val[573 * nCulm + 2] = 34.459584;
      val[573 * nCulm + 3] = -49.098431;
      val[573 * nCulm + 4] = 48.332158;
      val[573 * nCulm + 5] = -8.343051;
      val[574 * nCulm + 0] = -11.563739;
      val[574 * nCulm + 1] = -25.316923;
      val[574 * nCulm + 2] = 17.564712;
      val[574 * nCulm + 3] = 12.214907;
      val[574 * nCulm + 4] = -32.869875;
      val[574 * nCulm + 5] = 2.116719;
      val[575 * nCulm + 0] = 41.263091;
      val[575 * nCulm + 1] = -42.620897;
      val[575 * nCulm + 2] = -13.172882;
      val[575 * nCulm + 3] = 17.723173;
      val[575 * nCulm + 4] = 13.549840;
      val[575 * nCulm + 5] = -8.467462;
      val[576 * nCulm + 0] = 23.752845;
      val[576 * nCulm + 1] = -16.412843;
      val[576 * nCulm + 2] = -14.058950;
      val[576 * nCulm + 3] = -49.178068;
      val[576 * nCulm + 4] = 38.791883;
      val[576 * nCulm + 5] = -7.773315;
      val[577 * nCulm + 0] = -36.151174;
      val[577 * nCulm + 1] = -4.100603;
      val[577 * nCulm + 2] = 39.755141;
      val[577 * nCulm + 3] = 45.067706;
      val[577 * nCulm + 4] = 36.089114;
      val[577 * nCulm + 5] = 5.603115;
      val[578 * nCulm + 0] = -34.886194;
      val[578 * nCulm + 1] = 15.686366;
      val[578 * nCulm + 2] = 44.215337;
      val[578 * nCulm + 3] = -24.987965;
      val[578 * nCulm + 4] = -29.954365;
      val[578 * nCulm + 5] = 1.699822;
      val[579 * nCulm + 0] = 5.754226;
      val[579 * nCulm + 1] = -22.330277;
      val[579 * nCulm + 2] = 25.344213;
      val[579 * nCulm + 3] = 37.689735;
      val[579 * nCulm + 4] = -9.093945;
      val[579 * nCulm + 5] = -7.764487;
      val[580 * nCulm + 0] = 10.588579;
      val[580 * nCulm + 1] = 0.692094;
      val[580 * nCulm + 2] = -13.837258;
      val[580 * nCulm + 3] = -1.029840;
      val[580 * nCulm + 4] = 47.816913;
      val[580 * nCulm + 5] = 0.196567;
      val[581 * nCulm + 0] = -34.000612;
      val[581 * nCulm + 1] = 31.269906;
      val[581 * nCulm + 2] = -43.884968;
      val[581 * nCulm + 3] = 38.649075;
      val[581 * nCulm + 4] = 10.800315;
      val[581 * nCulm + 5] = 30.872609;
      val[582 * nCulm + 0] = 7.113135;
      val[582 * nCulm + 1] = 5.651454;
      val[582 * nCulm + 2] = -2.709267;
      val[582 * nCulm + 3] = -9.276216;
      val[582 * nCulm + 4] = 16.619912;
      val[582 * nCulm + 5] = -0.802328;
      val[583 * nCulm + 0] = 26.928439;
      val[583 * nCulm + 1] = 37.967647;
      val[583 * nCulm + 2] = -35.499841;
      val[583 * nCulm + 3] = 19.192567;
      val[583 * nCulm + 4] = 13.791653;
      val[583 * nCulm + 5] = 19.847542;
      val[584 * nCulm + 0] = -14.420616;
      val[584 * nCulm + 1] = 18.890774;
      val[584 * nCulm + 2] = -39.307244;
      val[584 * nCulm + 3] = 5.318511;
      val[584 * nCulm + 4] = 35.310216;
      val[584 * nCulm + 5] = 3.475254;
      val[585 * nCulm + 0] = 41.749762;
      val[585 * nCulm + 1] = -11.061070;
      val[585 * nCulm + 2] = 48.110163;
      val[585 * nCulm + 3] = -37.055857;
      val[585 * nCulm + 4] = -5.695846;
      val[585 * nCulm + 5] = 40.215888;
      val[586 * nCulm + 0] = 28.568191;
      val[586 * nCulm + 1] = 0.388242;
      val[586 * nCulm + 2] = 16.222552;
      val[586 * nCulm + 3] = -15.897617;
      val[586 * nCulm + 4] = 8.995641;
      val[586 * nCulm + 5] = -7.930735;
      val[587 * nCulm + 0] = 3.010563;
      val[587 * nCulm + 1] = 5.429043;
      val[587 * nCulm + 2] = 15.940263;
      val[587 * nCulm + 3] = -13.117140;
      val[587 * nCulm + 4] = -32.573733;
      val[587 * nCulm + 5] = 1.347168;
      val[588 * nCulm + 0] = 47.155150;
      val[588 * nCulm + 1] = 23.001407;
      val[588 * nCulm + 2] = 12.980137;
      val[588 * nCulm + 3] = -45.159586;
      val[588 * nCulm + 4] = 40.423615;
      val[588 * nCulm + 5] = -2.364574;
      val[589 * nCulm + 0] = -10.788889;
      val[589 * nCulm + 1] = 15.827588;
      val[589 * nCulm + 2] = 32.216732;
      val[589 * nCulm + 3] = 20.224760;
      val[589 * nCulm + 4] = -15.942458;
      val[589 * nCulm + 5] = -10.473982;
      val[590 * nCulm + 0] = -46.956119;
      val[590 * nCulm + 1] = 0.721188;
      val[590 * nCulm + 2] = -23.668917;
      val[590 * nCulm + 3] = -3.509338;
      val[590 * nCulm + 4] = -19.231288;
      val[590 * nCulm + 5] = 0.916238;
      val[591 * nCulm + 0] = 2.818727;
      val[591 * nCulm + 1] = -20.264743;
      val[591 * nCulm + 2] = 43.338983;
      val[591 * nCulm + 3] = 2.940856;
      val[591 * nCulm + 4] = 49.248994;
      val[591 * nCulm + 5] = -1.435003;
      val[592 * nCulm + 0] = -48.169600;
      val[592 * nCulm + 1] = 2.139381;
      val[592 * nCulm + 2] = -26.527200;
      val[592 * nCulm + 3] = -39.152454;
      val[592 * nCulm + 4] = 48.105242;
      val[592 * nCulm + 5] = -3.411915;
      val[593 * nCulm + 0] = 21.782122;
      val[593 * nCulm + 1] = 30.982269;
      val[593 * nCulm + 2] = -47.825558;
      val[593 * nCulm + 3] = 34.970875;
      val[593 * nCulm + 4] = 40.624044;
      val[593 * nCulm + 5] = 7.914568;
      val[594 * nCulm + 0] = -26.227204;
      val[594 * nCulm + 1] = -34.899324;
      val[594 * nCulm + 2] = -23.600623;
      val[594 * nCulm + 3] = -20.811320;
      val[594 * nCulm + 4] = 1.615077;
      val[594 * nCulm + 5] = -163.042170;
      val[595 * nCulm + 0] = -21.592665;
      val[595 * nCulm + 1] = 3.486128;
      val[595 * nCulm + 2] = -29.680718;
      val[595 * nCulm + 3] = -42.942718;
      val[595 * nCulm + 4] = 20.250241;
      val[595 * nCulm + 5] = -8.992665;
      val[596 * nCulm + 0] = 47.729720;
      val[596 * nCulm + 1] = -17.215486;
      val[596 * nCulm + 2] = -37.041964;
      val[596 * nCulm + 3] = -49.166562;
      val[596 * nCulm + 4] = 13.783982;
      val[596 * nCulm + 5] = -22.565180;
      val[597 * nCulm + 0] = -13.417748;
      val[597 * nCulm + 1] = -9.678107;
      val[597 * nCulm + 2] = -49.016155;
      val[597 * nCulm + 3] = -22.048113;
      val[597 * nCulm + 4] = 22.124870;
      val[597 * nCulm + 5] = -6.557420;
      val[598 * nCulm + 0] = 42.706484;
      val[598 * nCulm + 1] = -13.082671;
      val[598 * nCulm + 2] = -9.389412;
      val[598 * nCulm + 3] = -45.975759;
      val[598 * nCulm + 4] = -5.810825;
      val[598 * nCulm + 5] = 48.337325;
      val[599 * nCulm + 0] = 23.775870;
      val[599 * nCulm + 1] = 13.897920;
      val[599 * nCulm + 2] = 40.909291;
      val[599 * nCulm + 3] = 23.690435;
      val[599 * nCulm + 4] = -23.903346;
      val[599 * nCulm + 5] = -7.213235;
      val[600 * nCulm + 0] = -36.138749;
      val[600 * nCulm + 1] = -8.610747;
      val[600 * nCulm + 2] = 9.020136;
      val[600 * nCulm + 3] = -23.965334;
      val[600 * nCulm + 4] = -48.562187;
      val[600 * nCulm + 5] = 3.405175;
      val[601 * nCulm + 0] = -30.715118;
      val[601 * nCulm + 1] = 48.046824;
      val[601 * nCulm + 2] = 46.499507;
      val[601 * nCulm + 3] = 30.516881;
      val[601 * nCulm + 4] = -33.317735;
      val[601 * nCulm + 5] = -10.931269;
      val[602 * nCulm + 0] = -16.782944;
      val[602 * nCulm + 1] = 44.145756;
      val[602 * nCulm + 2] = 0.646331;
      val[602 * nCulm + 3] = -20.384445;
      val[602 * nCulm + 4] = 12.445689;
      val[602 * nCulm + 5] = 9.266881;
      val[603 * nCulm + 0] = -45.236967;
      val[603 * nCulm + 1] = 0.732446;
      val[603 * nCulm + 2] = -34.766223;
      val[603 * nCulm + 3] = 12.682092;
      val[603 * nCulm + 4] = 41.417541;
      val[603 * nCulm + 5] = 1.763058;
      val[604 * nCulm + 0] = -34.480422;
      val[604 * nCulm + 1] = 10.945593;
      val[604 * nCulm + 2] = -1.976122;
      val[604 * nCulm + 3] = -29.264792;
      val[604 * nCulm + 4] = 33.353901;
      val[604 * nCulm + 5] = -2.369722;
      val[605 * nCulm + 0] = 29.378105;
      val[605 * nCulm + 1] = 16.709715;
      val[605 * nCulm + 2] = -26.029356;
      val[605 * nCulm + 3] = 14.603378;
      val[605 * nCulm + 4] = -30.194803;
      val[605 * nCulm + 5] = -4.678636;
      val[606 * nCulm + 0] = -23.183844;
      val[606 * nCulm + 1] = -48.405846;
      val[606 * nCulm + 2] = 6.139757;
      val[606 * nCulm + 3] = 31.021266;
      val[606 * nCulm + 4] = 14.276095;
      val[606 * nCulm + 5] = -5.533972;
      val[607 * nCulm + 0] = 30.358517;
      val[607 * nCulm + 1] = -12.234858;
      val[607 * nCulm + 2] = -21.315028;
      val[607 * nCulm + 3] = -4.488017;
      val[607 * nCulm + 4] = -45.925260;
      val[607 * nCulm + 5] = 1.953560;
      val[608 * nCulm + 0] = 47.864227;
      val[608 * nCulm + 1] = -22.904491;
      val[608 * nCulm + 2] = 35.666546;
      val[608 * nCulm + 3] = 25.488543;
      val[608 * nCulm + 4] = 31.863055;
      val[608 * nCulm + 5] = 0.613867;
      val[609 * nCulm + 0] = 43.209004;
      val[609 * nCulm + 1] = 23.880608;
      val[609 * nCulm + 2] = -47.356219;
      val[609 * nCulm + 3] = 5.666589;
      val[609 * nCulm + 4] = 16.828025;
      val[609 * nCulm + 5] = 8.540942;
      val[610 * nCulm + 0] = 27.461223;
      val[610 * nCulm + 1] = -42.692663;
      val[610 * nCulm + 2] = -47.665171;
      val[610 * nCulm + 3] = 17.298276;
      val[610 * nCulm + 4] = -32.290109;
      val[610 * nCulm + 5] = 3.952505;
      val[611 * nCulm + 0] = -12.753849;
      val[611 * nCulm + 1] = -19.164116;
      val[611 * nCulm + 2] = -5.710306;
      val[611 * nCulm + 3] = 49.787036;
      val[611 * nCulm + 4] = 36.413433;
      val[611 * nCulm + 5] = 4.210632;
      val[612 * nCulm + 0] = 27.687768;
      val[612 * nCulm + 1] = 10.524465;
      val[612 * nCulm + 2] = 4.295205;
      val[612 * nCulm + 3] = 49.171008;
      val[612 * nCulm + 4] = -42.267516;
      val[612 * nCulm + 5] = -6.455005;
      val[613 * nCulm + 0] = -4.090408;
      val[613 * nCulm + 1] = 16.892611;
      val[613 * nCulm + 2] = 4.228041;
      val[613 * nCulm + 3] = 40.473492;
      val[613 * nCulm + 4] = -7.985297;
      val[613 * nCulm + 5] = -33.774105;
      val[614 * nCulm + 0] = 26.204815;
      val[614 * nCulm + 1] = 4.227958;
      val[614 * nCulm + 2] = -30.347974;
      val[614 * nCulm + 3] = 45.023957;
      val[614 * nCulm + 4] = 29.325934;
      val[614 * nCulm + 5] = 8.179473;
      val[615 * nCulm + 0] = 38.021219;
      val[615 * nCulm + 1] = -24.454949;
      val[615 * nCulm + 2] = -10.687546;
      val[615 * nCulm + 3] = -19.861729;
      val[615 * nCulm + 4] = -8.998900;
      val[615 * nCulm + 5] = 23.540138;
      val[616 * nCulm + 0] = -34.752727;
      val[616 * nCulm + 1] = 44.366294;
      val[616 * nCulm + 2] = 32.147768;
      val[616 * nCulm + 3] = -45.522669;
      val[616 * nCulm + 4] = -26.164294;
      val[616 * nCulm + 5] = 0.439198;
      val[617 * nCulm + 0] = -17.630384;
      val[617 * nCulm + 1] = 42.338542;
      val[617 * nCulm + 2] = 26.508552;
      val[617 * nCulm + 3] = -9.331472;
      val[617 * nCulm + 4] = 49.181786;
      val[617 * nCulm + 5] = 3.406653;
      val[618 * nCulm + 0] = 42.938160;
      val[618 * nCulm + 1] = 47.947893;
      val[618 * nCulm + 2] = 46.417247;
      val[618 * nCulm + 3] = -1.310128;
      val[618 * nCulm + 4] = 47.270702;
      val[618 * nCulm + 5] = 4.899956;
      val[619 * nCulm + 0] = 39.027785;
      val[619 * nCulm + 1] = -27.286530;
      val[619 * nCulm + 2] = 49.563573;
      val[619 * nCulm + 3] = 29.665645;
      val[619 * nCulm + 4] = -44.112972;
      val[619 * nCulm + 5] = -0.025280;
      val[620 * nCulm + 0] = 30.893959;
      val[620 * nCulm + 1] = 19.668278;
      val[620 * nCulm + 2] = -40.143535;
      val[620 * nCulm + 3] = -19.812834;
      val[620 * nCulm + 4] = -25.053791;
      val[620 * nCulm + 5] = 0.257310;
      val[621 * nCulm + 0] = -8.215020;
      val[621 * nCulm + 1] = -8.265308;
      val[621 * nCulm + 2] = -4.015621;
      val[621 * nCulm + 3] = 14.493201;
      val[621 * nCulm + 4] = -2.602006;
      val[621 * nCulm + 5] = -11.099220;
      val[622 * nCulm + 0] = 15.630733;
      val[622 * nCulm + 1] = -31.324685;
      val[622 * nCulm + 2] = -32.233270;
      val[622 * nCulm + 3] = 22.915407;
      val[622 * nCulm + 4] = -25.159908;
      val[622 * nCulm + 5] = 1.812037;
      val[623 * nCulm + 0] = 19.195899;
      val[623 * nCulm + 1] = 18.209529;
      val[623 * nCulm + 2] = 33.499161;
      val[623 * nCulm + 3] = 0.867095;
      val[623 * nCulm + 4] = -45.884784;
      val[623 * nCulm + 5] = -1.737886;
      val[624 * nCulm + 0] = -48.865080;
      val[624 * nCulm + 1] = 2.785013;
      val[624 * nCulm + 2] = -25.278452;
      val[624 * nCulm + 3] = -14.228393;
      val[624 * nCulm + 4] = 33.802303;
      val[624 * nCulm + 5] = -1.372416;
      val[625 * nCulm + 0] = -25.772119;
      val[625 * nCulm + 1] = -4.994971;
      val[625 * nCulm + 2] = -39.008759;
      val[625 * nCulm + 3] = 27.134024;
      val[625 * nCulm + 4] = -36.298061;
      val[625 * nCulm + 5] = -2.656973;
      val[626 * nCulm + 0] = 1.816397;
      val[626 * nCulm + 1] = 14.762544;
      val[626 * nCulm + 2] = 26.367792;
      val[626 * nCulm + 3] = -15.444170;
      val[626 * nCulm + 4] = -25.867999;
      val[626 * nCulm + 5] = 0.354724;
      val[627 * nCulm + 0] = -38.741518;
      val[627 * nCulm + 1] = 38.846567;
      val[627 * nCulm + 2] = -31.582529;
      val[627 * nCulm + 3] = -30.798859;
      val[627 * nCulm + 4] = 37.707298;
      val[627 * nCulm + 5] = 1.240215;
      val[628 * nCulm + 0] = 11.632682;
      val[628 * nCulm + 1] = 47.157316;
      val[628 * nCulm + 2] = -13.025916;
      val[628 * nCulm + 3] = -32.569577;
      val[628 * nCulm + 4] = -34.202746;
      val[628 * nCulm + 5] = -1.788804;
      val[629 * nCulm + 0] = -11.947583;
      val[629 * nCulm + 1] = -31.875848;
      val[629 * nCulm + 2] = 30.576369;
      val[629 * nCulm + 3] = 4.357010;
      val[629 * nCulm + 4] = 1.755202;
      val[629 * nCulm + 5] = -73.981302;
      val[630 * nCulm + 0] = 35.527166;
      val[630 * nCulm + 1] = -9.939161;
      val[630 * nCulm + 2] = 22.721216;
      val[630 * nCulm + 3] = -44.335565;
      val[630 * nCulm + 4] = -43.858080;
      val[630 * nCulm + 5] = 6.087538;
      val[631 * nCulm + 0] = -35.126525;
      val[631 * nCulm + 1] = 28.344429;
      val[631 * nCulm + 2] = 14.304003;
      val[631 * nCulm + 3] = -44.106071;
      val[631 * nCulm + 4] = 20.824558;
      val[631 * nCulm + 5] = -3.352554;
      val[632 * nCulm + 0] = -40.084465;
      val[632 * nCulm + 1] = 44.483259;
      val[632 * nCulm + 2] = 26.083936;
      val[632 * nCulm + 3] = -34.512285;
      val[632 * nCulm + 4] = -4.566741;
      val[632 * nCulm + 5] = -10.104711;
      val[633 * nCulm + 0] = -20.168700;
      val[633 * nCulm + 1] = -2.683242;
      val[633 * nCulm + 2] = -4.727397;
      val[633 * nCulm + 3] = -4.495456;
      val[633 * nCulm + 4] = 34.668817;
      val[633 * nCulm + 5] = -0.750108;
      val[634 * nCulm + 0] = 41.255045;
      val[634 * nCulm + 1] = -19.566634;
      val[634 * nCulm + 2] = -13.693471;
      val[634 * nCulm + 3] = -21.806347;
      val[634 * nCulm + 4] = -31.654108;
      val[634 * nCulm + 5] = 6.416625;
      val[635 * nCulm + 0] = -26.646211;
      val[635 * nCulm + 1] = 24.262107;
      val[635 * nCulm + 2] = 4.160528;
      val[635 * nCulm + 3] = -46.542300;
      val[635 * nCulm + 4] = 37.250809;
      val[635 * nCulm + 5] = -2.601068;
      val[636 * nCulm + 0] = 17.538160;
      val[636 * nCulm + 1] = 49.034020;
      val[636 * nCulm + 2] = -43.955263;
      val[636 * nCulm + 3] = 15.009999;
      val[636 * nCulm + 4] = 17.288301;
      val[636 * nCulm + 5] = 17.764499;
      val[637 * nCulm + 0] = -27.366550;
      val[637 * nCulm + 1] = 9.537053;
      val[637 * nCulm + 2] = 49.402888;
      val[637 * nCulm + 3] = -32.137361;
      val[637 * nCulm + 4] = -11.498086;
      val[637 * nCulm + 5] = 9.533704;
      val[638 * nCulm + 0] = -34.093283;
      val[638 * nCulm + 1] = 47.003604;
      val[638 * nCulm + 2] = 21.650549;
      val[638 * nCulm + 3] = -0.916025;
      val[638 * nCulm + 4] = -36.987382;
      val[638 * nCulm + 5] = -5.667900;
      val[639 * nCulm + 0] = 28.246798;
      val[639 * nCulm + 1] = -25.332386;
      val[639 * nCulm + 2] = 24.332558;
      val[639 * nCulm + 3] = -39.761554;
      val[639 * nCulm + 4] = -49.909314;
      val[639 * nCulm + 5] = 6.403423;
      val[640 * nCulm + 0] = 29.331155;
      val[640 * nCulm + 1] = -15.462595;
      val[640 * nCulm + 2] = 26.927274;
      val[640 * nCulm + 3] = -25.641404;
      val[640 * nCulm + 4] = 32.257224;
      val[640 * nCulm + 5] = -5.801484;
      val[641 * nCulm + 0] = 32.227673;
      val[641 * nCulm + 1] = -25.686844;
      val[641 * nCulm + 2] = 19.809191;
      val[641 * nCulm + 3] = 17.858227;
      val[641 * nCulm + 4] = -23.522353;
      val[641 * nCulm + 5] = 1.805329;
      val[642 * nCulm + 0] = -15.599350;
      val[642 * nCulm + 1] = -37.051309;
      val[642 * nCulm + 2] = 13.781525;
      val[642 * nCulm + 3] = 10.828970;
      val[642 * nCulm + 4] = 27.076066;
      val[642 * nCulm + 5] = -4.354088;
      val[643 * nCulm + 0] = -48.730793;
      val[643 * nCulm + 1] = -25.770272;
      val[643 * nCulm + 2] = -9.326241;
      val[643 * nCulm + 3] = 3.950957;
      val[643 * nCulm + 4] = -38.654487;
      val[643 * nCulm + 5] = 2.901827;
      val[644 * nCulm + 0] = -49.686528;
      val[644 * nCulm + 1] = -33.100928;
      val[644 * nCulm + 2] = 18.440883;
      val[644 * nCulm + 3] = -27.315809;
      val[644 * nCulm + 4] = -48.478040;
      val[644 * nCulm + 5] = 6.129012;
      val[645 * nCulm + 0] = 29.188588;
      val[645 * nCulm + 1] = 25.520903;
      val[645 * nCulm + 2] = -7.971745;
      val[645 * nCulm + 3] = 0.077208;
      val[645 * nCulm + 4] = -37.399788;
      val[645 * nCulm + 5] = -3.009708;
      val[646 * nCulm + 0] = 40.781654;
      val[646 * nCulm + 1] = 48.063327;
      val[646 * nCulm + 2] = -31.600140;
      val[646 * nCulm + 3] = 8.291463;
      val[646 * nCulm + 4] = -29.808298;
      val[646 * nCulm + 5] = -8.718716;
      val[647 * nCulm + 0] = -2.643742;
      val[647 * nCulm + 1] = 29.701572;
      val[647 * nCulm + 2] = 36.406858;
      val[647 * nCulm + 3] = 10.313517;
      val[647 * nCulm + 4] = 36.371460;
      val[647 * nCulm + 5] = 5.437510;
      val[648 * nCulm + 0] = -15.141014;
      val[648 * nCulm + 1] = -12.109249;
      val[648 * nCulm + 2] = -19.562702;
      val[648 * nCulm + 3] = -7.571038;
      val[648 * nCulm + 4] = 21.781228;
      val[648 * nCulm + 5] = -4.046773;
      val[649 * nCulm + 0] = -45.609295;
      val[649 * nCulm + 1] = -16.275539;
      val[649 * nCulm + 2] = 42.978464;
      val[649 * nCulm + 3] = -1.932002;
      val[649 * nCulm + 4] = -42.202804;
      val[649 * nCulm + 5] = 2.272100;
      val[650 * nCulm + 0] = -28.279261;
      val[650 * nCulm + 1] = -19.197701;
      val[650 * nCulm + 2] = -36.120113;
      val[650 * nCulm + 3] = -35.360601;
      val[650 * nCulm + 4] = -45.617711;
      val[650 * nCulm + 5] = 5.891017;
      val[651 * nCulm + 0] = -48.715503;
      val[651 * nCulm + 1] = -34.486969;
      val[651 * nCulm + 2] = -26.951088;
      val[651 * nCulm + 3] = -20.828695;
      val[651 * nCulm + 4] = -41.352090;
      val[651 * nCulm + 5] = 6.561662;
      val[652 * nCulm + 0] = -8.564747;
      val[652 * nCulm + 1] = -42.465884;
      val[652 * nCulm + 2] = -18.833987;
      val[652 * nCulm + 3] = 1.897309;
      val[652 * nCulm + 4] = 23.425587;
      val[652 * nCulm + 5] = -7.967216;
      val[653 * nCulm + 0] = 33.833296;
      val[653 * nCulm + 1] = -28.667482;
      val[653 * nCulm + 2] = 37.552895;
      val[653 * nCulm + 3] = 33.760582;
      val[653 * nCulm + 4] = -23.968370;
      val[653 * nCulm + 5] = -0.775798;
      val[654 * nCulm + 0] = 14.823765;
      val[654 * nCulm + 1] = 43.626284;
      val[654 * nCulm + 2] = 27.184132;
      val[654 * nCulm + 3] = 13.232530;
      val[654 * nCulm + 4] = -30.053247;
      val[654 * nCulm + 5] = -8.725163;
      val[655 * nCulm + 0] = -34.410477;
      val[655 * nCulm + 1] = 8.837724;
      val[655 * nCulm + 2] = -29.064186;
      val[655 * nCulm + 3] = -42.468118;
      val[655 * nCulm + 4] = -48.730379;
      val[655 * nCulm + 5] = 3.496625;
      val[656 * nCulm + 0] = 18.456312;
      val[656 * nCulm + 1] = 29.970807;
      val[656 * nCulm + 2] = 34.049872;
      val[656 * nCulm + 3] = -45.444757;
      val[656 * nCulm + 4] = -45.374823;
      val[656 * nCulm + 5] = 1.844185;
      val[657 * nCulm + 0] = -36.707300;
      val[657 * nCulm + 1] = 12.229021;
      val[657 * nCulm + 2] = 19.341201;
      val[657 * nCulm + 3] = -34.873696;
      val[657 * nCulm + 4] = 27.859013;
      val[657 * nCulm + 5] = -3.617401;
      val[658 * nCulm + 0] = 8.248008;
      val[658 * nCulm + 1] = -11.670258;
      val[658 * nCulm + 2] = -18.628946;
      val[658 * nCulm + 3] = 29.881286;
      val[658 * nCulm + 4] = -43.914043;
      val[658 * nCulm + 5] = -1.732900;
      val[659 * nCulm + 0] = -39.496178;
      val[659 * nCulm + 1] = -46.780401;
      val[659 * nCulm + 2] = 49.194087;
      val[659 * nCulm + 3] = 18.666782;
      val[659 * nCulm + 4] = 37.629720;
      val[659 * nCulm + 5] = -3.306331;
      val[660 * nCulm + 0] = -31.665464;
      val[660 * nCulm + 1] = 28.112239;
      val[660 * nCulm + 2] = 37.087388;
      val[660 * nCulm + 3] = 0.004561;
      val[660 * nCulm + 4] = -34.038902;
      val[660 * nCulm + 5] = -3.679826;
      val[661 * nCulm + 0] = 1.476060;
      val[661 * nCulm + 1] = -31.354834;
      val[661 * nCulm + 2] = 46.319559;
      val[661 * nCulm + 3] = 6.403090;
      val[661 * nCulm + 4] = 43.637428;
      val[661 * nCulm + 5] = -2.476505;
      val[662 * nCulm + 0] = -14.491342;
      val[662 * nCulm + 1] = 18.718798;
      val[662 * nCulm + 2] = -41.406770;
      val[662 * nCulm + 3] = -34.218150;
      val[662 * nCulm + 4] = 20.204572;
      val[662 * nCulm + 5] = -3.401040;
      val[663 * nCulm + 0] = 12.737857;
      val[663 * nCulm + 1] = -6.709129;
      val[663 * nCulm + 2] = -2.520801;
      val[663 * nCulm + 3] = 11.274642;
      val[663 * nCulm + 4] = -2.656743;
      val[663 * nCulm + 5] = -7.904056;
      val[664 * nCulm + 0] = -36.217300;
      val[664 * nCulm + 1] = -36.099103;
      val[664 * nCulm + 2] = -6.387170;
      val[664 * nCulm + 3] = 1.223184;
      val[664 * nCulm + 4] = -29.377028;
      val[664 * nCulm + 5] = 5.849335;
      val[665 * nCulm + 0] = 16.728809;
      val[665 * nCulm + 1] = -24.138715;
      val[665 * nCulm + 2] = 35.510556;
      val[665 * nCulm + 3] = 24.215675;
      val[665 * nCulm + 4] = -8.795928;
      val[665 * nCulm + 5] = 0.188585;
      val[666 * nCulm + 0] = -33.063393;
      val[666 * nCulm + 1] = -0.651102;
      val[666 * nCulm + 2] = -12.179494;
      val[666 * nCulm + 3] = -13.965576;
      val[666 * nCulm + 4] = 2.374577;
      val[666 * nCulm + 5] = -28.905968;
      val[667 * nCulm + 0] = 7.690737;
      val[667 * nCulm + 1] = -44.082251;
      val[667 * nCulm + 2] = 49.010685;
      val[667 * nCulm + 3] = -13.918000;
      val[667 * nCulm + 4] = -35.776627;
      val[667 * nCulm + 5] = 7.903572;
      val[668 * nCulm + 0] = -14.720995;
      val[668 * nCulm + 1] = -48.619442;
      val[668 * nCulm + 2] = 42.332936;
      val[668 * nCulm + 3] = 23.513003;
      val[668 * nCulm + 4] = -33.458991;
      val[668 * nCulm + 5] = 3.781725;
      val[669 * nCulm + 0] = 15.756153;
      val[669 * nCulm + 1] = 21.173414;
      val[669 * nCulm + 2] = 32.426760;
      val[669 * nCulm + 3] = 26.729771;
      val[669 * nCulm + 4] = 11.482407;
      val[669 * nCulm + 5] = 19.976882;
      val[670 * nCulm + 0] = -0.857338;
      val[670 * nCulm + 1] = -15.304890;
      val[670 * nCulm + 2] = -48.071360;
      val[670 * nCulm + 3] = 29.551815;
      val[670 * nCulm + 4] = -46.840964;
      val[670 * nCulm + 5] = -1.209668;
      val[671 * nCulm + 0] = -33.641785;
      val[671 * nCulm + 1] = 7.605353;
      val[671 * nCulm + 2] = -3.639974;
      val[671 * nCulm + 3] = 40.892734;
      val[671 * nCulm + 4] = -9.716202;
      val[671 * nCulm + 5] = -23.396270;
      val[672 * nCulm + 0] = 28.233029;
      val[672 * nCulm + 1] = -41.056737;
      val[672 * nCulm + 2] = -5.118632;
      val[672 * nCulm + 3] = 14.082982;
      val[672 * nCulm + 4] = 42.674302;
      val[672 * nCulm + 5] = -2.761866;
      val[673 * nCulm + 0] = -25.757582;
      val[673 * nCulm + 1] = 2.280247;
      val[673 * nCulm + 2] = 45.086316;
      val[673 * nCulm + 3] = 34.366370;
      val[673 * nCulm + 4] = 9.410253;
      val[673 * nCulm + 5] = 18.663155;
      val[674 * nCulm + 0] = 7.257575;
      val[674 * nCulm + 1] = -42.558926;
      val[674 * nCulm + 2] = -6.607332;
      val[674 * nCulm + 3] = -35.082707;
      val[674 * nCulm + 4] = -22.044026;
      val[674 * nCulm + 5] = 16.901352;
      val[675 * nCulm + 0] = 12.170247;
      val[675 * nCulm + 1] = -7.089314;
      val[675 * nCulm + 2] = -28.849969;
      val[675 * nCulm + 3] = -10.661187;
      val[675 * nCulm + 4] = 48.428533;
      val[675 * nCulm + 5] = -1.504908;
      val[676 * nCulm + 0] = -42.618761;
      val[676 * nCulm + 1] = 9.815616;
      val[676 * nCulm + 2] = -12.875803;
      val[676 * nCulm + 3] = 31.937253;
      val[676 * nCulm + 4] = 10.047621;
      val[676 * nCulm + 5] = 19.899357;
      val[677 * nCulm + 0] = 49.908648;
      val[677 * nCulm + 1] = 42.525900;
      val[677 * nCulm + 2] = -39.270098;
      val[677 * nCulm + 3] = -19.097966;
      val[677 * nCulm + 4] = -18.322814;
      val[677 * nCulm + 5] = -5.822139;
      val[678 * nCulm + 0] = 28.121577;
      val[678 * nCulm + 1] = 44.871617;
      val[678 * nCulm + 2] = -42.946723;
      val[678 * nCulm + 3] = -42.760459;
      val[678 * nCulm + 4] = -21.752395;
      val[678 * nCulm + 5] = -0.229389;
      val[679 * nCulm + 0] = 10.264254;
      val[679 * nCulm + 1] = -5.749605;
      val[679 * nCulm + 2] = -44.043886;
      val[679 * nCulm + 3] = -37.412508;
      val[679 * nCulm + 4] = 17.260678;
      val[679 * nCulm + 5] = -11.606190;
      val[680 * nCulm + 0] = 17.475284;
      val[680 * nCulm + 1] = 17.518925;
      val[680 * nCulm + 2] = -18.399997;
      val[680 * nCulm + 3] = 21.278592;
      val[680 * nCulm + 4] = -47.435793;
      val[680 * nCulm + 5] = -3.641372;
      val[681 * nCulm + 0] = 13.594009;
      val[681 * nCulm + 1] = -37.575766;
      val[681 * nCulm + 2] = -28.761194;
      val[681 * nCulm + 3] = -44.859499;
      val[681 * nCulm + 4] = 29.272287;
      val[681 * nCulm + 5] = -13.099795;
      val[682 * nCulm + 0] = 5.671588;
      val[682 * nCulm + 1] = -0.819480;
      val[682 * nCulm + 2] = -15.951539;
      val[682 * nCulm + 3] = -9.028000;
      val[682 * nCulm + 4] = 3.824421;
      val[682 * nCulm + 5] = -11.957832;
      val[683 * nCulm + 0] = -11.919047;
      val[683 * nCulm + 1] = -29.002995;
      val[683 * nCulm + 2] = 14.326488;
      val[683 * nCulm + 3] = 11.005555;
      val[683 * nCulm + 4] = -5.557000;
      val[683 * nCulm + 5] = 15.559834;
      val[684 * nCulm + 0] = -5.275407;
      val[684 * nCulm + 1] = -38.620626;
      val[684 * nCulm + 2] = 1.426988;
      val[684 * nCulm + 3] = -33.299116;
      val[684 * nCulm + 4] = -43.747110;
      val[684 * nCulm + 5] = 8.011545;
      val[685 * nCulm + 0] = 2.605304;
      val[685 * nCulm + 1] = -48.037168;
      val[685 * nCulm + 2] = -38.261900;
      val[685 * nCulm + 3] = 48.509980;
      val[685 * nCulm + 4] = -13.294185;
      val[685 * nCulm + 5] = 0.061657;
      val[686 * nCulm + 0] = -0.415895;
      val[686 * nCulm + 1] = -2.999053;
      val[686 * nCulm + 2] = -47.567651;
      val[686 * nCulm + 3] = -15.868333;
      val[686 * nCulm + 4] = 20.803884;
      val[686 * nCulm + 5] = -4.062738;
      val[687 * nCulm + 0] = 19.866205;
      val[687 * nCulm + 1] = -41.256155;
      val[687 * nCulm + 2] = 38.518567;
      val[687 * nCulm + 3] = 1.647013;
      val[687 * nCulm + 4] = -38.457570;
      val[687 * nCulm + 5] = 5.105068;
      val[688 * nCulm + 0] = 31.796632;
      val[688 * nCulm + 1] = 7.336972;
      val[688 * nCulm + 2] = 46.253159;
      val[688 * nCulm + 3] = 10.253513;
      val[688 * nCulm + 4] = -48.944872;
      val[688 * nCulm + 5] = -1.471131;
      val[689 * nCulm + 0] = 22.413231;
      val[689 * nCulm + 1] = -12.823644;
      val[689 * nCulm + 2] = 23.634564;
      val[689 * nCulm + 3] = 39.958366;
      val[689 * nCulm + 4] = -38.711450;
      val[689 * nCulm + 5] = -3.087822;
      val[690 * nCulm + 0] = -46.665596;
      val[690 * nCulm + 1] = 8.013404;
      val[690 * nCulm + 2] = -41.456752;
      val[690 * nCulm + 3] = -7.031929;
      val[690 * nCulm + 4] = 14.440366;
      val[690 * nCulm + 5] = 0.551713;
      val[691 * nCulm + 0] = 9.320410;
      val[691 * nCulm + 1] = -49.929612;
      val[691 * nCulm + 2] = -37.635795;
      val[691 * nCulm + 3] = 36.675933;
      val[691 * nCulm + 4] = 8.915254;
      val[691 * nCulm + 5] = -6.806713;
      val[692 * nCulm + 0] = -45.193382;
      val[692 * nCulm + 1] = 34.356865;
      val[692 * nCulm + 2] = 41.451571;
      val[692 * nCulm + 3] = 22.704922;
      val[692 * nCulm + 4] = -17.926517;
      val[692 * nCulm + 5] = -14.836645;
      val[693 * nCulm + 0] = -18.067837;
      val[693 * nCulm + 1] = -23.093522;
      val[693 * nCulm + 2] = -31.591947;
      val[693 * nCulm + 3] = -17.745761;
      val[693 * nCulm + 4] = -13.960855;
      val[693 * nCulm + 5] = 14.076282;
      val[694 * nCulm + 0] = -26.871825;
      val[694 * nCulm + 1] = 40.346545;
      val[694 * nCulm + 2] = -10.957079;
      val[694 * nCulm + 3] = 40.889994;
      val[694 * nCulm + 4] = -31.003010;
      val[694 * nCulm + 5] = -12.172654;
      val[695 * nCulm + 0] = 27.828843;
      val[695 * nCulm + 1] = -27.309246;
      val[695 * nCulm + 2] = -29.306514;
      val[695 * nCulm + 3] = -43.089251;
      val[695 * nCulm + 4] = 41.877868;
      val[695 * nCulm + 5] = -7.726937;
      val[696 * nCulm + 0] = -17.975903;
      val[696 * nCulm + 1] = 34.988352;
      val[696 * nCulm + 2] = -32.259262;
      val[696 * nCulm + 3] = -8.220247;
      val[696 * nCulm + 4] = -0.224191;
      val[696 * nCulm + 5] = -564.922842;
      val[697 * nCulm + 0] = -18.495302;
      val[697 * nCulm + 1] = -25.621190;
      val[697 * nCulm + 2] = 0.828911;
      val[697 * nCulm + 3] = -15.143636;
      val[697 * nCulm + 4] = 10.170778;
      val[697 * nCulm + 5] = -18.741361;
      val[698 * nCulm + 0] = -8.504309;
      val[698 * nCulm + 1] = -7.257161;
      val[698 * nCulm + 2] = -24.805661;
      val[698 * nCulm + 3] = -3.787131;
      val[698 * nCulm + 4] = -43.345787;
      val[698 * nCulm + 5] = 1.436030;
      val[699 * nCulm + 0] = 13.508589;
      val[699 * nCulm + 1] = -41.226694;
      val[699 * nCulm + 2] = -33.364234;
      val[699 * nCulm + 3] = -5.125046;
      val[699 * nCulm + 4] = 19.736240;
      val[699 * nCulm + 5] = -10.886517;
      val[700 * nCulm + 0] = 17.040290;
      val[700 * nCulm + 1] = 20.122843;
      val[700 * nCulm + 2] = 18.354439;
      val[700 * nCulm + 3] = -31.548623;
      val[700 * nCulm + 4] = 23.407540;
      val[700 * nCulm + 5] = -2.080453;
      val[701 * nCulm + 0] = -43.910405;
      val[701 * nCulm + 1] = 49.197517;
      val[701 * nCulm + 2] = 30.780282;
      val[701 * nCulm + 3] = 48.048352;
      val[701 * nCulm + 4] = -34.135686;
      val[701 * nCulm + 5] = -13.254338;
      val[702 * nCulm + 0] = -14.622982;
      val[702 * nCulm + 1] = 8.130430;
      val[702 * nCulm + 2] = -47.629152;
      val[702 * nCulm + 3] = -33.871108;
      val[702 * nCulm + 4] = -5.994218;
      val[702 * nCulm + 5] = 20.556124;
      val[703 * nCulm + 0] = -30.913627;
      val[703 * nCulm + 1] = -46.770722;
      val[703 * nCulm + 2] = -21.105637;
      val[703 * nCulm + 3] = 10.042159;
      val[703 * nCulm + 4] = 31.015194;
      val[703 * nCulm + 5] = -5.375270;
      val[704 * nCulm + 0] = -16.297752;
      val[704 * nCulm + 1] = -35.312090;
      val[704 * nCulm + 2] = 34.725635;
      val[704 * nCulm + 3] = -40.311614;
      val[704 * nCulm + 4] = -4.697542;
      val[704 * nCulm + 5] = 76.429891;
      val[705 * nCulm + 0] = 33.072454;
      val[705 * nCulm + 1] = 28.431053;
      val[705 * nCulm + 2] = -10.038327;
      val[705 * nCulm + 3] = 20.175271;
      val[705 * nCulm + 4] = -23.794214;
      val[705 * nCulm + 5] = -9.439155;
      val[706 * nCulm + 0] = 28.367423;
      val[706 * nCulm + 1] = -35.518478;
      val[706 * nCulm + 2] = -49.602328;
      val[706 * nCulm + 3] = 30.374183;
      val[706 * nCulm + 4] = -44.355721;
      val[706 * nCulm + 5] = 0.778963;
      val[707 * nCulm + 0] = -5.889844;
      val[707 * nCulm + 1] = 46.201464;
      val[707 * nCulm + 2] = 1.993777;
      val[707 * nCulm + 3] = -15.778462;
      val[707 * nCulm + 4] = 37.555069;
      val[707 * nCulm + 5] = 4.064428;
      val[708 * nCulm + 0] = -28.344722;
      val[708 * nCulm + 1] = -7.243777;
      val[708 * nCulm + 2] = 29.042193;
      val[708 * nCulm + 3] = -29.747193;
      val[708 * nCulm + 4] = 9.566548;
      val[708 * nCulm + 5] = -18.072380;
      val[709 * nCulm + 0] = -35.933008;
      val[709 * nCulm + 1] = 30.658797;
      val[709 * nCulm + 2] = -32.898097;
      val[709 * nCulm + 3] = 38.590930;
      val[709 * nCulm + 4] = -28.182139;
      val[709 * nCulm + 5] = -11.400843;
      val[710 * nCulm + 0] = -24.223772;
      val[710 * nCulm + 1] = 47.955497;
      val[710 * nCulm + 2] = -9.519268;
      val[710 * nCulm + 3] = -15.716099;
      val[710 * nCulm + 4] = 12.187539;
      val[710 * nCulm + 5] = 12.750970;
      val[711 * nCulm + 0] = 4.274632;
      val[711 * nCulm + 1] = -11.387215;
      val[711 * nCulm + 2] = -42.330942;
      val[711 * nCulm + 3] = 14.013888;
      val[711 * nCulm + 4] = 38.560103;
      val[711 * nCulm + 5] = 0.552430;
      val[712 * nCulm + 0] = -34.168137;
      val[712 * nCulm + 1] = -4.104984;
      val[712 * nCulm + 2] = -19.322260;
      val[712 * nCulm + 3] = 37.983264;
      val[712 * nCulm + 4] = -18.331274;
      val[712 * nCulm + 5] = -8.517739;
      val[713 * nCulm + 0] = 34.311910;
      val[713 * nCulm + 1] = 29.130280;
      val[713 * nCulm + 2] = -42.083643;
      val[713 * nCulm + 3] = 12.643203;
      val[713 * nCulm + 4] = -23.307601;
      val[713 * nCulm + 5] = -8.253405;
      val[714 * nCulm + 0] = -39.958366;
      val[714 * nCulm + 1] = 16.772024;
      val[714 * nCulm + 2] = 9.411841;
      val[714 * nCulm + 3] = 49.316805;
      val[714 * nCulm + 4] = 30.286681;
      val[714 * nCulm + 5] = 10.558647;
      val[715 * nCulm + 0] = 22.058264;
      val[715 * nCulm + 1] = -9.371396;
      val[715 * nCulm + 2] = -10.266105;
      val[715 * nCulm + 3] = 16.576735;
      val[715 * nCulm + 4] = -4.955457;
      val[715 * nCulm + 5] = -6.652368;
      val[716 * nCulm + 0] = -24.491761;
      val[716 * nCulm + 1] = -41.981834;
      val[716 * nCulm + 2] = -27.955237;
      val[716 * nCulm + 3] = 38.994786;
      val[716 * nCulm + 4] = 39.038080;
      val[716 * nCulm + 5] = -0.132177;
      val[717 * nCulm + 0] = -34.349488;
      val[717 * nCulm + 1] = 36.032091;
      val[717 * nCulm + 2] = 17.934292;
      val[717 * nCulm + 3] = 45.522372;
      val[717 * nCulm + 4] = 6.248907;
      val[717 * nCulm + 5] = 62.004715;
      val[718 * nCulm + 0] = -1.687363;
      val[718 * nCulm + 1] = -24.941375;
      val[718 * nCulm + 2] = 33.925509;
      val[718 * nCulm + 3] = 4.104593;
      val[718 * nCulm + 4] = -35.115258;
      val[718 * nCulm + 5] = 3.038677;
      val[719 * nCulm + 0] = 21.564717;
      val[719 * nCulm + 1] = -26.651946;
      val[719 * nCulm + 2] = -36.670543;
      val[719 * nCulm + 3] = -46.353861;
      val[719 * nCulm + 4] = 16.471873;
      val[719 * nCulm + 5] = -20.748841;
      val[720 * nCulm + 0] = 39.534797;
      val[720 * nCulm + 1] = -31.595150;
      val[720 * nCulm + 2] = -35.020058;
      val[720 * nCulm + 3] = 30.834527;
      val[720 * nCulm + 4] = -9.741811;
      val[720 * nCulm + 5] = 0.599570;
      val[721 * nCulm + 0] = -38.489059;
      val[721 * nCulm + 1] = 12.131079;
      val[721 * nCulm + 2] = 16.235828;
      val[721 * nCulm + 3] = 49.079990;
      val[721 * nCulm + 4] = 14.937885;
      val[721 * nCulm + 5] = 19.625811;
      val[722 * nCulm + 0] = -24.954649;
      val[722 * nCulm + 1] = -12.480187;
      val[722 * nCulm + 2] = -16.491745;
      val[722 * nCulm + 3] = -16.674171;
      val[722 * nCulm + 4] = 47.880065;
      val[722 * nCulm + 5] = -2.652145;
      val[723 * nCulm + 0] = 22.849817;
      val[723 * nCulm + 1] = 40.195268;
      val[723 * nCulm + 2] = -0.241936;
      val[723 * nCulm + 3] = 9.901910;
      val[723 * nCulm + 4] = -28.180255;
      val[723 * nCulm + 5] = -8.184638;
      val[724 * nCulm + 0] = -37.957684;
      val[724 * nCulm + 1] = -10.824540;
      val[724 * nCulm + 2] = 16.245440;
      val[724 * nCulm + 3] = 49.875107;
      val[724 * nCulm + 4] = -0.071113;
      val[724 * nCulm + 5] = -2598.994507;
      val[725 * nCulm + 0] = 14.610731;
      val[725 * nCulm + 1] = 20.969356;
      val[725 * nCulm + 2] = -31.321386;
      val[725 * nCulm + 3] = 27.303808;
      val[725 * nCulm + 4] = -44.370769;
      val[725 * nCulm + 5] = -4.919628;
      val[726 * nCulm + 0] = 17.095234;
      val[726 * nCulm + 1] = 24.246635;
      val[726 * nCulm + 2] = -30.338097;
      val[726 * nCulm + 3] = -5.057256;
      val[726 * nCulm + 4] = -17.086094;
      val[726 * nCulm + 5] = -5.086003;
      val[727 * nCulm + 0] = -40.515253;
      val[727 * nCulm + 1] = 33.888179;
      val[727 * nCulm + 2] = -30.509541;
      val[727 * nCulm + 3] = -24.163428;
      val[727 * nCulm + 4] = -41.579997;
      val[727 * nCulm + 5] = -0.877034;
      val[728 * nCulm + 0] = 26.107582;
      val[728 * nCulm + 1] = -1.357535;
      val[728 * nCulm + 2] = -10.231230;
      val[728 * nCulm + 3] = 45.022717;
      val[728 * nCulm + 4] = -13.873954;
      val[728 * nCulm + 5] = -14.667113;
      val[729 * nCulm + 0] = 38.904651;
      val[729 * nCulm + 1] = -31.007968;
      val[729 * nCulm + 2] = -24.179799;
      val[729 * nCulm + 3] = 39.265756;
      val[729 * nCulm + 4] = -21.422768;
      val[729 * nCulm + 5] = -1.594548;
      val[730 * nCulm + 0] = 46.638574;
      val[730 * nCulm + 1] = -28.798132;
      val[730 * nCulm + 2] = 41.637537;
      val[730 * nCulm + 3] = 31.261847;
      val[730 * nCulm + 4] = 12.459397;
      val[730 * nCulm + 5] = 1.165967;
      val[731 * nCulm + 0] = 42.790787;
      val[731 * nCulm + 1] = -1.234722;
      val[731 * nCulm + 2] = -12.491155;
      val[731 * nCulm + 3] = -42.784015;
      val[731 * nCulm + 4] = 44.860729;
      val[731 * nCulm + 5] = -4.414493;
      val[732 * nCulm + 0] = 28.028178;
      val[732 * nCulm + 1] = -1.388075;
      val[732 * nCulm + 2] = 18.923336;
      val[732 * nCulm + 3] = -41.042539;
      val[732 * nCulm + 4] = -10.838689;
      val[732 * nCulm + 5] = 18.759754;
      val[733 * nCulm + 0] = -43.159688;
      val[733 * nCulm + 1] = 43.652974;
      val[733 * nCulm + 2] = -44.064628;
      val[733 * nCulm + 3] = -29.211281;
      val[733 * nCulm + 4] = 48.545600;
      val[733 * nCulm + 5] = 1.638106;
      val[734 * nCulm + 0] = -44.872877;
      val[734 * nCulm + 1] = -29.680024;
      val[734 * nCulm + 2] = -36.829730;
      val[734 * nCulm + 3] = -15.632105;
      val[734 * nCulm + 4] = -28.253034;
      val[734 * nCulm + 5] = 7.821306;
      val[735 * nCulm + 0] = -27.926505;
      val[735 * nCulm + 1] = -36.706706;
      val[735 * nCulm + 2] = 28.769021;
      val[735 * nCulm + 3] = -32.178033;
      val[735 * nCulm + 4] = -17.923740;
      val[735 * nCulm + 5] = 18.421205;
      val[736 * nCulm + 0] = -33.737237;
      val[736 * nCulm + 1] = 34.466435;
      val[736 * nCulm + 2] = 17.293506;
      val[736 * nCulm + 3] = 31.216639;
      val[736 * nCulm + 4] = 38.492974;
      val[736 * nCulm + 5] = 8.306796;
      val[737 * nCulm + 0] = 14.186731;
      val[737 * nCulm + 1] = 31.973100;
      val[737 * nCulm + 2] = 19.071695;
      val[737 * nCulm + 3] = -17.552753;
      val[737 * nCulm + 4] = -46.855228;
      val[737 * nCulm + 5] = -1.226749;
      val[738 * nCulm + 0] = 18.803819;
      val[738 * nCulm + 1] = 34.841261;
      val[738 * nCulm + 2] = 26.812616;
      val[738 * nCulm + 3] = -12.936864;
      val[738 * nCulm + 4] = 37.887927;
      val[738 * nCulm + 5] = 2.966513;
      val[739 * nCulm + 0] = 42.095516;
      val[739 * nCulm + 1] = -34.117330;
      val[739 * nCulm + 2] = 49.191050;
      val[739 * nCulm + 3] = 0.553198;
      val[739 * nCulm + 4] = 48.380079;
      val[739 * nCulm + 5] = -3.053794;
      val[740 * nCulm + 0] = 10.427972;
      val[740 * nCulm + 1] = 45.780682;
      val[740 * nCulm + 2] = -24.266399;
      val[740 * nCulm + 3] = 22.297574;
      val[740 * nCulm + 4] = -3.435479;
      val[740 * nCulm + 5] = -93.566841;
      val[741 * nCulm + 0] = 32.097994;
      val[741 * nCulm + 1] = -9.981305;
      val[741 * nCulm + 2] = 1.697843;
      val[741 * nCulm + 3] = -10.465517;
      val[741 * nCulm + 4] = -31.399690;
      val[741 * nCulm + 5] = 3.312248;
      val[742 * nCulm + 0] = -31.294267;
      val[742 * nCulm + 1] = 26.593222;
      val[742 * nCulm + 2] = 3.327410;
      val[742 * nCulm + 3] = -26.468676;
      val[742 * nCulm + 4] = -46.678649;
      val[742 * nCulm + 5] = 0.217371;
      val[743 * nCulm + 0] = 10.746360;
      val[743 * nCulm + 1] = -42.348493;
      val[743 * nCulm + 2] = 16.685861;
      val[743 * nCulm + 3] = 41.088546;
      val[743 * nCulm + 4] = 4.943087;
      val[743 * nCulm + 5] = -0.976483;
      val[744 * nCulm + 0] = -3.450028;
      val[744 * nCulm + 1] = -35.201542;
      val[744 * nCulm + 2] = 30.484449;
      val[744 * nCulm + 3] = 21.543933;
      val[744 * nCulm + 4] = -8.487435;
      val[744 * nCulm + 5] = 7.846673;
      val[745 * nCulm + 0] = 9.410343;
      val[745 * nCulm + 1] = -2.916713;
      val[745 * nCulm + 2] = 15.575286;
      val[745 * nCulm + 3] = -37.894578;
      val[745 * nCulm + 4] = -25.208064;
      val[745 * nCulm + 5] = 7.893161;
      val[746 * nCulm + 0] = -1.864188;
      val[746 * nCulm + 1] = 20.478236;
      val[746 * nCulm + 2] = 33.143135;
      val[746 * nCulm + 3] = -0.188352;
      val[746 * nCulm + 4] = 45.348106;
      val[746 * nCulm + 5] = 2.347812;
      val[747 * nCulm + 0] = 18.585594;
      val[747 * nCulm + 1] = 36.406862;
      val[747 * nCulm + 2] = 33.889880;
      val[747 * nCulm + 3] = 46.694707;
      val[747 * nCulm + 4] = -46.725730;
      val[747 * nCulm + 5] = -8.188219;
      val[748 * nCulm + 0] = 2.963883;
      val[748 * nCulm + 1] = 6.386240;
      val[748 * nCulm + 2] = -2.702374;
      val[748 * nCulm + 3] = -38.025258;
      val[748 * nCulm + 4] = -41.235985;
      val[748 * nCulm + 5] = 3.861731;
      val[749 * nCulm + 0] = 8.244062;
      val[749 * nCulm + 1] = 28.597293;
      val[749 * nCulm + 2] = 30.629671;
      val[749 * nCulm + 3] = 24.986159;
      val[749 * nCulm + 4] = 9.664838;
      val[749 * nCulm + 5] = 26.472379;
      val[750 * nCulm + 0] = -11.876091;
      val[750 * nCulm + 1] = -27.291997;
      val[750 * nCulm + 2] = -20.069714;
      val[750 * nCulm + 3] = 0.148250;
      val[750 * nCulm + 4] = 15.564721;
      val[750 * nCulm + 5] = -8.024591;
      val[751 * nCulm + 0] = 22.097747;
      val[751 * nCulm + 1] = 43.534955;
      val[751 * nCulm + 2] = -14.697025;
      val[751 * nCulm + 3] = 21.565538;
      val[751 * nCulm + 4] = 47.100026;
      val[751 * nCulm + 5] = 6.772296;
      val[752 * nCulm + 0] = 6.493346;
      val[752 * nCulm + 1] = -9.001716;
      val[752 * nCulm + 2] = 25.044253;
      val[752 * nCulm + 3] = -30.159879;
      val[752 * nCulm + 4] = -42.953158;
      val[752 * nCulm + 5] = 4.545512;
      val[753 * nCulm + 0] = -18.911732;
      val[753 * nCulm + 1] = -32.962574;
      val[753 * nCulm + 2] = -33.430253;
      val[753 * nCulm + 3] = 7.991848;
      val[753 * nCulm + 4] = 34.857241;
      val[753 * nCulm + 5] = -3.160824;
      val[754 * nCulm + 0] = -17.876519;
      val[754 * nCulm + 1] = 40.308213;
      val[754 * nCulm + 2] = 49.567540;
      val[754 * nCulm + 3] = -35.642953;
      val[754 * nCulm + 4] = -34.604553;
      val[754 * nCulm + 5] = -0.408131;
      val[755 * nCulm + 0] = -36.141017;
      val[755 * nCulm + 1] = -46.879806;
      val[755 * nCulm + 2] = 14.662584;
      val[755 * nCulm + 3] = -13.477039;
      val[755 * nCulm + 4] = -14.495953;
      val[755 * nCulm + 5] = 19.938194;
      val[756 * nCulm + 0] = -41.026065;
      val[756 * nCulm + 1] = -33.605756;
      val[756 * nCulm + 2] = -10.781896;
      val[756 * nCulm + 3] = -40.360875;
      val[756 * nCulm + 4] = -37.709042;
      val[756 * nCulm + 5] = 9.514477;
      val[757 * nCulm + 0] = -44.171452;
      val[757 * nCulm + 1] = -46.620299;
      val[757 * nCulm + 2] = -38.456058;
      val[757 * nCulm + 3] = -31.879608;
      val[757 * nCulm + 4] = -40.725985;
      val[757 * nCulm + 5] = 9.353566;
      val[758 * nCulm + 0] = 43.904363;
      val[758 * nCulm + 1] = -22.669540;
      val[758 * nCulm + 2] = -46.351356;
      val[758 * nCulm + 3] = 43.239301;
      val[758 * nCulm + 4] = -35.909202;
      val[758 * nCulm + 5] = -2.481381;
      val[759 * nCulm + 0] = -47.411726;
      val[759 * nCulm + 1] = -1.809700;
      val[759 * nCulm + 2] = 11.209175;
      val[759 * nCulm + 3] = 30.076058;
      val[759 * nCulm + 4] = 0.081602;
      val[759 * nCulm + 5] = 1639.821222;
      val[760 * nCulm + 0] = 39.045647;
      val[760 * nCulm + 1] = 33.187889;
      val[760 * nCulm + 2] = -45.547416;
      val[760 * nCulm + 3] = -46.964963;
      val[760 * nCulm + 4] = 38.814080;
      val[760 * nCulm + 5] = -1.450099;
      val[761 * nCulm + 0] = -39.363882;
      val[761 * nCulm + 1] = 30.464869;
      val[761 * nCulm + 2] = 34.975434;
      val[761 * nCulm + 3] = 28.647561;
      val[761 * nCulm + 4] = 23.128738;
      val[761 * nCulm + 5] = 12.327454;
      val[762 * nCulm + 0] = 26.352373;
      val[762 * nCulm + 1] = -33.521237;
      val[762 * nCulm + 2] = 19.782742;
      val[762 * nCulm + 3] = -4.031566;
      val[762 * nCulm + 4] = -37.434586;
      val[762 * nCulm + 5] = 4.978281;
      val[763 * nCulm + 0] = -3.099580;
      val[763 * nCulm + 1] = -3.269546;
      val[763 * nCulm + 2] = 43.967197;
      val[763 * nCulm + 3] = -22.984317;
      val[763 * nCulm + 4] = -5.559678;
      val[763 * nCulm + 5] = 22.581704;
      val[764 * nCulm + 0] = 27.930873;
      val[764 * nCulm + 1] = 15.666996;
      val[764 * nCulm + 2] = -26.912931;
      val[764 * nCulm + 3] = 0.005956;
      val[764 * nCulm + 4] = -11.370744;
      val[764 * nCulm + 5] = -6.294227;
      val[765 * nCulm + 0] = 44.431689;
      val[765 * nCulm + 1] = -4.370586;
      val[765 * nCulm + 2] = 12.501011;
      val[765 * nCulm + 3] = 21.173704;
      val[765 * nCulm + 4] = -42.946332;
      val[765 * nCulm + 5] = -1.621957;
      val[766 * nCulm + 0] = -19.646751;
      val[766 * nCulm + 1] = 15.535847;
      val[766 * nCulm + 2] = 17.748691;
      val[766 * nCulm + 3] = 41.352766;
      val[766 * nCulm + 4] = 37.923271;
      val[766 * nCulm + 5] = 7.330463;
      val[767 * nCulm + 0] = 30.754948;
      val[767 * nCulm + 1] = -49.416523;
      val[767 * nCulm + 2] = -27.549620;
      val[767 * nCulm + 3] = 32.375237;
      val[767 * nCulm + 4] = 47.530140;
      val[767 * nCulm + 5] = -1.467072;
      val[768 * nCulm + 0] = 16.207820;
      val[768 * nCulm + 1] = 32.834905;
      val[768 * nCulm + 2] = 24.048657;
      val[768 * nCulm + 3] = 39.743206;
      val[768 * nCulm + 4] = 3.178882;
      val[768 * nCulm + 5] = 108.298321;
      val[769 * nCulm + 0] = -30.274642;
      val[769 * nCulm + 1] = 35.688265;
      val[769 * nCulm + 2] = -34.854332;
      val[769 * nCulm + 3] = -40.050986;
      val[769 * nCulm + 4] = 21.065902;
      val[769 * nCulm + 5] = -0.750267;
      val[770 * nCulm + 0] = 32.162857;
      val[770 * nCulm + 1] = -11.642037;
      val[770 * nCulm + 2] = -0.564752;
      val[770 * nCulm + 3] = 9.232700;
      val[770 * nCulm + 4] = -49.003370;
      val[770 * nCulm + 5] = 0.462723;
      val[771 * nCulm + 0] = 20.112761;
      val[771 * nCulm + 1] = 46.791982;
      val[771 * nCulm + 2] = -39.241181;
      val[771 * nCulm + 3] = -3.547189;
      val[771 * nCulm + 4] = 49.911978;
      val[771 * nCulm + 5] = 4.331060;
      val[772 * nCulm + 0] = 32.573691;
      val[772 * nCulm + 1] = 49.904661;
      val[772 * nCulm + 2] = 7.533404;
      val[772 * nCulm + 3] = 13.825668;
      val[772 * nCulm + 4] = -1.892464;
      val[772 * nCulm + 5] = -159.169047;
      val[773 * nCulm + 0] = -36.903185;
      val[773 * nCulm + 1] = 12.752504;
      val[773 * nCulm + 2] = 6.319995;
      val[773 * nCulm + 3] = 29.098832;
      val[773 * nCulm + 4] = 4.514068;
      val[773 * nCulm + 5] = 44.114216;
      val[774 * nCulm + 0] = 15.226766;
      val[774 * nCulm + 1] = 27.071725;
      val[774 * nCulm + 2] = 0.305170;
      val[774 * nCulm + 3] = -39.132686;
      val[774 * nCulm + 4] = -44.042255;
      val[774 * nCulm + 5] = 1.526222;
      val[775 * nCulm + 0] = 48.740524;
      val[775 * nCulm + 1] = -43.133844;
      val[775 * nCulm + 2] = -44.918047;
      val[775 * nCulm + 3] = -44.862775;
      val[775 * nCulm + 4] = -10.684789;
      val[775 * nCulm + 5] = 39.212269;
      val[776 * nCulm + 0] = -20.531642;
      val[776 * nCulm + 1] = -30.973256;
      val[776 * nCulm + 2] = 30.527408;
      val[776 * nCulm + 3] = 33.883075;
      val[776 * nCulm + 4] = 8.455627;
      val[776 * nCulm + 5] = 1.858873;
      val[777 * nCulm + 0] = -8.959863;
      val[777 * nCulm + 1] = -15.404550;
      val[777 * nCulm + 2] = 16.336377;
      val[777 * nCulm + 3] = 2.820624;
      val[777 * nCulm + 4] = 24.245140;
      val[777 * nCulm + 5] = -2.226736;
      val[778 * nCulm + 0] = 4.313308;
      val[778 * nCulm + 1] = 14.527087;
      val[778 * nCulm + 2] = -14.887555;
      val[778 * nCulm + 3] = 24.271336;
      val[778 * nCulm + 4] = -41.483339;
      val[778 * nCulm + 5] = -4.196979;
      val[779 * nCulm + 0] = 31.371744;
      val[779 * nCulm + 1] = 27.734120;
      val[779 * nCulm + 2] = -41.823106;
      val[779 * nCulm + 3] = -47.059526;
      val[779 * nCulm + 4] = -47.659590;
      val[779 * nCulm + 5] = 2.149311;
      val[780 * nCulm + 0] = 48.559900;
      val[780 * nCulm + 1] = 33.389765;
      val[780 * nCulm + 2] = -33.866948;
      val[780 * nCulm + 3] = 20.314833;
      val[780 * nCulm + 4] = 23.440722;
      val[780 * nCulm + 5] = 11.074451;
      val[781 * nCulm + 0] = 38.328685;
      val[781 * nCulm + 1] = -17.427537;
      val[781 * nCulm + 2] = 1.248442;
      val[781 * nCulm + 3] = 37.596986;
      val[781 * nCulm + 4] = 20.975567;
      val[781 * nCulm + 5] = 4.781425;
      val[782 * nCulm + 0] = 19.495020;
      val[782 * nCulm + 1] = -8.202330;
      val[782 * nCulm + 2] = 9.896063;
      val[782 * nCulm + 3] = 44.752748;
      val[782 * nCulm + 4] = -5.037976;
      val[782 * nCulm + 5] = -34.110243;
      val[783 * nCulm + 0] = 46.171860;
      val[783 * nCulm + 1] = 38.660145;
      val[783 * nCulm + 2] = 21.634704;
      val[783 * nCulm + 3] = 7.623449;
      val[783 * nCulm + 4] = -22.414738;
      val[783 * nCulm + 5] = -9.543734;
      val[784 * nCulm + 0] = -8.397949;
      val[784 * nCulm + 1] = 9.470328;
      val[784 * nCulm + 2] = 41.315089;
      val[784 * nCulm + 3] = -10.070554;
      val[784 * nCulm + 4] = 18.681067;
      val[784 * nCulm + 5] = 0.077917;
      val[785 * nCulm + 0] = 2.912179;
      val[785 * nCulm + 1] = -21.394896;
      val[785 * nCulm + 2] = 26.242097;
      val[785 * nCulm + 3] = -43.308317;
      val[785 * nCulm + 4] = 42.378108;
      val[785 * nCulm + 5] = -6.996889;
      val[786 * nCulm + 0] = 38.732029;
      val[786 * nCulm + 1] = -22.161042;
      val[786 * nCulm + 2] = 11.589538;
      val[786 * nCulm + 3] = -46.110537;
      val[786 * nCulm + 4] = -15.877519;
      val[786 * nCulm + 5] = 20.582811;
      val[787 * nCulm + 0] = -6.860989;
      val[787 * nCulm + 1] = 0.161532;
      val[787 * nCulm + 2] = 6.097918;
      val[787 * nCulm + 3] = 6.189210;
      val[787 * nCulm + 4] = -18.526520;
      val[787 * nCulm + 5] = -1.392549;
      val[788 * nCulm + 0] = -8.030203;
      val[788 * nCulm + 1] = 23.163297;
      val[788 * nCulm + 2] = 6.236338;
      val[788 * nCulm + 3] = -38.955128;
      val[788 * nCulm + 4] = -30.669339;
      val[788 * nCulm + 5] = 2.667222;
      val[789 * nCulm + 0] = -0.747731;
      val[789 * nCulm + 1] = -1.408733;
      val[789 * nCulm + 2] = 7.025971;
      val[789 * nCulm + 3] = -26.545947;
      val[789 * nCulm + 4] = -44.373769;
      val[789 * nCulm + 5] = 3.211915;
      val[790 * nCulm + 0] = 2.282025;
      val[790 * nCulm + 1] = -15.637025;
      val[790 * nCulm + 2] = 47.832413;
      val[790 * nCulm + 3] = 37.436177;
      val[790 * nCulm + 4] = 16.893195;
      val[790 * nCulm + 5] = 6.337942;
      val[791 * nCulm + 0] = -5.976723;
      val[791 * nCulm + 1] = -7.300954;
      val[791 * nCulm + 2] = -12.364365;
      val[791 * nCulm + 3] = 48.881841;
      val[791 * nCulm + 4] = 33.901740;
      val[791 * nCulm + 5] = 6.035490;
      val[792 * nCulm + 0] = -1.376490;
      val[792 * nCulm + 1] = -14.393717;
      val[792 * nCulm + 2] = -30.497013;
      val[792 * nCulm + 3] = -23.590828;
      val[792 * nCulm + 4] = -18.798714;
      val[792 * nCulm + 5] = 9.794139;
      val[793 * nCulm + 0] = 17.705350;
      val[793 * nCulm + 1] = 27.346934;
      val[793 * nCulm + 2] = 16.120955;
      val[793 * nCulm + 3] = -48.961222;
      val[793 * nCulm + 4] = 10.764038;
      val[793 * nCulm + 5] = -9.274577;
      val[794 * nCulm + 0] = 13.274032;
      val[794 * nCulm + 1] = -6.772500;
      val[794 * nCulm + 2] = -27.377504;
      val[794 * nCulm + 3] = -37.291782;
      val[794 * nCulm + 4] = 40.866999;
      val[794 * nCulm + 5] = -4.873652;
      val[795 * nCulm + 0] = -39.900029;
      val[795 * nCulm + 1] = -18.292173;
      val[795 * nCulm + 2] = -46.177904;
      val[795 * nCulm + 3] = 39.539068;
      val[795 * nCulm + 4] = 33.411363;
      val[795 * nCulm + 5] = 3.240013;
      val[796 * nCulm + 0] = 16.615136;
      val[796 * nCulm + 1] = 17.490457;
      val[796 * nCulm + 2] = 30.770557;
      val[796 * nCulm + 3] = 11.616420;
      val[796 * nCulm + 4] = 47.743253;
      val[796 * nCulm + 5] = 3.115697;
      val[797 * nCulm + 0] = 42.666223;
      val[797 * nCulm + 1] = -28.040144;
      val[797 * nCulm + 2] = -39.297410;
      val[797 * nCulm + 3] = -29.438024;
      val[797 * nCulm + 4] = -5.224296;
      val[797 * nCulm + 5] = 52.306554;
      val[798 * nCulm + 0] = -1.376886;
      val[798 * nCulm + 1] = 1.136168;
      val[798 * nCulm + 2] = 4.851735;
      val[798 * nCulm + 3] = -10.924128;
      val[798 * nCulm + 4] = -24.471640;
      val[798 * nCulm + 5] = 2.123199;
      val[799 * nCulm + 0] = -38.613517;
      val[799 * nCulm + 1] = -46.778881;
      val[799 * nCulm + 2] = -30.365858;
      val[799 * nCulm + 3] = 4.281960;
      val[799 * nCulm + 4] = 4.136564;
      val[799 * nCulm + 5] = -48.397822;
      val[800 * nCulm + 0] = 22.814826;
      val[800 * nCulm + 1] = -9.646973;
      val[800 * nCulm + 2] = 35.056190;
      val[800 * nCulm + 3] = 42.386207;
      val[800 * nCulm + 4] = 26.434351;
      val[800 * nCulm + 5] = 6.092285;
      val[801 * nCulm + 0] = 45.730627;
      val[801 * nCulm + 1] = -32.927675;
      val[801 * nCulm + 2] = 12.823390;
      val[801 * nCulm + 3] = -13.895481;
      val[801 * nCulm + 4] = -31.993135;
      val[801 * nCulm + 5] = 7.157411;
      val[802 * nCulm + 0] = 5.168471;
      val[802 * nCulm + 1] = 49.258913;
      val[802 * nCulm + 2] = 16.868279;
      val[802 * nCulm + 3] = 15.388117;
      val[802 * nCulm + 4] = 27.625046;
      val[802 * nCulm + 5] = 11.306758;
      val[803 * nCulm + 0] = 2.438127;
      val[803 * nCulm + 1] = 41.247029;
      val[803 * nCulm + 2] = 14.435604;
      val[803 * nCulm + 3] = -42.575418;
      val[803 * nCulm + 4] = -37.354247;
      val[803 * nCulm + 5] = 0.398326;
      val[804 * nCulm + 0] = -28.398328;
      val[804 * nCulm + 1] = -21.189419;
      val[804 * nCulm + 2] = 47.745791;
      val[804 * nCulm + 3] = 9.120914;
      val[804 * nCulm + 4] = 37.034491;
      val[804 * nCulm + 5] = -1.312461;
      val[805 * nCulm + 0] = 40.935840;
      val[805 * nCulm + 1] = 44.591250;
      val[805 * nCulm + 2] = -39.710686;
      val[805 * nCulm + 3] = 33.477122;
      val[805 * nCulm + 4] = -5.038057;
      val[805 * nCulm + 5] = -73.116452;
      val[806 * nCulm + 0] = 2.003859;
      val[806 * nCulm + 1] = 27.818428;
      val[806 * nCulm + 2] = -0.294669;
      val[806 * nCulm + 3] = 8.456178;
      val[806 * nCulm + 4] = 2.736384;
      val[806 * nCulm + 5] = 62.976968;
      val[807 * nCulm + 0] = 23.554233;
      val[807 * nCulm + 1] = 6.545936;
      val[807 * nCulm + 2] = 6.630947;
      val[807 * nCulm + 3] = 28.089215;
      val[807 * nCulm + 4] = -30.530225;
      val[807 * nCulm + 5] = -5.139751;
      val[808 * nCulm + 0] = 0.701414;
      val[808 * nCulm + 1] = -21.204268;
      val[808 * nCulm + 2] = 4.723446;
      val[808 * nCulm + 3] = -9.132674;
      val[808 * nCulm + 4] = 28.826780;
      val[808 * nCulm + 5] = -4.751301;
      val[809 * nCulm + 0] = 1.214553;
      val[809 * nCulm + 1] = -24.100523;
      val[809 * nCulm + 2] = 47.192078;
      val[809 * nCulm + 3] = 21.195955;
      val[809 * nCulm + 4] = 49.373352;
      val[809 * nCulm + 5] = -0.048456;
      val[810 * nCulm + 0] = -25.083903;
      val[810 * nCulm + 1] = -12.421911;
      val[810 * nCulm + 2] = -42.082722;
      val[810 * nCulm + 3] = -3.849709;
      val[810 * nCulm + 4] = 40.028809;
      val[810 * nCulm + 5] = -1.694089;
      val[811 * nCulm + 0] = -20.823530;
      val[811 * nCulm + 1] = -29.072325;
      val[811 * nCulm + 2] = -34.374639;
      val[811 * nCulm + 3] = 13.841952;
      val[811 * nCulm + 4] = -38.077051;
      val[811 * nCulm + 5] = 2.123278;
      val[812 * nCulm + 0] = 4.512014;
      val[812 * nCulm + 1] = 32.560758;
      val[812 * nCulm + 2] = 18.594425;
      val[812 * nCulm + 3] = 43.974750;
      val[812 * nCulm + 4] = -10.305335;
      val[812 * nCulm + 5] = -34.923451;
      val[813 * nCulm + 0] = 40.324577;
      val[813 * nCulm + 1] = 2.154555;
      val[813 * nCulm + 2] = -31.102584;
      val[813 * nCulm + 3] = 36.945139;
      val[813 * nCulm + 4] = -10.358129;
      val[813 * nCulm + 5] = -17.637308;
      val[814 * nCulm + 0] = -16.085903;
      val[814 * nCulm + 1] = -37.850459;
      val[814 * nCulm + 2] = 32.013765;
      val[814 * nCulm + 3] = -34.047875;
      val[814 * nCulm + 4] = -48.404058;
      val[814 * nCulm + 5] = 7.260790;
      val[815 * nCulm + 0] = -13.293176;
      val[815 * nCulm + 1] = -10.925818;
      val[815 * nCulm + 2] = -38.057745;
      val[815 * nCulm + 3] = -49.017338;
      val[815 * nCulm + 4] = -30.492210;
      val[815 * nCulm + 5] = 9.535031;
      val[816 * nCulm + 0] = 25.865429;
      val[816 * nCulm + 1] = 47.644551;
      val[816 * nCulm + 2] = 0.957581;
      val[816 * nCulm + 3] = 49.043127;
      val[816 * nCulm + 4] = -12.827751;
      val[816 * nCulm + 5] = -35.446948;
      val[817 * nCulm + 0] = 26.693491;
      val[817 * nCulm + 1] = -12.153698;
      val[817 * nCulm + 2] = -5.410488;
      val[817 * nCulm + 3] = -18.111228;
      val[817 * nCulm + 4] = 14.471192;
      val[817 * nCulm + 5] = -9.669253;
      val[818 * nCulm + 0] = -14.253050;
      val[818 * nCulm + 1] = 26.791492;
      val[818 * nCulm + 2] = 25.945020;
      val[818 * nCulm + 3] = -47.690316;
      val[818 * nCulm + 4] = -33.504093;
      val[818 * nCulm + 5] = 3.182508;
      val[819 * nCulm + 0] = 7.943433;
      val[819 * nCulm + 1] = -39.823266;
      val[819 * nCulm + 2] = 30.124948;
      val[819 * nCulm + 3] = -12.825472;
      val[819 * nCulm + 4] = 20.823752;
      val[819 * nCulm + 5] = -11.737297;
      val[820 * nCulm + 0] = -41.286121;
      val[820 * nCulm + 1] = 27.827916;
      val[820 * nCulm + 2] = 20.562257;
      val[820 * nCulm + 3] = -10.873446;
      val[820 * nCulm + 4] = 32.171613;
      val[820 * nCulm + 5] = 2.724471;
      val[821 * nCulm + 0] = -37.376355;
      val[821 * nCulm + 1] = 11.089007;
      val[821 * nCulm + 2] = 4.963560;
      val[821 * nCulm + 3] = 0.877791;
      val[821 * nCulm + 4] = 18.937915;
      val[821 * nCulm + 5] = 3.220976;
      val[822 * nCulm + 0] = -9.098243;
      val[822 * nCulm + 1] = 5.782776;
      val[822 * nCulm + 2] = -46.380265;
      val[822 * nCulm + 3] = 15.405337;
      val[822 * nCulm + 4] = 13.615187;
      val[822 * nCulm + 5] = 7.596069;
      val[823 * nCulm + 0] = 22.097009;
      val[823 * nCulm + 1] = -44.392480;
      val[823 * nCulm + 2] = 38.555899;
      val[823 * nCulm + 3] = 27.855788;
      val[823 * nCulm + 4] = 38.059113;
      val[823 * nCulm + 5] = -1.826634;
      val[824 * nCulm + 0] = -18.725440;
      val[824 * nCulm + 1] = 3.954797;
      val[824 * nCulm + 2] = 40.152275;
      val[824 * nCulm + 3] = 35.392135;
      val[824 * nCulm + 4] = 17.252326;
      val[824 * nCulm + 5] = 11.025190;
      val[825 * nCulm + 0] = -40.522593;
      val[825 * nCulm + 1] = -9.752106;
      val[825 * nCulm + 2] = -15.301122;
      val[825 * nCulm + 3] = 34.800671;
      val[825 * nCulm + 4] = 31.517617;
      val[825 * nCulm + 5] = 3.991807;
      val[826 * nCulm + 0] = -29.552795;
      val[826 * nCulm + 1] = 41.755269;
      val[826 * nCulm + 2] = 32.984432;
      val[826 * nCulm + 3] = 11.004744;
      val[826 * nCulm + 4] = -10.133667;
      val[826 * nCulm + 5] = -24.413669;
      val[827 * nCulm + 0] = -22.291325;
      val[827 * nCulm + 1] = 40.031454;
      val[827 * nCulm + 2] = -23.525041;
      val[827 * nCulm + 3] = -22.421664;
      val[827 * nCulm + 4] = 13.150175;
      val[827 * nCulm + 5] = 6.568547;
      val[828 * nCulm + 0] = -13.305821;
      val[828 * nCulm + 1] = 34.743111;
      val[828 * nCulm + 2] = 48.624224;
      val[828 * nCulm + 3] = 11.428230;
      val[828 * nCulm + 4] = -20.934497;
      val[828 * nCulm + 5] = -10.209436;
      val[829 * nCulm + 0] = 34.526708;
      val[829 * nCulm + 1] = 48.422384;
      val[829 * nCulm + 2] = -22.386978;
      val[829 * nCulm + 3] = -8.503253;
      val[829 * nCulm + 4] = 35.908350;
      val[829 * nCulm + 5] = 5.492023;
      val[830 * nCulm + 0] = -24.665240;
      val[830 * nCulm + 1] = 14.703773;
      val[830 * nCulm + 2] = 3.382203;
      val[830 * nCulm + 3] = -39.872845;
      val[830 * nCulm + 4] = -13.871353;
      val[830 * nCulm + 5] = 8.818464;
      val[831 * nCulm + 0] = 19.118339;
      val[831 * nCulm + 1] = -44.299064;
      val[831 * nCulm + 2] = 34.231855;
      val[831 * nCulm + 3] = -11.004366;
      val[831 * nCulm + 4] = 25.076183;
      val[831 * nCulm + 5] = -10.208972;
      val[832 * nCulm + 0] = -49.379722;
      val[832 * nCulm + 1] = -34.991837;
      val[832 * nCulm + 2] = -21.480228;
      val[832 * nCulm + 3] = 42.926093;
      val[832 * nCulm + 4] = 22.196144;
      val[832 * nCulm + 5] = 1.921982;
      val[833 * nCulm + 0] = 49.126332;
      val[833 * nCulm + 1] = 12.831439;
      val[833 * nCulm + 2] = -25.651476;
      val[833 * nCulm + 3] = -22.733240;
      val[833 * nCulm + 4] = -41.588140;
      val[833 * nCulm + 5] = 1.356968;
      val[834 * nCulm + 0] = 46.160159;
      val[834 * nCulm + 1] = -15.390800;
      val[834 * nCulm + 2] = 36.652320;
      val[834 * nCulm + 3] = 27.690179;
      val[834 * nCulm + 4] = 41.306121;
      val[834 * nCulm + 5] = 1.639405;
      val[835 * nCulm + 0] = 28.776255;
      val[835 * nCulm + 1] = 47.007231;
      val[835 * nCulm + 2] = 33.482356;
      val[835 * nCulm + 3] = 5.100709;
      val[835 * nCulm + 4] = 41.984304;
      val[835 * nCulm + 5] = 6.104678;
      val[836 * nCulm + 0] = 0.565247;
      val[836 * nCulm + 1] = 17.883668;
      val[836 * nCulm + 2] = -6.966169;
      val[836 * nCulm + 3] = -39.876376;
      val[836 * nCulm + 4] = 31.531565;
      val[836 * nCulm + 5] = -3.071416;
      val[837 * nCulm + 0] = -23.527201;
      val[837 * nCulm + 1] = -10.202708;
      val[837 * nCulm + 2] = 20.470263;
      val[837 * nCulm + 3] = -45.809974;
      val[837 * nCulm + 4] = -39.295092;
      val[837 * nCulm + 5] = 6.977069;
      val[838 * nCulm + 0] = 10.629490;
      val[838 * nCulm + 1] = -3.338471;
      val[838 * nCulm + 2] = -6.764226;
      val[838 * nCulm + 3] = -22.365859;
      val[838 * nCulm + 4] = -22.595381;
      val[838 * nCulm + 5] = 5.614603;
      val[839 * nCulm + 0] = 36.837461;
      val[839 * nCulm + 1] = 46.178353;
      val[839 * nCulm + 2] = -33.006296;
      val[839 * nCulm + 3] = 27.970804;
      val[839 * nCulm + 4] = -37.469386;
      val[839 * nCulm + 5] = -9.136918;
      val[840 * nCulm + 0] = -19.653310;
      val[840 * nCulm + 1] = -28.423575;
      val[840 * nCulm + 2] = 13.942825;
      val[840 * nCulm + 3] = -37.919917;
      val[840 * nCulm + 4] = -8.831586;
      val[840 * nCulm + 5] = 35.787132;
      val[841 * nCulm + 0] = 15.235677;
      val[841 * nCulm + 1] = 20.361337;
      val[841 * nCulm + 2] = -26.342722;
      val[841 * nCulm + 3] = 11.543861;
      val[841 * nCulm + 4] = 15.141474;
      val[841 * nCulm + 5] = 10.203794;
      val[842 * nCulm + 0] = -13.067555;
      val[842 * nCulm + 1] = 46.447399;
      val[842 * nCulm + 2] = -7.015579;
      val[842 * nCulm + 3] = -45.899125;
      val[842 * nCulm + 4] = -10.600875;
      val[842 * nCulm + 5] = -0.014807;
      val[843 * nCulm + 0] = 5.316328;
      val[843 * nCulm + 1] = 25.982757;
      val[843 * nCulm + 2] = -5.623988;
      val[843 * nCulm + 3] = 36.772082;
      val[843 * nCulm + 4] = 32.099522;
      val[843 * nCulm + 5] = 9.483707;
      val[844 * nCulm + 0] = 40.351800;
      val[844 * nCulm + 1] = -28.665882;
      val[844 * nCulm + 2] = 28.476048;
      val[844 * nCulm + 3] = -7.522707;
      val[844 * nCulm + 4] = 34.121040;
      val[844 * nCulm + 5] = -4.790148;
      val[845 * nCulm + 0] = 7.734323;
      val[845 * nCulm + 1] = -40.744078;
      val[845 * nCulm + 2] = 28.935511;
      val[845 * nCulm + 3] = 33.198737;
      val[845 * nCulm + 4] = -41.055514;
      val[845 * nCulm + 5] = 1.099910;
      val[846 * nCulm + 0] = -12.489257;
      val[846 * nCulm + 1] = -1.189272;
      val[846 * nCulm + 2] = -1.487529;
      val[846 * nCulm + 3] = -30.407134;
      val[846 * nCulm + 4] = 4.284896;
      val[846 * nCulm + 5] = -34.673136;
      val[847 * nCulm + 0] = 46.806795;
      val[847 * nCulm + 1] = -17.961598;
      val[847 * nCulm + 2] = 48.296520;
      val[847 * nCulm + 3] = -8.048016;
      val[847 * nCulm + 4] = 47.008837;
      val[847 * nCulm + 5] = -2.388915;
      val[848 * nCulm + 0] = -38.936301;
      val[848 * nCulm + 1] = -16.047315;
      val[848 * nCulm + 2] = 20.248785;
      val[848 * nCulm + 3] = -2.837789;
      val[848 * nCulm + 4] = 12.717959;
      val[848 * nCulm + 5] = -6.798604;
      val[849 * nCulm + 0] = -1.540932;
      val[849 * nCulm + 1] = -28.871778;
      val[849 * nCulm + 2] = 16.974581;
      val[849 * nCulm + 3] = 8.742436;
      val[849 * nCulm + 4] = 21.476598;
      val[849 * nCulm + 5] = -4.206405;
      val[850 * nCulm + 0] = 48.844813;
      val[850 * nCulm + 1] = -24.334886;
      val[850 * nCulm + 2] = 22.316014;
      val[850 * nCulm + 3] = 35.607169;
      val[850 * nCulm + 4] = 43.310658;
      val[850 * nCulm + 5] = 1.461925;
      val[851 * nCulm + 0] = 20.036313;
      val[851 * nCulm + 1] = 40.193651;
      val[851 * nCulm + 2] = 44.381827;
      val[851 * nCulm + 3] = -36.131909;
      val[851 * nCulm + 4] = -36.402607;
      val[851 * nCulm + 5] = -0.298137;
      val[852 * nCulm + 0] = 41.964437;
      val[852 * nCulm + 1] = 33.021373;
      val[852 * nCulm + 2] = -12.433509;
      val[852 * nCulm + 3] = 47.388393;
      val[852 * nCulm + 4] = 38.645012;
      val[852 * nCulm + 5] = 10.078780;
      val[853 * nCulm + 0] = 12.067720;
      val[853 * nCulm + 1] = -16.063400;
      val[853 * nCulm + 2] = -46.443462;
      val[853 * nCulm + 3] = 9.998408;
      val[853 * nCulm + 4] = 22.144455;
      val[853 * nCulm + 5] = -1.066380;
      val[854 * nCulm + 0] = -21.408397;
      val[854 * nCulm + 1] = 43.443272;
      val[854 * nCulm + 2] = 10.976876;
      val[854 * nCulm + 3] = 16.467800;
      val[854 * nCulm + 4] = -3.711601;
      val[854 * nCulm + 5] = -76.173443;
      val[855 * nCulm + 0] = -44.155090;
      val[855 * nCulm + 1] = 40.931808;
      val[855 * nCulm + 2] = 31.561474;
      val[855 * nCulm + 3] = -33.949397;
      val[855 * nCulm + 4] = -19.757405;
      val[855 * nCulm + 5] = -1.442795;
      val[856 * nCulm + 0] = 47.191284;
      val[856 * nCulm + 1] = 7.851485;
      val[856 * nCulm + 2] = -9.919640;
      val[856 * nCulm + 3] = 18.461766;
      val[856 * nCulm + 4] = 28.027935;
      val[856 * nCulm + 5] = 4.673759;
      val[857 * nCulm + 0] = 34.690245;
      val[857 * nCulm + 1] = 47.464376;
      val[857 * nCulm + 2] = 43.887809;
      val[857 * nCulm + 3] = -13.095438;
      val[857 * nCulm + 4] = 8.540535;
      val[857 * nCulm + 5] = 19.277944;
      val[858 * nCulm + 0] = -4.347757;
      val[858 * nCulm + 1] = 45.917555;
      val[858 * nCulm + 2] = 26.832485;
      val[858 * nCulm + 3] = -46.425228;
      val[858 * nCulm + 4] = 47.882276;
      val[858 * nCulm + 5] = 0.179815;
      val[859 * nCulm + 0] = -19.806963;
      val[859 * nCulm + 1] = 12.265686;
      val[859 * nCulm + 2] = 5.838310;
      val[859 * nCulm + 3] = 25.777101;
      val[859 * nCulm + 4] = 21.403866;
      val[859 * nCulm + 5] = 8.642929;
      val[860 * nCulm + 0] = -2.647550;
      val[860 * nCulm + 1] = 21.365048;
      val[860 * nCulm + 2] = -12.942542;
      val[860 * nCulm + 3] = 17.886529;
      val[860 * nCulm + 4] = 27.009478;
      val[860 * nCulm + 5] = 7.108726;
      val[861 * nCulm + 0] = -49.741472;
      val[861 * nCulm + 1] = 6.836257;
      val[861 * nCulm + 2] = -36.835644;
      val[861 * nCulm + 3] = 19.334916;
      val[861 * nCulm + 4] = 32.279537;
      val[861 * nCulm + 5] = 4.067629;
      val[862 * nCulm + 0] = -21.071479;
      val[862 * nCulm + 1] = -25.346264;
      val[862 * nCulm + 2] = -48.432230;
      val[862 * nCulm + 3] = 40.720109;
      val[862 * nCulm + 4] = 30.493576;
      val[862 * nCulm + 5] = 2.616389;
      val[863 * nCulm + 0] = 44.257929;
      val[863 * nCulm + 1] = 9.467636;
      val[863 * nCulm + 2] = 47.532513;
      val[863 * nCulm + 3] = -22.192225;
      val[863 * nCulm + 4] = 29.226887;
      val[863 * nCulm + 5] = -1.830764;
      val[864 * nCulm + 0] = -29.276598;
      val[864 * nCulm + 1] = 24.517306;
      val[864 * nCulm + 2] = 10.119712;
      val[864 * nCulm + 3] = -17.432396;
      val[864 * nCulm + 4] = -45.736050;
      val[864 * nCulm + 5] = -0.503234;
      val[865 * nCulm + 0] = 49.005824;
      val[865 * nCulm + 1] = -48.906622;
      val[865 * nCulm + 2] = -13.421220;
      val[865 * nCulm + 3] = -6.025072;
      val[865 * nCulm + 4] = -48.587877;
      val[865 * nCulm + 5] = 5.581335;
      val[866 * nCulm + 0] = 37.169294;
      val[866 * nCulm + 1] = -44.645483;
      val[866 * nCulm + 2] = 21.333292;
      val[866 * nCulm + 3] = -48.404699;
      val[866 * nCulm + 4] = -1.863956;
      val[866 * nCulm + 5] = 236.521756;
      val[867 * nCulm + 0] = 30.699847;
      val[867 * nCulm + 1] = -31.233313;
      val[867 * nCulm + 2] = 37.830477;
      val[867 * nCulm + 3] = 10.802813;
      val[867 * nCulm + 4] = -14.702309;
      val[867 * nCulm + 5] = 6.807495;
      val[868 * nCulm + 0] = 18.709064;
      val[868 * nCulm + 1] = 32.293245;
      val[868 * nCulm + 2] = -41.772535;
      val[868 * nCulm + 3] = -29.679041;
      val[868 * nCulm + 4] = 46.039421;
      val[868 * nCulm + 5] = 0.498768;
      val[869 * nCulm + 0] = 28.708472;
      val[869 * nCulm + 1] = -30.773605;
      val[869 * nCulm + 2] = 4.559825;
      val[869 * nCulm + 3] = 43.093064;
      val[869 * nCulm + 4] = 36.371808;
      val[869 * nCulm + 5] = 1.833223;
      val[870 * nCulm + 0] = -26.083004;
      val[870 * nCulm + 1] = -40.253323;
      val[870 * nCulm + 2] = 27.751852;
      val[870 * nCulm + 3] = 4.462721;
      val[870 * nCulm + 4] = 28.274223;
      val[870 * nCulm + 5] = -5.761636;
      val[871 * nCulm + 0] = -24.056260;
      val[871 * nCulm + 1] = 8.707965;
      val[871 * nCulm + 2] = 25.296158;
      val[871 * nCulm + 3] = 49.401495;
      val[871 * nCulm + 4] = 17.776588;
      val[871 * nCulm + 5] = 15.702680;
      val[872 * nCulm + 0] = 44.737762;
      val[872 * nCulm + 1] = 47.453492;
      val[872 * nCulm + 2] = -13.431061;
      val[872 * nCulm + 3] = -20.718095;
      val[872 * nCulm + 4] = -37.905533;
      val[872 * nCulm + 5] = -3.108498;
      val[873 * nCulm + 0] = -2.489442;
      val[873 * nCulm + 1] = 49.409710;
      val[873 * nCulm + 2] = 22.989254;
      val[873 * nCulm + 3] = 48.941718;
      val[873 * nCulm + 4] = 35.220987;
      val[873 * nCulm + 5] = 13.447406;
      val[874 * nCulm + 0] = 49.965069;
      val[874 * nCulm + 1] = -5.778630;
      val[874 * nCulm + 2] = -48.087980;
      val[874 * nCulm + 3] = -24.248694;
      val[874 * nCulm + 4] = 44.397664;
      val[874 * nCulm + 5] = -2.971280;
      val[875 * nCulm + 0] = -21.445895;
      val[875 * nCulm + 1] = -26.016204;
      val[875 * nCulm + 2] = -35.704906;
      val[875 * nCulm + 3] = -47.068143;
      val[875 * nCulm + 4] = 10.656547;
      val[875 * nCulm + 5] = -32.231977;
      val[876 * nCulm + 0] = 19.320607;
      val[876 * nCulm + 1] = 16.273238;
      val[876 * nCulm + 2] = 32.796899;
      val[876 * nCulm + 3] = -5.978049;
      val[876 * nCulm + 4] = -29.554639;
      val[876 * nCulm + 5] = -1.418829;
      val[877 * nCulm + 0] = -9.857304;
      val[877 * nCulm + 1] = -49.090617;
      val[877 * nCulm + 2] = 22.589122;
      val[877 * nCulm + 3] = 38.491253;
      val[877 * nCulm + 4] = -5.174377;
      val[877 * nCulm + 5] = 9.925916;
      val[878 * nCulm + 0] = 48.195024;
      val[878 * nCulm + 1] = 40.146746;
      val[878 * nCulm + 2] = 43.887661;
      val[878 * nCulm + 3] = -15.345739;
      val[878 * nCulm + 4] = 15.498739;
      val[878 * nCulm + 5] = 7.804257;
      val[879 * nCulm + 0] = -41.727333;
      val[879 * nCulm + 1] = 44.666150;
      val[879 * nCulm + 2] = 11.156689;
      val[879 * nCulm + 3] = -13.192133;
      val[879 * nCulm + 4] = -6.103462;
      val[879 * nCulm + 5] = -24.178609;
      val[880 * nCulm + 0] = -22.061821;
      val[880 * nCulm + 1] = 48.891468;
      val[880 * nCulm + 2] = 34.105891;
      val[880 * nCulm + 3] = 18.637505;
      val[880 * nCulm + 4] = 2.964444;
      val[880 * nCulm + 5] = 108.053657;
      val[881 * nCulm + 0] = 13.060490;
      val[881 * nCulm + 1] = -38.913654;
      val[881 * nCulm + 2] = -21.088019;
      val[881 * nCulm + 3] = -39.103436;
      val[881 * nCulm + 4] = 44.484038;
      val[881 * nCulm + 5] = -8.071425;
      val[882 * nCulm + 0] = -20.490004;
      val[882 * nCulm + 1] = -33.607584;
      val[882 * nCulm + 2] = 23.786293;
      val[882 * nCulm + 3] = -32.840952;
      val[882 * nCulm + 4] = 19.718546;
      val[882 * nCulm + 5] = -15.720622;
      val[883 * nCulm + 0] = 27.271786;
      val[883 * nCulm + 1] = -15.443032;
      val[883 * nCulm + 2] = -44.582124;
      val[883 * nCulm + 3] = -48.994529;
      val[883 * nCulm + 4] = 18.205126;
      val[883 * nCulm + 5] = -16.523768;
      val[884 * nCulm + 0] = 23.581456;
      val[884 * nCulm + 1] = 4.062162;
      val[884 * nCulm + 2] = -17.191231;
      val[884 * nCulm + 3] = 22.065215;
      val[884 * nCulm + 4] = 8.670970;
      val[884 * nCulm + 5] = 14.492485;
      val[885 * nCulm + 0] = 30.397886;
      val[885 * nCulm + 1] = 4.567477;
      val[885 * nCulm + 2] = -35.940479;
      val[885 * nCulm + 3] = -15.214665;
      val[885 * nCulm + 4] = -21.211995;
      val[885 * nCulm + 5] = 2.605858;
      val[886 * nCulm + 0] = -15.762189;
      val[886 * nCulm + 1] = 27.624890;
      val[886 * nCulm + 2] = 19.507871;
      val[886 * nCulm + 3] = -3.750309;
      val[886 * nCulm + 4] = 27.509174;
      val[886 * nCulm + 5] = 4.337952;
      val[887 * nCulm + 0] = 49.693476;
      val[887 * nCulm + 1] = 49.979761;
      val[887 * nCulm + 2] = -47.450607;
      val[887 * nCulm + 3] = 14.662180;
      val[887 * nCulm + 4] = -19.419869;
      val[887 * nCulm + 5] = -15.525608;
      val[888 * nCulm + 0] = -34.298710;
      val[888 * nCulm + 1] = -34.809969;
      val[888 * nCulm + 2] = 39.166808;
      val[888 * nCulm + 3] = 46.743636;
      val[888 * nCulm + 4] = 7.059580;
      val[888 * nCulm + 5] = 8.231329;
      val[889 * nCulm + 0] = 19.027556;
      val[889 * nCulm + 1] = 25.220319;
      val[889 * nCulm + 2] = 7.513941;
      val[889 * nCulm + 3] = 11.611161;
      val[889 * nCulm + 4] = 21.055888;
      val[889 * nCulm + 5] = 8.509664;
      val[890 * nCulm + 0] = 23.225562;
      val[890 * nCulm + 1] = -41.720410;
      val[890 * nCulm + 2] = -38.290337;
      val[890 * nCulm + 3] = -13.746488;
      val[890 * nCulm + 4] = 33.029335;
      val[890 * nCulm + 5] = -7.718792;
      val[891 * nCulm + 0] = 2.982846;
      val[891 * nCulm + 1] = 31.189526;
      val[891 * nCulm + 2] = 13.694422;
      val[891 * nCulm + 3] = 14.830762;
      val[891 * nCulm + 4] = 39.232540;
      val[891 * nCulm + 5] = 5.782263;
      val[892 * nCulm + 0] = -20.297036;
      val[892 * nCulm + 1] = -44.813344;
      val[892 * nCulm + 2] = 30.817669;
      val[892 * nCulm + 3] = 7.421472;
      val[892 * nCulm + 4] = 7.420348;
      val[892 * nCulm + 5] = -23.621737;
      val[893 * nCulm + 0] = 39.688584;
      val[893 * nCulm + 1] = -22.453881;
      val[893 * nCulm + 2] = -40.021690;
      val[893 * nCulm + 3] = 36.742121;
      val[893 * nCulm + 4] = 3.711757;
      val[893 * nCulm + 5] = 18.450751;
      val[894 * nCulm + 0] = 30.819372;
      val[894 * nCulm + 1] = -23.921660;
      val[894 * nCulm + 2] = -24.372572;
      val[894 * nCulm + 3] = 43.099194;
      val[894 * nCulm + 4] = 27.896421;
      val[894 * nCulm + 5] = 3.483954;
      val[895 * nCulm + 0] = -6.958343;
      val[895 * nCulm + 1] = 16.594151;
      val[895 * nCulm + 2] = -43.604820;
      val[895 * nCulm + 3] = -7.692598;
      val[895 * nCulm + 4] = -29.333494;
      val[895 * nCulm + 5] = -1.206379;
      val[896 * nCulm + 0] = -15.475407;
      val[896 * nCulm + 1] = 17.501606;
      val[896 * nCulm + 2] = 13.881998;
      val[896 * nCulm + 3] = -6.201399;
      val[896 * nCulm + 4] = -48.470648;
      val[896 * nCulm + 5] = -0.873506;
      val[897 * nCulm + 0] = -1.878354;
      val[897 * nCulm + 1] = -6.583914;
      val[897 * nCulm + 2] = 18.867483;
      val[897 * nCulm + 3] = 24.343072;
      val[897 * nCulm + 4] = 6.510165;
      val[897 * nCulm + 5] = 13.142117;
      val[898 * nCulm + 0] = -21.740914;
      val[898 * nCulm + 1] = -4.772291;
      val[898 * nCulm + 2] = -26.860341;
      val[898 * nCulm + 3] = -25.052750;
      val[898 * nCulm + 4] = 37.670495;
      val[898 * nCulm + 5] = -3.517545;
      val[899 * nCulm + 0] = -18.703328;
      val[899 * nCulm + 1] = -33.277567;
      val[899 * nCulm + 2] = -11.565652;
      val[899 * nCulm + 3] = -27.738591;
      val[899 * nCulm + 4] = -5.631633;
      val[899 * nCulm + 5] = 51.513493;
      val[900 * nCulm + 0] = 3.206848;
      val[900 * nCulm + 1] = 41.715398;
      val[900 * nCulm + 2] = 40.316230;
      val[900 * nCulm + 3] = -34.755137;
      val[900 * nCulm + 4] = 6.987622;
      val[900 * nCulm + 5] = 4.944799;
      val[901 * nCulm + 0] = 1.452945;
      val[901 * nCulm + 1] = -28.066724;
      val[901 * nCulm + 2] = 2.844796;
      val[901 * nCulm + 3] = 30.196560;
      val[901 * nCulm + 4] = -1.828545;
      val[901 * nCulm + 5] = -5.283248;
      val[902 * nCulm + 0] = 18.611353;
      val[902 * nCulm + 1] = -34.607293;
      val[902 * nCulm + 2] = 35.337522;
      val[902 * nCulm + 3] = -6.363838;
      val[902 * nCulm + 4] = 35.201127;
      val[902 * nCulm + 5] = -5.279199;
      val[903 * nCulm + 0] = 7.845771;
      val[903 * nCulm + 1] = -31.862221;
      val[903 * nCulm + 2] = -17.787021;
      val[903 * nCulm + 3] = 40.256738;
      val[903 * nCulm + 4] = 31.024285;
      val[903 * nCulm + 5] = 1.510740;
      val[904 * nCulm + 0] = 11.727329;
      val[904 * nCulm + 1] = -46.295540;
      val[904 * nCulm + 2] = 17.648457;
      val[904 * nCulm + 3] = 37.504958;
      val[904 * nCulm + 4] = 47.299819;
      val[904 * nCulm + 5] = -0.649681;
      val[905 * nCulm + 0] = -20.060536;
      val[905 * nCulm + 1] = -36.807570;
      val[905 * nCulm + 2] = -15.087292;
      val[905 * nCulm + 3] = -20.493359;
      val[905 * nCulm + 4] = 31.508740;
      val[905 * nCulm + 5] = -8.377910;
      val[906 * nCulm + 0] = -15.688727;
      val[906 * nCulm + 1] = 32.549158;
      val[906 * nCulm + 2] = 16.509572;
      val[906 * nCulm + 3] = -29.430458;
      val[906 * nCulm + 4] = 9.263470;
      val[906 * nCulm + 5] = 1.823554;
      val[907 * nCulm + 0] = -5.741826;
      val[907 * nCulm + 1] = 39.766501;
      val[907 * nCulm + 2] = 27.377041;
      val[907 * nCulm + 3] = 39.906678;
      val[907 * nCulm + 4] = 45.526139;
      val[907 * nCulm + 5] = 8.513587;
      val[908 * nCulm + 0] = -42.553999;
      val[908 * nCulm + 1] = 44.120889;
      val[908 * nCulm + 2] = -34.716534;
      val[908 * nCulm + 3] = 28.753135;
      val[908 * nCulm + 4] = -0.458810;
      val[908 * nCulm + 5] = -751.577827;
      val[909 * nCulm + 0] = -32.833914;
      val[909 * nCulm + 1] = 47.941280;
      val[909 * nCulm + 2] = 38.258196;
      val[909 * nCulm + 3] = 29.008206;
      val[909 * nCulm + 4] = -2.831855;
      val[909 * nCulm + 5] = -128.388027;
      val[910 * nCulm + 0] = 42.606345;
      val[910 * nCulm + 1] = -14.618736;
      val[910 * nCulm + 2] = 29.494864;
      val[910 * nCulm + 3] = -4.217448;
      val[910 * nCulm + 4] = -35.122544;
      val[910 * nCulm + 5] = 2.768482;
      val[911 * nCulm + 0] = 13.534413;
      val[911 * nCulm + 1] = 24.087996;
      val[911 * nCulm + 2] = -19.690041;
      val[911 * nCulm + 3] = -30.946780;
      val[911 * nCulm + 4] = 45.296789;
      val[911 * nCulm + 5] = -0.486715;
      val[912 * nCulm + 0] = 31.323986;
      val[912 * nCulm + 1] = -46.202242;
      val[912 * nCulm + 2] = -47.436188;
      val[912 * nCulm + 3] = 38.351289;
      val[912 * nCulm + 4] = -16.446809;
      val[912 * nCulm + 5] = 2.489476;
      val[913 * nCulm + 0] = 25.714326;
      val[913 * nCulm + 1] = 37.476512;
      val[913 * nCulm + 2] = -3.494214;
      val[913 * nCulm + 3] = 15.799320;
      val[913 * nCulm + 4] = 31.768674;
      val[913 * nCulm + 5] = 8.167765;
      val[914 * nCulm + 0] = 32.247481;
      val[914 * nCulm + 1] = -43.021613;
      val[914 * nCulm + 2] = -10.890785;
      val[914 * nCulm + 3] = -25.300616;
      val[914 * nCulm + 4] = -12.513996;
      val[914 * nCulm + 5] = 26.072415;
      val[915 * nCulm + 0] = -11.903763;
      val[915 * nCulm + 1] = -21.349433;
      val[915 * nCulm + 2] = -9.716490;
      val[915 * nCulm + 3] = -6.513971;
      val[915 * nCulm + 4] = 29.458753;
      val[915 * nCulm + 5] = -4.246998;
      val[916 * nCulm + 0] = -24.127426;
      val[916 * nCulm + 1] = 10.201914;
      val[916 * nCulm + 2] = 42.379508;
      val[916 * nCulm + 3] = 10.636349;
      val[916 * nCulm + 4] = -21.524168;
      val[916 * nCulm + 5] = -4.352497;
      val[917 * nCulm + 0] = 41.106838;
      val[917 * nCulm + 1] = 24.131472;
      val[917 * nCulm + 2] = -2.891288;
      val[917 * nCulm + 3] = 11.748386;
      val[917 * nCulm + 4] = -9.761807;
      val[917 * nCulm + 5] = -17.167529;
      val[918 * nCulm + 0] = 9.148933;
      val[918 * nCulm + 1] = -24.448972;
      val[918 * nCulm + 2] = 21.893109;
      val[918 * nCulm + 3] = -7.316741;
      val[918 * nCulm + 4] = 35.219896;
      val[918 * nCulm + 5] = -4.039113;
      val[919 * nCulm + 0] = 30.681688;
      val[919 * nCulm + 1] = 27.343308;
      val[919 * nCulm + 2] = 2.887065;
      val[919 * nCulm + 3] = 0.141992;
      val[919 * nCulm + 4] = 5.945113;
      val[919 * nCulm + 5] = 22.113031;
      val[920 * nCulm + 0] = 25.654652;
      val[920 * nCulm + 1] = 19.503288;
      val[920 * nCulm + 2] = -37.201394;
      val[920 * nCulm + 3] = 40.390413;
      val[920 * nCulm + 4] = -25.011341;
      val[920 * nCulm + 5] = -11.104732;
      val[921 * nCulm + 0] = -24.384747;
      val[921 * nCulm + 1] = 5.731865;
      val[921 * nCulm + 2] = -29.049130;
      val[921 * nCulm + 3] = -28.947126;
      val[921 * nCulm + 4] = -46.177123;
      val[921 * nCulm + 5] = 2.609654;
      val[922 * nCulm + 0] = 30.216685;
      val[922 * nCulm + 1] = -12.762836;
      val[922 * nCulm + 2] = -18.971682;
      val[922 * nCulm + 3] = 35.781389;
      val[922 * nCulm + 4] = -4.883365;
      val[922 * nCulm + 5] = -22.081354;
      val[923 * nCulm + 0] = -5.668016;
      val[923 * nCulm + 1] = -11.672176;
      val[923 * nCulm + 2] = 1.207892;
      val[923 * nCulm + 3] = 27.967385;
      val[923 * nCulm + 4] = 36.094674;
      val[923 * nCulm + 5] = 2.366899;
      val[924 * nCulm + 0] = -30.052059;
      val[924 * nCulm + 1] = 20.718110;
      val[924 * nCulm + 2] = -11.190065;
      val[924 * nCulm + 3] = -34.835975;
      val[924 * nCulm + 4] = 24.182281;
      val[924 * nCulm + 5] = -2.533369;
      val[925 * nCulm + 0] = 35.176434;
      val[925 * nCulm + 1] = 17.108475;
      val[925 * nCulm + 2] = 49.875894;
      val[925 * nCulm + 3] = 4.754321;
      val[925 * nCulm + 4] = 6.453756;
      val[925 * nCulm + 5] = 16.264678;
      val[926 * nCulm + 0] = -15.582928;
      val[926 * nCulm + 1] = 36.435985;
      val[926 * nCulm + 2] = 8.712428;
      val[926 * nCulm + 3] = 39.329011;
      val[926 * nCulm + 4] = -42.257194;
      val[926 * nCulm + 5] = -8.256626;
      val[927 * nCulm + 0] = -29.953940;
      val[927 * nCulm + 1] = 24.243848;
      val[927 * nCulm + 2] = 14.098326;
      val[927 * nCulm + 3] = -24.671014;
      val[927 * nCulm + 4] = -0.884959;
      val[927 * nCulm + 5] = 2.514761;
      val[928 * nCulm + 0] = -18.554568;
      val[928 * nCulm + 1] = 1.678102;
      val[928 * nCulm + 2] = 8.775220;
      val[928 * nCulm + 3] = 6.511005;
      val[928 * nCulm + 4] = -49.147683;
      val[928 * nCulm + 5] = -0.558680;
      val[929 * nCulm + 0] = 30.001236;
      val[929 * nCulm + 1] = -4.778919;
      val[929 * nCulm + 2] = -4.900922;
      val[929 * nCulm + 3] = 7.349838;
      val[929 * nCulm + 4] = 28.707242;
      val[929 * nCulm + 5] = 0.653901;
      val[930 * nCulm + 0] = 5.162420;
      val[930 * nCulm + 1] = 31.758637;
      val[930 * nCulm + 2] = -38.128900;
      val[930 * nCulm + 3] = 45.220084;
      val[930 * nCulm + 4] = 13.465316;
      val[930 * nCulm + 5] = 27.289591;
      val[931 * nCulm + 0] = 3.992854;
      val[931 * nCulm + 1] = -6.604697;
      val[931 * nCulm + 2] = -4.638542;
      val[931 * nCulm + 3] = 27.720785;
      val[931 * nCulm + 4] = -41.173339;
      val[931 * nCulm + 5] = -2.197529;
      val[932 * nCulm + 0] = -31.260587;
      val[932 * nCulm + 1] = 28.520062;
      val[932 * nCulm + 2] = 24.002093;
      val[932 * nCulm + 3] = -30.877301;
      val[932 * nCulm + 4] = -44.227893;
      val[932 * nCulm + 5] = 0.482275;
      val[933 * nCulm + 0] = 7.729613;
      val[933 * nCulm + 1] = -3.422790;
      val[933 * nCulm + 2] = -29.989247;
      val[933 * nCulm + 3] = 40.833425;
      val[933 * nCulm + 4] = 13.260575;
      val[933 * nCulm + 5] = 13.583645;
      val[934 * nCulm + 0] = 5.131439;
      val[934 * nCulm + 1] = 26.502533;
      val[934 * nCulm + 2] = -15.778885;
      val[934 * nCulm + 3] = 30.092734;
      val[934 * nCulm + 4] = -32.211115;
      val[934 * nCulm + 5] = -8.086516;
      val[935 * nCulm + 0] = 21.051031;
      val[935 * nCulm + 1] = -41.720624;
      val[935 * nCulm + 2] = 36.878541;
      val[935 * nCulm + 3] = 25.210031;
      val[935 * nCulm + 4] = 43.100111;
      val[935 * nCulm + 5] = -1.583224;
      val[936 * nCulm + 0] = -5.135894;
      val[936 * nCulm + 1] = -37.507494;
      val[936 * nCulm + 2] = -18.809138;
      val[936 * nCulm + 3] = 18.584178;
      val[936 * nCulm + 4] = -21.665330;
      val[936 * nCulm + 5] = 4.364272;
      val[937 * nCulm + 0] = 24.768955;
      val[937 * nCulm + 1] = -13.333162;
      val[937 * nCulm + 2] = -4.416026;
      val[937 * nCulm + 3] = 24.916337;
      val[937 * nCulm + 4] = 35.514549;
      val[937 * nCulm + 5] = 1.773791;
      val[938 * nCulm + 0] = -45.538997;
      val[938 * nCulm + 1] = -11.822280;
      val[938 * nCulm + 2] = -5.101383;
      val[938 * nCulm + 3] = -38.572242;
      val[938 * nCulm + 4] = 48.651674;
      val[938 * nCulm + 5] = -4.672895;
      val[939 * nCulm + 0] = 14.697541;
      val[939 * nCulm + 1] = -13.463594;
      val[939 * nCulm + 2] = 44.417920;
      val[939 * nCulm + 3] = 7.189378;
      val[939 * nCulm + 4] = -19.487503;
      val[939 * nCulm + 5] = 1.753949;
      val[940 * nCulm + 0] = -33.630796;
      val[940 * nCulm + 1] = 1.281242;
      val[940 * nCulm + 2] = 36.731438;
      val[940 * nCulm + 3] = -5.585454;
      val[940 * nCulm + 4] = 7.749838;
      val[940 * nCulm + 5] = -2.398864;
      val[941 * nCulm + 0] = -43.317600;
      val[941 * nCulm + 1] = -32.926556;
      val[941 * nCulm + 2] = 36.223053;
      val[941 * nCulm + 3] = 27.521393;
      val[941 * nCulm + 4] = 20.542018;
      val[941 * nCulm + 5] = -1.015469;
      val[942 * nCulm + 0] = -8.324052;
      val[942 * nCulm + 1] = -3.166207;
      val[942 * nCulm + 2] = -6.796225;
      val[942 * nCulm + 3] = 26.790297;
      val[942 * nCulm + 4] = 20.153592;
      val[942 * nCulm + 5] = 5.778425;
      val[943 * nCulm + 0] = -9.955401;
      val[943 * nCulm + 1] = 15.681551;
      val[943 * nCulm + 2] = 47.961337;
      val[943 * nCulm + 3] = -25.189667;
      val[943 * nCulm + 4] = 28.840053;
      val[943 * nCulm + 5] = -1.330506;
      val[944 * nCulm + 0] = -27.080722;
      val[944 * nCulm + 1] = -24.773652;
      val[944 * nCulm + 2] = -6.847103;
      val[944 * nCulm + 3] = 28.833082;
      val[944 * nCulm + 4] = 46.835490;
      val[944 * nCulm + 5] = 0.640258;
      val[945 * nCulm + 0] = 39.565451;
      val[945 * nCulm + 1] = -25.687374;
      val[945 * nCulm + 2] = -35.696105;
      val[945 * nCulm + 3] = -43.062358;
      val[945 * nCulm + 4] = 21.341801;
      val[945 * nCulm + 5] = -15.017795;
      val[946 * nCulm + 0] = -0.913444;
      val[946 * nCulm + 1] = -17.916912;
      val[946 * nCulm + 2] = 48.709947;
      val[946 * nCulm + 3] = 19.950858;
      val[946 * nCulm + 4] = -10.114466;
      val[946 * nCulm + 5] = -0.721839;
      val[947 * nCulm + 0] = 15.618340;
      val[947 * nCulm + 1] = -11.060911;
      val[947 * nCulm + 2] = 27.867554;
      val[947 * nCulm + 3] = 31.443853;
      val[947 * nCulm + 4] = -39.469449;
      val[947 * nCulm + 5] = -2.214404;
      val[948 * nCulm + 0] = 20.983054;
      val[948 * nCulm + 1] = -23.391545;
      val[948 * nCulm + 2] = 31.420432;
      val[948 * nCulm + 3] = 20.850826;
      val[948 * nCulm + 4] = 2.553300;
      val[948 * nCulm + 5] = -4.480012;
      val[949 * nCulm + 0] = 3.205764;
      val[949 * nCulm + 1] = 6.249369;
      val[949 * nCulm + 2] = -35.409401;
      val[949 * nCulm + 3] = -22.215231;
      val[949 * nCulm + 4] = 15.218375;
      val[949 * nCulm + 5] = -4.735822;
      val[950 * nCulm + 0] = 17.823410;
      val[950 * nCulm + 1] = 21.372905;
      val[950 * nCulm + 2] = -44.806785;
      val[950 * nCulm + 3] = -17.053023;
      val[950 * nCulm + 4] = 45.114628;
      val[950 * nCulm + 5] = 0.683233;
      val[951 * nCulm + 0] = -44.621255;
      val[951 * nCulm + 1] = -20.293049;
      val[951 * nCulm + 2] = -23.135888;
      val[951 * nCulm + 3] = -37.174582;
      val[951 * nCulm + 4] = 46.798289;
      val[951 * nCulm + 5] = -5.582466;
      val[952 * nCulm + 0] = 28.994638;
      val[952 * nCulm + 1] = -39.528281;
      val[952 * nCulm + 2] = -24.371496;
      val[952 * nCulm + 3] = -16.039977;
      val[952 * nCulm + 4] = -20.540436;
      val[952 * nCulm + 5] = 13.035137;
      val[953 * nCulm + 0] = 12.135293;
      val[953 * nCulm + 1] = -49.976567;
      val[953 * nCulm + 2] = 38.290773;
      val[953 * nCulm + 3] = -3.695165;
      val[953 * nCulm + 4] = -4.757795;
      val[953 * nCulm + 5] = 53.625790;
      val[954 * nCulm + 0] = -18.639560;
      val[954 * nCulm + 1] = 44.457554;
      val[954 * nCulm + 2] = -6.505301;
      val[954 * nCulm + 3] = -33.961713;
      val[954 * nCulm + 4] = -33.936079;
      val[954 * nCulm + 5] = -1.233938;
      val[955 * nCulm + 0] = -32.417009;
      val[955 * nCulm + 1] = -26.343277;
      val[955 * nCulm + 2] = 3.147781;
      val[955 * nCulm + 3] = 36.062145;
      val[955 * nCulm + 4] = -41.414404;
      val[955 * nCulm + 5] = -0.880788;
      val[956 * nCulm + 0] = -19.465025;
      val[956 * nCulm + 1] = 21.502681;
      val[956 * nCulm + 2] = -23.052290;
      val[956 * nCulm + 3] = 15.618584;
      val[956 * nCulm + 4] = 48.875063;
      val[956 * nCulm + 5] = 3.825030;
      val[957 * nCulm + 0] = -9.561769;
      val[957 * nCulm + 1] = -14.379533;
      val[957 * nCulm + 2] = -14.233625;
      val[957 * nCulm + 3] = -24.270561;
      val[957 * nCulm + 4] = 11.171610;
      val[957 * nCulm + 5] = -16.145776;
      val[958 * nCulm + 0] = -7.663397;
      val[958 * nCulm + 1] = 21.788303;
      val[958 * nCulm + 2] = -42.502916;
      val[958 * nCulm + 3] = -48.475379;
      val[958 * nCulm + 4] = 24.174724;
      val[958 * nCulm + 5] = -4.995244;
      val[959 * nCulm + 0] = 21.838483;
      val[959 * nCulm + 1] = 48.209867;
      val[959 * nCulm + 2] = 7.929309;
      val[959 * nCulm + 3] = 26.600993;
      val[959 * nCulm + 4] = 6.428204;
      val[959 * nCulm + 5] = 55.316107;
      val[960 * nCulm + 0] = 12.546850;
      val[960 * nCulm + 1] = 6.911260;
      val[960 * nCulm + 2] = 18.346201;
      val[960 * nCulm + 3] = -19.510374;
      val[960 * nCulm + 4] = 49.542861;
      val[960 * nCulm + 5] = -0.973721;
      val[961 * nCulm + 0] = -5.519624;
      val[961 * nCulm + 1] = -16.899845;
      val[961 * nCulm + 2] = 39.610160;
      val[961 * nCulm + 3] = 15.834600;
      val[961 * nCulm + 4] = 3.709326;
      val[961 * nCulm + 5] = -1.129320;
      val[962 * nCulm + 0] = 39.457125;
      val[962 * nCulm + 1] = -18.924908;
      val[962 * nCulm + 2] = 10.761816;
      val[962 * nCulm + 3] = 27.807338;
      val[962 * nCulm + 4] = -32.221833;
      val[962 * nCulm + 5] = -1.074814;
      val[963 * nCulm + 0] = 26.827327;
      val[963 * nCulm + 1] = -6.105391;
      val[963 * nCulm + 2] = 36.473635;
      val[963 * nCulm + 3] = -36.386515;
      val[963 * nCulm + 4] = -9.074299;
      val[963 * nCulm + 5] = 22.394616;
      val[964 * nCulm + 0] = 42.359071;
      val[964 * nCulm + 1] = -31.592669;
      val[964 * nCulm + 2] = -47.515527;
      val[964 * nCulm + 3] = 18.589102;
      val[964 * nCulm + 4] = 29.757276;
      val[964 * nCulm + 5] = -1.838409;
      val[965 * nCulm + 0] = 16.266947;
      val[965 * nCulm + 1] = -22.117926;
      val[965 * nCulm + 2] = -44.770744;
      val[965 * nCulm + 3] = 34.868531;
      val[965 * nCulm + 4] = 2.564044;
      val[965 * nCulm + 5] = 23.768151;
      val[966 * nCulm + 0] = 22.787252;
      val[966 * nCulm + 1] = -46.825740;
      val[966 * nCulm + 2] = 3.031112;
      val[966 * nCulm + 3] = 40.579908;
      val[966 * nCulm + 4] = 32.733269;
      val[966 * nCulm + 5] = -0.673167;
      val[967 * nCulm + 0] = 35.762549;
      val[967 * nCulm + 1] = 47.295775;
      val[967 * nCulm + 2] = 21.063933;
      val[967 * nCulm + 3] = -25.474946;
      val[967 * nCulm + 4] = -14.011017;
      val[967 * nCulm + 5] = -7.141717;
      val[968 * nCulm + 0] = 16.098652;
      val[968 * nCulm + 1] = -29.915784;
      val[968 * nCulm + 2] = 28.575469;
      val[968 * nCulm + 3] = -35.714116;
      val[968 * nCulm + 4] = -44.725093;
      val[968 * nCulm + 5] = 7.175725;
      val[969 * nCulm + 0] = 31.061200;
      val[969 * nCulm + 1] = -28.291779;
      val[969 * nCulm + 2] = -1.450297;
      val[969 * nCulm + 3] = 22.048921;
      val[969 * nCulm + 4] = 48.899352;
      val[969 * nCulm + 5] = -0.374293;
      val[970 * nCulm + 0] = 37.445721;
      val[970 * nCulm + 1] = -43.796012;
      val[970 * nCulm + 2] = -22.082178;
      val[970 * nCulm + 3] = -2.999204;
      val[970 * nCulm + 4] = -22.823505;
      val[970 * nCulm + 5] = 9.934792;
      val[971 * nCulm + 0] = 1.121943;
      val[971 * nCulm + 1] = -17.887054;
      val[971 * nCulm + 2] = -22.679355;
      val[971 * nCulm + 3] = -33.228048;
      val[971 * nCulm + 4] = -3.552514;
      val[971 * nCulm + 5] = 68.335242;
      val[972 * nCulm + 0] = -17.284120;
      val[972 * nCulm + 1] = 5.059044;
      val[972 * nCulm + 2] = -39.725495;
      val[972 * nCulm + 3] = -0.657416;
      val[972 * nCulm + 4] = -30.067145;
      val[972 * nCulm + 5] = -0.462928;
      val[973 * nCulm + 0] = 35.761200;
      val[973 * nCulm + 1] = 6.280652;
      val[973 * nCulm + 2] = 27.184333;
      val[973 * nCulm + 3] = 13.703060;
      val[973 * nCulm + 4] = -35.090201;
      val[973 * nCulm + 5] = -2.465612;
      val[974 * nCulm + 0] = 0.275457;
      val[974 * nCulm + 1] = -11.212996;
      val[974 * nCulm + 2] = -31.987167;
      val[974 * nCulm + 3] = -40.408748;
      val[974 * nCulm + 4] = 23.059826;
      val[974 * nCulm + 5] = -10.366044;
      val[975 * nCulm + 0] = 22.797014;
      val[975 * nCulm + 1] = 12.534868;
      val[975 * nCulm + 2] = 3.580262;
      val[975 * nCulm + 3] = -30.941476;
      val[975 * nCulm + 4] = -33.291259;
      val[975 * nCulm + 5] = 2.847042;
      val[976 * nCulm + 0] = 37.418670;
      val[976 * nCulm + 1] = 17.341274;
      val[976 * nCulm + 2] = -40.332214;
      val[976 * nCulm + 3] = 21.148492;
      val[976 * nCulm + 4] = -31.201362;
      val[976 * nCulm + 5] = -5.609004;
      val[977 * nCulm + 0] = -2.921079;
      val[977 * nCulm + 1] = -33.976016;
      val[977 * nCulm + 2] = -7.692081;
      val[977 * nCulm + 3] = -47.816530;
      val[977 * nCulm + 4] = 28.408184;
      val[977 * nCulm + 5] = -13.398164;
      val[978 * nCulm + 0] = -30.330342;
      val[978 * nCulm + 1] = 5.995320;
      val[978 * nCulm + 2] = 20.784919;
      val[978 * nCulm + 3] = -32.587683;
      val[978 * nCulm + 4] = 14.605919;
      val[978 * nCulm + 5] = -8.387775;
      val[979 * nCulm + 0] = 25.714497;
      val[979 * nCulm + 1] = 23.704561;
      val[979 * nCulm + 2] = -30.165476;
      val[979 * nCulm + 3] = 31.093989;
      val[979 * nCulm + 4] = -6.059040;
      val[979 * nCulm + 5] = -42.578726;
      val[980 * nCulm + 0] = -46.549334;
      val[980 * nCulm + 1] = 2.636597;
      val[980 * nCulm + 2] = 36.646793;
      val[980 * nCulm + 3] = 46.682758;
      val[980 * nCulm + 4] = -7.725705;
      val[980 * nCulm + 5] = -29.986655;
      val[981 * nCulm + 0] = -15.510471;
      val[981 * nCulm + 1] = 10.732877;
      val[981 * nCulm + 2] = 5.095256;
      val[981 * nCulm + 3] = 41.411109;
      val[981 * nCulm + 4] = -38.698694;
      val[981 * nCulm + 5] = -6.147860;
      val[982 * nCulm + 0] = -18.015145;
      val[982 * nCulm + 1] = -47.661536;
      val[982 * nCulm + 2] = -0.626431;
      val[982 * nCulm + 3] = 38.281688;
      val[982 * nCulm + 4] = 14.842457;
      val[982 * nCulm + 5] = -2.761280;
      val[983 * nCulm + 0] = -21.889864;
      val[983 * nCulm + 1] = -11.209458;
      val[983 * nCulm + 2] = -20.219162;
      val[983 * nCulm + 3] = -45.345028;
      val[983 * nCulm + 4] = -3.211149;
      val[983 * nCulm + 5] = 83.593063;
      val[984 * nCulm + 0] = -14.180814;
      val[984 * nCulm + 1] = -12.156587;
      val[984 * nCulm + 2] = 22.965171;
      val[984 * nCulm + 3] = -35.369944;
      val[984 * nCulm + 4] = 29.291151;
      val[984 * nCulm + 5] = -7.450098;
      val[985 * nCulm + 0] = -10.321126;
      val[985 * nCulm + 1] = 24.446971;
      val[985 * nCulm + 2] = 34.188719;
      val[985 * nCulm + 3] = -21.489840;
      val[985 * nCulm + 4] = -46.484985;
      val[985 * nCulm + 5] = -0.071110;
      val[986 * nCulm + 0] = 27.929062;
      val[986 * nCulm + 1] = 31.984735;
      val[986 * nCulm + 2] = -42.167514;
      val[986 * nCulm + 3] = -30.167209;
      val[986 * nCulm + 4] = -34.901158;
      val[986 * nCulm + 5] = -0.016495;
      val[987 * nCulm + 0] = -32.022978;
      val[987 * nCulm + 1] = -29.465177;
      val[987 * nCulm + 2] = 42.941401;
      val[987 * nCulm + 3] = 13.084131;
      val[987 * nCulm + 4] = -32.089497;
      val[987 * nCulm + 5] = 2.646272;
      val[988 * nCulm + 0] = -28.393946;
      val[988 * nCulm + 1] = -11.030531;
      val[988 * nCulm + 2] = -6.039578;
      val[988 * nCulm + 3] = 23.898126;
      val[988 * nCulm + 4] = 14.333010;
      val[988 * nCulm + 5] = 4.479395;
      val[989 * nCulm + 0] = 45.023928;
      val[989 * nCulm + 1] = -34.609575;
      val[989 * nCulm + 2] = 36.497948;
      val[989 * nCulm + 3] = 3.344276;
      val[989 * nCulm + 4] = -33.493159;
      val[989 * nCulm + 5] = 4.648487;
      val[990 * nCulm + 0] = -42.800500;
      val[990 * nCulm + 1] = 21.249452;
      val[990 * nCulm + 2] = 21.808583;
      val[990 * nCulm + 3] = 14.090501;
      val[990 * nCulm + 4] = 17.052330;
      val[990 * nCulm + 5] = 10.039555;
      val[991 * nCulm + 0] = -25.716074;
      val[991 * nCulm + 1] = 4.955986;
      val[991 * nCulm + 2] = 2.251667;
      val[991 * nCulm + 3] = 34.515632;
      val[991 * nCulm + 4] = -35.581309;
      val[991 * nCulm + 5] = -5.020856;
      val[992 * nCulm + 0] = -49.953304;
      val[992 * nCulm + 1] = 3.190559;
      val[992 * nCulm + 2] = -38.541711;
      val[992 * nCulm + 3] = 13.168969;
      val[992 * nCulm + 4] = -36.526123;
      val[992 * nCulm + 5] = -1.889992;
      val[993 * nCulm + 0] = -5.699888;
      val[993 * nCulm + 1] = 29.204346;
      val[993 * nCulm + 2] = 43.389435;
      val[993 * nCulm + 3] = 12.151034;
      val[993 * nCulm + 4] = 23.105345;
      val[993 * nCulm + 5] = 8.702014;
      val[994 * nCulm + 0] = -26.300175;
      val[994 * nCulm + 1] = 19.283844;
      val[994 * nCulm + 2] = 28.023055;
      val[994 * nCulm + 3] = -34.221086;
      val[994 * nCulm + 4] = -25.729504;
      val[994 * nCulm + 5] = 2.977933;
      val[995 * nCulm + 0] = 35.673156;
      val[995 * nCulm + 1] = -20.364467;
      val[995 * nCulm + 2] = 7.714907;
      val[995 * nCulm + 3] = 0.903770;
      val[995 * nCulm + 4] = -31.014536;
      val[995 * nCulm + 5] = 3.200026;
      val[996 * nCulm + 0] = -38.025641;
      val[996 * nCulm + 1] = 21.919056;
      val[996 * nCulm + 2] = 49.096124;
      val[996 * nCulm + 3] = 15.659744;
      val[996 * nCulm + 4] = 11.128887;
      val[996 * nCulm + 5] = 16.212999;
      val[997 * nCulm + 0] = -3.864367;
      val[997 * nCulm + 1] = -12.553156;
      val[997 * nCulm + 2] = -10.525801;
      val[997 * nCulm + 3] = -43.682163;
      val[997 * nCulm + 4] = -1.521550;
      val[997 * nCulm + 5] = 175.170332;
      val[998 * nCulm + 0] = -8.016712;
      val[998 * nCulm + 1] = -4.744306;
      val[998 * nCulm + 2] = -31.017251;
      val[998 * nCulm + 3] = -26.171339;
      val[998 * nCulm + 4] = 47.815470;
      val[998 * nCulm + 5] = -2.830391;
      val[999 * nCulm + 0] = -18.355849;
      val[999 * nCulm + 1] = -26.341295;
      val[999 * nCulm + 2] = 45.030514;
      val[999 * nCulm + 3] = 29.712196;
      val[999 * nCulm + 4] = -31.799713;
      val[999 * nCulm + 5] = -0.271753;
      val[1000 * nCulm + 0] = -1.041844;
      val[1000 * nCulm + 1] = 22.436381;
      val[1000 * nCulm + 2] = 29.614468;
      val[1000 * nCulm + 3] = -6.247294;
      val[1000 * nCulm + 4] = 43.239777;
      val[1000 * nCulm + 5] = 2.002173;
      val[1001 * nCulm + 0] = -14.482185;
      val[1001 * nCulm + 1] = -36.152604;
      val[1001 * nCulm + 2] = 17.823713;
      val[1001 * nCulm + 3] = 14.509808;
      val[1001 * nCulm + 4] = -26.955020;
      val[1001 * nCulm + 5] = 4.030501;
      val[1002 * nCulm + 0] = -3.494941;
      val[1002 * nCulm + 1] = -15.591703;
      val[1002 * nCulm + 2] = 23.591041;
      val[1002 * nCulm + 3] = 32.069400;
      val[1002 * nCulm + 4] = 5.520435;
      val[1002 * nCulm + 5] = 14.358312;
      val[1003 * nCulm + 0] = 42.316996;
      val[1003 * nCulm + 1] = 15.334864;
      val[1003 * nCulm + 2] = 32.063296;
      val[1003 * nCulm + 3] = 19.598180;
      val[1003 * nCulm + 4] = -19.964338;
      val[1003 * nCulm + 5] = -8.052255;
      val[1004 * nCulm + 0] = -18.250353;
      val[1004 * nCulm + 1] = 47.503314;
      val[1004 * nCulm + 2] = -7.509839;
      val[1004 * nCulm + 3] = -47.619622;
      val[1004 * nCulm + 4] = 26.790781;
      val[1004 * nCulm + 5] = 0.209451;
      val[1005 * nCulm + 0] = -43.801315;
      val[1005 * nCulm + 1] = -48.847898;
      val[1005 * nCulm + 2] = 18.696084;
      val[1005 * nCulm + 3] = 9.440907;
      val[1005 * nCulm + 4] = 12.515720;
      val[1005 * nCulm + 5] = -14.673371;
      val[1006 * nCulm + 0] = 48.929327;
      val[1006 * nCulm + 1] = 21.496388;
      val[1006 * nCulm + 2] = 27.196175;
      val[1006 * nCulm + 3] = -16.437885;
      val[1006 * nCulm + 4] = -25.468761;
      val[1006 * nCulm + 5] = -0.710116;
      val[1007 * nCulm + 0] = 10.413839;
      val[1007 * nCulm + 1] = 12.748028;
      val[1007 * nCulm + 2] = 13.697376;
      val[1007 * nCulm + 3] = -10.239816;
      val[1007 * nCulm + 4] = 19.531304;
      val[1007 * nCulm + 5] = 0.837855;
      val[1008 * nCulm + 0] = -15.459536;
      val[1008 * nCulm + 1] = -26.185991;
      val[1008 * nCulm + 2] = -5.064318;
      val[1008 * nCulm + 3] = -18.659798;
      val[1008 * nCulm + 4] = 47.006947;
      val[1008 * nCulm + 5] = -4.285717;
      val[1009 * nCulm + 0] = -41.843121;
      val[1009 * nCulm + 1] = -3.381583;
      val[1009 * nCulm + 2] = -18.234788;
      val[1009 * nCulm + 3] = -17.226978;
      val[1009 * nCulm + 4] = -37.176469;
      val[1009 * nCulm + 5] = 2.853896;
      val[1010 * nCulm + 0] = -0.108583;
      val[1010 * nCulm + 1] = -6.878275;
      val[1010 * nCulm + 2] = 27.613152;
      val[1010 * nCulm + 3] = -44.244706;
      val[1010 * nCulm + 4] = -20.983378;
      val[1010 * nCulm + 5] = 11.762086;
      val[1011 * nCulm + 0] = 38.558871;
      val[1011 * nCulm + 1] = -13.325528;
      val[1011 * nCulm + 2] = 22.100624;
      val[1011 * nCulm + 3] = -1.282178;
      val[1011 * nCulm + 4] = -2.669871;
      val[1011 * nCulm + 5] = 26.127563;
      val[1012 * nCulm + 0] = 22.019887;
      val[1012 * nCulm + 1] = -41.241226;
      val[1012 * nCulm + 2] = -35.845545;
      val[1012 * nCulm + 3] = -26.473871;
      val[1012 * nCulm + 4] = -14.517275;
      val[1012 * nCulm + 5] = 22.308394;
      val[1013 * nCulm + 0] = 22.327846;
      val[1013 * nCulm + 1] = 40.757161;
      val[1013 * nCulm + 2] = -46.122313;
      val[1013 * nCulm + 3] = 27.025139;
      val[1013 * nCulm + 4] = 29.027536;
      val[1013 * nCulm + 5] = 11.282823;
      val[1014 * nCulm + 0] = -34.649219;
      val[1014 * nCulm + 1] = -15.978658;
      val[1014 * nCulm + 2] = -3.883212;
      val[1014 * nCulm + 3] = 40.092969;
      val[1014 * nCulm + 4] = 16.889570;
      val[1014 * nCulm + 5] = 6.988080;
      val[1015 * nCulm + 0] = 5.088323;
      val[1015 * nCulm + 1] = 34.201384;
      val[1015 * nCulm + 2] = 30.362233;
      val[1015 * nCulm + 3] = 20.558717;
      val[1015 * nCulm + 4] = 8.727584;
      val[1015 * nCulm + 5] = 29.928691;
      val[1016 * nCulm + 0] = 32.709354;
      val[1016 * nCulm + 1] = -6.268980;
      val[1016 * nCulm + 2] = 46.750983;
      val[1016 * nCulm + 3] = 6.051276;
      val[1016 * nCulm + 4] = -12.529727;
      val[1016 * nCulm + 5] = 0.312241;
      val[1017 * nCulm + 0] = -46.930782;
      val[1017 * nCulm + 1] = 48.473845;
      val[1017 * nCulm + 2] = 2.302760;
      val[1017 * nCulm + 3] = -5.671067;
      val[1017 * nCulm + 4] = -42.223393;
      val[1017 * nCulm + 5] = -4.568284;
      val[1018 * nCulm + 0] = -19.727764;
      val[1018 * nCulm + 1] = -34.857163;
      val[1018 * nCulm + 2] = 39.047347;
      val[1018 * nCulm + 3] = -14.224843;
      val[1018 * nCulm + 4] = 37.274814;
      val[1018 * nCulm + 5] = -6.002667;
      val[1019 * nCulm + 0] = 26.827545;
      val[1019 * nCulm + 1] = -24.900732;
      val[1019 * nCulm + 2] = -41.983638;
      val[1019 * nCulm + 3] = -38.505344;
      val[1019 * nCulm + 4] = 1.021734;
      val[1019 * nCulm + 5] = -293.508121;
      val[1020 * nCulm + 0] = -19.823494;
      val[1020 * nCulm + 1] = 22.539026;
      val[1020 * nCulm + 2] = 33.860716;
      val[1020 * nCulm + 3] = 39.509685;
      val[1020 * nCulm + 4] = -8.391392;
      val[1020 * nCulm + 5] = -34.769822;
      val[1021 * nCulm + 0] = 25.292521;
      val[1021 * nCulm + 1] = -15.051725;
      val[1021 * nCulm + 2] = -14.059884;
      val[1021 * nCulm + 3] = 27.477947;
      val[1021 * nCulm + 4] = 37.612006;
      val[1021 * nCulm + 5] = 1.793795;
      val[1022 * nCulm + 0] = 36.308796;
      val[1022 * nCulm + 1] = 31.512676;
      val[1022 * nCulm + 2] = 37.441928;
      val[1022 * nCulm + 3] = 38.031928;
      val[1022 * nCulm + 4] = 22.929012;
      val[1022 * nCulm + 5] = 14.586388;
      val[1023 * nCulm + 0] = 8.772029;
      val[1023 * nCulm + 1] = 12.457339;
      val[1023 * nCulm + 2] = 23.886260;
      val[1023 * nCulm + 3] = 46.453906;
      val[1023 * nCulm + 4] = -42.954256;
      val[1023 * nCulm + 5] = -6.261710;
      val[1024 * nCulm + 0] = 42.185865;
      val[1024 * nCulm + 1] = 7.250049;
      val[1024 * nCulm + 2] = 6.745123;
      val[1024 * nCulm + 3] = -44.416500;
      val[1024 * nCulm + 4] = -11.583033;
      val[1024 * nCulm + 5] = 15.417835;
      val[1025 * nCulm + 0] = -31.825440;
      val[1025 * nCulm + 1] = -21.974919;
      val[1025 * nCulm + 2] = 38.903825;
      val[1025 * nCulm + 3] = 4.826404;
      val[1025 * nCulm + 4] = 49.761404;
      val[1025 * nCulm + 5] = -1.401177;
      val[1026 * nCulm + 0] = -35.174396;
      val[1026 * nCulm + 1] = -35.928230;
      val[1026 * nCulm + 2] = 26.386950;
      val[1026 * nCulm + 3] = -4.091689;
      val[1026 * nCulm + 4] = 39.971752;
      val[1026 * nCulm + 5] = -4.509037;
      val[1027 * nCulm + 0] = -10.218854;
      val[1027 * nCulm + 1] = -19.148675;
      val[1027 * nCulm + 2] = 4.244128;
      val[1027 * nCulm + 3] = 18.310358;
      val[1027 * nCulm + 4] = -27.209776;
      val[1027 * nCulm + 5] = 0.375831;
      val[1028 * nCulm + 0] = 47.753875;
      val[1028 * nCulm + 1] = -27.033470;
      val[1028 * nCulm + 2] = 9.167973;
      val[1028 * nCulm + 3] = -9.958041;
      val[1028 * nCulm + 4] = -33.835954;
      val[1028 * nCulm + 5] = 5.404766;
      val[1029 * nCulm + 0] = -42.080489;
      val[1029 * nCulm + 1] = -44.882609;
      val[1029 * nCulm + 2] = 30.505827;
      val[1029 * nCulm + 3] = 16.917904;
      val[1029 * nCulm + 4] = 27.818334;
      val[1029 * nCulm + 5] = -4.528239;
      val[1030 * nCulm + 0] = -17.666603;
      val[1030 * nCulm + 1] = 18.599714;
      val[1030 * nCulm + 2] = -16.125173;
      val[1030 * nCulm + 3] = 35.359950;
      val[1030 * nCulm + 4] = 5.599470;
      val[1030 * nCulm + 5] = 45.843085;
      val[1031 * nCulm + 0] = 38.675993;
      val[1031 * nCulm + 1] = -31.683362;
      val[1031 * nCulm + 2] = -38.595017;
      val[1031 * nCulm + 3] = 32.460186;
      val[1031 * nCulm + 4] = 45.518849;
      val[1031 * nCulm + 5] = 0.310779;
      val[1032 * nCulm + 0] = 38.090471;
      val[1032 * nCulm + 1] = -32.939074;
      val[1032 * nCulm + 2] = -8.057402;
      val[1032 * nCulm + 3] = 43.757655;
      val[1032 * nCulm + 4] = 36.305279;
      val[1032 * nCulm + 5] = 1.640482;
      val[1033 * nCulm + 0] = 39.838139;
      val[1033 * nCulm + 1] = -37.290894;
      val[1033 * nCulm + 2] = -4.070096;
      val[1033 * nCulm + 3] = 29.512255;
      val[1033 * nCulm + 4] = 26.268373;
      val[1033 * nCulm + 5] = -1.171643;
      val[1034 * nCulm + 0] = -41.814187;
      val[1034 * nCulm + 1] = -35.352820;
      val[1034 * nCulm + 2] = -30.344715;
      val[1034 * nCulm + 3] = 40.927178;
      val[1034 * nCulm + 4] = 49.142383;
      val[1034 * nCulm + 5] = 0.766915;
      val[1035 * nCulm + 0] = 2.446113;
      val[1035 * nCulm + 1] = 28.451432;
      val[1035 * nCulm + 2] = -25.478223;
      val[1035 * nCulm + 3] = -8.532084;
      val[1035 * nCulm + 4] = 49.842092;
      val[1035 * nCulm + 5] = 2.121672;
      val[1036 * nCulm + 0] = 29.794640;
      val[1036 * nCulm + 1] = -21.102887;
      val[1036 * nCulm + 2] = -0.602457;
      val[1036 * nCulm + 3] = 10.635421;
      val[1036 * nCulm + 4] = -7.378026;
      val[1036 * nCulm + 5] = 6.945347;
      val[1037 * nCulm + 0] = 42.859598;
      val[1037 * nCulm + 1] = 17.740441;
      val[1037 * nCulm + 2] = 40.715031;
      val[1037 * nCulm + 3] = 38.312050;
      val[1037 * nCulm + 4] = -18.829950;
      val[1037 * nCulm + 5] = -13.860060;
      val[1038 * nCulm + 0] = 40.417187;
      val[1038 * nCulm + 1] = -16.869196;
      val[1038 * nCulm + 2] = -12.104312;
      val[1038 * nCulm + 3] = -40.049342;
      val[1038 * nCulm + 4] = 34.952125;
      val[1038 * nCulm + 5] = -7.478098;
      val[1039 * nCulm + 0] = -15.286442;
      val[1039 * nCulm + 1] = 4.868249;
      val[1039 * nCulm + 2] = -11.559916;
      val[1039 * nCulm + 3] = 15.229902;
      val[1039 * nCulm + 4] = -3.659920;
      val[1039 * nCulm + 5] = -25.762713;
      val[1040 * nCulm + 0] = -23.128022;
      val[1040 * nCulm + 1] = -36.269945;
      val[1040 * nCulm + 2] = 34.196702;
      val[1040 * nCulm + 3] = 5.272369;
      val[1040 * nCulm + 4] = -15.128200;
      val[1040 * nCulm + 5] = 9.928566;
      val[1041 * nCulm + 0] = 7.974478;
      val[1041 * nCulm + 1] = 25.777904;
      val[1041 * nCulm + 2] = 40.753494;
      val[1041 * nCulm + 3] = 37.480309;
      val[1041 * nCulm + 4] = -16.666571;
      val[1041 * nCulm + 5] = -17.735436;
      val[1042 * nCulm + 0] = 33.331814;
      val[1042 * nCulm + 1] = 38.072790;
      val[1042 * nCulm + 2] = -6.474245;
      val[1042 * nCulm + 3] = 27.337919;
      val[1042 * nCulm + 4] = 9.920339;
      val[1042 * nCulm + 5] = 31.439689;
      val[1043 * nCulm + 0] = 15.013296;
      val[1043 * nCulm + 1] = 27.721003;
      val[1043 * nCulm + 2] = -5.450305;
      val[1043 * nCulm + 3] = -17.738908;
      val[1043 * nCulm + 4] = -3.581257;
      val[1043 * nCulm + 5] = -12.963295;
      val[1044 * nCulm + 0] = 22.279338;
      val[1044 * nCulm + 1] = 48.460911;
      val[1044 * nCulm + 2] = 10.838825;
      val[1044 * nCulm + 3] = -4.472676;
      val[1044 * nCulm + 4] = -27.542655;
      val[1044 * nCulm + 5] = -7.329583;
      val[1045 * nCulm + 0] = -0.224032;
      val[1045 * nCulm + 1] = 0.185175;
      val[1045 * nCulm + 2] = 37.000271;
      val[1045 * nCulm + 3] = 45.002036;
      val[1045 * nCulm + 4] = 43.765921;
      val[1045 * nCulm + 5] = 5.117047;
      val[1046 * nCulm + 0] = 17.415692;
      val[1046 * nCulm + 1] = 8.697914;
      val[1046 * nCulm + 2] = 49.595125;
      val[1046 * nCulm + 3] = 17.155171;
      val[1046 * nCulm + 4] = 3.066454;
      val[1046 * nCulm + 5] = 40.136445;
      val[1047 * nCulm + 0] = 16.212610;
      val[1047 * nCulm + 1] = -30.377276;
      val[1047 * nCulm + 2] = -2.109051;
      val[1047 * nCulm + 3] = -19.263903;
      val[1047 * nCulm + 4] = -12.083226;
      val[1047 * nCulm + 5] = 19.675820;
      val[1048 * nCulm + 0] = 32.718447;
      val[1048 * nCulm + 1] = 19.893840;
      val[1048 * nCulm + 2] = 43.151405;
      val[1048 * nCulm + 3] = 47.943673;
      val[1048 * nCulm + 4] = -16.617830;
      val[1048 * nCulm + 5] = -19.092472;
      val[1049 * nCulm + 0] = -46.647959;
      val[1049 * nCulm + 1] = 14.893955;
      val[1049 * nCulm + 2] = 5.715928;
      val[1049 * nCulm + 3] = -12.648742;
      val[1049 * nCulm + 4] = 38.410753;
      val[1049 * nCulm + 5] = 0.506676;
      val[1050 * nCulm + 0] = -35.774088;
      val[1050 * nCulm + 1] = 1.756087;
      val[1050 * nCulm + 2] = 48.986700;
      val[1050 * nCulm + 3] = 7.195441;
      val[1050 * nCulm + 4] = -32.981866;
      val[1050 * nCulm + 5] = -1.054662;
      val[1051 * nCulm + 0] = 6.445962;
      val[1051 * nCulm + 1] = -5.633014;
      val[1051 * nCulm + 2] = -33.708693;
      val[1051 * nCulm + 3] = -22.105730;
      val[1051 * nCulm + 4] = -0.682057;
      val[1051 * nCulm + 5] = 192.731144;
      val[1052 * nCulm + 0] = -15.305717;
      val[1052 * nCulm + 1] = 19.783153;
      val[1052 * nCulm + 2] = -47.528696;
      val[1052 * nCulm + 3] = 35.378591;
      val[1052 * nCulm + 4] = 40.617151;
      val[1052 * nCulm + 5] = 6.658292;
      val[1053 * nCulm + 0] = 46.703534;
      val[1053 * nCulm + 1] = -17.344677;
      val[1053 * nCulm + 2] = -33.445116;
      val[1053 * nCulm + 3] = -39.835787;
      val[1053 * nCulm + 4] = 47.660798;
      val[1053 * nCulm + 5] = -5.448759;
      val[1054 * nCulm + 0] = -35.846787;
      val[1054 * nCulm + 1] = 35.484303;
      val[1054 * nCulm + 2] = 25.929901;
      val[1054 * nCulm + 3] = 45.535366;
      val[1054 * nCulm + 4] = 42.447134;
      val[1054 * nCulm + 5] = 9.264605;
      val[1055 * nCulm + 0] = 20.447893;
      val[1055 * nCulm + 1] = -42.986719;
      val[1055 * nCulm + 2] = -1.628783;
      val[1055 * nCulm + 3] = -37.979653;
      val[1055 * nCulm + 4] = -1.931489;
      val[1055 * nCulm + 5] = 198.647283;
      val[1056 * nCulm + 0] = -2.083553;
      val[1056 * nCulm + 1] = 32.298693;
      val[1056 * nCulm + 2] = 44.096011;
      val[1056 * nCulm + 3] = 4.784435;
      val[1056 * nCulm + 4] = -28.713163;
      val[1056 * nCulm + 5] = -5.883113;
      val[1057 * nCulm + 0] = -1.198927;
      val[1057 * nCulm + 1] = 25.169511;
      val[1057 * nCulm + 2] = -49.615459;
      val[1057 * nCulm + 3] = -45.190498;
      val[1057 * nCulm + 4] = 46.525726;
      val[1057 * nCulm + 5] = -1.806852;
      val[1058 * nCulm + 0] = 0.647474;
      val[1058 * nCulm + 1] = 47.932850;
      val[1058 * nCulm + 2] = -45.195383;
      val[1058 * nCulm + 3] = 18.416486;
      val[1058 * nCulm + 4] = -6.912711;
      val[1058 * nCulm + 5] = -45.201310;
      val[1059 * nCulm + 0] = -32.593503;
      val[1059 * nCulm + 1] = 37.894927;
      val[1059 * nCulm + 2] = 31.251784;
      val[1059 * nCulm + 3] = -5.623595;
      val[1059 * nCulm + 4] = -3.949280;
      val[1059 * nCulm + 5] = -38.448177;
      val[1060 * nCulm + 0] = 30.123843;
      val[1060 * nCulm + 1] = 8.092581;
      val[1060 * nCulm + 2] = -22.786738;
      val[1060 * nCulm + 3] = -14.534267;
      val[1060 * nCulm + 4] = 15.914308;
      val[1060 * nCulm + 5] = -1.685927;
      val[1061 * nCulm + 0] = -15.614447;
      val[1061 * nCulm + 1] = 14.074612;
      val[1061 * nCulm + 2] = -9.099557;
      val[1061 * nCulm + 3] = -38.304919;
      val[1061 * nCulm + 4] = -0.520534;
      val[1061 * nCulm + 5] = 220.561615;
      val[1062 * nCulm + 0] = -41.888078;
      val[1062 * nCulm + 1] = 47.510022;
      val[1062 * nCulm + 2] = 26.213703;
      val[1062 * nCulm + 3] = 1.613908;
      val[1062 * nCulm + 4] = -39.962937;
      val[1062 * nCulm + 5] = -5.588390;
      val[1063 * nCulm + 0] = -27.542926;
      val[1063 * nCulm + 1] = -48.117780;
      val[1063 * nCulm + 2] = -11.317105;
      val[1063 * nCulm + 3] = 4.990672;
      val[1063 * nCulm + 4] = 39.822193;
      val[1063 * nCulm + 5] = -4.896161;
      val[1064 * nCulm + 0] = -41.444491;
      val[1064 * nCulm + 1] = -47.073387;
      val[1064 * nCulm + 2] = 2.868130;
      val[1064 * nCulm + 3] = -34.427032;
      val[1064 * nCulm + 4] = -8.916938;
      val[1064 * nCulm + 5] = 43.492455;
      val[1065 * nCulm + 0] = -47.576516;
      val[1065 * nCulm + 1] = 34.595347;
      val[1065 * nCulm + 2] = 1.935900;
      val[1065 * nCulm + 3] = -36.214781;
      val[1065 * nCulm + 4] = 29.827370;
      val[1065 * nCulm + 5] = -0.026989;
      val[1066 * nCulm + 0] = 0.933706;
      val[1066 * nCulm + 1] = -4.446689;
      val[1066 * nCulm + 2] = -13.104420;
      val[1066 * nCulm + 3] = 46.332513;
      val[1066 * nCulm + 4] = -26.937331;
      val[1066 * nCulm + 5] = -7.130030;
      val[1067 * nCulm + 0] = -28.907902;
      val[1067 * nCulm + 1] = 44.867930;
      val[1067 * nCulm + 2] = 34.569281;
      val[1067 * nCulm + 3] = -45.589066;
      val[1067 * nCulm + 4] = 39.467108;
      val[1067 * nCulm + 5] = 0.143513;
      val[1068 * nCulm + 0] = 23.828545;
      val[1068 * nCulm + 1] = -33.089328;
      val[1068 * nCulm + 2] = -5.354124;
      val[1068 * nCulm + 3] = 4.289870;
      val[1068 * nCulm + 4] = -38.111105;
      val[1068 * nCulm + 5] = 3.806843;
      val[1069 * nCulm + 0] = -22.439359;
      val[1069 * nCulm + 1] = -49.376480;
      val[1069 * nCulm + 2] = -12.127375;
      val[1069 * nCulm + 3] = 31.696777;
      val[1069 * nCulm + 4] = 15.621816;
      val[1069 * nCulm + 5] = -5.126863;
      val[1070 * nCulm + 0] = 1.213059;
      val[1070 * nCulm + 1] = -26.887983;
      val[1070 * nCulm + 2] = -38.066652;
      val[1070 * nCulm + 3] = -11.041277;
      val[1070 * nCulm + 4] = 8.321620;
      val[1070 * nCulm + 5] = -21.344145;
      val[1071 * nCulm + 0] = -25.464248;
      val[1071 * nCulm + 1] = -28.730348;
      val[1071 * nCulm + 2] = -44.706317;
      val[1071 * nCulm + 3] = 24.442123;
      val[1071 * nCulm + 4] = -46.332941;
      val[1071 * nCulm + 5] = 0.668081;
      val[1072 * nCulm + 0] = 35.249737;
      val[1072 * nCulm + 1] = -10.556438;
      val[1072 * nCulm + 2] = -36.844648;
      val[1072 * nCulm + 3] = 9.979187;
      val[1072 * nCulm + 4] = -7.993051;
      val[1072 * nCulm + 5] = 0.571837;
      val[1073 * nCulm + 0] = -48.127235;
      val[1073 * nCulm + 1] = -17.426554;
      val[1073 * nCulm + 2] = 16.269453;
      val[1073 * nCulm + 3] = 37.299263;
      val[1073 * nCulm + 4] = 0.727771;
      val[1073 * nCulm + 5] = 129.479578;
      val[1074 * nCulm + 0] = -8.023615;
      val[1074 * nCulm + 1] = -9.045780;
      val[1074 * nCulm + 2] = -36.842973;
      val[1074 * nCulm + 3] = -19.800061;
      val[1074 * nCulm + 4] = 10.829799;
      val[1074 * nCulm + 5] = -12.377527;
      val[1075 * nCulm + 0] = -19.834448;
      val[1075 * nCulm + 1] = -15.248109;
      val[1075 * nCulm + 2] = 22.969048;
      val[1075 * nCulm + 3] = 19.750075;
      val[1075 * nCulm + 4] = 28.442974;
      val[1075 * nCulm + 5] = 0.979194;
      val[1076 * nCulm + 0] = 1.978403;
      val[1076 * nCulm + 1] = 43.541868;
      val[1076 * nCulm + 2] = -44.805003;
      val[1076 * nCulm + 3] = -40.034481;
      val[1076 * nCulm + 4] = -15.339543;
      val[1076 * nCulm + 5] = -0.852277;
      val[1077 * nCulm + 0] = 23.504073;
      val[1077 * nCulm + 1] = 46.617524;
      val[1077 * nCulm + 2] = -46.536012;
      val[1077 * nCulm + 3] = -19.725290;
      val[1077 * nCulm + 4] = 39.405049;
      val[1077 * nCulm + 5] = 3.460294;
      val[1078 * nCulm + 0] = -10.495156;
      val[1078 * nCulm + 1] = 45.328969;
      val[1078 * nCulm + 2] = -2.516025;
      val[1078 * nCulm + 3] = -22.193668;
      val[1078 * nCulm + 4] = 43.016423;
      val[1078 * nCulm + 5] = 2.775704;
      val[1079 * nCulm + 0] = 32.474561;
      val[1079 * nCulm + 1] = 16.755110;
      val[1079 * nCulm + 2] = 30.753570;
      val[1079 * nCulm + 3] = 39.962863;
      val[1079 * nCulm + 4] = -14.477836;
      val[1079 * nCulm + 5] = -18.313177;
      val[1080 * nCulm + 0] = 40.428445;
      val[1080 * nCulm + 1] = -20.998873;
      val[1080 * nCulm + 2] = 21.599887;
      val[1080 * nCulm + 3] = -36.964530;
      val[1080 * nCulm + 4] = 22.001079;
      val[1080 * nCulm + 5] = -12.240302;
      val[1081 * nCulm + 0] = 2.987943;
      val[1081 * nCulm + 1] = -47.663485;
      val[1081 * nCulm + 2] = 2.518602;
      val[1081 * nCulm + 3] = 46.692406;
      val[1081 * nCulm + 4] = 49.197526;
      val[1081 * nCulm + 5] = 0.136572;
      val[1082 * nCulm + 0] = 34.733755;
      val[1082 * nCulm + 1] = 17.853219;
      val[1082 * nCulm + 2] = 17.270601;
      val[1082 * nCulm + 3] = -19.145970;
      val[1082 * nCulm + 4] = -37.423310;
      val[1082 * nCulm + 5] = 0.393508;
      val[1083 * nCulm + 0] = -24.997427;
      val[1083 * nCulm + 1] = 43.751284;
      val[1083 * nCulm + 2] = -44.378829;
      val[1083 * nCulm + 3] = -11.005397;
      val[1083 * nCulm + 4] = 15.879207;
      val[1083 * nCulm + 5] = 9.991016;
      val[1084 * nCulm + 0] = 8.313165;
      val[1084 * nCulm + 1] = 34.696071;
      val[1084 * nCulm + 2] = 4.645662;
      val[1084 * nCulm + 3] = 26.228006;
      val[1084 * nCulm + 4] = 5.073349;
      val[1084 * nCulm + 5] = 57.070948;
      val[1085 * nCulm + 0] = -2.511688;
      val[1085 * nCulm + 1] = -23.714349;
      val[1085 * nCulm + 2] = -2.041459;
      val[1085 * nCulm + 3] = -42.916676;
      val[1085 * nCulm + 4] = -29.198889;
      val[1085 * nCulm + 5] = 11.031330;
      val[1086 * nCulm + 0] = 29.994085;
      val[1086 * nCulm + 1] = 12.217462;
      val[1086 * nCulm + 2] = 11.785796;
      val[1086 * nCulm + 3] = -34.027455;
      val[1086 * nCulm + 4] = -27.709818;
      val[1086 * nCulm + 5] = 3.955538;
      val[1087 * nCulm + 0] = -23.188871;
      val[1087 * nCulm + 1] = -3.678301;
      val[1087 * nCulm + 2] = 9.092531;
      val[1087 * nCulm + 3] = 43.012399;
      val[1087 * nCulm + 4] = 15.740218;
      val[1087 * nCulm + 5] = 12.058387;
      val[1088 * nCulm + 0] = -13.490188;
      val[1088 * nCulm + 1] = 12.245524;
      val[1088 * nCulm + 2] = 12.030922;
      val[1088 * nCulm + 3] = -44.518411;
      val[1088 * nCulm + 4] = 35.711113;
      val[1088 * nCulm + 5] = -4.047613;
      val[1089 * nCulm + 0] = -5.819661;
      val[1089 * nCulm + 1] = -23.083839;
      val[1089 * nCulm + 2] = 15.241035;
      val[1089 * nCulm + 3] = 22.530330;
      val[1089 * nCulm + 4] = 7.026901;
      val[1089 * nCulm + 5] = -0.142845;
      val[1090 * nCulm + 0] = -11.192339;
      val[1090 * nCulm + 1] = -3.257177;
      val[1090 * nCulm + 2] = 30.903292;
      val[1090 * nCulm + 3] = -48.497139;
      val[1090 * nCulm + 4] = 27.446815;
      val[1090 * nCulm + 5] = -8.695277;
      val[1091 * nCulm + 0] = -28.553536;
      val[1091 * nCulm + 1] = 9.534773;
      val[1091 * nCulm + 2] = -19.932305;
      val[1091 * nCulm + 3] = 49.063586;
      val[1091 * nCulm + 4] = 45.658263;
      val[1091 * nCulm + 5] = 6.304816;
      val[1092 * nCulm + 0] = -12.284173;
      val[1092 * nCulm + 1] = -34.511454;
      val[1092 * nCulm + 2] = 32.291993;
      val[1092 * nCulm + 3] = -27.469867;
      val[1092 * nCulm + 4] = 10.451449;
      val[1092 * nCulm + 5] = -27.840581;
      val[1093 * nCulm + 0] = 4.667640;
      val[1093 * nCulm + 1] = 6.398144;
      val[1093 * nCulm + 2] = -32.331995;
      val[1093 * nCulm + 3] = 39.772601;
      val[1093 * nCulm + 4] = 15.142754;
      val[1093 * nCulm + 5] = 14.662086;
      val[1094 * nCulm + 0] = 37.782668;
      val[1094 * nCulm + 1] = 35.162757;
      val[1094 * nCulm + 2] = -17.898720;
      val[1094 * nCulm + 3] = 33.152630;
      val[1094 * nCulm + 4] = 40.914389;
      val[1094 * nCulm + 5] = 8.133320;
      val[1095 * nCulm + 0] = -2.100237;
      val[1095 * nCulm + 1] = 20.182168;
      val[1095 * nCulm + 2] = 35.147257;
      val[1095 * nCulm + 3] = 46.761482;
      val[1095 * nCulm + 4] = 43.790737;
      val[1095 * nCulm + 5] = 7.465928;
      val[1096 * nCulm + 0] = -49.655254;
      val[1096 * nCulm + 1] = 10.540135;
      val[1096 * nCulm + 2] = -43.869557;
      val[1096 * nCulm + 3] = -4.133317;
      val[1096 * nCulm + 4] = -8.346948;
      val[1096 * nCulm + 5] = -3.403137;
      val[1097 * nCulm + 0] = 12.584280;
      val[1097 * nCulm + 1] = 44.046660;
      val[1097 * nCulm + 2] = -2.660991;
      val[1097 * nCulm + 3] = -17.645430;
      val[1097 * nCulm + 4] = 37.388789;
      val[1097 * nCulm + 5] = 3.572334;
      val[1098 * nCulm + 0] = -34.301813;
      val[1098 * nCulm + 1] = 1.059730;
      val[1098 * nCulm + 2] = 43.497664;
      val[1098 * nCulm + 3] = 38.303322;
      val[1098 * nCulm + 4] = -9.231169;
      val[1098 * nCulm + 5] = -19.953623;
      val[1099 * nCulm + 0] = 13.022295;
      val[1099 * nCulm + 1] = -26.064492;
      val[1099 * nCulm + 2] = -7.872997;
      val[1099 * nCulm + 3] = -44.228712;
      val[1099 * nCulm + 4] = -29.029907;
      val[1099 * nCulm + 5] = 11.691324;
      val[1100 * nCulm + 0] = -45.587411;
      val[1100 * nCulm + 1] = 9.607954;
      val[1100 * nCulm + 2] = 19.480418;
      val[1100 * nCulm + 3] = -8.879747;
      val[1100 * nCulm + 4] = 28.532438;
      val[1100 * nCulm + 5] = 0.350805;
      val[1101 * nCulm + 0] = 30.689114;
      val[1101 * nCulm + 1] = -38.903870;
      val[1101 * nCulm + 2] = 6.517120;
      val[1101 * nCulm + 3] = -31.150793;
      val[1101 * nCulm + 4] = -43.730482;
      val[1101 * nCulm + 5] = 7.812630;
      val[1102 * nCulm + 0] = -5.426292;
      val[1102 * nCulm + 1] = 23.010393;
      val[1102 * nCulm + 2] = 22.406302;
      val[1102 * nCulm + 3] = -6.548676;
      val[1102 * nCulm + 4] = -25.010904;
      val[1102 * nCulm + 5] = -2.885393;
      val[1103 * nCulm + 0] = 34.562514;
      val[1103 * nCulm + 1] = -40.755021;
      val[1103 * nCulm + 2] = 15.367025;
      val[1103 * nCulm + 3] = -44.309495;
      val[1103 * nCulm + 4] = -35.732476;
      val[1103 * nCulm + 5] = 11.498145;
      val[1104 * nCulm + 0] = -6.002384;
      val[1104 * nCulm + 1] = -47.806285;
      val[1104 * nCulm + 2] = -33.479111;
      val[1104 * nCulm + 3] = 3.016454;
      val[1104 * nCulm + 4] = 31.536924;
      val[1104 * nCulm + 5] = -6.492444;
      val[1105 * nCulm + 0] = -46.358328;
      val[1105 * nCulm + 1] = -46.015708;
      val[1105 * nCulm + 2] = 2.837320;
      val[1105 * nCulm + 3] = 44.289375;
      val[1105 * nCulm + 4] = -32.667843;
      val[1105 * nCulm + 5] = 0.480133;
      val[1106 * nCulm + 0] = -19.078637;
      val[1106 * nCulm + 1] = -42.814579;
      val[1106 * nCulm + 2] = 38.996817;
      val[1106 * nCulm + 3] = -40.858746;
      val[1106 * nCulm + 4] = 3.971872;
      val[1106 * nCulm + 5] = -99.484626;
      val[1107 * nCulm + 0] = -19.018537;
      val[1107 * nCulm + 1] = 38.893605;
      val[1107 * nCulm + 2] = 18.546213;
      val[1107 * nCulm + 3] = 28.688269;
      val[1107 * nCulm + 4] = -9.512192;
      val[1107 * nCulm + 5] = -33.399214;
      val[1108 * nCulm + 0] = -13.612325;
      val[1108 * nCulm + 1] = -24.736945;
      val[1108 * nCulm + 2] = -34.362180;
      val[1108 * nCulm + 3] = -15.311964;
      val[1108 * nCulm + 4] = 28.425704;
      val[1108 * nCulm + 5] = -6.438782;
      val[1109 * nCulm + 0] = -10.985968;
      val[1109 * nCulm + 1] = -36.554131;
      val[1109 * nCulm + 2] = -35.946812;
      val[1109 * nCulm + 3] = -40.582638;
      val[1109 * nCulm + 4] = 0.973703;
      val[1109 * nCulm + 5] = -374.744819;
      val[1110 * nCulm + 0] = -27.730657;
      val[1110 * nCulm + 1] = 26.353358;
      val[1110 * nCulm + 2] = -6.907561;
      val[1110 * nCulm + 3] = 13.306872;
      val[1110 * nCulm + 4] = 18.796641;
      val[1110 * nCulm + 5] = 10.217161;
      val[1111 * nCulm + 0] = -2.559713;
      val[1111 * nCulm + 1] = 21.291275;
      val[1111 * nCulm + 2] = -21.513663;
      val[1111 * nCulm + 3] = -29.949475;
      val[1111 * nCulm + 4] = -3.021906;
      val[1111 * nCulm + 5] = 13.791687;
      val[1112 * nCulm + 0] = 14.475042;
      val[1112 * nCulm + 1] = 21.861832;
      val[1112 * nCulm + 2] = -29.190348;
      val[1112 * nCulm + 3] = -44.396540;
      val[1112 * nCulm + 4] = 0.184517;
      val[1112 * nCulm + 5] = -577.843601;
      val[1113 * nCulm + 0] = 39.320250;
      val[1113 * nCulm + 1] = 32.835176;
      val[1113 * nCulm + 2] = -6.866015;
      val[1113 * nCulm + 3] = 20.597057;
      val[1113 * nCulm + 4] = 49.353216;
      val[1113 * nCulm + 5] = 5.354541;
      val[1114 * nCulm + 0] = -5.579247;
      val[1114 * nCulm + 1] = 7.850282;
      val[1114 * nCulm + 2] = 40.350831;
      val[1114 * nCulm + 3] = 9.328189;
      val[1114 * nCulm + 4] = 1.482016;
      val[1114 * nCulm + 5] = 55.095409;
      val[1115 * nCulm + 0] = 39.364295;
      val[1115 * nCulm + 1] = -41.428922;
      val[1115 * nCulm + 2] = 39.614133;
      val[1115 * nCulm + 3] = -46.330603;
      val[1115 * nCulm + 4] = -7.902333;
      val[1115 * nCulm + 5] = 52.796136;
      val[1116 * nCulm + 0] = 6.679358;
      val[1116 * nCulm + 1] = -14.034423;
      val[1116 * nCulm + 2] = -14.847378;
      val[1116 * nCulm + 3] = -12.252545;
      val[1116 * nCulm + 4] = 5.224929;
      val[1116 * nCulm + 5] = -23.583717;
      val[1117 * nCulm + 0] = -22.882527;
      val[1117 * nCulm + 1] = 20.599372;
      val[1117 * nCulm + 2] = -27.988578;
      val[1117 * nCulm + 3] = 44.376131;
      val[1117 * nCulm + 4] = -49.021656;
      val[1117 * nCulm + 5] = -6.043772;
      val[1118 * nCulm + 0] = -45.657361;
      val[1118 * nCulm + 1] = -33.880441;
      val[1118 * nCulm + 2] = -14.042175;
      val[1118 * nCulm + 3] = -3.997648;
      val[1118 * nCulm + 4] = -7.599188;
      val[1118 * nCulm + 5] = 23.823261;
      val[1119 * nCulm + 0] = 9.185967;
      val[1119 * nCulm + 1] = 14.051417;
      val[1119 * nCulm + 2] = 33.066349;
      val[1119 * nCulm + 3] = -2.320822;
      val[1119 * nCulm + 4] = -46.421903;
      val[1119 * nCulm + 5] = -0.966091;
      val[1120 * nCulm + 0] = 25.764561;
      val[1120 * nCulm + 1] = -38.399310;
      val[1120 * nCulm + 2] = -38.528480;
      val[1120 * nCulm + 3] = 24.592411;
      val[1120 * nCulm + 4] = -9.416174;
      val[1120 * nCulm + 5] = 7.170468;
      val[1121 * nCulm + 0] = -33.392224;
      val[1121 * nCulm + 1] = -35.467200;
      val[1121 * nCulm + 2] = 22.020825;
      val[1121 * nCulm + 3] = 43.528479;
      val[1121 * nCulm + 4] = 24.482398;
      val[1121 * nCulm + 5] = 1.788537;
      val[1122 * nCulm + 0] = -21.678013;
      val[1122 * nCulm + 1] = 47.650711;
      val[1122 * nCulm + 2] = -25.015078;
      val[1122 * nCulm + 3] = 37.675941;
      val[1122 * nCulm + 4] = 34.734385;
      val[1122 * nCulm + 5] = 11.857656;
      val[1123 * nCulm + 0] = -40.844316;
      val[1123 * nCulm + 1] = 27.334850;
      val[1123 * nCulm + 2] = 8.393954;
      val[1123 * nCulm + 3] = 11.968938;
      val[1123 * nCulm + 4] = 24.214562;
      val[1123 * nCulm + 5] = 7.912895;
      val[1124 * nCulm + 0] = -30.057975;
      val[1124 * nCulm + 1] = -12.782788;
      val[1124 * nCulm + 2] = 7.938812;
      val[1124 * nCulm + 3] = -33.452077;
      val[1124 * nCulm + 4] = -44.824687;
      val[1124 * nCulm + 5] = 5.112243;
      val[1125 * nCulm + 0] = 31.531528;
      val[1125 * nCulm + 1] = 18.994386;
      val[1125 * nCulm + 2] = 40.071267;
      val[1125 * nCulm + 3] = -27.960933;
      val[1125 * nCulm + 4] = 13.759812;
      val[1125 * nCulm + 5] = -2.854465;
      val[1126 * nCulm + 0] = -42.325939;
      val[1126 * nCulm + 1] = 1.232904;
      val[1126 * nCulm + 2] = -40.134255;
      val[1126 * nCulm + 3] = 36.401839;
      val[1126 * nCulm + 4] = -41.860354;
      val[1126 * nCulm + 5] = -4.025525;
      val[1127 * nCulm + 0] = 22.596260;
      val[1127 * nCulm + 1] = -27.505093;
      val[1127 * nCulm + 2] = -9.063724;
      val[1127 * nCulm + 3] = 23.369153;
      val[1127 * nCulm + 4] = -40.230379;
      val[1127 * nCulm + 5] = 0.716617;
      val[1128 * nCulm + 0] = 49.831568;
      val[1128 * nCulm + 1] = -38.169498;
      val[1128 * nCulm + 2] = -38.858389;
      val[1128 * nCulm + 3] = -45.275588;
      val[1128 * nCulm + 4] = -45.348404;
      val[1128 * nCulm + 5] = 8.939753;
      val[1129 * nCulm + 0] = 2.917211;
      val[1129 * nCulm + 1] = 49.731242;
      val[1129 * nCulm + 2] = 45.370263;
      val[1129 * nCulm + 3] = 3.979561;
      val[1129 * nCulm + 4] = 29.687572;
      val[1129 * nCulm + 5] = 8.793554;
      val[1130 * nCulm + 0] = -45.690750;
      val[1130 * nCulm + 1] = 16.757023;
      val[1130 * nCulm + 2] = 36.599853;
      val[1130 * nCulm + 3] = 48.596821;
      val[1130 * nCulm + 4] = -24.692920;
      val[1130 * nCulm + 5] = -12.297539;
      val[1131 * nCulm + 0] = -12.031982;
      val[1131 * nCulm + 1] = -27.210950;
      val[1131 * nCulm + 2] = 34.551873;
      val[1131 * nCulm + 3] = -33.374203;
      val[1131 * nCulm + 4] = 24.230675;
      val[1131 * nCulm + 5] = -11.604987;
      val[1132 * nCulm + 0] = -40.780719;
      val[1132 * nCulm + 1] = 9.291332;
      val[1132 * nCulm + 2] = 27.963920;
      val[1132 * nCulm + 3] = 26.179317;
      val[1132 * nCulm + 4] = 17.429593;
      val[1132 * nCulm + 5] = 9.862721;
      val[1133 * nCulm + 0] = 46.201796;
      val[1133 * nCulm + 1] = 25.136461;
      val[1133 * nCulm + 2] = 15.036310;
      val[1133 * nCulm + 3] = 41.233335;
      val[1133 * nCulm + 4] = 30.909565;
      val[1133 * nCulm + 5] = 10.393532;
      val[1134 * nCulm + 0] = -45.720301;
      val[1134 * nCulm + 1] = -24.554412;
      val[1134 * nCulm + 2] = -42.149990;
      val[1134 * nCulm + 3] = 31.185606;
      val[1134 * nCulm + 4] = -17.121186;
      val[1134 * nCulm + 5] = -1.603264;
      val[1135 * nCulm + 0] = -1.374975;
      val[1135 * nCulm + 1] = 42.063006;
      val[1135 * nCulm + 2] = 37.351860;
      val[1135 * nCulm + 3] = 37.009285;
      val[1135 * nCulm + 4] = -1.546697;
      val[1135 * nCulm + 5] = -241.753747;
      val[1136 * nCulm + 0] = -7.388429;
      val[1136 * nCulm + 1] = 13.581976;
      val[1136 * nCulm + 2] = 4.285849;
      val[1136 * nCulm + 3] = 18.935138;
      val[1136 * nCulm + 4] = -1.784548;
      val[1136 * nCulm + 5] = -86.018366;
      val[1137 * nCulm + 0] = -12.170682;
      val[1137 * nCulm + 1] = 39.581614;
      val[1137 * nCulm + 2] = 45.286044;
      val[1137 * nCulm + 3] = 18.733593;
      val[1137 * nCulm + 4] = 40.502268;
      val[1137 * nCulm + 5] = 7.045058;
      val[1138 * nCulm + 0] = 11.672447;
      val[1138 * nCulm + 1] = 26.464875;
      val[1138 * nCulm + 2] = 18.948425;
      val[1138 * nCulm + 3] = 6.787010;
      val[1138 * nCulm + 4] = -13.001169;
      val[1138 * nCulm + 5] = -11.876008;
      val[1139 * nCulm + 0] = 48.974595;
      val[1139 * nCulm + 1] = 34.004613;
      val[1139 * nCulm + 2] = 35.345585;
      val[1139 * nCulm + 3] = 12.631148;
      val[1139 * nCulm + 4] = -34.667002;
      val[1139 * nCulm + 5] = -6.137514;
      val[1140 * nCulm + 0] = 33.733698;
      val[1140 * nCulm + 1] = 44.358138;
      val[1140 * nCulm + 2] = 47.628655;
      val[1140 * nCulm + 3] = -44.906647;
      val[1140 * nCulm + 4] = 20.233824;
      val[1140 * nCulm + 5] = 0.101686;
      val[1141 * nCulm + 0] = 23.280452;
      val[1141 * nCulm + 1] = 16.994279;
      val[1141 * nCulm + 2] = 2.466688;
      val[1141 * nCulm + 3] = 49.350155;
      val[1141 * nCulm + 4] = -19.817584;
      val[1141 * nCulm + 5] = -15.616044;
      val[1142 * nCulm + 0] = -1.397784;
      val[1142 * nCulm + 1] = -15.378993;
      val[1142 * nCulm + 2] = -8.967261;
      val[1142 * nCulm + 3] = 21.458087;
      val[1142 * nCulm + 4] = 48.185640;
      val[1142 * nCulm + 5] = 0.827157;
      val[1143 * nCulm + 0] = -10.491131;
      val[1143 * nCulm + 1] = 43.093594;
      val[1143 * nCulm + 2] = 22.019909;
      val[1143 * nCulm + 3] = -24.306985;
      val[1143 * nCulm + 4] = -35.641912;
      val[1143 * nCulm + 5] = -2.264908;
      val[1144 * nCulm + 0] = 3.272963;
      val[1144 * nCulm + 1] = -4.540658;
      val[1144 * nCulm + 2] = -34.201070;
      val[1144 * nCulm + 3] = -48.735001;
      val[1144 * nCulm + 4] = -29.370917;
      val[1144 * nCulm + 5] = 8.815753;
      val[1145 * nCulm + 0] = 27.357198;
      val[1145 * nCulm + 1] = -41.451395;
      val[1145 * nCulm + 2] = 19.632680;
      val[1145 * nCulm + 3] = 28.696513;
      val[1145 * nCulm + 4] = -33.720104;
      val[1145 * nCulm + 5] = 2.020419;
      val[1146 * nCulm + 0] = -14.348805;
      val[1146 * nCulm + 1] = -12.519448;
      val[1146 * nCulm + 2] = -36.167177;
      val[1146 * nCulm + 3] = 15.740908;
      val[1146 * nCulm + 4] = -45.607629;
      val[1146 * nCulm + 5] = -0.104335;
      val[1147 * nCulm + 0] = -12.881603;
      val[1147 * nCulm + 1] = -27.708464;
      val[1147 * nCulm + 2] = 25.277053;
      val[1147 * nCulm + 3] = 18.739411;
      val[1147 * nCulm + 4] = -17.214906;
      val[1147 * nCulm + 5] = 2.696091;
      val[1148 * nCulm + 0] = 13.576316;
      val[1148 * nCulm + 1] = 29.744353;
      val[1148 * nCulm + 2] = -45.076100;
      val[1148 * nCulm + 3] = -31.366007;
      val[1148 * nCulm + 4] = -10.593115;
      val[1148 * nCulm + 5] = 0.954605;
      val[1149 * nCulm + 0] = -49.588362;
      val[1149 * nCulm + 1] = -44.057146;
      val[1149 * nCulm + 2] = 38.668264;
      val[1149 * nCulm + 3] = 20.866292;
      val[1149 * nCulm + 4] = -20.649859;
      val[1149 * nCulm + 5] = 5.545777;
      val[1150 * nCulm + 0] = -24.810784;
      val[1150 * nCulm + 1] = -37.074472;
      val[1150 * nCulm + 2] = -48.289752;
      val[1150 * nCulm + 3] = -44.537862;
      val[1150 * nCulm + 4] = -8.954038;
      val[1150 * nCulm + 5] = 43.372366;
      val[1151 * nCulm + 0] = 23.048347;
      val[1151 * nCulm + 1] = -26.314983;
      val[1151 * nCulm + 2] = 23.986450;
      val[1151 * nCulm + 3] = -18.816006;
      val[1151 * nCulm + 4] = -22.078513;
      val[1151 * nCulm + 5] = 9.905471;
      val[1152 * nCulm + 0] = -17.301041;
      val[1152 * nCulm + 1] = 37.954039;
      val[1152 * nCulm + 2] = 26.064782;
      val[1152 * nCulm + 3] = -15.985175;
      val[1152 * nCulm + 4] = 12.464713;
      val[1152 * nCulm + 5] = 8.572427;
      val[1153 * nCulm + 0] = 25.957850;
      val[1153 * nCulm + 1] = 33.822171;
      val[1153 * nCulm + 2] = -21.140699;
      val[1153 * nCulm + 3] = 30.083220;
      val[1153 * nCulm + 4] = 15.878106;
      val[1153 * nCulm + 5] = 19.280479;
      val[1154 * nCulm + 0] = -14.115342;
      val[1154 * nCulm + 1] = 42.076567;
      val[1154 * nCulm + 2] = -39.191768;
      val[1154 * nCulm + 3] = -32.878305;
      val[1154 * nCulm + 4] = -44.462141;
      val[1154 * nCulm + 5] = -0.749225;
      val[1155 * nCulm + 0] = -1.007327;
      val[1155 * nCulm + 1] = -32.611374;
      val[1155 * nCulm + 2] = 36.718251;
      val[1155 * nCulm + 3] = 45.336294;
      val[1155 * nCulm + 4] = -19.248585;
      val[1155 * nCulm + 5] = -2.899128;
      val[1156 * nCulm + 0] = -2.555702;
      val[1156 * nCulm + 1] = -32.008410;
      val[1156 * nCulm + 2] = 8.715631;
      val[1156 * nCulm + 3] = -26.974860;
      val[1156 * nCulm + 4] = 47.532169;
      val[1156 * nCulm + 5] = -5.643653;
      val[1157 * nCulm + 0] = -36.125782;
      val[1157 * nCulm + 1] = -6.706584;
      val[1157 * nCulm + 2] = -45.216264;
      val[1157 * nCulm + 3] = -36.540374;
      val[1157 * nCulm + 4] = 8.642522;
      val[1157 * nCulm + 5] = -23.455479;
      val[1158 * nCulm + 0] = -23.997554;
      val[1158 * nCulm + 1] = -1.687521;
      val[1158 * nCulm + 2] = -42.872878;
      val[1158 * nCulm + 3] = -38.261943;
      val[1158 * nCulm + 4] = 42.908747;
      val[1158 * nCulm + 5] = -4.176890;
      val[1159 * nCulm + 0] = -45.167060;
      val[1159 * nCulm + 1] = 34.186504;
      val[1159 * nCulm + 2] = 21.954111;
      val[1159 * nCulm + 3] = -13.227524;
      val[1159 * nCulm + 4] = -8.120020;
      val[1159 * nCulm + 5] = -11.987438;
      val[1160 * nCulm + 0] = 12.787978;
      val[1160 * nCulm + 1] = 29.241500;
      val[1160 * nCulm + 2] = 2.045715;
      val[1160 * nCulm + 3] = 35.789612;
      val[1160 * nCulm + 4] = -4.374495;
      val[1160 * nCulm + 5] = -70.135590;
      val[1161 * nCulm + 0] = 4.226719;
      val[1161 * nCulm + 1] = 5.481334;
      val[1161 * nCulm + 2] = 30.843850;
      val[1161 * nCulm + 3] = -5.288481;
      val[1161 * nCulm + 4] = 23.090308;
      val[1161 * nCulm + 5] = 0.269533;
      val[1162 * nCulm + 0] = -26.181418;
      val[1162 * nCulm + 1] = -36.439931;
      val[1162 * nCulm + 2] = 48.462286;
      val[1162 * nCulm + 3] = -37.834421;
      val[1162 * nCulm + 4] = -33.983451;
      val[1162 * nCulm + 5] = 10.575190;
      val[1163 * nCulm + 0] = -46.881871;
      val[1163 * nCulm + 1] = 18.021465;
      val[1163 * nCulm + 2] = 11.757519;
      val[1163 * nCulm + 3] = -22.913178;
      val[1163 * nCulm + 4] = 6.971624;
      val[1163 * nCulm + 5] = -3.091193;
      val[1164 * nCulm + 0] = 41.391107;
      val[1164 * nCulm + 1] = 19.337701;
      val[1164 * nCulm + 2] = -34.013001;
      val[1164 * nCulm + 3] = 49.990346;
      val[1164 * nCulm + 4] = -29.096948;
      val[1164 * nCulm + 5] = -11.047910;
      val[1165 * nCulm + 0] = 25.353531;
      val[1165 * nCulm + 1] = -40.274385;
      val[1165 * nCulm + 2] = -8.924021;
      val[1165 * nCulm + 3] = -4.098802;
      val[1165 * nCulm + 4] = -17.869900;
      val[1165 * nCulm + 5] = 11.983456;
      val[1166 * nCulm + 0] = 24.013661;
      val[1166 * nCulm + 1] = -7.492130;
      val[1166 * nCulm + 2] = 46.754062;
      val[1166 * nCulm + 3] = -35.339783;
      val[1166 * nCulm + 4] = 8.862104;
      val[1166 * nCulm + 5] = -22.646930;
      val[1167 * nCulm + 0] = -34.188312;
      val[1167 * nCulm + 1] = 49.369381;
      val[1167 * nCulm + 2] = -32.399791;
      val[1167 * nCulm + 3] = -1.981836;
      val[1167 * nCulm + 4] = 32.430301;
      val[1167 * nCulm + 5] = 7.146403;
      val[1168 * nCulm + 0] = -39.710845;
      val[1168 * nCulm + 1] = -26.336490;
      val[1168 * nCulm + 2] = 15.565826;
      val[1168 * nCulm + 3] = 14.043477;
      val[1168 * nCulm + 4] = -44.258768;
      val[1168 * nCulm + 5] = 1.544698;
      val[1169 * nCulm + 0] = -28.913072;
      val[1169 * nCulm + 1] = 47.244962;
      val[1169 * nCulm + 2] = -15.799537;
      val[1169 * nCulm + 3] = 9.258136;
      val[1169 * nCulm + 4] = -48.277517;
      val[1169 * nCulm + 5] = -5.309804;
      val[1170 * nCulm + 0] = 37.557806;
      val[1170 * nCulm + 1] = -12.948433;
      val[1170 * nCulm + 2] = -4.550291;
      val[1170 * nCulm + 3] = -28.426687;
      val[1170 * nCulm + 4] = 41.681505;
      val[1170 * nCulm + 5] = -4.468540;
      val[1171 * nCulm + 0] = 22.503880;
      val[1171 * nCulm + 1] = -23.841792;
      val[1171 * nCulm + 2] = 19.450841;
      val[1171 * nCulm + 3] = 28.873560;
      val[1171 * nCulm + 4] = 19.586072;
      val[1171 * nCulm + 5] = 1.446019;
      val[1172 * nCulm + 0] = 29.206863;
      val[1172 * nCulm + 1] = -38.605736;
      val[1172 * nCulm + 2] = 7.424306;
      val[1172 * nCulm + 3] = -1.290376;
      val[1172 * nCulm + 4] = -17.589134;
      val[1172 * nCulm + 5] = 10.966265;
      val[1173 * nCulm + 0] = 13.852095;
      val[1173 * nCulm + 1] = 45.320295;
      val[1173 * nCulm + 2] = 27.095096;
      val[1173 * nCulm + 3] = -21.030880;
      val[1173 * nCulm + 4] = 16.522721;
      val[1173 * nCulm + 5] = 7.188291;
      val[1174 * nCulm + 0] = 18.444940;
      val[1174 * nCulm + 1] = -11.703670;
      val[1174 * nCulm + 2] = -49.718369;
      val[1174 * nCulm + 3] = -41.580116;
      val[1174 * nCulm + 4] = -21.844427;
      val[1174 * nCulm + 5] = 11.775733;
      val[1175 * nCulm + 0] = -28.364267;
      val[1175 * nCulm + 1] = 22.253209;
      val[1175 * nCulm + 2] = 4.737039;
      val[1175 * nCulm + 3] = -47.907921;
      val[1175 * nCulm + 4] = 40.462701;
      val[1175 * nCulm + 5] = -2.771092;
      val[1176 * nCulm + 0] = 17.556191;
      val[1176 * nCulm + 1] = 35.975614;
      val[1176 * nCulm + 2] = -5.069708;
      val[1176 * nCulm + 3] = -14.664732;
      val[1176 * nCulm + 4] = -3.978072;
      val[1176 * nCulm + 5] = -25.126884;
      val[1177 * nCulm + 0] = -12.994730;
      val[1177 * nCulm + 1] = -14.255548;
      val[1177 * nCulm + 2] = -17.349168;
      val[1177 * nCulm + 3] = 41.454377;
      val[1177 * nCulm + 4] = 21.430861;
      val[1177 * nCulm + 5] = 6.237277;
      val[1178 * nCulm + 0] = -36.821611;
      val[1178 * nCulm + 1] = 33.255775;
      val[1178 * nCulm + 2] = -26.984366;
      val[1178 * nCulm + 3] = 45.111536;
      val[1178 * nCulm + 4] = -12.398246;
      val[1178 * nCulm + 5] = -29.688635;
      val[1179 * nCulm + 0] = 12.748314;
      val[1179 * nCulm + 1] = -36.926351;
      val[1179 * nCulm + 2] = 5.822787;
      val[1179 * nCulm + 3] = 29.464378;
      val[1179 * nCulm + 4] = 23.799003;
      val[1179 * nCulm + 5] = -1.254096;
      val[1180 * nCulm + 0] = 8.487753;
      val[1180 * nCulm + 1] = 15.126355;
      val[1180 * nCulm + 2] = 31.166310;
      val[1180 * nCulm + 3] = 45.568987;
      val[1180 * nCulm + 4] = -17.515312;
      val[1180 * nCulm + 5] = -16.172294;
      val[1181 * nCulm + 0] = 4.242150;
      val[1181 * nCulm + 1] = -17.547441;
      val[1181 * nCulm + 2] = 38.263489;
      val[1181 * nCulm + 3] = -19.311159;
      val[1181 * nCulm + 4] = -0.291831;
      val[1181 * nCulm + 5] = 598.055481;
      val[1182 * nCulm + 0] = 26.402009;
      val[1182 * nCulm + 1] = -10.716539;
      val[1182 * nCulm + 2] = -5.844826;
      val[1182 * nCulm + 3] = 13.906180;
      val[1182 * nCulm + 4] = 2.730946;
      val[1182 * nCulm + 5] = 5.758355;
      val[1183 * nCulm + 0] = -27.163308;
      val[1183 * nCulm + 1] = 4.203878;
      val[1183 * nCulm + 2] = -37.236482;
      val[1183 * nCulm + 3] = 0.427233;
      val[1183 * nCulm + 4] = 25.944946;
      val[1183 * nCulm + 5] = 1.074889;
      val[1184 * nCulm + 0] = -3.015829;
      val[1184 * nCulm + 1] = 14.016624;
      val[1184 * nCulm + 2] = -47.855354;
      val[1184 * nCulm + 3] = -43.808530;
      val[1184 * nCulm + 4] = -44.560082;
      val[1184 * nCulm + 5] = 3.394604;
      val[1185 * nCulm + 0] = -8.409475;
      val[1185 * nCulm + 1] = 38.419014;
      val[1185 * nCulm + 2] = -16.137411;
      val[1185 * nCulm + 3] = -9.105368;
      val[1185 * nCulm + 4] = 25.657180;
      val[1185 * nCulm + 5] = 5.637892;
      val[1186 * nCulm + 0] = -49.875159;
      val[1186 * nCulm + 1] = 7.708859;
      val[1186 * nCulm + 2] = 26.654160;
      val[1186 * nCulm + 3] = 43.814629;
      val[1186 * nCulm + 4] = -38.772768;
      val[1186 * nCulm + 5] = -6.059926;
      val[1187 * nCulm + 0] = 41.749140;
      val[1187 * nCulm + 1] = 6.006686;
      val[1187 * nCulm + 2] = -31.636701;
      val[1187 * nCulm + 3] = -8.244892;
      val[1187 * nCulm + 4] = -37.967959;
      val[1187 * nCulm + 5] = 0.509029;
      val[1188 * nCulm + 0] = 11.368823;
      val[1188 * nCulm + 1] = -35.703995;
      val[1188 * nCulm + 2] = -47.998337;
      val[1188 * nCulm + 3] = 49.147629;
      val[1188 * nCulm + 4] = -39.985132;
      val[1188 * nCulm + 5] = -1.361421;
      val[1189 * nCulm + 0] = -37.739056;
      val[1189 * nCulm + 1] = 20.652714;
      val[1189 * nCulm + 2] = -43.292641;
      val[1189 * nCulm + 3] = 15.535697;
      val[1189 * nCulm + 4] = -13.291118;
      val[1189 * nCulm + 5] = -12.657690;
      val[1190 * nCulm + 0] = -8.358270;
      val[1190 * nCulm + 1] = 48.898180;
      val[1190 * nCulm + 2] = 26.013945;
      val[1190 * nCulm + 3] = -6.764909;
      val[1190 * nCulm + 4] = -48.545399;
      val[1190 * nCulm + 5] = -3.878130;
      val[1191 * nCulm + 0] = -14.017374;
      val[1191 * nCulm + 1] = -15.443046;
      val[1191 * nCulm + 2] = 49.428511;
      val[1191 * nCulm + 3] = 10.941335;
      val[1191 * nCulm + 4] = -48.485038;
      val[1191 * nCulm + 5] = 0.669478;
      val[1192 * nCulm + 0] = -15.755233;
      val[1192 * nCulm + 1] = -22.944787;
      val[1192 * nCulm + 2] = -34.961980;
      val[1192 * nCulm + 3] = 32.942099;
      val[1192 * nCulm + 4] = 31.758558;
      val[1192 * nCulm + 5] = 1.720011;
      val[1193 * nCulm + 0] = -6.609452;
      val[1193 * nCulm + 1] = 10.454069;
      val[1193 * nCulm + 2] = -27.751432;
      val[1193 * nCulm + 3] = -11.581843;
      val[1193 * nCulm + 4] = 47.159966;
      val[1193 * nCulm + 5] = 0.116808;
      val[1194 * nCulm + 0] = -4.675228;
      val[1194 * nCulm + 1] = -45.361903;
      val[1194 * nCulm + 2] = -32.794237;
      val[1194 * nCulm + 3] = -33.692855;
      val[1194 * nCulm + 4] = 10.627591;
      val[1194 * nCulm + 5] = -34.979533;
      val[1195 * nCulm + 0] = 34.927918;
      val[1195 * nCulm + 1] = 5.821124;
      val[1195 * nCulm + 2] = -37.789791;
      val[1195 * nCulm + 3] = -35.765328;
      val[1195 * nCulm + 4] = 30.151306;
      val[1195 * nCulm + 5] = -4.470821;
      val[1196 * nCulm + 0] = 32.666627;
      val[1196 * nCulm + 1] = 10.179954;
      val[1196 * nCulm + 2] = 10.347967;
      val[1196 * nCulm + 3] = 33.354107;
      val[1196 * nCulm + 4] = -42.409945;
      val[1196 * nCulm + 5] = -4.628795;
      val[1197 * nCulm + 0] = -39.217185;
      val[1197 * nCulm + 1] = -0.098939;
      val[1197 * nCulm + 2] = 0.164043;
      val[1197 * nCulm + 3] = -16.949263;
      val[1197 * nCulm + 4] = 48.288591;
      val[1197 * nCulm + 5] = -1.441095;
      val[1198 * nCulm + 0] = 31.985428;
      val[1198 * nCulm + 1] = 10.353471;
      val[1198 * nCulm + 2] = 37.862161;
      val[1198 * nCulm + 3] = -0.109513;
      val[1198 * nCulm + 4] = -1.076670;
      val[1198 * nCulm + 5] = -44.805205;
      val[1199 * nCulm + 0] = -3.926360;
      val[1199 * nCulm + 1] = 40.670049;
      val[1199 * nCulm + 2] = 10.133927;
      val[1199 * nCulm + 3] = 22.686167;
      val[1199 * nCulm + 4] = 6.032579;
      val[1199 * nCulm + 5] = 49.941089;
      val[1200 * nCulm + 0] = 47.439012;
      val[1200 * nCulm + 1] = 21.712936;
      val[1200 * nCulm + 2] = 48.754457;
      val[1200 * nCulm + 3] = -47.593695;
      val[1200 * nCulm + 4] = -31.765878;
      val[1200 * nCulm + 5] = 4.086410;
      val[1201 * nCulm + 0] = -46.204314;
      val[1201 * nCulm + 1] = -48.736928;
      val[1201 * nCulm + 2] = 44.820816;
      val[1201 * nCulm + 3] = 16.119524;
      val[1201 * nCulm + 4] = 43.891423;
      val[1201 * nCulm + 5] = -3.287522;
      val[1202 * nCulm + 0] = 38.312523;
      val[1202 * nCulm + 1] = -9.259510;
      val[1202 * nCulm + 2] = 35.773037;
      val[1202 * nCulm + 3] = 15.912831;
      val[1202 * nCulm + 4] = -17.737045;
      val[1202 * nCulm + 5] = -1.545515;
      val[1203 * nCulm + 0] = -48.383694;
      val[1203 * nCulm + 1] = -32.168481;
      val[1203 * nCulm + 2] = -25.859360;
      val[1203 * nCulm + 3] = 18.264857;
      val[1203 * nCulm + 4] = 23.213455;
      val[1203 * nCulm + 5] = -2.605015;
      val[1204 * nCulm + 0] = -30.477706;
      val[1204 * nCulm + 1] = 33.442982;
      val[1204 * nCulm + 2] = 4.352714;
      val[1204 * nCulm + 3] = -31.059500;
      val[1204 * nCulm + 4] = -31.453301;
      val[1204 * nCulm + 5] = -0.128685;
      val[1205 * nCulm + 0] = -9.295150;
      val[1205 * nCulm + 1] = 21.341344;
      val[1205 * nCulm + 2] = 49.359127;
      val[1205 * nCulm + 3] = 7.744418;
      val[1205 * nCulm + 4] = 28.330679;
      val[1205 * nCulm + 5] = 5.089488;
      val[1206 * nCulm + 0] = 0.214456;
      val[1206 * nCulm + 1] = 36.257343;
      val[1206 * nCulm + 2] = 25.409798;
      val[1206 * nCulm + 3] = 8.984611;
      val[1206 * nCulm + 4] = -14.087420;
      val[1206 * nCulm + 5] = -14.971169;
      val[1207 * nCulm + 0] = 33.148105;
      val[1207 * nCulm + 1] = 4.815935;
      val[1207 * nCulm + 2] = -7.541202;
      val[1207 * nCulm + 3] = -11.824689;
      val[1207 * nCulm + 4] = -4.392033;
      val[1207 * nCulm + 5] = 7.783396;
      val[1208 * nCulm + 0] = -5.168154;
      val[1208 * nCulm + 1] = -47.626598;
      val[1208 * nCulm + 2] = 42.689234;
      val[1208 * nCulm + 3] = 32.206357;
      val[1208 * nCulm + 4] = 1.169098;
      val[1208 * nCulm + 5] = -62.202022;
      val[1209 * nCulm + 0] = -46.179369;
      val[1209 * nCulm + 1] = 32.861913;
      val[1209 * nCulm + 2] = -7.952329;
      val[1209 * nCulm + 3] = -38.761803;
      val[1209 * nCulm + 4] = 29.419549;
      val[1209 * nCulm + 5] = -0.719238;
      val[1210 * nCulm + 0] = 42.199839;
      val[1210 * nCulm + 1] = 31.047406;
      val[1210 * nCulm + 2] = 24.931754;
      val[1210 * nCulm + 3] = 24.360458;
      val[1210 * nCulm + 4] = 33.232625;
      val[1210 * nCulm + 5] = 8.121760;
      val[1211 * nCulm + 0] = -18.754039;
      val[1211 * nCulm + 1] = 30.052041;
      val[1211 * nCulm + 2] = -13.660170;
      val[1211 * nCulm + 3] = 10.617041;
      val[1211 * nCulm + 4] = -25.803292;
      val[1211 * nCulm + 5] = -7.230301;
      val[1212 * nCulm + 0] = -43.713403;
      val[1212 * nCulm + 1] = 40.906442;
      val[1212 * nCulm + 2] = 30.088986;
      val[1212 * nCulm + 3] = 35.537219;
      val[1212 * nCulm + 4] = 28.380174;
      val[1212 * nCulm + 5] = 12.979511;
      val[1213 * nCulm + 0] = -43.809292;
      val[1213 * nCulm + 1] = -42.603680;
      val[1213 * nCulm + 2] = -19.375426;
      val[1213 * nCulm + 3] = -29.678514;
      val[1213 * nCulm + 4] = 16.478498;
      val[1213 * nCulm + 5] = -20.532555;
      val[1214 * nCulm + 0] = 44.484244;
      val[1214 * nCulm + 1] = 47.223926;
      val[1214 * nCulm + 2] = 46.547620;
      val[1214 * nCulm + 3] = -30.813878;
      val[1214 * nCulm + 4] = 46.909505;
      val[1214 * nCulm + 5] = 1.885831;
      val[1215 * nCulm + 0] = -8.181684;
      val[1215 * nCulm + 1] = 0.932366;
      val[1215 * nCulm + 2] = -16.591827;
      val[1215 * nCulm + 3] = -10.610524;
      val[1215 * nCulm + 4] = 37.582615;
      val[1215 * nCulm + 5] = -0.988913;
      val[1216 * nCulm + 0] = 13.996479;
      val[1216 * nCulm + 1] = -14.374093;
      val[1216 * nCulm + 2] = -29.009930;
      val[1216 * nCulm + 3] = 44.000751;
      val[1216 * nCulm + 4] = 48.707326;
      val[1216 * nCulm + 5] = 3.109091;
      val[1217 * nCulm + 0] = 45.223768;
      val[1217 * nCulm + 1] = -44.043684;
      val[1217 * nCulm + 2] = -33.638704;
      val[1217 * nCulm + 3] = 13.658264;
      val[1217 * nCulm + 4] = 24.151908;
      val[1217 * nCulm + 5] = -5.724988;
      val[1218 * nCulm + 0] = -42.375799;
      val[1218 * nCulm + 1] = 18.739874;
      val[1218 * nCulm + 2] = -30.444096;
      val[1218 * nCulm + 3] = 35.437767;
      val[1218 * nCulm + 4] = -33.323290;
      val[1218 * nCulm + 5] = -7.465544;
      val[1219 * nCulm + 0] = -1.658431;
      val[1219 * nCulm + 1] = 37.379135;
      val[1219 * nCulm + 2] = -13.398761;
      val[1219 * nCulm + 3] = -23.586739;
      val[1219 * nCulm + 4] = -46.776721;
      val[1219 * nCulm + 5] = -1.165652;
      val[1220 * nCulm + 0] = -20.620699;
      val[1220 * nCulm + 1] = 36.670029;
      val[1220 * nCulm + 2] = 45.152395;
      val[1220 * nCulm + 3] = 47.949169;
      val[1220 * nCulm + 4] = 34.634873;
      val[1220 * nCulm + 5] = 11.794381;
      val[1221 * nCulm + 0] = -47.474651;
      val[1221 * nCulm + 1] = -14.369690;
      val[1221 * nCulm + 2] = 13.274692;
      val[1221 * nCulm + 3] = 25.419642;
      val[1221 * nCulm + 4] = 18.849799;
      val[1221 * nCulm + 5] = 3.004730;
      val[1222 * nCulm + 0] = 8.720462;
      val[1222 * nCulm + 1] = -23.449399;
      val[1222 * nCulm + 2] = 13.119415;
      val[1222 * nCulm + 3] = -28.614715;
      val[1222 * nCulm + 4] = 30.180630;
      val[1222 * nCulm + 5] = -7.935396;
      val[1223 * nCulm + 0] = 34.415033;
      val[1223 * nCulm + 1] = 20.312995;
      val[1223 * nCulm + 2] = 0.314939;
      val[1223 * nCulm + 3] = 44.097321;
      val[1223 * nCulm + 4] = 19.651265;
      val[1223 * nCulm + 5] = 15.744294;
      val[1224 * nCulm + 0] = 27.651787;
      val[1224 * nCulm + 1] = 34.247232;
      val[1224 * nCulm + 2] = 36.284997;
      val[1224 * nCulm + 3] = 46.802785;
      val[1224 * nCulm + 4] = -47.581408;
      val[1224 * nCulm + 5] = -7.832745;
      val[1225 * nCulm + 0] = 1.140213;
      val[1225 * nCulm + 1] = -14.159163;
      val[1225 * nCulm + 2] = -14.320879;
      val[1225 * nCulm + 3] = 24.697595;
      val[1225 * nCulm + 4] = -7.320903;
      val[1225 * nCulm + 5] = -6.583628;
      val[1226 * nCulm + 0] = -27.532704;
      val[1226 * nCulm + 1] = 10.410484;
      val[1226 * nCulm + 2] = 23.227744;
      val[1226 * nCulm + 3] = 33.191154;
      val[1226 * nCulm + 4] = 14.231584;
      val[1226 * nCulm + 5] = 14.731624;
      val[1227 * nCulm + 0] = 1.713680;
      val[1227 * nCulm + 1] = 16.041781;
      val[1227 * nCulm + 2] = 13.332229;
      val[1227 * nCulm + 3] = 21.037516;
      val[1227 * nCulm + 4] = 34.317113;
      val[1227 * nCulm + 5] = 5.344319;
      val[1228 * nCulm + 0] = 36.236350;
      val[1228 * nCulm + 1] = 32.940992;
      val[1228 * nCulm + 2] = 47.504184;
      val[1228 * nCulm + 3] = 7.338545;
      val[1228 * nCulm + 4] = -43.157457;
      val[1228 * nCulm + 5] = -4.187695;
      val[1229 * nCulm + 0] = 28.969900;
      val[1229 * nCulm + 1] = -1.092308;
      val[1229 * nCulm + 2] = 14.543248;
      val[1229 * nCulm + 3] = -3.101212;
      val[1229 * nCulm + 4] = 37.891029;
      val[1229 * nCulm + 5] = -0.293853;
      val[1230 * nCulm + 0] = 39.425074;
      val[1230 * nCulm + 1] = 30.517784;
      val[1230 * nCulm + 2] = -20.523267;
      val[1230 * nCulm + 3] = 31.002060;
      val[1230 * nCulm + 4] = -49.971198;
      val[1230 * nCulm + 5] = -5.597235;
      val[1231 * nCulm + 0] = 4.347654;
      val[1231 * nCulm + 1] = 36.308971;
      val[1231 * nCulm + 2] = 18.291271;
      val[1231 * nCulm + 3] = -36.641373;
      val[1231 * nCulm + 4] = 28.836891;
      val[1231 * nCulm + 5] = 0.175439;
      val[1232 * nCulm + 0] = 45.957704;
      val[1232 * nCulm + 1] = 10.251019;
      val[1232 * nCulm + 2] = -31.128852;
      val[1232 * nCulm + 3] = 34.469664;
      val[1232 * nCulm + 4] = -38.257888;
      val[1232 * nCulm + 5] = -5.302922;
      val[1233 * nCulm + 0] = -6.933840;
      val[1233 * nCulm + 1] = -7.910370;
      val[1233 * nCulm + 2] = -47.923204;
      val[1233 * nCulm + 3] = -15.389853;
      val[1233 * nCulm + 4] = -16.116699;
      val[1233 * nCulm + 5] = 7.073072;
      val[1234 * nCulm + 0] = 11.426247;
      val[1234 * nCulm + 1] = -20.351105;
      val[1234 * nCulm + 2] = 13.119253;
      val[1234 * nCulm + 3] = -8.677071;
      val[1234 * nCulm + 4] = -41.739660;
      val[1234 * nCulm + 5] = 3.521834;
      val[1235 * nCulm + 0] = 1.763367;
      val[1235 * nCulm + 1] = 44.922203;
      val[1235 * nCulm + 2] = 26.905441;
      val[1235 * nCulm + 3] = -37.907568;
      val[1235 * nCulm + 4] = -27.196610;
      val[1235 * nCulm + 5] = -0.990836;
      val[1236 * nCulm + 0] = -2.408323;
      val[1236 * nCulm + 1] = 32.170857;
      val[1236 * nCulm + 2] = -10.927536;
      val[1236 * nCulm + 3] = 34.973087;
      val[1236 * nCulm + 4] = -21.102405;
      val[1236 * nCulm + 5] = -14.830590;
      val[1237 * nCulm + 0] = -2.175429;
      val[1237 * nCulm + 1] = -43.996152;
      val[1237 * nCulm + 2] = -40.589697;
      val[1237 * nCulm + 3] = 8.802269;
      val[1237 * nCulm + 4] = 39.356500;
      val[1237 * nCulm + 5] = -4.002703;
      val[1238 * nCulm + 0] = 0.510973;
      val[1238 * nCulm + 1] = -44.347838;
      val[1238 * nCulm + 2] = -46.937581;
      val[1238 * nCulm + 3] = -32.416456;
      val[1238 * nCulm + 4] = 36.028046;
      val[1238 * nCulm + 5] = -9.855226;
      val[1239 * nCulm + 0] = 46.520777;
      val[1239 * nCulm + 1] = -42.830186;
      val[1239 * nCulm + 2] = -40.217444;
      val[1239 * nCulm + 3] = 7.710084;
      val[1239 * nCulm + 4] = -25.623161;
      val[1239 * nCulm + 5] = 6.717691;
      val[1240 * nCulm + 0] = 29.864941;
      val[1240 * nCulm + 1] = 33.295444;
      val[1240 * nCulm + 2] = -15.156853;
      val[1240 * nCulm + 3] = 14.176258;
      val[1240 * nCulm + 4] = -9.224792;
      val[1240 * nCulm + 5] = -24.128207;
      val[1241 * nCulm + 0] = -25.666662;
      val[1241 * nCulm + 1] = 47.392725;
      val[1241 * nCulm + 2] = 36.991793;
      val[1241 * nCulm + 3] = -46.650171;
      val[1241 * nCulm + 4] = 17.478206;
      val[1241 * nCulm + 5] = 0.431094;
      val[1242 * nCulm + 0] = 42.955710;
      val[1242 * nCulm + 1] = 32.338933;
      val[1242 * nCulm + 2] = -21.360183;
      val[1242 * nCulm + 3] = 25.901623;
      val[1242 * nCulm + 4] = 36.316829;
      val[1242 * nCulm + 5] = 7.820750;
      val[1243 * nCulm + 0] = 45.530142;
      val[1243 * nCulm + 1] = 23.630027;
      val[1243 * nCulm + 2] = -11.663145;
      val[1243 * nCulm + 3] = -40.088345;
      val[1243 * nCulm + 4] = 45.637636;
      val[1243 * nCulm + 5] = -1.476984;
      val[1244 * nCulm + 0] = 44.383300;
      val[1244 * nCulm + 1] = 0.270082;
      val[1244 * nCulm + 2] = -4.135434;
      val[1244 * nCulm + 3] = -31.023420;
      val[1244 * nCulm + 4] = 7.292134;
      val[1244 * nCulm + 5] = -19.732030;
      val[1245 * nCulm + 0] = -12.017118;
      val[1245 * nCulm + 1] = -32.550347;
      val[1245 * nCulm + 2] = -28.603375;
      val[1245 * nCulm + 3] = 23.199838;
      val[1245 * nCulm + 4] = 42.495766;
      val[1245 * nCulm + 5] = -0.811494;
      val[1246 * nCulm + 0] = -34.023566;
      val[1246 * nCulm + 1] = 16.116648;
      val[1246 * nCulm + 2] = 33.046489;
      val[1246 * nCulm + 3] = -46.760847;
      val[1246 * nCulm + 4] = -32.873520;
      val[1246 * nCulm + 5] = 4.642342;
      val[1247 * nCulm + 0] = -12.922914;
      val[1247 * nCulm + 1] = -3.298089;
      val[1247 * nCulm + 2] = 39.432619;
      val[1247 * nCulm + 3] = 44.623452;
      val[1247 * nCulm + 4] = 20.319813;
      val[1247 * nCulm + 5] = 9.856403;
      val[1248 * nCulm + 0] = -41.349593;
      val[1248 * nCulm + 1] = -3.442197;
      val[1248 * nCulm + 2] = 19.756225;
      val[1248 * nCulm + 3] = 17.819679;
      val[1248 * nCulm + 4] = -4.425627;
      val[1248 * nCulm + 5] = -15.147125;
      val[1249 * nCulm + 0] = 40.574916;
      val[1249 * nCulm + 1] = -23.923234;
      val[1249 * nCulm + 2] = 10.459159;
      val[1249 * nCulm + 3] = 46.758421;
      val[1249 * nCulm + 4] = 16.962735;
      val[1249 * nCulm + 5] = 6.602000;
      val[1250 * nCulm + 0] = -33.065379;
      val[1250 * nCulm + 1] = -31.113732;
      val[1250 * nCulm + 2] = -16.931484;
      val[1250 * nCulm + 3] = 32.397869;
      val[1250 * nCulm + 4] = 5.550217;
      val[1250 * nCulm + 5] = 1.325137;
      val[1251 * nCulm + 0] = -35.672472;
      val[1251 * nCulm + 1] = 13.041679;
      val[1251 * nCulm + 2] = -38.100695;
      val[1251 * nCulm + 3] = 27.539837;
      val[1251 * nCulm + 4] = -13.499086;
      val[1251 * nCulm + 5] = -13.999545;
      val[1252 * nCulm + 0] = -1.239136;
      val[1252 * nCulm + 1] = 8.357817;
      val[1252 * nCulm + 2] = -13.743391;
      val[1252 * nCulm + 3] = -45.225522;
      val[1252 * nCulm + 4] = -5.094655;
      val[1252 * nCulm + 5] = 34.482981;
      val[1253 * nCulm + 0] = -45.512042;
      val[1253 * nCulm + 1] = -25.878838;
      val[1253 * nCulm + 2] = 8.142611;
      val[1253 * nCulm + 3] = -44.635028;
      val[1253 * nCulm + 4] = 18.633969;
      val[1253 * nCulm + 5] = -17.681677;
      val[1254 * nCulm + 0] = -13.686756;
      val[1254 * nCulm + 1] = -9.884240;
      val[1254 * nCulm + 2] = 2.234376;
      val[1254 * nCulm + 3] = 22.575473;
      val[1254 * nCulm + 4] = -13.250754;
      val[1254 * nCulm + 5] = -4.303466;
      val[1255 * nCulm + 0] = 39.987792;
      val[1255 * nCulm + 1] = 33.315870;
      val[1255 * nCulm + 2] = -27.486179;
      val[1255 * nCulm + 3] = -20.758727;
      val[1255 * nCulm + 4] = -40.886918;
      val[1255 * nCulm + 5] = -1.223696;
      val[1256 * nCulm + 0] = 26.006422;
      val[1256 * nCulm + 1] = 48.998338;
      val[1256 * nCulm + 2] = -7.483552;
      val[1256 * nCulm + 3] = 30.375530;
      val[1256 * nCulm + 4] = -21.907650;
      val[1256 * nCulm + 5] = -16.919396;
      val[1257 * nCulm + 0] = 22.782322;
      val[1257 * nCulm + 1] = -35.633866;
      val[1257 * nCulm + 2] = 24.874526;
      val[1257 * nCulm + 3] = 15.198282;
      val[1257 * nCulm + 4] = 22.117368;
      val[1257 * nCulm + 5] = -4.143415;
      val[1258 * nCulm + 0] = 43.075778;
      val[1258 * nCulm + 1] = -33.519691;
      val[1258 * nCulm + 2] = -38.957227;
      val[1258 * nCulm + 3] = -40.896092;
      val[1258 * nCulm + 4] = 28.729026;
      val[1258 * nCulm + 5] = -12.030587;
      val[1259 * nCulm + 0] = -26.913693;
      val[1259 * nCulm + 1] = -40.557232;
      val[1259 * nCulm + 2] = 30.219146;
      val[1259 * nCulm + 3] = -32.830275;
      val[1259 * nCulm + 4] = -9.710231;
      val[1259 * nCulm + 5] = 36.003355;
      val[1260 * nCulm + 0] = 6.146137;
      val[1260 * nCulm + 1] = 44.743249;
      val[1260 * nCulm + 2] = 27.305274;
      val[1260 * nCulm + 3] = -15.780931;
      val[1260 * nCulm + 4] = 21.602928;
      val[1260 * nCulm + 5] = 6.575821;
      val[1261 * nCulm + 0] = -11.959054;
      val[1261 * nCulm + 1] = 24.317608;
      val[1261 * nCulm + 2] = -30.353722;
      val[1261 * nCulm + 3] = 27.506244;
      val[1261 * nCulm + 4] = 2.444590;
      val[1261 * nCulm + 5] = 100.573830;
      val[1262 * nCulm + 0] = -2.447849;
      val[1262 * nCulm + 1] = -41.590865;
      val[1262 * nCulm + 2] = -31.111582;
      val[1262 * nCulm + 3] = -38.173875;
      val[1262 * nCulm + 4] = 4.840090;
      val[1262 * nCulm + 5] = -77.775385;
      val[1263 * nCulm + 0] = 42.039389;
      val[1263 * nCulm + 1] = -37.611228;
      val[1263 * nCulm + 2] = 49.771314;
      val[1263 * nCulm + 3] = -11.558362;
      val[1263 * nCulm + 4] = -26.105347;
      val[1263 * nCulm + 5] = 9.145264;
      val[1264 * nCulm + 0] = -36.494243;
      val[1264 * nCulm + 1] = -40.576163;
      val[1264 * nCulm + 2] = -31.071583;
      val[1264 * nCulm + 3] = 35.293434;
      val[1264 * nCulm + 4] = 3.067315;
      val[1264 * nCulm + 5] = -7.922054;
      val[1265 * nCulm + 0] = -49.375231;
      val[1265 * nCulm + 1] = 38.718547;
      val[1265 * nCulm + 2] = -13.494412;
      val[1265 * nCulm + 3] = 26.705303;
      val[1265 * nCulm + 4] = 45.850970;
      val[1265 * nCulm + 5] = 6.983900;
      val[1266 * nCulm + 0] = -12.395170;
      val[1266 * nCulm + 1] = 31.246124;
      val[1266 * nCulm + 2] = -48.446093;
      val[1266 * nCulm + 3] = -35.164798;
      val[1266 * nCulm + 4] = 10.539122;
      val[1266 * nCulm + 5] = -1.529956;
      val[1267 * nCulm + 0] = 8.785499;
      val[1267 * nCulm + 1] = -48.182885;
      val[1267 * nCulm + 2] = -35.968631;
      val[1267 * nCulm + 3] = -6.328740;
      val[1267 * nCulm + 4] = -28.770857;
      val[1267 * nCulm + 5] = 9.198162;
      val[1268 * nCulm + 0] = 46.365481;
      val[1268 * nCulm + 1] = -25.286144;
      val[1268 * nCulm + 2] = -46.403106;
      val[1268 * nCulm + 3] = -33.224220;
      val[1268 * nCulm + 4] = 22.500979;
      val[1268 * nCulm + 5] = -12.078311;
      val[1269 * nCulm + 0] = 15.287031;
      val[1269 * nCulm + 1] = 1.971216;
      val[1269 * nCulm + 2] = 10.485822;
      val[1269 * nCulm + 3] = -28.437331;
      val[1269 * nCulm + 4] = 5.856266;
      val[1269 * nCulm + 5] = -21.161265;
      val[1270 * nCulm + 0] = 2.042166;
      val[1270 * nCulm + 1] = 28.796361;
      val[1270 * nCulm + 2] = 37.994252;
      val[1270 * nCulm + 3] = 19.939333;
      val[1270 * nCulm + 4] = -25.705829;
      val[1270 * nCulm + 5] = -8.743929;
      val[1271 * nCulm + 0] = 41.856363;
      val[1271 * nCulm + 1] = -26.649108;
      val[1271 * nCulm + 2] = -26.103458;
      val[1271 * nCulm + 3] = -41.850705;
      val[1271 * nCulm + 4] = -42.333436;
      val[1271 * nCulm + 5] = 7.889016;
      val[1272 * nCulm + 0] = -28.176567;
      val[1272 * nCulm + 1] = -45.295774;
      val[1272 * nCulm + 2] = -2.799745;
      val[1272 * nCulm + 3] = -18.690782;
      val[1272 * nCulm + 4] = -7.273676;
      val[1272 * nCulm + 5] = 41.869151;
      val[1273 * nCulm + 0] = 0.739898;
      val[1273 * nCulm + 1] = -36.640747;
      val[1273 * nCulm + 2] = -0.624331;
      val[1273 * nCulm + 3] = -13.704392;
      val[1273 * nCulm + 4] = 13.443917;
      val[1273 * nCulm + 5] = -17.495513;
      val[1274 * nCulm + 0] = 20.616064;
      val[1274 * nCulm + 1] = 38.877973;
      val[1274 * nCulm + 2] = 29.181129;
      val[1274 * nCulm + 3] = -36.798528;
      val[1274 * nCulm + 4] = -34.470670;
      val[1274 * nCulm + 5] = -0.055539;
      val[1275 * nCulm + 0] = 25.235615;
      val[1275 * nCulm + 1] = 13.827275;
      val[1275 * nCulm + 2] = -29.480469;
      val[1275 * nCulm + 3] = 44.601916;
      val[1275 * nCulm + 4] = -3.561458;
      val[1275 * nCulm + 5] = -77.424954;
      val[1276 * nCulm + 0] = 30.396387;
      val[1276 * nCulm + 1] = 30.957500;
      val[1276 * nCulm + 2] = -32.157528;
      val[1276 * nCulm + 3] = 26.109088;
      val[1276 * nCulm + 4] = -36.731148;
      val[1276 * nCulm + 5] = -7.123845;
      val[1277 * nCulm + 0] = 8.455708;
      val[1277 * nCulm + 1] = 2.136701;
      val[1277 * nCulm + 2] = -22.375072;
      val[1277 * nCulm + 3] = -47.593377;
      val[1277 * nCulm + 4] = -20.971374;
      val[1277 * nCulm + 5] = 10.489776;
      val[1278 * nCulm + 0] = 23.340079;
      val[1278 * nCulm + 1] = 41.629490;
      val[1278 * nCulm + 2] = 33.525483;
      val[1278 * nCulm + 3] = -29.054797;
      val[1278 * nCulm + 4] = 39.030968;
      val[1278 * nCulm + 5] = 1.754948;
      val[1279 * nCulm + 0] = 49.744624;
      val[1279 * nCulm + 1] = 5.445307;
      val[1279 * nCulm + 2] = -21.578962;
      val[1279 * nCulm + 3] = 49.452692;
      val[1279 * nCulm + 4] = -7.032041;
      val[1279 * nCulm + 5] = -36.722360;
      val[1280 * nCulm + 0] = -2.582822;
      val[1280 * nCulm + 1] = 17.606342;
      val[1280 * nCulm + 2] = -2.487964;
      val[1280 * nCulm + 3] = -43.346200;
      val[1280 * nCulm + 4] = -17.635405;
      val[1280 * nCulm + 5] = 7.138564;
      val[1281 * nCulm + 0] = -39.999779;
      val[1281 * nCulm + 1] = -24.928866;
      val[1281 * nCulm + 2] = -22.980437;
      val[1281 * nCulm + 3] = -19.044820;
      val[1281 * nCulm + 4] = -31.912504;
      val[1281 * nCulm + 5] = 6.752274;
      val[1282 * nCulm + 0] = -0.878159;
      val[1282 * nCulm + 1] = -33.336979;
      val[1282 * nCulm + 2] = -11.456168;
      val[1282 * nCulm + 3] = -8.282316;
      val[1282 * nCulm + 4] = 13.784842;
      val[1282 * nCulm + 5] = -14.060914;
      val[1283 * nCulm + 0] = -7.784297;
      val[1283 * nCulm + 1] = -19.571147;
      val[1283 * nCulm + 2] = -19.338875;
      val[1283 * nCulm + 3] = 42.529969;
      val[1283 * nCulm + 4] = -2.630022;
      val[1283 * nCulm + 5] = -41.089708;
      val[1284 * nCulm + 0] = 26.708827;
      val[1284 * nCulm + 1] = 12.915337;
      val[1284 * nCulm + 2] = 41.009159;
      val[1284 * nCulm + 3] = 7.446539;
      val[1284 * nCulm + 4] = -7.724698;
      val[1284 * nCulm + 5] = -12.246805;
      val[1285 * nCulm + 0] = 6.563554;
      val[1285 * nCulm + 1] = -12.026317;
      val[1285 * nCulm + 2] = 41.419909;
      val[1285 * nCulm + 3] = -26.314645;
      val[1285 * nCulm + 4] = -47.704030;
      val[1285 * nCulm + 5] = 4.034302;
      val[1286 * nCulm + 0] = 18.281617;
      val[1286 * nCulm + 1] = -15.738320;
      val[1286 * nCulm + 2] = 4.190422;
      val[1286 * nCulm + 3] = -44.316682;
      val[1286 * nCulm + 4] = -48.673002;
      val[1286 * nCulm + 5] = 6.070206;
      val[1287 * nCulm + 0] = 14.772347;
      val[1287 * nCulm + 1] = -33.400235;
      val[1287 * nCulm + 2] = 35.755773;
      val[1287 * nCulm + 3] = 35.574029;
      val[1287 * nCulm + 4] = -11.156309;
      val[1287 * nCulm + 5] = -0.692285;
      val[1288 * nCulm + 0] = -33.262987;
      val[1288 * nCulm + 1] = 43.472250;
      val[1288 * nCulm + 2] = -0.305011;
      val[1288 * nCulm + 3] = 10.795627;
      val[1288 * nCulm + 4] = -2.750896;
      val[1288 * nCulm + 5] = -93.146092;
      val[1289 * nCulm + 0] = -38.862584;
      val[1289 * nCulm + 1] = -26.246770;
      val[1289 * nCulm + 2] = -31.450505;
      val[1289 * nCulm + 3] = 25.426877;
      val[1289 * nCulm + 4] = 10.488029;
      val[1289 * nCulm + 5] = -0.140024;
      val[1290 * nCulm + 0] = -9.051082;
      val[1290 * nCulm + 1] = -32.166336;
      val[1290 * nCulm + 2] = -6.109682;
      val[1290 * nCulm + 3] = -5.163360;
      val[1290 * nCulm + 4] = -33.628680;
      val[1290 * nCulm + 5] = 5.484262;
      val[1291 * nCulm + 0] = 48.330600;
      val[1291 * nCulm + 1] = 36.695571;
      val[1291 * nCulm + 2] = -33.544599;
      val[1291 * nCulm + 3] = 34.876138;
      val[1291 * nCulm + 4] = 1.453556;
      val[1291 * nCulm + 5] = 233.294757;
      val[1292 * nCulm + 0] = -19.016384;
      val[1292 * nCulm + 1] = 0.483774;
      val[1292 * nCulm + 2] = 11.860380;
      val[1292 * nCulm + 3] = 26.669180;
      val[1292 * nCulm + 4] = 25.103003;
      val[1292 * nCulm + 5] = 5.349865;
      val[1293 * nCulm + 0] = 31.935979;
      val[1293 * nCulm + 1] = 37.169616;
      val[1293 * nCulm + 2] = 15.234909;
      val[1293 * nCulm + 3] = -42.084959;
      val[1293 * nCulm + 4] = 14.594120;
      val[1293 * nCulm + 5] = -1.364201;
      val[1294 * nCulm + 0] = 8.492181;
      val[1294 * nCulm + 1] = 40.120951;
      val[1294 * nCulm + 2] = 38.228934;
      val[1294 * nCulm + 3] = 25.185236;
      val[1294 * nCulm + 4] = 10.390540;
      val[1294 * nCulm + 5] = 29.979749;
      val[1295 * nCulm + 0] = 13.812267;
      val[1295 * nCulm + 1] = -19.301021;
      val[1295 * nCulm + 2] = -40.779852;
      val[1295 * nCulm + 3] = 12.629668;
      val[1295 * nCulm + 4] = 47.674356;
      val[1295 * nCulm + 5] = -0.432363;
      val[1296 * nCulm + 0] = 45.411677;
      val[1296 * nCulm + 1] = -18.494598;
      val[1296 * nCulm + 2] = 39.113939;
      val[1296 * nCulm + 3] = 15.208919;
      val[1296 * nCulm + 4] = -12.924028;
      val[1296 * nCulm + 5] = 1.433356;
      val[1297 * nCulm + 0] = -19.268103;
      val[1297 * nCulm + 1] = 16.364324;
      val[1297 * nCulm + 2] = 3.873020;
      val[1297 * nCulm + 3] = 31.505756;
      val[1297 * nCulm + 4] = -31.439681;
      val[1297 * nCulm + 5] = -6.976977;
      val[1298 * nCulm + 0] = 23.672123;
      val[1298 * nCulm + 1] = 5.933583;
      val[1298 * nCulm + 2] = -17.357094;
      val[1298 * nCulm + 3] = -19.872248;
      val[1298 * nCulm + 4] = 32.920914;
      val[1298 * nCulm + 5] = -1.774086;
      val[1299 * nCulm + 0] = -12.681057;
      val[1299 * nCulm + 1] = 40.407441;
      val[1299 * nCulm + 2] = 20.470523;
      val[1299 * nCulm + 3] = -28.761342;
      val[1299 * nCulm + 4] = -9.534713;
      val[1299 * nCulm + 5] = -5.551492;
      val[1300 * nCulm + 0] = -33.491839;
      val[1300 * nCulm + 1] = -39.198408;
      val[1300 * nCulm + 2] = 5.244081;
      val[1300 * nCulm + 3] = -20.949917;
      val[1300 * nCulm + 4] = -28.060566;
      val[1300 * nCulm + 5] = 10.375985;
      val[1301 * nCulm + 0] = 12.510867;
      val[1301 * nCulm + 1] = 27.038156;
      val[1301 * nCulm + 2] = 25.614232;
      val[1301 * nCulm + 3] = -47.796558;
      val[1301 * nCulm + 4] = -22.131779;
      val[1301 * nCulm + 5] = 4.669609;
      val[1302 * nCulm + 0] = 35.001606;
      val[1302 * nCulm + 1] = -22.891860;
      val[1302 * nCulm + 2] = -25.438037;
      val[1302 * nCulm + 3] = -8.897034;
      val[1302 * nCulm + 4] = -15.178708;
      val[1302 * nCulm + 5] = 10.143059;
      val[1303 * nCulm + 0] = -49.554934;
      val[1303 * nCulm + 1] = -32.472152;
      val[1303 * nCulm + 2] = -28.023618;
      val[1303 * nCulm + 3] = -20.141622;
      val[1303 * nCulm + 4] = 20.231940;
      val[1303 * nCulm + 5] = -12.079177;
      val[1304 * nCulm + 0] = -25.634661;
      val[1304 * nCulm + 1] = -0.510634;
      val[1304 * nCulm + 2] = 39.799427;
      val[1304 * nCulm + 3] = 21.138499;
      val[1304 * nCulm + 4] = -18.350214;
      val[1304 * nCulm + 5] = -5.090841;
      val[1305 * nCulm + 0] = 33.495749;
      val[1305 * nCulm + 1] = 8.342815;
      val[1305 * nCulm + 2] = -47.465612;
      val[1305 * nCulm + 3] = 28.344152;
      val[1305 * nCulm + 4] = 15.186325;
      val[1305 * nCulm + 5] = 11.664737;
      val[1306 * nCulm + 0] = -31.909225;
      val[1306 * nCulm + 1] = 32.979755;
      val[1306 * nCulm + 2] = 28.091440;
      val[1306 * nCulm + 3] = -12.820122;
      val[1306 * nCulm + 4] = 42.220406;
      val[1306 * nCulm + 5] = 2.490098;
      val[1307 * nCulm + 0] = 27.151241;
      val[1307 * nCulm + 1] = 30.431658;
      val[1307 * nCulm + 2] = -4.969815;
      val[1307 * nCulm + 3] = 12.196817;
      val[1307 * nCulm + 4] = -49.224678;
      val[1307 * nCulm + 5] = -3.869057;
      val[1308 * nCulm + 0] = 1.957240;
      val[1308 * nCulm + 1] = -33.407796;
      val[1308 * nCulm + 2] = 10.383109;
      val[1308 * nCulm + 3] = 42.319930;
      val[1308 * nCulm + 4] = 8.479059;
      val[1308 * nCulm + 5] = 5.205092;
      val[1309 * nCulm + 0] = 43.989483;
      val[1309 * nCulm + 1] = 34.607514;
      val[1309 * nCulm + 2] = 48.118069;
      val[1309 * nCulm + 3] = -45.716203;
      val[1309 * nCulm + 4] = 35.317533;
      val[1309 * nCulm + 5] = -1.258811;
      val[1310 * nCulm + 0] = -28.338550;
      val[1310 * nCulm + 1] = -10.743858;
      val[1310 * nCulm + 2] = -28.625974;
      val[1310 * nCulm + 3] = -3.340865;
      val[1310 * nCulm + 4] = -44.294303;
      val[1310 * nCulm + 5] = 1.735108;
      val[1311 * nCulm + 0] = -41.947854;
      val[1311 * nCulm + 1] = -32.915588;
      val[1311 * nCulm + 2] = 19.734080;
      val[1311 * nCulm + 3] = 21.680501;
      val[1311 * nCulm + 4] = 40.380079;
      val[1311 * nCulm + 5] = -1.086971;
      val[1312 * nCulm + 0] = -31.890383;
      val[1312 * nCulm + 1] = 16.652883;
      val[1312 * nCulm + 2] = -41.900007;
      val[1312 * nCulm + 3] = -22.367268;
      val[1312 * nCulm + 4] = -34.091180;
      val[1312 * nCulm + 5] = 1.023404;
      val[1313 * nCulm + 0] = 21.984107;
      val[1313 * nCulm + 1] = -39.381131;
      val[1313 * nCulm + 2] = -37.026207;
      val[1313 * nCulm + 3] = 0.141520;
      val[1313 * nCulm + 4] = -25.519212;
      val[1313 * nCulm + 5] = 7.508209;
      val[1314 * nCulm + 0] = 13.161244;
      val[1314 * nCulm + 1] = 48.928283;
      val[1314 * nCulm + 2] = 33.680317;
      val[1314 * nCulm + 3] = -33.399795;
      val[1314 * nCulm + 4] = -33.008183;
      val[1314 * nCulm + 5] = -1.996766;
      val[1315 * nCulm + 0] = -34.276569;
      val[1315 * nCulm + 1] = -18.620965;
      val[1315 * nCulm + 2] = -33.072300;
      val[1315 * nCulm + 3] = -7.320957;
      val[1315 * nCulm + 4] = 41.523371;
      val[1315 * nCulm + 5] = -2.727172;
      val[1316 * nCulm + 0] = -14.046577;
      val[1316 * nCulm + 1] = -11.866165;
      val[1316 * nCulm + 2] = -12.627491;
      val[1316 * nCulm + 3] = -46.626725;
      val[1316 * nCulm + 4] = -29.380656;
      val[1316 * nCulm + 5] = 9.653423;
      val[1317 * nCulm + 0] = -16.876910;
      val[1317 * nCulm + 1] = 41.977431;
      val[1317 * nCulm + 2] = -12.493283;
      val[1317 * nCulm + 3] = 2.219343;
      val[1317 * nCulm + 4] = 22.736739;
      val[1317 * nCulm + 5] = 9.430882;
      val[1318 * nCulm + 0] = 33.125421;
      val[1318 * nCulm + 1] = -3.968307;
      val[1318 * nCulm + 2] = -15.322533;
      val[1318 * nCulm + 3] = 13.406818;
      val[1318 * nCulm + 4] = 9.587880;
      val[1318 * nCulm + 5] = 4.889593;
      val[1319 * nCulm + 0] = 1.979155;
      val[1319 * nCulm + 1] = 33.582025;
      val[1319 * nCulm + 2] = -14.947257;
      val[1319 * nCulm + 3] = 10.978240;
      val[1319 * nCulm + 4] = 26.580708;
      val[1319 * nCulm + 5] = 8.165025;
      val[1320 * nCulm + 0] = 36.396075;
      val[1320 * nCulm + 1] = -24.371367;
      val[1320 * nCulm + 2] = -8.075390;
      val[1320 * nCulm + 3] = -21.725122;
      val[1320 * nCulm + 4] = -8.619948;
      val[1320 * nCulm + 5] = 25.542222;
      val[1321 * nCulm + 0] = 24.240074;
      val[1321 * nCulm + 1] = 20.867781;
      val[1321 * nCulm + 2] = 7.978134;
      val[1321 * nCulm + 3] = -19.501566;
      val[1321 * nCulm + 4] = -49.428428;
      val[1321 * nCulm + 5] = 0.099169;
      val[1322 * nCulm + 0] = -33.562326;
      val[1322 * nCulm + 1] = 11.905382;
      val[1322 * nCulm + 2] = -24.975171;
      val[1322 * nCulm + 3] = 47.628553;
      val[1322 * nCulm + 4] = -30.465328;
      val[1322 * nCulm + 5] = -9.019661;
      val[1323 * nCulm + 0] = 19.716418;
      val[1323 * nCulm + 1] = -39.332797;
      val[1323 * nCulm + 2] = 10.813502;
      val[1323 * nCulm + 3] = -43.972479;
      val[1323 * nCulm + 4] = -12.255747;
      val[1323 * nCulm + 5] = 32.403612;
      val[1324 * nCulm + 0] = -23.601348;
      val[1324 * nCulm + 1] = 3.825624;
      val[1324 * nCulm + 2] = 7.472572;
      val[1324 * nCulm + 3] = 19.873685;
      val[1324 * nCulm + 4] = -47.062999;
      val[1324 * nCulm + 5] = -2.153544;
      val[1325 * nCulm + 0] = 6.259109;
      val[1325 * nCulm + 1] = -6.847212;
      val[1325 * nCulm + 2] = -6.183535;
      val[1325 * nCulm + 3] = 25.299345;
      val[1325 * nCulm + 4] = 27.703605;
      val[1325 * nCulm + 5] = 3.382662;
      val[1326 * nCulm + 0] = -7.162958;
      val[1326 * nCulm + 1] = -23.304006;
      val[1326 * nCulm + 2] = -1.628586;
      val[1326 * nCulm + 3] = 43.164778;
      val[1326 * nCulm + 4] = -45.936647;
      val[1326 * nCulm + 5] = -1.816463;
      val[1327 * nCulm + 0] = -45.055328;
      val[1327 * nCulm + 1] = -40.360103;
      val[1327 * nCulm + 2] = 42.940780;
      val[1327 * nCulm + 3] = -13.002760;
      val[1327 * nCulm + 4] = 38.769051;
      val[1327 * nCulm + 5] = -6.285099;
      val[1328 * nCulm + 0] = -41.639720;
      val[1328 * nCulm + 1] = 22.208189;
      val[1328 * nCulm + 2] = -3.407978;
      val[1328 * nCulm + 3] = -24.568001;
      val[1328 * nCulm + 4] = -18.663229;
      val[1328 * nCulm + 5] = 0.828491;
      val[1329 * nCulm + 0] = -32.643560;
      val[1329 * nCulm + 1] = 8.809439;
      val[1329 * nCulm + 2] = 10.361177;
      val[1329 * nCulm + 3] = 27.609018;
      val[1329 * nCulm + 4] = 6.516509;
      val[1329 * nCulm + 5] = 26.682921;
      val[1330 * nCulm + 0] = -47.274113;
      val[1330 * nCulm + 1] = -4.228986;
      val[1330 * nCulm + 2] = 0.259174;
      val[1330 * nCulm + 3] = 13.258300;
      val[1330 * nCulm + 4] = -26.994829;
      val[1330 * nCulm + 5] = -1.353220;
      val[1331 * nCulm + 0] = -20.919331;
      val[1331 * nCulm + 1] = 5.528637;
      val[1331 * nCulm + 2] = -44.531309;
      val[1331 * nCulm + 3] = -10.496885;
      val[1331 * nCulm + 4] = -22.931545;
      val[1331 * nCulm + 5] = 1.255503;
      val[1332 * nCulm + 0] = -48.014613;
      val[1332 * nCulm + 1] = 35.639248;
      val[1332 * nCulm + 2] = 10.274587;
      val[1332 * nCulm + 3] = 3.392119;
      val[1332 * nCulm + 4] = -22.030680;
      val[1332 * nCulm + 5] = -8.155963;
      val[1333 * nCulm + 0] = -5.857476;
      val[1333 * nCulm + 1] = -4.858089;
      val[1333 * nCulm + 2] = 45.317565;
      val[1333 * nCulm + 3] = 40.651066;
      val[1333 * nCulm + 4] = -14.465708;
      val[1333 * nCulm + 5] = -11.481842;
      val[1334 * nCulm + 0] = -36.041743;
      val[1334 * nCulm + 1] = 27.832866;
      val[1334 * nCulm + 2] = -0.841334;
      val[1334 * nCulm + 3] = 4.813498;
      val[1334 * nCulm + 4] = 48.230915;
      val[1334 * nCulm + 5] = 3.433881;
      val[1335 * nCulm + 0] = 17.833522;
      val[1335 * nCulm + 1] = 23.132297;
      val[1335 * nCulm + 2] = -23.151161;
      val[1335 * nCulm + 3] = -42.775853;
      val[1335 * nCulm + 4] = -28.381245;
      val[1335 * nCulm + 5] = 3.506089;
      val[1336 * nCulm + 0] = -3.794315;
      val[1336 * nCulm + 1] = -22.135314;
      val[1336 * nCulm + 2] = 9.905812;
      val[1336 * nCulm + 3] = -49.945793;
      val[1336 * nCulm + 4] = 0.071194;
      val[1336 * nCulm + 5] = -4792.050585;
      val[1337 * nCulm + 0] = 27.933308;
      val[1337 * nCulm + 1] = -20.699701;
      val[1337 * nCulm + 2] = -22.218679;
      val[1337 * nCulm + 3] = 27.841610;
      val[1337 * nCulm + 4] = 1.418923;
      val[1337 * nCulm + 5] = 24.054429;
      val[1338 * nCulm + 0] = -25.338124;
      val[1338 * nCulm + 1] = 41.237296;
      val[1338 * nCulm + 2] = -7.406255;
      val[1338 * nCulm + 3] = 32.665143;
      val[1338 * nCulm + 4] = 29.276632;
      val[1338 * nCulm + 5] = 12.178262;
      val[1339 * nCulm + 0] = 4.667423;
      val[1339 * nCulm + 1] = -18.401553;
      val[1339 * nCulm + 2] = -0.100496;
      val[1339 * nCulm + 3] = -24.696571;
      val[1339 * nCulm + 4] = 7.529587;
      val[1339 * nCulm + 5] = -26.862825;
      val[1340 * nCulm + 0] = 26.857676;
      val[1340 * nCulm + 1] = -9.637935;
      val[1340 * nCulm + 2] = 0.637539;
      val[1340 * nCulm + 3] = 5.660752;
      val[1340 * nCulm + 4] = 20.862919;
      val[1340 * nCulm + 5] = -0.672335;
      val[1341 * nCulm + 0] = 30.603682;
      val[1341 * nCulm + 1] = -41.093403;
      val[1341 * nCulm + 2] = -19.293701;
      val[1341 * nCulm + 3] = 1.442375;
      val[1341 * nCulm + 4] = -38.247840;
      val[1341 * nCulm + 5] = 5.136984;
      val[1342 * nCulm + 0] = 33.704943;
      val[1342 * nCulm + 1] = 20.208902;
      val[1342 * nCulm + 2] = -8.630960;
      val[1342 * nCulm + 3] = 2.367323;
      val[1342 * nCulm + 4] = 6.746942;
      val[1342 * nCulm + 5] = 16.068405;
      val[1343 * nCulm + 0] = -24.885369;
      val[1343 * nCulm + 1] = -20.354574;
      val[1343 * nCulm + 2] = -44.030435;
      val[1343 * nCulm + 3] = -12.311982;
      val[1343 * nCulm + 4] = 36.872645;
      val[1343 * nCulm + 5] = -3.963399;
      val[1344 * nCulm + 0] = -10.065219;
      val[1344 * nCulm + 1] = 5.607507;
      val[1344 * nCulm + 2] = -5.096937;
      val[1344 * nCulm + 3] = -38.738087;
      val[1344 * nCulm + 4] = 18.148603;
      val[1344 * nCulm + 5] = -8.410779;
      val[1345 * nCulm + 0] = -12.012361;
      val[1345 * nCulm + 1] = -35.512096;
      val[1345 * nCulm + 2] = 44.023106;
      val[1345 * nCulm + 3] = 32.577832;
      val[1345 * nCulm + 4] = 22.980568;
      val[1345 * nCulm + 5] = -0.374374;
      val[1346 * nCulm + 0] = -36.741815;
      val[1346 * nCulm + 1] = 37.294729;
      val[1346 * nCulm + 2] = -47.406230;
      val[1346 * nCulm + 3] = 16.824453;
      val[1346 * nCulm + 4] = 36.162895;
      val[1346 * nCulm + 5] = 7.313618;
      val[1347 * nCulm + 0] = -13.442024;
      val[1347 * nCulm + 1] = -30.651723;
      val[1347 * nCulm + 2] = 47.570299;
      val[1347 * nCulm + 3] = -7.653537;
      val[1347 * nCulm + 4] = 10.397360;
      val[1347 * nCulm + 5] = -17.208231;
      val[1348 * nCulm + 0] = -1.573937;
      val[1348 * nCulm + 1] = 22.146626;
      val[1348 * nCulm + 2] = -33.692200;
      val[1348 * nCulm + 3] = -25.466038;
      val[1348 * nCulm + 4] = 3.453180;
      val[1348 * nCulm + 5] = -4.319976;
      val[1349 * nCulm + 0] = 9.266451;
      val[1349 * nCulm + 1] = 9.502349;
      val[1349 * nCulm + 2] = -3.373110;
      val[1349 * nCulm + 3] = -3.246741;
      val[1349 * nCulm + 4] = -21.796837;
      val[1349 * nCulm + 5] = -1.128448;
      val[1350 * nCulm + 0] = 16.558693;
      val[1350 * nCulm + 1] = 19.472210;
      val[1350 * nCulm + 2] = 26.644256;
      val[1350 * nCulm + 3] = -5.680631;
      val[1350 * nCulm + 4] = 46.048650;
      val[1350 * nCulm + 5] = 1.647634;
      val[1351 * nCulm + 0] = -13.987273;
      val[1351 * nCulm + 1] = 3.099949;
      val[1351 * nCulm + 2] = -23.498954;
      val[1351 * nCulm + 3] = -38.750320;
      val[1351 * nCulm + 4] = 45.841057;
      val[1351 * nCulm + 5] = -3.451091;
      val[1352 * nCulm + 0] = -15.124920;
      val[1352 * nCulm + 1] = 31.534558;
      val[1352 * nCulm + 2] = 22.907973;
      val[1352 * nCulm + 3] = 9.981094;
      val[1352 * nCulm + 4] = -25.775146;
      val[1352 * nCulm + 5] = -7.393911;
      val[1353 * nCulm + 0] = -3.998467;
      val[1353 * nCulm + 1] = -41.035357;
      val[1353 * nCulm + 2] = 28.878618;
      val[1353 * nCulm + 3] = 47.569962;
      val[1353 * nCulm + 4] = -40.721411;
      val[1353 * nCulm + 5] = -0.529563;
      val[1354 * nCulm + 0] = 4.940187;
      val[1354 * nCulm + 1] = -17.019230;
      val[1354 * nCulm + 2] = 33.531447;
      val[1354 * nCulm + 3] = 8.597791;
      val[1354 * nCulm + 4] = -37.121612;
      val[1354 * nCulm + 5] = 1.303808;
      val[1355 * nCulm + 0] = 39.854227;
      val[1355 * nCulm + 1] = 12.933385;
      val[1355 * nCulm + 2] = 33.365681;
      val[1355 * nCulm + 3] = 42.159762;
      val[1355 * nCulm + 4] = -9.842591;
      val[1355 * nCulm + 5] = -26.264468;
      val[1356 * nCulm + 0] = -33.062839;
      val[1356 * nCulm + 1] = -39.536218;
      val[1356 * nCulm + 2] = 29.631587;
      val[1356 * nCulm + 3] = 29.923809;
      val[1356 * nCulm + 4] = -45.986419;
      val[1356 * nCulm + 5] = 1.219395;
      val[1357 * nCulm + 0] = -13.345605;
      val[1357 * nCulm + 1] = 13.906356;
      val[1357 * nCulm + 2] = 32.412970;
      val[1357 * nCulm + 3] = 32.615923;
      val[1357 * nCulm + 4] = 6.600313;
      val[1357 * nCulm + 5] = 33.592881;
      val[1358 * nCulm + 0] = -43.050530;
      val[1358 * nCulm + 1] = 8.755972;
      val[1358 * nCulm + 2] = -31.943490;
      val[1358 * nCulm + 3] = -19.630813;
      val[1358 * nCulm + 4] = 8.899670;
      val[1358 * nCulm + 5] = -5.553838;
      val[1359 * nCulm + 0] = -1.398304;
      val[1359 * nCulm + 1] = 10.494999;
      val[1359 * nCulm + 2] = 32.160759;
      val[1359 * nCulm + 3] = 39.147911;
      val[1359 * nCulm + 4] = 11.405234;
      val[1359 * nCulm + 5] = 20.832510;
      val[1360 * nCulm + 0] = -29.882068;
      val[1360 * nCulm + 1] = 14.372198;
      val[1360 * nCulm + 2] = 11.707102;
      val[1360 * nCulm + 3] = -24.739411;
      val[1360 * nCulm + 4] = 42.762311;
      val[1360 * nCulm + 5] = -0.917540;
      val[1361 * nCulm + 0] = -14.198476;
      val[1361 * nCulm + 1] = 11.556717;
      val[1361 * nCulm + 2] = 22.085347;
      val[1361 * nCulm + 3] = 10.446685;
      val[1361 * nCulm + 4] = -34.725196;
      val[1361 * nCulm + 5] = -2.769247;
      val[1362 * nCulm + 0] = -40.793556;
      val[1362 * nCulm + 1] = -47.027975;
      val[1362 * nCulm + 2] = -24.891340;
      val[1362 * nCulm + 3] = -0.650035;
      val[1362 * nCulm + 4] = -46.416002;
      val[1362 * nCulm + 5] = 5.092028;
      val[1363 * nCulm + 0] = 13.732938;
      val[1363 * nCulm + 1] = 9.798137;
      val[1363 * nCulm + 2] = 1.434769;
      val[1363 * nCulm + 3] = 26.328417;
      val[1363 * nCulm + 4] = -36.752669;
      val[1363 * nCulm + 5] = -4.422697;
      val[1364 * nCulm + 0] = 24.019692;
      val[1364 * nCulm + 1] = 40.600627;
      val[1364 * nCulm + 2] = 30.847676;
      val[1364 * nCulm + 3] = 45.291477;
      val[1364 * nCulm + 4] = 27.592997;
      val[1364 * nCulm + 5] = 14.964027;
      val[1365 * nCulm + 0] = -18.714319;
      val[1365 * nCulm + 1] = -7.703228;
      val[1365 * nCulm + 2] = -49.911003;
      val[1365 * nCulm + 3] = 8.322228;
      val[1365 * nCulm + 4] = 12.948978;
      val[1365 * nCulm + 5] = 0.456267;
      val[1366 * nCulm + 0] = 38.710660;
      val[1366 * nCulm + 1] = -21.027365;
      val[1366 * nCulm + 2] = -21.637039;
      val[1366 * nCulm + 3] = -14.440731;
      val[1366 * nCulm + 4] = 38.049509;
      val[1366 * nCulm + 5] = -4.182207;
      val[1367 * nCulm + 0] = 31.299831;
      val[1367 * nCulm + 1] = -29.871502;
      val[1367 * nCulm + 2] = -18.114746;
      val[1367 * nCulm + 3] = -11.899245;
      val[1367 * nCulm + 4] = 43.665359;
      val[1367 * nCulm + 5] = -4.297957;
      val[1368 * nCulm + 0] = -33.787055;
      val[1368 * nCulm + 1] = 17.268000;
      val[1368 * nCulm + 2] = 11.557874;
      val[1368 * nCulm + 3] = -40.136845;
      val[1368 * nCulm + 4] = 38.360902;
      val[1368 * nCulm + 5] = -2.591776;
      val[1369 * nCulm + 0] = 28.303769;
      val[1369 * nCulm + 1] = 36.920019;
      val[1369 * nCulm + 2] = -24.357776;
      val[1369 * nCulm + 3] = 12.281234;
      val[1369 * nCulm + 4] = -48.864740;
      val[1369 * nCulm + 5] = -4.535930;
      val[1370 * nCulm + 0] = 34.747380;
      val[1370 * nCulm + 1] = 38.253417;
      val[1370 * nCulm + 2] = 32.098287;
      val[1370 * nCulm + 3] = 12.030189;
      val[1370 * nCulm + 4] = 48.592994;
      val[1370 * nCulm + 5] = 5.128012;
      val[1371 * nCulm + 0] = -15.869070;
      val[1371 * nCulm + 1] = 20.336010;
      val[1371 * nCulm + 2] = -12.446035;
      val[1371 * nCulm + 3] = 2.009358;
      val[1371 * nCulm + 4] = -24.954053;
      val[1371 * nCulm + 5] = -4.008513;
      val[1372 * nCulm + 0] = -30.095414;
      val[1372 * nCulm + 1] = -42.230440;
      val[1372 * nCulm + 2] = 37.064268;
      val[1372 * nCulm + 3] = -3.832900;
      val[1372 * nCulm + 4] = 7.930999;
      val[1372 * nCulm + 5] = -27.261260;
      val[1373 * nCulm + 0] = -37.782695;
      val[1373 * nCulm + 1] = 49.907732;
      val[1373 * nCulm + 2] = -41.651255;
      val[1373 * nCulm + 3] = -39.663028;
      val[1373 * nCulm + 4] = -30.161366;
      val[1373 * nCulm + 5] = -1.377739;
      val[1374 * nCulm + 0] = -10.172779;
      val[1374 * nCulm + 1] = -44.116415;
      val[1374 * nCulm + 2] = 31.068666;
      val[1374 * nCulm + 3] = -39.482763;
      val[1374 * nCulm + 4] = 33.771244;
      val[1374 * nCulm + 5] = -11.487151;
      val[1375 * nCulm + 0] = -2.710418;
      val[1375 * nCulm + 1] = 46.908847;
      val[1375 * nCulm + 2] = 27.693296;
      val[1375 * nCulm + 3] = -35.644166;
      val[1375 * nCulm + 4] = -26.897843;
      val[1375 * nCulm + 5] = -1.752296;
      val[1376 * nCulm + 0] = -19.446392;
      val[1376 * nCulm + 1] = 17.247680;
      val[1376 * nCulm + 2] = 40.559364;
      val[1376 * nCulm + 3] = 49.753544;
      val[1376 * nCulm + 4] = 34.419203;
      val[1376 * nCulm + 5] = 9.444017;
      val[1377 * nCulm + 0] = 4.266103;
      val[1377 * nCulm + 1] = -43.258365;
      val[1377 * nCulm + 2] = 45.541094;
      val[1377 * nCulm + 3] = 18.714757;
      val[1377 * nCulm + 4] = 3.183651;
      val[1377 * nCulm + 5] = -36.260515;
      val[1378 * nCulm + 0] = -8.810968;
      val[1378 * nCulm + 1] = -15.880129;
      val[1378 * nCulm + 2] = -39.473425;
      val[1378 * nCulm + 3] = -9.235214;
      val[1378 * nCulm + 4] = -21.299850;
      val[1378 * nCulm + 5] = 5.811227;
      val[1379 * nCulm + 0] = -27.329145;
      val[1379 * nCulm + 1] = -8.008947;
      val[1379 * nCulm + 2] = 46.012779;
      val[1379 * nCulm + 3] = 22.739418;
      val[1379 * nCulm + 4] = 4.195561;
      val[1379 * nCulm + 5] = 16.848572;
      val[1380 * nCulm + 0] = 2.920373;
      val[1380 * nCulm + 1] = 4.028370;
      val[1380 * nCulm + 2] = -49.210087;
      val[1380 * nCulm + 3] = 2.279810;
      val[1380 * nCulm + 4] = -43.084860;
      val[1380 * nCulm + 5] = -0.463021;
      val[1381 * nCulm + 0] = 15.541139;
      val[1381 * nCulm + 1] = -16.545453;
      val[1381 * nCulm + 2] = 10.209490;
      val[1381 * nCulm + 3] = 49.687921;
      val[1381 * nCulm + 4] = 36.945171;
      val[1381 * nCulm + 5] = 4.476139;
      val[1382 * nCulm + 0] = -22.840151;
      val[1382 * nCulm + 1] = -41.399832;
      val[1382 * nCulm + 2] = -23.190002;
      val[1382 * nCulm + 3] = 32.677888;
      val[1382 * nCulm + 4] = 41.854467;
      val[1382 * nCulm + 5] = -0.756367;
      val[1383 * nCulm + 0] = -25.901734;
      val[1383 * nCulm + 1] = 27.876590;
      val[1383 * nCulm + 2] = 28.888922;
      val[1383 * nCulm + 3] = -24.234425;
      val[1383 * nCulm + 4] = 27.697857;
      val[1383 * nCulm + 5] = 0.852416;
      val[1384 * nCulm + 0] = 22.187302;
      val[1384 * nCulm + 1] = -17.550892;
      val[1384 * nCulm + 2] = -1.444102;
      val[1384 * nCulm + 3] = -34.885340;
      val[1384 * nCulm + 4] = -4.457672;
      val[1384 * nCulm + 5] = 55.908872;
      val[1385 * nCulm + 0] = 38.700812;
      val[1385 * nCulm + 1] = 37.152953;
      val[1385 * nCulm + 2] = -13.489072;
      val[1385 * nCulm + 3] = -11.495494;
      val[1385 * nCulm + 4] = 24.457054;
      val[1385 * nCulm + 5] = 5.195655;
      val[1386 * nCulm + 0] = 40.762125;
      val[1386 * nCulm + 1] = 42.570430;
      val[1386 * nCulm + 2] = -22.306776;
      val[1386 * nCulm + 3] = 40.703933;
      val[1386 * nCulm + 4] = -27.855164;
      val[1386 * nCulm + 5] = -13.920530;
      val[1387 * nCulm + 0] = -13.020110;
      val[1387 * nCulm + 1] = -0.756910;
      val[1387 * nCulm + 2] = 15.574150;
      val[1387 * nCulm + 3] = -24.611352;
      val[1387 * nCulm + 4] = -3.304183;
      val[1387 * nCulm + 5] = 36.570739;
      val[1388 * nCulm + 0] = -39.847233;
      val[1388 * nCulm + 1] = 1.190188;
      val[1388 * nCulm + 2] = 44.319791;
      val[1388 * nCulm + 3] = -34.224628;
      val[1388 * nCulm + 4] = 41.864235;
      val[1388 * nCulm + 5] = -3.505002;
      val[1389 * nCulm + 0] = 42.829926;
      val[1389 * nCulm + 1] = 26.042641;
      val[1389 * nCulm + 2] = 44.596397;
      val[1389 * nCulm + 3] = 42.547378;
      val[1389 * nCulm + 4] = 26.729192;
      val[1389 * nCulm + 5] = 12.376249;
      val[1390 * nCulm + 0] = -6.375381;
      val[1390 * nCulm + 1] = 29.725126;
      val[1390 * nCulm + 2] = 36.905785;
      val[1390 * nCulm + 3] = 48.176901;
      val[1390 * nCulm + 4] = 38.350507;
      val[1390 * nCulm + 5] = 9.844899;
      val[1391 * nCulm + 0] = 31.468481;
      val[1391 * nCulm + 1] = 5.910473;
      val[1391 * nCulm + 2] = -47.886639;
      val[1391 * nCulm + 3] = 6.729670;
      val[1391 * nCulm + 4] = -32.705449;
      val[1391 * nCulm + 5] = -1.599359;
      val[1392 * nCulm + 0] = 47.720654;
      val[1392 * nCulm + 1] = -47.864219;
      val[1392 * nCulm + 2] = -6.724714;
      val[1392 * nCulm + 3] = -1.987233;
      val[1392 * nCulm + 4] = -34.866163;
      val[1392 * nCulm + 5] = 6.997695;
      val[1393 * nCulm + 0] = 0.743040;
      val[1393 * nCulm + 1] = 40.331707;
      val[1393 * nCulm + 2] = -48.899934;
      val[1393 * nCulm + 3] = 9.371649;
      val[1393 * nCulm + 4] = 28.798702;
      val[1393 * nCulm + 5] = 8.399207;
      val[1394 * nCulm + 0] = 31.208722;
      val[1394 * nCulm + 1] = 18.029753;
      val[1394 * nCulm + 2] = -41.730515;
      val[1394 * nCulm + 3] = 40.216929;
      val[1394 * nCulm + 4] = 39.737734;
      val[1394 * nCulm + 5] = 7.168014;
      val[1395 * nCulm + 0] = 36.933147;
      val[1395 * nCulm + 1] = -30.895332;
      val[1395 * nCulm + 2] = -8.521017;
      val[1395 * nCulm + 3] = 19.481656;
      val[1395 * nCulm + 4] = 38.087726;
      val[1395 * nCulm + 5] = -1.188429;
      val[1396 * nCulm + 0] = -6.092228;
      val[1396 * nCulm + 1] = 16.971705;
      val[1396 * nCulm + 2] = 36.987775;
      val[1396 * nCulm + 3] = -2.467783;
      val[1396 * nCulm + 4] = 40.728433;
      val[1396 * nCulm + 5] = 1.915601;
      val[1397 * nCulm + 0] = -14.029044;
      val[1397 * nCulm + 1] = 48.805865;
      val[1397 * nCulm + 2] = -12.856671;
      val[1397 * nCulm + 3] = -43.927869;
      val[1397 * nCulm + 4] = -2.512101;
      val[1397 * nCulm + 5] = -8.961183;
      val[1398 * nCulm + 0] = 32.078654;
      val[1398 * nCulm + 1] = 0.956870;
      val[1398 * nCulm + 2] = -4.671647;
      val[1398 * nCulm + 3] = 42.071481;
      val[1398 * nCulm + 4] = 33.232436;
      val[1398 * nCulm + 5] = 6.358577;
      val[1399 * nCulm + 0] = -2.690314;
      val[1399 * nCulm + 1] = -9.709460;
      val[1399 * nCulm + 2] = -8.511318;
      val[1399 * nCulm + 3] = -20.382871;
      val[1399 * nCulm + 4] = 48.013387;
      val[1399 * nCulm + 5] = -2.736611;
      val[1400 * nCulm + 0] = -35.031691;
      val[1400 * nCulm + 1] = 21.608800;
      val[1400 * nCulm + 2] = 22.725192;
      val[1400 * nCulm + 3] = 18.703492;
      val[1400 * nCulm + 4] = -34.284233;
      val[1400 * nCulm + 5] = -5.335576;
      val[1401 * nCulm + 0] = -47.953538;
      val[1401 * nCulm + 1] = -40.207589;
      val[1401 * nCulm + 2] = -16.419927;
      val[1401 * nCulm + 3] = -45.835683;
      val[1401 * nCulm + 4] = 16.860314;
      val[1401 * nCulm + 5] = -23.925629;
      val[1402 * nCulm + 0] = -45.775901;
      val[1402 * nCulm + 1] = 24.711058;
      val[1402 * nCulm + 2] = 20.397581;
      val[1402 * nCulm + 3] = 23.497197;
      val[1402 * nCulm + 4] = 49.166188;
      val[1402 * nCulm + 5] = 4.871111;
      val[1403 * nCulm + 0] = -2.737020;
      val[1403 * nCulm + 1] = -7.378542;
      val[1403 * nCulm + 2] = -47.424979;
      val[1403 * nCulm + 3] = 25.929472;
      val[1403 * nCulm + 4] = 48.046181;
      val[1403 * nCulm + 5] = 2.057569;
      val[1404 * nCulm + 0] = 38.344574;
      val[1404 * nCulm + 1] = -39.461899;
      val[1404 * nCulm + 2] = 20.418866;
      val[1404 * nCulm + 3] = 46.987545;
      val[1404 * nCulm + 4] = -49.866665;
      val[1404 * nCulm + 5] = -0.484333;
      val[1405 * nCulm + 0] = 19.174226;
      val[1405 * nCulm + 1] = 41.689347;
      val[1405 * nCulm + 2] = 22.757478;
      val[1405 * nCulm + 3] = 48.928064;
      val[1405 * nCulm + 4] = -5.890893;
      val[1405 * nCulm + 5] = -72.581105;
      val[1406 * nCulm + 0] = 33.947585;
      val[1406 * nCulm + 1] = 3.524982;
      val[1406 * nCulm + 2] = 2.404611;
      val[1406 * nCulm + 3] = 22.848763;
      val[1406 * nCulm + 4] = 22.954467;
      val[1406 * nCulm + 5] = 5.668407;
      val[1407 * nCulm + 0] = 46.593327;
      val[1407 * nCulm + 1] = 12.277063;
      val[1407 * nCulm + 2] = 42.506471;
      val[1407 * nCulm + 3] = 30.263213;
      val[1407 * nCulm + 4] = 13.155064;
      val[1407 * nCulm + 5] = 15.536448;
      val[1408 * nCulm + 0] = 34.561936;
      val[1408 * nCulm + 1] = 48.896960;
      val[1408 * nCulm + 2] = 24.050936;
      val[1408 * nCulm + 3] = 21.539952;
      val[1408 * nCulm + 4] = -31.263456;
      val[1408 * nCulm + 5] = -10.434252;
      val[1409 * nCulm + 0] = 19.105476;
      val[1409 * nCulm + 1] = 47.441482;
      val[1409 * nCulm + 2] = -20.384599;
      val[1409 * nCulm + 3] = 33.326477;
      val[1409 * nCulm + 4] = -37.371627;
      val[1409 * nCulm + 5] = -9.999731;
      val[1410 * nCulm + 0] = -5.838691;
      val[1410 * nCulm + 1] = -10.591134;
      val[1410 * nCulm + 2] = 1.294825;
      val[1410 * nCulm + 3] = -9.309609;
      val[1410 * nCulm + 4] = -20.986723;
      val[1410 * nCulm + 5] = 4.718402;
      val[1411 * nCulm + 0] = 5.058464;
      val[1411 * nCulm + 1] = -9.588161;
      val[1411 * nCulm + 2] = -5.037500;
      val[1411 * nCulm + 3] = 4.488058;
      val[1411 * nCulm + 4] = -42.203326;
      val[1411 * nCulm + 5] = 0.802004;
      val[1412 * nCulm + 0] = -22.750391;
      val[1412 * nCulm + 1] = 48.987242;
      val[1412 * nCulm + 2] = 4.930913;
      val[1412 * nCulm + 3] = 43.645041;
      val[1412 * nCulm + 4] = 25.211373;
      val[1412 * nCulm + 5] = 17.621337;
      val[1413 * nCulm + 0] = -47.067352;
      val[1413 * nCulm + 1] = 31.822744;
      val[1413 * nCulm + 2] = 39.883286;
      val[1413 * nCulm + 3] = 49.085470;
      val[1413 * nCulm + 4] = -27.644620;
      val[1413 * nCulm + 5] = -13.623167;
      val[1414 * nCulm + 0] = 8.829939;
      val[1414 * nCulm + 1] = 14.250914;
      val[1414 * nCulm + 2] = -6.658788;
      val[1414 * nCulm + 3] = -42.712452;
      val[1414 * nCulm + 4] = -20.392894;
      val[1414 * nCulm + 5] = 6.836122;
      val[1415 * nCulm + 0] = 19.622144;
      val[1415 * nCulm + 1] = 39.854709;
      val[1415 * nCulm + 2] = 1.254492;
      val[1415 * nCulm + 3] = -24.077526;
      val[1415 * nCulm + 4] = -0.214349;
      val[1415 * nCulm + 5] = -348.167464;
      val[1416 * nCulm + 0] = -2.729417;
      val[1416 * nCulm + 1] = -29.162775;
      val[1416 * nCulm + 2] = 29.087071;
      val[1416 * nCulm + 3] = -10.094577;
      val[1416 * nCulm + 4] = -37.807827;
      val[1416 * nCulm + 5] = 5.144806;
      val[1417 * nCulm + 0] = 37.738328;
      val[1417 * nCulm + 1] = -2.975679;
      val[1417 * nCulm + 2] = 48.995675;
      val[1417 * nCulm + 3] = 45.238340;
      val[1417 * nCulm + 4] = -1.087924;
      val[1417 * nCulm + 5] = -183.646087;
      val[1418 * nCulm + 0] = -33.356311;
      val[1418 * nCulm + 1] = -36.595611;
      val[1418 * nCulm + 2] = -6.020772;
      val[1418 * nCulm + 3] = -9.615984;
      val[1418 * nCulm + 4] = -5.526353;
      val[1418 * nCulm + 5] = 39.810331;
      val[1419 * nCulm + 0] = 12.353431;
      val[1419 * nCulm + 1] = -36.148204;
      val[1419 * nCulm + 2] = 1.265120;
      val[1419 * nCulm + 3] = 37.219264;
      val[1419 * nCulm + 4] = 24.939678;
      val[1419 * nCulm + 5] = 0.433278;
      val[1420 * nCulm + 0] = -19.783251;
      val[1420 * nCulm + 1] = -8.756858;
      val[1420 * nCulm + 2] = -49.732079;
      val[1420 * nCulm + 3] = 29.118101;
      val[1420 * nCulm + 4] = 49.443158;
      val[1420 * nCulm + 5] = 2.179239;
      val[1421 * nCulm + 0] = -0.398381;
      val[1421 * nCulm + 1] = 26.024557;
      val[1421 * nCulm + 2] = -45.442330;
      val[1421 * nCulm + 3] = 42.101423;
      val[1421 * nCulm + 4] = 25.372579;
      val[1421 * nCulm + 5] = 12.939113;
      val[1422 * nCulm + 0] = 10.935337;
      val[1422 * nCulm + 1] = 10.040189;
      val[1422 * nCulm + 2] = 6.176226;
      val[1422 * nCulm + 3] = 43.251101;
      val[1422 * nCulm + 4] = -7.117768;
      val[1422 * nCulm + 5] = -35.208841;
      val[1423 * nCulm + 0] = 13.761316;
      val[1423 * nCulm + 1] = -12.268624;
      val[1423 * nCulm + 2] = 23.362508;
      val[1423 * nCulm + 3] = -44.588091;
      val[1423 * nCulm + 4] = -38.518019;
      val[1423 * nCulm + 5] = 7.216906;
      val[1424 * nCulm + 0] = 16.745189;
      val[1424 * nCulm + 1] = 47.102527;
      val[1424 * nCulm + 2] = -48.419674;
      val[1424 * nCulm + 3] = -47.724772;
      val[1424 * nCulm + 4] = -39.770201;
      val[1424 * nCulm + 5] = 0.304058;
      val[1425 * nCulm + 0] = -38.043335;
      val[1425 * nCulm + 1] = -17.737871;
      val[1425 * nCulm + 2] = -27.041667;
      val[1425 * nCulm + 3] = 33.620296;
      val[1425 * nCulm + 4] = 10.135437;
      val[1425 * nCulm + 5] = 7.647225;
      val[1426 * nCulm + 0] = -41.307536;
      val[1426 * nCulm + 1] = 33.659145;
      val[1426 * nCulm + 2] = -41.458304;
      val[1426 * nCulm + 3] = 28.247401;
      val[1426 * nCulm + 4] = -39.696052;
      val[1426 * nCulm + 5] = -7.151699;
      val[1427 * nCulm + 0] = 15.408419;
      val[1427 * nCulm + 1] = -38.646575;
      val[1427 * nCulm + 2] = 26.021774;
      val[1427 * nCulm + 3] = 45.197059;
      val[1427 * nCulm + 4] = 27.999172;
      val[1427 * nCulm + 5] = 1.337377;
      val[1428 * nCulm + 0] = -4.471377;
      val[1428 * nCulm + 1] = -47.442623;
      val[1428 * nCulm + 2] = 46.989875;
      val[1428 * nCulm + 3] = -29.741121;
      val[1428 * nCulm + 4] = 0.913770;
      val[1428 * nCulm + 5] = -399.582046;
      val[1429 * nCulm + 0] = -6.734516;
      val[1429 * nCulm + 1] = -38.707441;
      val[1429 * nCulm + 2] = -14.271516;
      val[1429 * nCulm + 3] = 13.881786;
      val[1429 * nCulm + 4] = 7.291955;
      val[1429 * nCulm + 5] = -15.884758;
      val[1430 * nCulm + 0] = 20.013226;
      val[1430 * nCulm + 1] = 22.834893;
      val[1430 * nCulm + 2] = -32.908360;
      val[1430 * nCulm + 3] = -34.838878;
      val[1430 * nCulm + 4] = 15.365749;
      val[1430 * nCulm + 5] = -3.467761;
      val[1431 * nCulm + 0] = 44.843161;
      val[1431 * nCulm + 1] = 35.071078;
      val[1431 * nCulm + 2] = -43.919347;
      val[1431 * nCulm + 3] = 43.522244;
      val[1431 * nCulm + 4] = -21.884339;
      val[1431 * nCulm + 5] = -16.768840;
      val[1432 * nCulm + 0] = -7.799771;
      val[1432 * nCulm + 1] = 24.420454;
      val[1432 * nCulm + 2] = 11.235797;
      val[1432 * nCulm + 3] = 8.273444;
      val[1432 * nCulm + 4] = -46.146050;
      val[1432 * nCulm + 5] = -3.123507;
      val[1433 * nCulm + 0] = 32.207076;
      val[1433 * nCulm + 1] = -18.855135;
      val[1433 * nCulm + 2] = -3.190234;
      val[1433 * nCulm + 3] = 39.323738;
      val[1433 * nCulm + 4] = 0.091046;
      val[1433 * nCulm + 5] = 1064.360932;
      val[1434 * nCulm + 0] = -26.354489;
      val[1434 * nCulm + 1] = 38.648238;
      val[1434 * nCulm + 2] = -23.820332;
      val[1434 * nCulm + 3] = 13.539242;
      val[1434 * nCulm + 4] = 17.002163;
      val[1434 * nCulm + 5] = 14.758783;
      val[1435 * nCulm + 0] = 0.931432;
      val[1435 * nCulm + 1] = 26.760598;
      val[1435 * nCulm + 2] = 20.076384;
      val[1435 * nCulm + 3] = 14.469423;
      val[1435 * nCulm + 4] = -32.865136;
      val[1435 * nCulm + 5] = -5.708068;
      val[1436 * nCulm + 0] = 26.809696;
      val[1436 * nCulm + 1] = -33.320262;
      val[1436 * nCulm + 2] = -47.331398;
      val[1436 * nCulm + 3] = 8.538884;
      val[1436 * nCulm + 4] = -24.472131;
      val[1436 * nCulm + 5] = 5.023147;
      val[1437 * nCulm + 0] = 19.489041;
      val[1437 * nCulm + 1] = 24.201260;
      val[1437 * nCulm + 2] = -22.192110;
      val[1437 * nCulm + 3] = 12.232100;
      val[1437 * nCulm + 4] = -34.750902;
      val[1437 * nCulm + 5] = -4.732497;
      val[1438 * nCulm + 0] = 32.262197;
      val[1438 * nCulm + 1] = -3.615081;
      val[1438 * nCulm + 2] = -39.179053;
      val[1438 * nCulm + 3] = 14.164732;
      val[1438 * nCulm + 4] = 19.955825;
      val[1438 * nCulm + 5] = 2.732278;
      val[1439 * nCulm + 0] = -49.224759;
      val[1439 * nCulm + 1] = 37.851399;
      val[1439 * nCulm + 2] = -21.332252;
      val[1439 * nCulm + 3] = -15.267495;
      val[1439 * nCulm + 4] = -28.169580;
      val[1439 * nCulm + 5] = -3.564772;
      val[1440 * nCulm + 0] = 49.917746;
      val[1440 * nCulm + 1] = 48.092387;
      val[1440 * nCulm + 2] = -23.563791;
      val[1440 * nCulm + 3] = 24.344150;
      val[1440 * nCulm + 4] = -22.376827;
      val[1440 * nCulm + 5] = -15.092381;
      val[1441 * nCulm + 0] = 38.671465;
      val[1441 * nCulm + 1] = 17.284641;
      val[1441 * nCulm + 2] = -41.459089;
      val[1441 * nCulm + 3] = 12.608523;
      val[1441 * nCulm + 4] = 41.167700;
      val[1441 * nCulm + 5] = 3.667023;
      val[1442 * nCulm + 0] = 43.849028;
      val[1442 * nCulm + 1] = 16.768699;
      val[1442 * nCulm + 2] = -29.064109;
      val[1442 * nCulm + 3] = 31.020549;
      val[1442 * nCulm + 4] = -40.831678;
      val[1442 * nCulm + 5] = -5.309876;
      val[1443 * nCulm + 0] = -25.181775;
      val[1443 * nCulm + 1] = -33.653056;
      val[1443 * nCulm + 2] = -41.698091;
      val[1443 * nCulm + 3] = 4.735309;
      val[1443 * nCulm + 4] = -48.932530;
      val[1443 * nCulm + 5] = 3.027267;
      val[1444 * nCulm + 0] = 42.224950;
      val[1444 * nCulm + 1] = -37.917950;
      val[1444 * nCulm + 2] = -3.554390;
      val[1444 * nCulm + 3] = 4.291822;
      val[1444 * nCulm + 4] = -9.461372;
      val[1444 * nCulm + 5] = 17.052473;
      val[1445 * nCulm + 0] = 42.933306;
      val[1445 * nCulm + 1] = -14.078846;
      val[1445 * nCulm + 2] = -35.250840;
      val[1445 * nCulm + 3] = -14.705895;
      val[1445 * nCulm + 4] = -36.616954;
      val[1445 * nCulm + 5] = 3.950893;
      val[1446 * nCulm + 0] = 21.987046;
      val[1446 * nCulm + 1] = 9.666671;
      val[1446 * nCulm + 2] = 23.553660;
      val[1446 * nCulm + 3] = -9.126558;
      val[1446 * nCulm + 4] = -4.047754;
      val[1446 * nCulm + 5] = -0.401594;
      val[1447 * nCulm + 0] = -31.425369;
      val[1447 * nCulm + 1] = -24.283627;
      val[1447 * nCulm + 2] = 7.970879;
      val[1447 * nCulm + 3] = 27.439035;
      val[1447 * nCulm + 4] = -11.296879;
      val[1447 * nCulm + 5] = -1.092099;
      val[1448 * nCulm + 0] = 44.264843;
      val[1448 * nCulm + 1] = 13.435003;
      val[1448 * nCulm + 2] = 33.743374;
      val[1448 * nCulm + 3] = 40.848618;
      val[1448 * nCulm + 4] = 10.970532;
      val[1448 * nCulm + 5] = 23.651149;
      val[1449 * nCulm + 0] = -4.733275;
      val[1449 * nCulm + 1] = 28.985980;
      val[1449 * nCulm + 2] = 48.098014;
      val[1449 * nCulm + 3] = 9.141336;
      val[1449 * nCulm + 4] = 15.696690;
      val[1449 * nCulm + 5] = 11.727283;
      val[1450 * nCulm + 0] = 16.910982;
      val[1450 * nCulm + 1] = -49.181573;
      val[1450 * nCulm + 2] = -44.555834;
      val[1450 * nCulm + 3] = -47.282789;
      val[1450 * nCulm + 4] = -22.667118;
      val[1450 * nCulm + 5] = 20.373628;
      val[1451 * nCulm + 0] = 14.596793;
      val[1451 * nCulm + 1] = -45.951274;
      val[1451 * nCulm + 2] = 43.454320;
      val[1451 * nCulm + 3] = 31.741970;
      val[1451 * nCulm + 4] = -0.934961;
      val[1451 * nCulm + 5] = 72.166016;
      val[1452 * nCulm + 0] = -49.598371;
      val[1452 * nCulm + 1] = -20.922698;
      val[1452 * nCulm + 2] = 26.568568;
      val[1452 * nCulm + 3] = -12.392710;
      val[1452 * nCulm + 4] = 6.425561;
      val[1452 * nCulm + 5] = -24.311504;
      val[1453 * nCulm + 0] = 34.831468;
      val[1453 * nCulm + 1] = -30.860063;
      val[1453 * nCulm + 2] = 35.217822;
      val[1453 * nCulm + 3] = -17.051065;
      val[1453 * nCulm + 4] = -49.434873;
      val[1453 * nCulm + 5] = 4.817437;
      val[1454 * nCulm + 0] = 44.880801;
      val[1454 * nCulm + 1] = 7.586449;
      val[1454 * nCulm + 2] = -7.844090;
      val[1454 * nCulm + 3] = 10.110219;
      val[1454 * nCulm + 4] = 16.926365;
      val[1454 * nCulm + 5] = 5.178743;
      val[1455 * nCulm + 0] = 13.376257;
      val[1455 * nCulm + 1] = -45.762216;
      val[1455 * nCulm + 2] = -20.325976;
      val[1455 * nCulm + 3] = 29.879328;
      val[1455 * nCulm + 4] = 8.951078;
      val[1455 * nCulm + 5] = -8.168877;
      val[1456 * nCulm + 0] = 38.393571;
      val[1456 * nCulm + 1] = -47.604767;
      val[1456 * nCulm + 2] = -15.306164;
      val[1456 * nCulm + 3] = 27.356396;
      val[1456 * nCulm + 4] = -48.440103;
      val[1456 * nCulm + 5] = 2.208573;
      val[1457 * nCulm + 0] = 27.621728;
      val[1457 * nCulm + 1] = 45.115952;
      val[1457 * nCulm + 2] = -4.628127;
      val[1457 * nCulm + 3] = 25.127666;
      val[1457 * nCulm + 4] = -47.472730;
      val[1457 * nCulm + 5] = -6.773736;
      val[1458 * nCulm + 0] = -47.370772;
      val[1458 * nCulm + 1] = -23.999333;
      val[1458 * nCulm + 2] = 25.979490;
      val[1458 * nCulm + 3] = -32.355127;
      val[1458 * nCulm + 4] = -11.680578;
      val[1458 * nCulm + 5] = 23.066579;
      val[1459 * nCulm + 0] = -1.739524;
      val[1459 * nCulm + 1] = -1.593531;
      val[1459 * nCulm + 2] = -25.204789;
      val[1459 * nCulm + 3] = 10.411521;
      val[1459 * nCulm + 4] = -15.716908;
      val[1459 * nCulm + 5] = -2.425642;
      val[1460 * nCulm + 0] = 5.422621;
      val[1460 * nCulm + 1] = 28.204696;
      val[1460 * nCulm + 2] = 48.776530;
      val[1460 * nCulm + 3] = -34.453967;
      val[1460 * nCulm + 4] = -46.575514;
      val[1460 * nCulm + 5] = 0.865095;
      val[1461 * nCulm + 0] = 27.708040;
      val[1461 * nCulm + 1] = -19.621649;
      val[1461 * nCulm + 2] = -0.187858;
      val[1461 * nCulm + 3] = -13.044608;
      val[1461 * nCulm + 4] = -37.085398;
      val[1461 * nCulm + 5] = 4.399304;
      val[1462 * nCulm + 0] = -1.832777;
      val[1462 * nCulm + 1] = 1.126133;
      val[1462 * nCulm + 2] = -6.241253;
      val[1462 * nCulm + 3] = 43.468533;
      val[1462 * nCulm + 4] = -20.396740;
      val[1462 * nCulm + 5] = -10.118782;
      val[1463 * nCulm + 0] = -24.506689;
      val[1463 * nCulm + 1] = 33.292112;
      val[1463 * nCulm + 2] = -47.558514;
      val[1463 * nCulm + 3] = -10.685622;
      val[1463 * nCulm + 4] = -11.189477;
      val[1463 * nCulm + 5] = -9.332918;
      val[1464 * nCulm + 0] = 31.982724;
      val[1464 * nCulm + 1] = -9.926580;
      val[1464 * nCulm + 2] = -12.256996;
      val[1464 * nCulm + 3] = 23.806735;
      val[1464 * nCulm + 4] = -4.621569;
      val[1464 * nCulm + 5] = -13.985822;
      val[1465 * nCulm + 0] = 38.982843;
      val[1465 * nCulm + 1] = -22.436964;
      val[1465 * nCulm + 2] = 18.948058;
      val[1465 * nCulm + 3] = -39.334028;
      val[1465 * nCulm + 4] = 35.314902;
      val[1465 * nCulm + 5] = -8.049301;
      val[1466 * nCulm + 0] = 6.224413;
      val[1466 * nCulm + 1] = -27.363339;
      val[1466 * nCulm + 2] = -4.215687;
      val[1466 * nCulm + 3] = -8.262486;
      val[1466 * nCulm + 4] = 43.010348;
      val[1466 * nCulm + 5] = -3.690659;
      val[1467 * nCulm + 0] = -12.491256;
      val[1467 * nCulm + 1] = 16.625609;
      val[1467 * nCulm + 2] = 38.469558;
      val[1467 * nCulm + 3] = 40.227377;
      val[1467 * nCulm + 4] = 34.416513;
      val[1467 * nCulm + 5] = 8.049041;
      val[1468 * nCulm + 0] = 6.707739;
      val[1468 * nCulm + 1] = 35.248366;
      val[1468 * nCulm + 2] = 8.913355;
      val[1468 * nCulm + 3] = 28.178217;
      val[1468 * nCulm + 4] = 11.821213;
      val[1468 * nCulm + 5] = 25.626645;
      val[1469 * nCulm + 0] = 35.687675;
      val[1469 * nCulm + 1] = 17.684908;
      val[1469 * nCulm + 2] = 28.033169;
      val[1469 * nCulm + 3] = -8.231230;
      val[1469 * nCulm + 4] = -43.837491;
      val[1469 * nCulm + 5] = -0.790757;
      val[1470 * nCulm + 0] = 25.788454;
      val[1470 * nCulm + 1] = 29.375654;
      val[1470 * nCulm + 2] = -40.947898;
      val[1470 * nCulm + 3] = -43.227068;
      val[1470 * nCulm + 4] = 17.464114;
      val[1470 * nCulm + 5] = -3.524176;
      val[1471 * nCulm + 0] = -24.159670;
      val[1471 * nCulm + 1] = 18.108586;
      val[1471 * nCulm + 2] = 28.750865;
      val[1471 * nCulm + 3] = 7.210538;
      val[1471 * nCulm + 4] = -26.331422;
      val[1471 * nCulm + 5] = -4.321363;
      val[1472 * nCulm + 0] = -6.684956;
      val[1472 * nCulm + 1] = 41.286990;
      val[1472 * nCulm + 2] = 34.924803;
      val[1472 * nCulm + 3] = 19.743637;
      val[1472 * nCulm + 4] = -10.094565;
      val[1472 * nCulm + 5] = -28.387212;
      val[1473 * nCulm + 0] = 5.228908;
      val[1473 * nCulm + 1] = -13.774927;
      val[1473 * nCulm + 2] = 29.348727;
      val[1473 * nCulm + 3] = -6.112011;
      val[1473 * nCulm + 4] = 36.759768;
      val[1473 * nCulm + 5] = -2.330721;
      val[1474 * nCulm + 0] = -38.753787;
      val[1474 * nCulm + 1] = -38.555882;
      val[1474 * nCulm + 2] = -29.058789;
      val[1474 * nCulm + 3] = -10.818608;
      val[1474 * nCulm + 4] = -29.878240;
      val[1474 * nCulm + 5] = 8.051944;
      val[1475 * nCulm + 0] = 47.837884;
      val[1475 * nCulm + 1] = 38.396690;
      val[1475 * nCulm + 2] = 4.383345;
      val[1475 * nCulm + 3] = 32.582389;
      val[1475 * nCulm + 4] = 9.556003;
      val[1475 * nCulm + 5] = 35.387757;
      val[1476 * nCulm + 0] = 13.155461;
      val[1476 * nCulm + 1] = -45.020189;
      val[1476 * nCulm + 2] = 15.226806;
      val[1476 * nCulm + 3] = -26.131278;
      val[1476 * nCulm + 4] = -6.594130;
      val[1476 * nCulm + 5] = 51.303246;
      val[1477 * nCulm + 0] = -1.664012;
      val[1477 * nCulm + 1] = -16.591491;
      val[1477 * nCulm + 2] = 9.819394;
      val[1477 * nCulm + 3] = 24.225097;
      val[1477 * nCulm + 4] = -32.637037;
      val[1477 * nCulm + 5] = -0.877098;
      val[1478 * nCulm + 0] = 3.286317;
      val[1478 * nCulm + 1] = -40.574510;
      val[1478 * nCulm + 2] = -1.863624;
      val[1478 * nCulm + 3] = -19.348455;
      val[1478 * nCulm + 4] = 29.515496;
      val[1478 * nCulm + 5] = -9.379710;
      val[1479 * nCulm + 0] = 34.196248;
      val[1479 * nCulm + 1] = 8.875541;
      val[1479 * nCulm + 2] = -32.820731;
      val[1479 * nCulm + 3] = 20.712637;
      val[1479 * nCulm + 4] = 0.318639;
      val[1479 * nCulm + 5] = 439.757544;
      val[1480 * nCulm + 0] = 3.327520;
      val[1480 * nCulm + 1] = -7.480034;
      val[1480 * nCulm + 2] = -41.262867;
      val[1480 * nCulm + 3] = 19.187463;
      val[1480 * nCulm + 4] = 15.819904;
      val[1480 * nCulm + 5] = 3.732876;
      val[1481 * nCulm + 0] = 47.689608;
      val[1481 * nCulm + 1] = -10.347366;
      val[1481 * nCulm + 2] = -19.578120;
      val[1481 * nCulm + 3] = -20.219383;
      val[1481 * nCulm + 4] = 23.060527;
      val[1481 * nCulm + 5] = -6.044037;
      val[1482 * nCulm + 0] = -48.717637;
      val[1482 * nCulm + 1] = 37.959371;
      val[1482 * nCulm + 2] = -36.199304;
      val[1482 * nCulm + 3] = -42.914661;
      val[1482 * nCulm + 4] = 24.642724;
      val[1482 * nCulm + 5] = -0.721804;
      val[1483 * nCulm + 0] = 7.436560;
      val[1483 * nCulm + 1] = -14.466317;
      val[1483 * nCulm + 2] = 10.120214;
      val[1483 * nCulm + 3] = -3.762491;
      val[1483 * nCulm + 4] = -13.598780;
      val[1483 * nCulm + 5] = 6.574909;
      val[1484 * nCulm + 0] = 35.078449;
      val[1484 * nCulm + 1] = 17.465784;
      val[1484 * nCulm + 2] = -28.975107;
      val[1484 * nCulm + 3] = -20.188638;
      val[1484 * nCulm + 4] = -25.730337;
      val[1484 * nCulm + 5] = 0.730894;
      val[1485 * nCulm + 0] = 43.420057;
      val[1485 * nCulm + 1] = -21.591547;
      val[1485 * nCulm + 2] = -10.614559;
      val[1485 * nCulm + 3] = 35.443788;
      val[1485 * nCulm + 4] = 15.918753;
      val[1485 * nCulm + 5] = 4.348870;
      val[1486 * nCulm + 0] = -48.627870;
      val[1486 * nCulm + 1] = 21.115241;
      val[1486 * nCulm + 2] = 9.401341;
      val[1486 * nCulm + 3] = 34.497001;
      val[1486 * nCulm + 4] = 24.509451;
      val[1486 * nCulm + 5] = 10.969991;
      val[1487 * nCulm + 0] = -30.441975;
      val[1487 * nCulm + 1] = -28.777579;
      val[1487 * nCulm + 2] = 42.564610;
      val[1487 * nCulm + 3] = -38.820288;
      val[1487 * nCulm + 4] = 9.507826;
      val[1487 * nCulm + 5] = -33.422619;
      val[1488 * nCulm + 0] = 32.369035;
      val[1488 * nCulm + 1] = 27.373247;
      val[1488 * nCulm + 2] = -18.609123;
      val[1488 * nCulm + 3] = -6.225991;
      val[1488 * nCulm + 4] = -29.466508;
      val[1488 * nCulm + 5] = -3.166976;
      val[1489 * nCulm + 0] = 14.280422;
      val[1489 * nCulm + 1] = 7.204601;
      val[1489 * nCulm + 2] = 33.215108;
      val[1489 * nCulm + 3] = -31.800568;
      val[1489 * nCulm + 4] = -11.681528;
      val[1489 * nCulm + 5] = 10.196239;
      val[1490 * nCulm + 0] = 29.939539;
      val[1490 * nCulm + 1] = 2.830325;
      val[1490 * nCulm + 2] = 45.438632;
      val[1490 * nCulm + 3] = 13.729714;
      val[1490 * nCulm + 4] = -7.678039;
      val[1490 * nCulm + 5] = -9.978881;
      val[1491 * nCulm + 0] = 14.949836;
      val[1491 * nCulm + 1] = 9.674144;
      val[1491 * nCulm + 2] = -39.724752;
      val[1491 * nCulm + 3] = 7.742458;
      val[1491 * nCulm + 4] = 6.299547;
      val[1491 * nCulm + 5] = 13.316431;
      val[1492 * nCulm + 0] = 39.838079;
      val[1492 * nCulm + 1] = 10.825094;
      val[1492 * nCulm + 2] = -0.619972;
      val[1492 * nCulm + 3] = 2.598207;
      val[1492 * nCulm + 4] = 33.938883;
      val[1492 * nCulm + 5] = 2.102099;
      val[1493 * nCulm + 0] = 12.830306;
      val[1493 * nCulm + 1] = 39.210680;
      val[1493 * nCulm + 2] = 39.860410;
      val[1493 * nCulm + 3] = -41.455199;
      val[1493 * nCulm + 4] = 24.915667;
      val[1493 * nCulm + 5] = -0.196401;
      val[1494 * nCulm + 0] = 24.834848;
      val[1494 * nCulm + 1] = 42.663504;
      val[1494 * nCulm + 2] = -15.952276;
      val[1494 * nCulm + 3] = 49.825479;
      val[1494 * nCulm + 4] = -43.558869;
      val[1494 * nCulm + 5] = -9.820334;
      val[1495 * nCulm + 0] = -13.226820;
      val[1495 * nCulm + 1] = 44.182783;
      val[1495 * nCulm + 2] = 17.450394;
      val[1495 * nCulm + 3] = 44.555050;
      val[1495 * nCulm + 4] = -1.646692;
      val[1495 * nCulm + 5] = -254.842413;
      val[1496 * nCulm + 0] = -30.941852;
      val[1496 * nCulm + 1] = -3.620233;
      val[1496 * nCulm + 2] = -11.542718;
      val[1496 * nCulm + 3] = 40.757875;
      val[1496 * nCulm + 4] = -5.538005;
      val[1496 * nCulm + 5] = -31.511545;
      val[1497 * nCulm + 0] = -14.708275;
      val[1497 * nCulm + 1] = -45.877295;
      val[1497 * nCulm + 2] = -10.278070;
      val[1497 * nCulm + 3] = 42.065906;
      val[1497 * nCulm + 4] = -43.093692;
      val[1497 * nCulm + 5] = 0.648636;
      val[1498 * nCulm + 0] = -41.944547;
      val[1498 * nCulm + 1] = -10.845488;
      val[1498 * nCulm + 2] = 5.333573;
      val[1498 * nCulm + 3] = 48.966585;
      val[1498 * nCulm + 4] = -42.376856;
      val[1498 * nCulm + 5] = -4.027981;
      val[1499 * nCulm + 0] = -34.839633;
      val[1499 * nCulm + 1] = -42.524526;
      val[1499 * nCulm + 2] = 31.727660;
      val[1499 * nCulm + 3] = -22.946823;
      val[1499 * nCulm + 4] = -3.552271;
      val[1499 * nCulm + 5] = 87.469328;
      val[1500 * nCulm + 0] = 5.513946;
      val[1500 * nCulm + 1] = 13.994255;
      val[1500 * nCulm + 2] = -13.946100;
      val[1500 * nCulm + 3] = -36.021902;
      val[1500 * nCulm + 4] = 5.679450;
      val[1500 * nCulm + 5] = -18.128151;
      val[1501 * nCulm + 0] = -3.706922;
      val[1501 * nCulm + 1] = 45.069003;
      val[1501 * nCulm + 2] = 48.872619;
      val[1501 * nCulm + 3] = 22.603001;
      val[1501 * nCulm + 4] = -23.493715;
      val[1501 * nCulm + 5] = -13.404036;
      val[1502 * nCulm + 0] = -39.749311;
      val[1502 * nCulm + 1] = 34.354174;
      val[1502 * nCulm + 2] = -45.755740;
      val[1502 * nCulm + 3] = -22.280610;
      val[1502 * nCulm + 4] = -26.355507;
      val[1502 * nCulm + 5] = -1.938359;
      val[1503 * nCulm + 0] = 33.431295;
      val[1503 * nCulm + 1] = 27.793789;
      val[1503 * nCulm + 2] = 38.130382;
      val[1503 * nCulm + 3] = 3.866894;
      val[1503 * nCulm + 4] = -44.204022;
      val[1503 * nCulm + 5] = -3.160202;
      val[1504 * nCulm + 0] = 30.775902;
      val[1504 * nCulm + 1] = 0.995803;
      val[1504 * nCulm + 2] = 39.794956;
      val[1504 * nCulm + 3] = -5.212428;
      val[1504 * nCulm + 4] = 29.707348;
      val[1504 * nCulm + 5] = -0.441844;
      val[1505 * nCulm + 0] = -18.790259;
      val[1505 * nCulm + 1] = 30.415068;
      val[1505 * nCulm + 2] = 49.520184;
      val[1505 * nCulm + 3] = 47.045901;
      val[1505 * nCulm + 4] = 2.604624;
      val[1505 * nCulm + 5] = 140.998316;
      val[1506 * nCulm + 0] = -41.431020;
      val[1506 * nCulm + 1] = -22.715702;
      val[1506 * nCulm + 2] = -12.234149;
      val[1506 * nCulm + 3] = 37.554582;
      val[1506 * nCulm + 4] = 15.588230;
      val[1506 * nCulm + 5] = 4.735794;
      val[1507 * nCulm + 0] = -34.926926;
      val[1507 * nCulm + 1] = -37.935656;
      val[1507 * nCulm + 2] = -2.812314;
      val[1507 * nCulm + 3] = 27.401898;
      val[1507 * nCulm + 4] = -3.166839;
      val[1507 * nCulm + 5] = 15.974339;
      val[1508 * nCulm + 0] = 25.921755;
      val[1508 * nCulm + 1] = 5.093771;
      val[1508 * nCulm + 2] = -12.454983;
      val[1508 * nCulm + 3] = -5.876109;
      val[1508 * nCulm + 4] = -26.839401;
      val[1508 * nCulm + 5] = 0.367971;
      val[1509 * nCulm + 0] = 17.544558;
      val[1509 * nCulm + 1] = -43.193963;
      val[1509 * nCulm + 2] = 27.079133;
      val[1509 * nCulm + 3] = -35.433555;
      val[1509 * nCulm + 4] = 48.557575;
      val[1509 * nCulm + 5] = -7.434515;
      val[1510 * nCulm + 0] = -4.550605;
      val[1510 * nCulm + 1] = 21.743562;
      val[1510 * nCulm + 2] = 1.781004;
      val[1510 * nCulm + 3] = 14.436213;
      val[1510 * nCulm + 4] = 46.991629;
      val[1510 * nCulm + 5] = 3.874286;
      val[1511 * nCulm + 0] = -22.758786;
      val[1511 * nCulm + 1] = 4.085588;
      val[1511 * nCulm + 2] = -4.815484;
      val[1511 * nCulm + 3] = 7.346854;
      val[1511 * nCulm + 4] = 32.021737;
      val[1511 * nCulm + 5] = 1.919901;
      val[1512 * nCulm + 0] = -6.451226;
      val[1512 * nCulm + 1] = 13.478173;
      val[1512 * nCulm + 2] = 33.995751;
      val[1512 * nCulm + 3] = 8.539701;
      val[1512 * nCulm + 4] = -21.885973;
      val[1512 * nCulm + 5] = -4.531860;
      val[1513 * nCulm + 0] = -17.290840;
      val[1513 * nCulm + 1] = -15.060576;
      val[1513 * nCulm + 2] = -13.959924;
      val[1513 * nCulm + 3] = 0.396257;
      val[1513 * nCulm + 4] = 41.681755;
      val[1513 * nCulm + 5] = -1.435264;
      val[1514 * nCulm + 0] = 22.807978;
      val[1514 * nCulm + 1] = 25.545358;
      val[1514 * nCulm + 2] = 35.026132;
      val[1514 * nCulm + 3] = -4.245672;
      val[1514 * nCulm + 4] = 29.304762;
      val[1514 * nCulm + 5] = 3.670346;
      val[1515 * nCulm + 0] = 8.148180;
      val[1515 * nCulm + 1] = 44.344734;
      val[1515 * nCulm + 2] = 34.633208;
      val[1515 * nCulm + 3] = -4.262208;
      val[1515 * nCulm + 4] = -11.352165;
      val[1515 * nCulm + 5] = -16.482580;
      val[1516 * nCulm + 0] = -9.970929;
      val[1516 * nCulm + 1] = -23.306874;
      val[1516 * nCulm + 2] = 49.847749;
      val[1516 * nCulm + 3] = 17.271891;
      val[1516 * nCulm + 4] = 42.605116;
      val[1516 * nCulm + 5] = -0.440473;
      val[1517 * nCulm + 0] = -36.759598;
      val[1517 * nCulm + 1] = 31.556259;
      val[1517 * nCulm + 2] = 23.511031;
      val[1517 * nCulm + 3] = 42.465017;
      val[1517 * nCulm + 4] = 20.279887;
      val[1517 * nCulm + 5] = 17.506594;
      val[1518 * nCulm + 0] = -0.026296;
      val[1518 * nCulm + 1] = -19.957189;
      val[1518 * nCulm + 2] = 24.781479;
      val[1518 * nCulm + 3] = 30.788589;
      val[1518 * nCulm + 4] = 27.216749;
      val[1518 * nCulm + 5] = 2.113716;
      val[1519 * nCulm + 0] = -6.184865;
      val[1519 * nCulm + 1] = -28.705366;
      val[1519 * nCulm + 2] = -22.542915;
      val[1519 * nCulm + 3] = -10.060287;
      val[1519 * nCulm + 4] = 22.891390;
      val[1519 * nCulm + 5] = -7.785711;
      val[1520 * nCulm + 0] = 11.019539;
      val[1520 * nCulm + 1] = 43.898407;
      val[1520 * nCulm + 2] = -17.375412;
      val[1520 * nCulm + 3] = 46.514953;
      val[1520 * nCulm + 4] = 14.125343;
      val[1520 * nCulm + 5] = 30.527074;
      val[1521 * nCulm + 0] = 25.401442;
      val[1521 * nCulm + 1] = -10.249100;
      val[1521 * nCulm + 2] = -42.021343;
      val[1521 * nCulm + 3] = -40.882456;
      val[1521 * nCulm + 4] = -10.649200;
      val[1521 * nCulm + 5] = 22.956844;
      val[1522 * nCulm + 0] = 7.173050;
      val[1522 * nCulm + 1] = -44.056856;
      val[1522 * nCulm + 2] = 36.462975;
      val[1522 * nCulm + 3] = 16.500150;
      val[1522 * nCulm + 4] = -31.171561;
      val[1522 * nCulm + 5] = 4.414425;
      val[1523 * nCulm + 0] = 13.077673;
      val[1523 * nCulm + 1] = -4.961470;
      val[1523 * nCulm + 2] = 16.045312;
      val[1523 * nCulm + 3] = 10.398733;
      val[1523 * nCulm + 4] = -11.917511;
      val[1523 * nCulm + 5] = -1.929543;
      val[1524 * nCulm + 0] = 1.530367;
      val[1524 * nCulm + 1] = -9.065042;
      val[1524 * nCulm + 2] = 3.425489;
      val[1524 * nCulm + 3] = -31.590088;
      val[1524 * nCulm + 4] = 31.950675;
      val[1524 * nCulm + 5] = -5.792855;
      val[1525 * nCulm + 0] = 34.981574;
      val[1525 * nCulm + 1] = -45.180887;
      val[1525 * nCulm + 2] = 5.808688;
      val[1525 * nCulm + 3] = -13.621570;
      val[1525 * nCulm + 4] = -11.472548;
      val[1525 * nCulm + 5] = 24.490663;
      val[1526 * nCulm + 0] = 25.738411;
      val[1526 * nCulm + 1] = 7.343873;
      val[1526 * nCulm + 2] = 42.842803;
      val[1526 * nCulm + 3] = -14.995609;
      val[1526 * nCulm + 4] = 14.044468;
      val[1526 * nCulm + 5] = -2.348824;
      val[1527 * nCulm + 0] = 33.852866;
      val[1527 * nCulm + 1] = -36.147256;
      val[1527 * nCulm + 2] = -26.146980;
      val[1527 * nCulm + 3] = -41.246109;
      val[1527 * nCulm + 4] = 38.629684;
      val[1527 * nCulm + 5] = -9.253085;
      val[1528 * nCulm + 0] = 2.197490;
      val[1528 * nCulm + 1] = -33.157544;
      val[1528 * nCulm + 2] = 33.353096;
      val[1528 * nCulm + 3] = 23.523277;
      val[1528 * nCulm + 4] = -46.049410;
      val[1528 * nCulm + 5] = 1.220288;
      val[1529 * nCulm + 0] = -48.795576;
      val[1529 * nCulm + 1] = -47.663544;
      val[1529 * nCulm + 2] = -45.316304;
      val[1529 * nCulm + 3] = 46.734844;
      val[1529 * nCulm + 4] = 12.447626;
      val[1529 * nCulm + 5] = -0.123147;
      val[1530 * nCulm + 0] = -24.076703;
      val[1530 * nCulm + 1] = -48.681067;
      val[1530 * nCulm + 2] = -21.338520;
      val[1530 * nCulm + 3] = 10.596943;
      val[1530 * nCulm + 4] = -15.404788;
      val[1530 * nCulm + 5] = 11.931872;
      val[1531 * nCulm + 0] = -1.446716;
      val[1531 * nCulm + 1] = -13.502905;
      val[1531 * nCulm + 2] = 37.567179;
      val[1531 * nCulm + 3] = 37.744854;
      val[1531 * nCulm + 4] = 34.703334;
      val[1531 * nCulm + 5] = 3.536461;
      val[1532 * nCulm + 0] = -49.490215;
      val[1532 * nCulm + 1] = -46.761626;
      val[1532 * nCulm + 2] = 22.421428;
      val[1532 * nCulm + 3] = 43.698156;
      val[1532 * nCulm + 4] = 4.387990;
      val[1532 * nCulm + 5] = -3.074571;
      val[1533 * nCulm + 0] = -47.375565;
      val[1533 * nCulm + 1] = -11.551781;
      val[1533 * nCulm + 2] = -43.234895;
      val[1533 * nCulm + 3] = 33.183491;
      val[1533 * nCulm + 4] = -36.193547;
      val[1533 * nCulm + 5] = -2.598960;
      val[1534 * nCulm + 0] = -39.175690;
      val[1534 * nCulm + 1] = -4.075990;
      val[1534 * nCulm + 2] = 3.251287;
      val[1534 * nCulm + 3] = -14.849736;
      val[1534 * nCulm + 4] = -17.596748;
      val[1534 * nCulm + 5] = 5.320814;
      val[1535 * nCulm + 0] = -42.177397;
      val[1535 * nCulm + 1] = 41.542843;
      val[1535 * nCulm + 2] = -25.350157;
      val[1535 * nCulm + 3] = 11.940522;
      val[1535 * nCulm + 4] = 32.993847;
      val[1535 * nCulm + 5] = 7.902782;
      val[1536 * nCulm + 0] = -12.290573;
      val[1536 * nCulm + 1] = 9.387724;
      val[1536 * nCulm + 2] = -7.317329;
      val[1536 * nCulm + 3] = 41.137071;
      val[1536 * nCulm + 4] = -10.786137;
      val[1536 * nCulm + 5] = -21.942043;
      val[1537 * nCulm + 0] = -10.276830;
      val[1537 * nCulm + 1] = 6.870990;
      val[1537 * nCulm + 2] = -28.086694;
      val[1537 * nCulm + 3] = 28.273784;
      val[1537 * nCulm + 4] = -35.379246;
      val[1537 * nCulm + 5] = -4.471964;
      val[1538 * nCulm + 0] = -49.974363;
      val[1538 * nCulm + 1] = 8.429682;
      val[1538 * nCulm + 2] = -25.860453;
      val[1538 * nCulm + 3] = -17.897230;
      val[1538 * nCulm + 4] = 16.461459;
      val[1538 * nCulm + 5] = -2.492302;
      val[1539 * nCulm + 0] = -33.736767;
      val[1539 * nCulm + 1] = 28.723438;
      val[1539 * nCulm + 2] = -9.086649;
      val[1539 * nCulm + 3] = -43.175555;
      val[1539 * nCulm + 4] = 22.387681;
      val[1539 * nCulm + 5] = -2.825550;
      val[1540 * nCulm + 0] = 29.769458;
      val[1540 * nCulm + 1] = -20.082565;
      val[1540 * nCulm + 2] = -21.727815;
      val[1540 * nCulm + 3] = -34.776075;
      val[1540 * nCulm + 4] = -27.619639;
      val[1540 * nCulm + 5] = 9.631435;
      val[1541 * nCulm + 0] = -3.379395;
      val[1541 * nCulm + 1] = 9.436678;
      val[1541 * nCulm + 2] = -45.273799;
      val[1541 * nCulm + 3] = 10.801167;
      val[1541 * nCulm + 4] = -28.509657;
      val[1541 * nCulm + 5] = -3.130001;
      val[1542 * nCulm + 0] = 21.682711;
      val[1542 * nCulm + 1] = -39.377130;
      val[1542 * nCulm + 2] = -40.890555;
      val[1542 * nCulm + 3] = 8.393592;
      val[1542 * nCulm + 4] = 31.930917;
      val[1542 * nCulm + 5] = -4.362897;
      val[1543 * nCulm + 0] = -26.507700;
      val[1543 * nCulm + 1] = -30.853412;
      val[1543 * nCulm + 2] = 31.468829;
      val[1543 * nCulm + 3] = -25.679389;
      val[1543 * nCulm + 4] = -36.619173;
      val[1543 * nCulm + 5] = 7.537336;
      val[1544 * nCulm + 0] = 26.466209;
      val[1544 * nCulm + 1] = 11.081664;
      val[1544 * nCulm + 2] = -47.920213;
      val[1544 * nCulm + 3] = -32.329084;
      val[1544 * nCulm + 4] = -23.807167;
      val[1544 * nCulm + 5] = 4.454405;
      val[1545 * nCulm + 0] = -49.149459;
      val[1545 * nCulm + 1] = 25.211696;
      val[1545 * nCulm + 2] = -40.932849;
      val[1545 * nCulm + 3] = 12.052363;
      val[1545 * nCulm + 4] = 11.254470;
      val[1545 * nCulm + 5] = 15.902280;
      val[1546 * nCulm + 0] = -37.449524;
      val[1546 * nCulm + 1] = 17.972257;
      val[1546 * nCulm + 2] = 18.256212;
      val[1546 * nCulm + 3] = -27.899792;
      val[1546 * nCulm + 4] = 33.783427;
      val[1546 * nCulm + 5] = -1.160928;
      val[1547 * nCulm + 0] = -16.999676;
      val[1547 * nCulm + 1] = -37.266356;
      val[1547 * nCulm + 2] = 42.631347;
      val[1547 * nCulm + 3] = -3.510549;
      val[1547 * nCulm + 4] = 47.752376;
      val[1547 * nCulm + 5] = -3.811908;
      val[1548 * nCulm + 0] = 18.107811;
      val[1548 * nCulm + 1] = -31.151252;
      val[1548 * nCulm + 2] = -9.675914;
      val[1548 * nCulm + 3] = 36.188273;
      val[1548 * nCulm + 4] = 18.685278;
      val[1548 * nCulm + 5] = 1.505973;
      val[1549 * nCulm + 0] = -20.755216;
      val[1549 * nCulm + 1] = 27.824651;
      val[1549 * nCulm + 2] = 1.969754;
      val[1549 * nCulm + 3] = -10.669443;
      val[1549 * nCulm + 4] = 41.172658;
      val[1549 * nCulm + 5] = 2.202215;
      val[1550 * nCulm + 0] = 37.709273;
      val[1550 * nCulm + 1] = -4.531180;
      val[1550 * nCulm + 2] = 41.618792;
      val[1550 * nCulm + 3] = -19.649293;
      val[1550 * nCulm + 4] = 32.108251;
      val[1550 * nCulm + 5] = -3.334636;
      val[1551 * nCulm + 0] = -47.660932;
      val[1551 * nCulm + 1] = -1.950170;
      val[1551 * nCulm + 2] = -35.524779;
      val[1551 * nCulm + 3] = -41.873381;
      val[1551 * nCulm + 4] = -28.785654;
      val[1551 * nCulm + 5] = 7.436071;
      val[1552 * nCulm + 0] = 4.883052;
      val[1552 * nCulm + 1] = 7.431655;
      val[1552 * nCulm + 2] = -48.250530;
      val[1552 * nCulm + 3] = 43.126531;
      val[1552 * nCulm + 4] = -4.764836;
      val[1552 * nCulm + 5] = -49.993924;
      val[1553 * nCulm + 0] = -1.144183;
      val[1553 * nCulm + 1] = -22.917755;
      val[1553 * nCulm + 2] = -0.176627;
      val[1553 * nCulm + 3] = 39.580821;
      val[1553 * nCulm + 4] = 18.711271;
      val[1553 * nCulm + 5] = 4.445205;
      val[1554 * nCulm + 0] = -9.998896;
      val[1554 * nCulm + 1] = -19.092873;
      val[1554 * nCulm + 2] = -21.345195;
      val[1554 * nCulm + 3] = 36.658811;
      val[1554 * nCulm + 4] = -39.195979;
      val[1554 * nCulm + 5] = -1.891275;
      val[1555 * nCulm + 0] = -24.622362;
      val[1555 * nCulm + 1] = 14.069144;
      val[1555 * nCulm + 2] = 29.324960;
      val[1555 * nCulm + 3] = -15.058683;
      val[1555 * nCulm + 4] = -28.751329;
      val[1555 * nCulm + 5] = 0.392908;
      val[1556 * nCulm + 0] = 12.411861;
      val[1556 * nCulm + 1] = -10.394836;
      val[1556 * nCulm + 2] = 27.437718;
      val[1556 * nCulm + 3] = 37.011287;
      val[1556 * nCulm + 4] = 4.430558;
      val[1556 * nCulm + 5] = 28.665362;
      val[1557 * nCulm + 0] = 18.713682;
      val[1557 * nCulm + 1] = -5.145747;
      val[1557 * nCulm + 2] = -49.545811;
      val[1557 * nCulm + 3] = -49.888967;
      val[1557 * nCulm + 4] = 30.462391;
      val[1557 * nCulm + 5] = -8.321451;
      val[1558 * nCulm + 0] = -3.330734;
      val[1558 * nCulm + 1] = 29.394762;
      val[1558 * nCulm + 2] = 25.285019;
      val[1558 * nCulm + 3] = 4.977161;
      val[1558 * nCulm + 4] = 28.803693;
      val[1558 * nCulm + 5] = 5.878365;
      val[1559 * nCulm + 0] = 2.027056;
      val[1559 * nCulm + 1] = 10.036671;
      val[1559 * nCulm + 2] = 11.969545;
      val[1559 * nCulm + 3] = 27.594660;
      val[1559 * nCulm + 4] = 41.236015;
      val[1559 * nCulm + 5] = 4.549565;
      val[1560 * nCulm + 0] = 13.684916;
      val[1560 * nCulm + 1] = 17.001725;
      val[1560 * nCulm + 2] = 3.379865;
      val[1560 * nCulm + 3] = 46.420379;
      val[1560 * nCulm + 4] = 5.952046;
      val[1560 * nCulm + 5] = 50.666095;
      val[1561 * nCulm + 0] = 22.498356;
      val[1561 * nCulm + 1] = -40.614999;
      val[1561 * nCulm + 2] = 15.505977;
      val[1561 * nCulm + 3] = -36.834539;
      val[1561 * nCulm + 4] = -11.499447;
      val[1561 * nCulm + 5] = 32.109313;
      val[1562 * nCulm + 0] = -28.468164;
      val[1562 * nCulm + 1] = -44.974929;
      val[1562 * nCulm + 2] = -14.495374;
      val[1562 * nCulm + 3] = -6.793603;
      val[1562 * nCulm + 4] = 13.634682;
      val[1562 * nCulm + 5] = -17.741649;
      val[1563 * nCulm + 0] = -49.846460;
      val[1563 * nCulm + 1] = -14.708410;
      val[1563 * nCulm + 2] = -32.990373;
      val[1563 * nCulm + 3] = -15.686743;
      val[1563 * nCulm + 4] = -22.258072;
      val[1563 * nCulm + 5] = 6.693740;
      val[1564 * nCulm + 0] = 8.099681;
      val[1564 * nCulm + 1] = -26.265232;
      val[1564 * nCulm + 2] = -26.624199;
      val[1564 * nCulm + 3] = 11.796339;
      val[1564 * nCulm + 4] = 30.045471;
      val[1564 * nCulm + 5] = -2.049415;
      val[1565 * nCulm + 0] = -43.483687;
      val[1565 * nCulm + 1] = 15.503683;
      val[1565 * nCulm + 2] = 39.216579;
      val[1565 * nCulm + 3] = -10.676736;
      val[1565 * nCulm + 4] = -49.468802;
      val[1565 * nCulm + 5] = -0.231858;
      val[1566 * nCulm + 0] = 49.476338;
      val[1566 * nCulm + 1] = 47.885482;
      val[1566 * nCulm + 2] = 24.955043;
      val[1566 * nCulm + 3] = 29.469928;
      val[1566 * nCulm + 4] = 28.227333;
      val[1566 * nCulm + 5] = 13.201432;
      val[1567 * nCulm + 0] = -30.710144;
      val[1567 * nCulm + 1] = 21.922746;
      val[1567 * nCulm + 2] = -49.898927;
      val[1567 * nCulm + 3] = 42.375831;
      val[1567 * nCulm + 4] = -41.506916;
      val[1567 * nCulm + 5] = -7.102431;
      val[1568 * nCulm + 0] = 26.913518;
      val[1568 * nCulm + 1] = 46.348503;
      val[1568 * nCulm + 2] = -39.743615;
      val[1568 * nCulm + 3] = 48.524351;
      val[1568 * nCulm + 4] = -16.483762;
      val[1568 * nCulm + 5] = -27.012861;
      val[1569 * nCulm + 0] = 12.465167;
      val[1569 * nCulm + 1] = 34.457448;
      val[1569 * nCulm + 2] = 23.569605;
      val[1569 * nCulm + 3] = -28.416817;
      val[1569 * nCulm + 4] = 28.088109;
      val[1569 * nCulm + 5] = 1.247951;
      val[1570 * nCulm + 0] = 25.481826;
      val[1570 * nCulm + 1] = -43.291675;
      val[1570 * nCulm + 2] = 33.914560;
      val[1570 * nCulm + 3] = -30.984949;
      val[1570 * nCulm + 4] = -25.208861;
      val[1570 * nCulm + 5] = 14.176526;
      val[1571 * nCulm + 0] = 8.989085;
      val[1571 * nCulm + 1] = -17.031419;
      val[1571 * nCulm + 2] = 9.516098;
      val[1571 * nCulm + 3] = -35.941171;
      val[1571 * nCulm + 4] = 37.000425;
      val[1571 * nCulm + 5] = -6.546596;
      val[1572 * nCulm + 0] = 26.228242;
      val[1572 * nCulm + 1] = -30.202101;
      val[1572 * nCulm + 2] = -15.123321;
      val[1572 * nCulm + 3] = 4.022430;
      val[1572 * nCulm + 4] = -26.502869;
      val[1572 * nCulm + 5] = 4.905611;
      val[1573 * nCulm + 0] = 6.523449;
      val[1573 * nCulm + 1] = -20.146372;
      val[1573 * nCulm + 2] = 27.618378;
      val[1573 * nCulm + 3] = 22.892438;
      val[1573 * nCulm + 4] = 47.863202;
      val[1573 * nCulm + 5] = 0.501567;
      val[1574 * nCulm + 0] = 15.064375;
      val[1574 * nCulm + 1] = 46.365274;
      val[1574 * nCulm + 2] = 7.722857;
      val[1574 * nCulm + 3] = 30.159476;
      val[1574 * nCulm + 4] = 29.116230;
      val[1574 * nCulm + 5] = 12.670386;
      val[1575 * nCulm + 0] = 15.573522;
      val[1575 * nCulm + 1] = 47.080079;
      val[1575 * nCulm + 2] = 9.006144;
      val[1575 * nCulm + 3] = -17.012109;
      val[1575 * nCulm + 4] = 31.906811;
      val[1575 * nCulm + 5] = 4.690544;
      val[1576 * nCulm + 0] = 18.088877;
      val[1576 * nCulm + 1] = 26.043909;
      val[1576 * nCulm + 2] = -47.272942;
      val[1576 * nCulm + 3] = 11.410835;
      val[1576 * nCulm + 4] = -14.382832;
      val[1576 * nCulm + 5] = -12.096209;
      val[1577 * nCulm + 0] = 16.342303;
      val[1577 * nCulm + 1] = -24.548772;
      val[1577 * nCulm + 2] = -42.777990;
      val[1577 * nCulm + 3] = 15.472906;
      val[1577 * nCulm + 4] = 29.732366;
      val[1577 * nCulm + 5] = -1.214860;
      val[1578 * nCulm + 0] = -6.598292;
      val[1578 * nCulm + 1] = 11.958629;
      val[1578 * nCulm + 2] = -34.295783;
      val[1578 * nCulm + 3] = -3.353681;
      val[1578 * nCulm + 4] = 36.306831;
      val[1578 * nCulm + 5] = 1.351830;
      val[1579 * nCulm + 0] = -21.446845;
      val[1579 * nCulm + 1] = -29.062818;
      val[1579 * nCulm + 2] = 34.579903;
      val[1579 * nCulm + 3] = -39.017760;
      val[1579 * nCulm + 4] = 30.798603;
      val[1579 * nCulm + 5] = -10.233074;
      val[1580 * nCulm + 0] = 23.453561;
      val[1580 * nCulm + 1] = 24.697852;
      val[1580 * nCulm + 2] = 36.787928;
      val[1580 * nCulm + 3] = -25.855121;
      val[1580 * nCulm + 4] = 32.139084;
      val[1580 * nCulm + 5] = 0.059561;
      val[1581 * nCulm + 0] = 3.254324;
      val[1581 * nCulm + 1] = 19.287483;
      val[1581 * nCulm + 2] = -30.532911;
      val[1581 * nCulm + 3] = 12.057562;
      val[1581 * nCulm + 4] = -37.370725;
      val[1581 * nCulm + 5] = -3.740128;
      val[1582 * nCulm + 0] = -10.600947;
      val[1582 * nCulm + 1] = -37.821623;
      val[1582 * nCulm + 2] = 16.337724;
      val[1582 * nCulm + 3] = 32.575841;
      val[1582 * nCulm + 4] = 16.654598;
      val[1582 * nCulm + 5] = -1.260882;
      val[1583 * nCulm + 0] = -29.691512;
      val[1583 * nCulm + 1] = 36.437879;
      val[1583 * nCulm + 2] = 2.117813;
      val[1583 * nCulm + 3] = 2.330557;
      val[1583 * nCulm + 4] = -3.904797;
      val[1583 * nCulm + 5] = -46.764482;
      val[1584 * nCulm + 0] = 48.152229;
      val[1584 * nCulm + 1] = -23.661897;
      val[1584 * nCulm + 2] = 37.940938;
      val[1584 * nCulm + 3] = -40.784591;
      val[1584 * nCulm + 4] = -46.239581;
      val[1584 * nCulm + 5] = 6.827091;
      val[1585 * nCulm + 0] = 17.975858;
      val[1585 * nCulm + 1] = 49.407466;
      val[1585 * nCulm + 2] = -33.422064;
      val[1585 * nCulm + 3] = 38.626703;
      val[1585 * nCulm + 4] = 24.240099;
      val[1585 * nCulm + 5] = 17.420320;
      val[1586 * nCulm + 0] = 11.373914;
      val[1586 * nCulm + 1] = -16.876715;
      val[1586 * nCulm + 2] = 23.686177;
      val[1586 * nCulm + 3] = -21.927179;
      val[1586 * nCulm + 4] = 22.186432;
      val[1586 * nCulm + 5] = -8.048562;
      val[1587 * nCulm + 0] = 33.087400;
      val[1587 * nCulm + 1] = 29.013057;
      val[1587 * nCulm + 2] = -39.387597;
      val[1587 * nCulm + 3] = -24.738904;
      val[1587 * nCulm + 4] = 34.232531;
      val[1587 * nCulm + 5] = 0.820987;
      val[1588 * nCulm + 0] = -1.497381;
      val[1588 * nCulm + 1] = 26.193839;
      val[1588 * nCulm + 2] = 1.315198;
      val[1588 * nCulm + 3] = 27.449918;
      val[1588 * nCulm + 4] = -15.606432;
      val[1588 * nCulm + 5] = -16.039817;
      val[1589 * nCulm + 0] = -6.521336;
      val[1589 * nCulm + 1] = -30.433223;
      val[1589 * nCulm + 2] = 39.110991;
      val[1589 * nCulm + 3] = 43.070969;
      val[1589 * nCulm + 4] = 0.456198;
      val[1589 * nCulm + 5] = 131.354275;
      val[1590 * nCulm + 0] = -47.171940;
      val[1590 * nCulm + 1] = -26.238265;
      val[1590 * nCulm + 2] = 18.681522;
      val[1590 * nCulm + 3] = -44.605665;
      val[1590 * nCulm + 4] = -12.579107;
      val[1590 * nCulm + 5] = 26.887531;
      val[1591 * nCulm + 0] = 34.451441;
      val[1591 * nCulm + 1] = 47.299580;
      val[1591 * nCulm + 2] = -34.997683;
      val[1591 * nCulm + 3] = -30.901176;
      val[1591 * nCulm + 4] = 15.923092;
      val[1591 * nCulm + 5] = 5.104626;
      val[1592 * nCulm + 0] = -21.313762;
      val[1592 * nCulm + 1] = -4.262101;
      val[1592 * nCulm + 2] = -9.538916;
      val[1592 * nCulm + 3] = 18.134222;
      val[1592 * nCulm + 4] = -12.819453;
      val[1592 * nCulm + 5] = -4.892011;
      val[1593 * nCulm + 0] = 31.350086;
      val[1593 * nCulm + 1] = 5.771348;
      val[1593 * nCulm + 2] = -40.223497;
      val[1593 * nCulm + 3] = -42.449776;
      val[1593 * nCulm + 4] = 13.648241;
      val[1593 * nCulm + 5] = -12.490411;
      val[1594 * nCulm + 0] = -39.343012;
      val[1594 * nCulm + 1] = -3.270120;
      val[1594 * nCulm + 2] = -22.383411;
      val[1594 * nCulm + 3] = -34.005469;
      val[1594 * nCulm + 4] = -40.733838;
      val[1594 * nCulm + 5] = 4.561480;
      val[1595 * nCulm + 0] = 22.160174;
      val[1595 * nCulm + 1] = -48.016306;
      val[1595 * nCulm + 2] = -16.373425;
      val[1595 * nCulm + 3] = 8.064724;
      val[1595 * nCulm + 4] = 30.377889;
      val[1595 * nCulm + 5] = -5.995059;
      val[1596 * nCulm + 0] = -6.092408;
      val[1596 * nCulm + 1] = 30.922928;
      val[1596 * nCulm + 2] = -30.671774;
      val[1596 * nCulm + 3] = 10.079401;
      val[1596 * nCulm + 4] = 15.006215;
      val[1596 * nCulm + 5] = 13.163154;
      val[1597 * nCulm + 0] = 41.691834;
      val[1597 * nCulm + 1] = -32.050405;
      val[1597 * nCulm + 2] = -4.913622;
      val[1597 * nCulm + 3] = -21.527889;
      val[1597 * nCulm + 4] = 34.373394;
      val[1597 * nCulm + 5] = -7.147913;
      val[1598 * nCulm + 0] = -44.662449;
      val[1598 * nCulm + 1] = 17.726482;
      val[1598 * nCulm + 2] = 11.716815;
      val[1598 * nCulm + 3] = -40.125282;
      val[1598 * nCulm + 4] = -29.098942;
      val[1598 * nCulm + 5] = 3.873465;
      val[1599 * nCulm + 0] = 26.304885;
      val[1599 * nCulm + 1] = -14.966121;
      val[1599 * nCulm + 2] = 29.479150;
      val[1599 * nCulm + 3] = -39.723968;
      val[1599 * nCulm + 4] = -26.651928;
      val[1599 * nCulm + 5] = 9.942859;
      val[1600 * nCulm + 0] = -10.281304;
      val[1600 * nCulm + 1] = -8.432141;
      val[1600 * nCulm + 2] = -4.549281;
      val[1600 * nCulm + 3] = 21.426017;
      val[1600 * nCulm + 4] = 35.151526;
      val[1600 * nCulm + 5] = 1.979692;
      val[1601 * nCulm + 0] = -11.031151;
      val[1601 * nCulm + 1] = 22.418847;
      val[1601 * nCulm + 2] = -12.889052;
      val[1601 * nCulm + 3] = 25.520290;
      val[1601 * nCulm + 4] = -28.529224;
      val[1601 * nCulm + 5] = -7.723666;
      val[1602 * nCulm + 0] = 11.818810;
      val[1602 * nCulm + 1] = -37.690646;
      val[1602 * nCulm + 2] = 45.441984;
      val[1602 * nCulm + 3] = -42.239554;
      val[1602 * nCulm + 4] = -0.729372;
      val[1602 * nCulm + 5] = 518.945272;
      val[1603 * nCulm + 0] = 20.104703;
      val[1603 * nCulm + 1] = 9.248800;
      val[1603 * nCulm + 2] = 19.967640;
      val[1603 * nCulm + 3] = -32.795845;
      val[1603 * nCulm + 4] = 41.625346;
      val[1603 * nCulm + 5] = -2.447600;
      val[1604 * nCulm + 0] = 9.055093;
      val[1604 * nCulm + 1] = -36.026719;
      val[1604 * nCulm + 2] = -1.390782;
      val[1604 * nCulm + 3] = -26.757043;
      val[1604 * nCulm + 4] = -44.410966;
      val[1604 * nCulm + 5] = 6.921511;
      val[1605 * nCulm + 0] = -12.143699;
      val[1605 * nCulm + 1] = 16.751927;
      val[1605 * nCulm + 2] = 17.186699;
      val[1605 * nCulm + 3] = 19.804852;
      val[1605 * nCulm + 4] = 19.074723;
      val[1605 * nCulm + 5] = 9.301451;
      val[1606 * nCulm + 0] = -5.713417;
      val[1606 * nCulm + 1] = -17.603719;
      val[1606 * nCulm + 2] = -35.365598;
      val[1606 * nCulm + 3] = 33.291505;
      val[1606 * nCulm + 4] = 46.817096;
      val[1606 * nCulm + 5] = 1.816077;
      val[1607 * nCulm + 0] = 37.193258;
      val[1607 * nCulm + 1] = 9.045285;
      val[1607 * nCulm + 2] = -3.392706;
      val[1607 * nCulm + 3] = -30.028942;
      val[1607 * nCulm + 4] = 36.483587;
      val[1607 * nCulm + 5] = -2.492393;
      val[1608 * nCulm + 0] = -15.679626;
      val[1608 * nCulm + 1] = 14.090272;
      val[1608 * nCulm + 2] = 38.269296;
      val[1608 * nCulm + 3] = 11.223525;
      val[1608 * nCulm + 4] = -26.528263;
      val[1608 * nCulm + 5] = -4.286641;
      val[1609 * nCulm + 0] = -10.165483;
      val[1609 * nCulm + 1] = -3.833363;
      val[1609 * nCulm + 2] = 43.173056;
      val[1609 * nCulm + 3] = -47.249115;
      val[1609 * nCulm + 4] = 45.460021;
      val[1609 * nCulm + 5] = -5.088748;
      val[1610 * nCulm + 0] = -26.901031;
      val[1610 * nCulm + 1] = 5.474808;
      val[1610 * nCulm + 2] = 35.529093;
      val[1610 * nCulm + 3] = -30.383539;
      val[1610 * nCulm + 4] = -27.179728;
      val[1610 * nCulm + 5] = 4.567840;
      val[1611 * nCulm + 0] = 45.637150;
      val[1611 * nCulm + 1] = -24.670242;
      val[1611 * nCulm + 2] = -15.629902;
      val[1611 * nCulm + 3] = -28.455993;
      val[1611 * nCulm + 4] = -9.707114;
      val[1611 * nCulm + 5] = 26.135143;
      val[1612 * nCulm + 0] = 14.183903;
      val[1612 * nCulm + 1] = -7.567005;
      val[1612 * nCulm + 2] = -4.587773;
      val[1612 * nCulm + 3] = -43.656590;
      val[1612 * nCulm + 4] = 39.670011;
      val[1612 * nCulm + 5] = -5.881880;
      val[1613 * nCulm + 0] = -16.972524;
      val[1613 * nCulm + 1] = -38.723292;
      val[1613 * nCulm + 2] = 18.641773;
      val[1613 * nCulm + 3] = -37.147849;
      val[1613 * nCulm + 4] = -40.583301;
      val[1613 * nCulm + 5] = 9.079044;
      val[1614 * nCulm + 0] = -35.432248;
      val[1614 * nCulm + 1] = 11.533543;
      val[1614 * nCulm + 2] = 4.066321;
      val[1614 * nCulm + 3] = 2.895596;
      val[1614 * nCulm + 4] = 6.862136;
      val[1614 * nCulm + 5] = 10.182867;
      val[1615 * nCulm + 0] = 11.924666;
      val[1615 * nCulm + 1] = 21.336045;
      val[1615 * nCulm + 2] = -19.213106;
      val[1615 * nCulm + 3] = 15.161860;
      val[1615 * nCulm + 4] = -6.567274;
      val[1615 * nCulm + 5] = -26.075701;
      val[1616 * nCulm + 0] = 15.331456;
      val[1616 * nCulm + 1] = -30.393408;
      val[1616 * nCulm + 2] = 25.273733;
      val[1616 * nCulm + 3] = -34.285381;
      val[1616 * nCulm + 4] = 22.475466;
      val[1616 * nCulm + 5] = -13.391354;
      val[1617 * nCulm + 0] = -19.940325;
      val[1617 * nCulm + 1] = 41.559705;
      val[1617 * nCulm + 2] = 32.692830;
      val[1617 * nCulm + 3] = -3.466693;
      val[1617 * nCulm + 4] = 23.748872;
      val[1617 * nCulm + 5] = 7.822231;
      val[1618 * nCulm + 0] = -42.232498;
      val[1618 * nCulm + 1] = 28.775252;
      val[1618 * nCulm + 2] = 13.033653;
      val[1618 * nCulm + 3] = 12.222386;
      val[1618 * nCulm + 4] = 13.456698;
      val[1618 * nCulm + 5] = 14.650736;
      val[1619 * nCulm + 0] = -34.558294;
      val[1619 * nCulm + 1] = 18.702647;
      val[1619 * nCulm + 2] = 38.100924;
      val[1619 * nCulm + 3] = -4.329175;
      val[1619 * nCulm + 4] = -29.162744;
      val[1619 * nCulm + 5] = -2.102923;
      val[1620 * nCulm + 0] = 38.183164;
      val[1620 * nCulm + 1] = -3.053592;
      val[1620 * nCulm + 2] = -34.308435;
      val[1620 * nCulm + 3] = -43.048188;
      val[1620 * nCulm + 4] = 29.613142;
      val[1620 * nCulm + 5] = -7.138860;
      val[1621 * nCulm + 0] = -47.991780;
      val[1621 * nCulm + 1] = -24.082342;
      val[1621 * nCulm + 2] = -16.258721;
      val[1621 * nCulm + 3] = 33.284111;
      val[1621 * nCulm + 4] = -42.023353;
      val[1621 * nCulm + 5] = -0.806448;
      val[1622 * nCulm + 0] = -35.920829;
      val[1622 * nCulm + 1] = -1.944720;
      val[1622 * nCulm + 2] = 4.786163;
      val[1622 * nCulm + 3] = 21.982521;
      val[1622 * nCulm + 4] = 45.221122;
      val[1622 * nCulm + 5] = 2.327374;
      val[1623 * nCulm + 0] = 32.859386;
      val[1623 * nCulm + 1] = -24.969364;
      val[1623 * nCulm + 2] = -6.233073;
      val[1623 * nCulm + 3] = -3.180659;
      val[1623 * nCulm + 4] = 38.701708;
      val[1623 * nCulm + 5] = -3.212831;
      val[1624 * nCulm + 0] = -48.711005;
      val[1624 * nCulm + 1] = -4.772324;
      val[1624 * nCulm + 2] = 11.519404;
      val[1624 * nCulm + 3] = 3.275615;
      val[1624 * nCulm + 4] = 44.838707;
      val[1624 * nCulm + 5] = 0.072002;
      val[1625 * nCulm + 0] = -12.218546;
      val[1625 * nCulm + 1] = -25.188971;
      val[1625 * nCulm + 2] = -44.432959;
      val[1625 * nCulm + 3] = -40.015112;
      val[1625 * nCulm + 4] = -27.236463;
      val[1625 * nCulm + 5] = 11.561599;
      val[1626 * nCulm + 0] = -45.696329;
      val[1626 * nCulm + 1] = 43.766177;
      val[1626 * nCulm + 2] = -31.789835;
      val[1626 * nCulm + 3] = 6.643310;
      val[1626 * nCulm + 4] = -30.681917;
      val[1626 * nCulm + 5] = -7.546727;
      val[1627 * nCulm + 0] = -18.077420;
      val[1627 * nCulm + 1] = -43.372946;
      val[1627 * nCulm + 2] = -17.933889;
      val[1627 * nCulm + 3] = 33.807747;
      val[1627 * nCulm + 4] = 17.619479;
      val[1627 * nCulm + 5] = -2.339615;
      val[1628 * nCulm + 0] = 15.172960;
      val[1628 * nCulm + 1] = -11.519332;
      val[1628 * nCulm + 2] = -37.063724;
      val[1628 * nCulm + 3] = 27.128719;
      val[1628 * nCulm + 4] = -6.447040;
      val[1628 * nCulm + 5] = -11.230209;
      val[1629 * nCulm + 0] = -14.875245;
      val[1629 * nCulm + 1] = -23.007363;
      val[1629 * nCulm + 2] = 5.037985;
      val[1629 * nCulm + 3] = -29.332707;
      val[1629 * nCulm + 4] = -15.374904;
      val[1629 * nCulm + 5] = 16.343467;
      val[1630 * nCulm + 0] = -46.869965;
      val[1630 * nCulm + 1] = 6.148490;
      val[1630 * nCulm + 2] = -0.548631;
      val[1630 * nCulm + 3] = 24.894914;
      val[1630 * nCulm + 4] = 3.123042;
      val[1630 * nCulm + 5] = 47.279889;
      val[1631 * nCulm + 0] = -32.706497;
      val[1631 * nCulm + 1] = 9.968410;
      val[1631 * nCulm + 2] = 31.066563;
      val[1631 * nCulm + 3] = -11.914135;
      val[1631 * nCulm + 4] = 27.232232;
      val[1631 * nCulm + 5] = -0.108194;
      val[1632 * nCulm + 0] = 21.658223;
      val[1632 * nCulm + 1] = 12.464535;
      val[1632 * nCulm + 2] = -43.026420;
      val[1632 * nCulm + 3] = 47.487296;
      val[1632 * nCulm + 4] = -42.856855;
      val[1632 * nCulm + 5] = -6.391391;
      val[1633 * nCulm + 0] = 23.051071;
      val[1633 * nCulm + 1] = -21.331944;
      val[1633 * nCulm + 2] = -20.144395;
      val[1633 * nCulm + 3] = 42.031328;
      val[1633 * nCulm + 4] = -45.067068;
      val[1633 * nCulm + 5] = -1.944028;
      val[1634 * nCulm + 0] = -6.880396;
      val[1634 * nCulm + 1] = -10.903732;
      val[1634 * nCulm + 2] = -36.492237;
      val[1634 * nCulm + 3] = -41.607016;
      val[1634 * nCulm + 4] = -39.262072;
      val[1634 * nCulm + 5] = 6.560559;
      val[1635 * nCulm + 0] = -12.815815;
      val[1635 * nCulm + 1] = -34.173366;
      val[1635 * nCulm + 2] = 4.947062;
      val[1635 * nCulm + 3] = -21.200317;
      val[1635 * nCulm + 4] = 4.313615;
      val[1635 * nCulm + 5] = -60.531583;
      val[1636 * nCulm + 0] = 15.221417;
      val[1636 * nCulm + 1] = -8.637676;
      val[1636 * nCulm + 2] = 20.777455;
      val[1636 * nCulm + 3] = -16.256213;
      val[1636 * nCulm + 4] = 46.811584;
      val[1636 * nCulm + 5] = -2.287135;
      val[1637 * nCulm + 0] = -37.924484;
      val[1637 * nCulm + 1] = -28.776324;
      val[1637 * nCulm + 2] = -43.316331;
      val[1637 * nCulm + 3] = -2.998386;
      val[1637 * nCulm + 4] = 36.285628;
      val[1637 * nCulm + 5] = -3.914900;
      val[1638 * nCulm + 0] = -30.610296;
      val[1638 * nCulm + 1] = -5.064327;
      val[1638 * nCulm + 2] = 9.335605;
      val[1638 * nCulm + 3] = 29.708488;
      val[1638 * nCulm + 4] = 49.849135;
      val[1638 * nCulm + 5] = 2.570041;
      val[1639 * nCulm + 0] = 30.405954;
      val[1639 * nCulm + 1] = 29.495295;
      val[1639 * nCulm + 2] = 3.734123;
      val[1639 * nCulm + 3] = 48.018669;
      val[1639 * nCulm + 4] = 24.188945;
      val[1639 * nCulm + 5] = 15.398062;
      val[1640 * nCulm + 0] = 47.366525;
      val[1640 * nCulm + 1] = 15.843452;
      val[1640 * nCulm + 2] = -31.944765;
      val[1640 * nCulm + 3] = 32.668548;
      val[1640 * nCulm + 4] = 10.580370;
      val[1640 * nCulm + 5] = 21.932782;
      val[1641 * nCulm + 0] = -36.374110;
      val[1641 * nCulm + 1] = -49.035789;
      val[1641 * nCulm + 2] = -16.794029;
      val[1641 * nCulm + 3] = 26.985807;
      val[1641 * nCulm + 4] = -38.362355;
      val[1641 * nCulm + 5] = 2.950634;
      val[1642 * nCulm + 0] = -42.872644;
      val[1642 * nCulm + 1] = 39.386439;
      val[1642 * nCulm + 2] = 9.633973;
      val[1642 * nCulm + 3] = 38.253519;
      val[1642 * nCulm + 4] = 34.172496;
      val[1642 * nCulm + 5] = 10.984140;
      val[1643 * nCulm + 0] = 10.432742;
      val[1643 * nCulm + 1] = -33.199282;
      val[1643 * nCulm + 2] = 41.566618;
      val[1643 * nCulm + 3] = -0.578191;
      val[1643 * nCulm + 4] = -43.970248;
      val[1643 * nCulm + 5] = 3.866096;
      val[1644 * nCulm + 0] = 5.611141;
      val[1644 * nCulm + 1] = -38.100593;
      val[1644 * nCulm + 2] = -36.466129;
      val[1644 * nCulm + 3] = -2.133410;
      val[1644 * nCulm + 4] = 39.807047;
      val[1644 * nCulm + 5] = -4.554101;
      val[1645 * nCulm + 0] = -20.919746;
      val[1645 * nCulm + 1] = -6.523176;
      val[1645 * nCulm + 2] = 38.951260;
      val[1645 * nCulm + 3] = -24.613601;
      val[1645 * nCulm + 4] = 0.725069;
      val[1645 * nCulm + 5] = -203.034469;
      val[1646 * nCulm + 0] = -16.587772;
      val[1646 * nCulm + 1] = -48.950501;
      val[1646 * nCulm + 2] = 0.904666;
      val[1646 * nCulm + 3] = -16.494648;
      val[1646 * nCulm + 4] = -48.453413;
      val[1646 * nCulm + 5] = 6.623228;
      val[1647 * nCulm + 0] = 26.839514;
      val[1647 * nCulm + 1] = -43.338326;
      val[1647 * nCulm + 2] = -37.081042;
      val[1647 * nCulm + 3] = -11.306041;
      val[1647 * nCulm + 4] = -1.385849;
      val[1647 * nCulm + 5] = 186.866453;
      val[1648 * nCulm + 0] = -5.219106;
      val[1648 * nCulm + 1] = 21.594692;
      val[1648 * nCulm + 2] = -2.498893;
      val[1648 * nCulm + 3] = -25.490267;
      val[1648 * nCulm + 4] = 20.582901;
      val[1648 * nCulm + 5] = -0.665843;
      val[1649 * nCulm + 0] = -13.629520;
      val[1649 * nCulm + 1] = -45.375785;
      val[1649 * nCulm + 2] = 11.463652;
      val[1649 * nCulm + 3] = 39.002630;
      val[1649 * nCulm + 4] = 35.336790;
      val[1649 * nCulm + 5] = -0.623679;
      val[1650 * nCulm + 0] = -42.850149;
      val[1650 * nCulm + 1] = 12.015313;
      val[1650 * nCulm + 2] = 31.582314;
      val[1650 * nCulm + 3] = -3.755952;
      val[1650 * nCulm + 4] = 35.606624;
      val[1650 * nCulm + 5] = 1.327951;
      val[1651 * nCulm + 0] = -33.936930;
      val[1651 * nCulm + 1] = -27.472973;
      val[1651 * nCulm + 2] = 40.929512;
      val[1651 * nCulm + 3] = 43.010766;
      val[1651 * nCulm + 4] = -3.388925;
      val[1651 * nCulm + 5] = -21.471735;
      val[1652 * nCulm + 0] = -44.316679;
      val[1652 * nCulm + 1] = 13.067323;
      val[1652 * nCulm + 2] = -17.073322;
      val[1652 * nCulm + 3] = -8.165354;
      val[1652 * nCulm + 4] = 5.293661;
      val[1652 * nCulm + 5] = 4.613102;
      val[1653 * nCulm + 0] = -0.538331;
      val[1653 * nCulm + 1] = 44.578052;
      val[1653 * nCulm + 2] = -28.589157;
      val[1653 * nCulm + 3] = 29.543259;
      val[1653 * nCulm + 4] = -42.544693;
      val[1653 * nCulm + 5] = -8.016407;
      val[1654 * nCulm + 0] = 23.177306;
      val[1654 * nCulm + 1] = 14.664021;
      val[1654 * nCulm + 2] = -24.027494;
      val[1654 * nCulm + 3] = 28.166914;
      val[1654 * nCulm + 4] = -1.667036;
      val[1654 * nCulm + 5] = -121.382934;
      val[1655 * nCulm + 0] = -21.365791;
      val[1655 * nCulm + 1] = 35.232470;
      val[1655 * nCulm + 2] = 45.975835;
      val[1655 * nCulm + 3] = 34.892859;
      val[1655 * nCulm + 4] = -24.329865;
      val[1655 * nCulm + 5] = -13.412762;
      val[1656 * nCulm + 0] = 22.261212;
      val[1656 * nCulm + 1] = -42.076458;
      val[1656 * nCulm + 2] = -20.706620;
      val[1656 * nCulm + 3] = 3.361653;
      val[1656 * nCulm + 4] = -13.040802;
      val[1656 * nCulm + 5] = 14.282055;
      val[1657 * nCulm + 0] = 7.382506;
      val[1657 * nCulm + 1] = 40.754292;
      val[1657 * nCulm + 2] = 36.980056;
      val[1657 * nCulm + 3] = -20.507573;
      val[1657 * nCulm + 4] = -48.068528;
      val[1657 * nCulm + 5] = -1.763705;
      val[1658 * nCulm + 0] = 11.104712;
      val[1658 * nCulm + 1] = 6.418017;
      val[1658 * nCulm + 2] = -18.651483;
      val[1658 * nCulm + 3] = -34.073917;
      val[1658 * nCulm + 4] = -14.113413;
      val[1658 * nCulm + 5] = 9.505190;
      val[1659 * nCulm + 0] = -23.116998;
      val[1659 * nCulm + 1] = -12.136289;
      val[1659 * nCulm + 2] = -44.385330;
      val[1659 * nCulm + 3] = 46.285983;
      val[1659 * nCulm + 4] = 40.891474;
      val[1659 * nCulm + 5] = 4.182948;
      val[1660 * nCulm + 0] = 49.289469;
      val[1660 * nCulm + 1] = -13.733689;
      val[1660 * nCulm + 2] = 35.337957;
      val[1660 * nCulm + 3] = -26.989979;
      val[1660 * nCulm + 4] = 23.309633;
      val[1660 * nCulm + 5] = -8.039487;
      val[1661 * nCulm + 0] = -28.541152;
      val[1661 * nCulm + 1] = 5.679186;
      val[1661 * nCulm + 2] = 26.586554;
      val[1661 * nCulm + 3] = -32.889307;
      val[1661 * nCulm + 4] = 37.317469;
      val[1661 * nCulm + 5] = -3.221321;
      val[1662 * nCulm + 0] = 11.831219;
      val[1662 * nCulm + 1] = -7.648580;
      val[1662 * nCulm + 2] = -16.895808;
      val[1662 * nCulm + 3] = 43.757053;
      val[1662 * nCulm + 4] = 18.816473;
      val[1662 * nCulm + 5] = 9.313181;
      val[1663 * nCulm + 0] = -0.929537;
      val[1663 * nCulm + 1] = 32.713868;
      val[1663 * nCulm + 2] = 45.154448;
      val[1663 * nCulm + 3] = 0.457387;
      val[1663 * nCulm + 4] = 5.276081;
      val[1663 * nCulm + 5] = 29.988942;
      val[1664 * nCulm + 0] = 1.566648;
      val[1664 * nCulm + 1] = 34.681802;
      val[1664 * nCulm + 2] = -31.047678;
      val[1664 * nCulm + 3] = -7.754443;
      val[1664 * nCulm + 4] = -13.056363;
      val[1664 * nCulm + 5] = -9.531996;
      val[1665 * nCulm + 0] = -40.150295;
      val[1665 * nCulm + 1] = -17.002711;
      val[1665 * nCulm + 2] = 49.286480;
      val[1665 * nCulm + 3] = 6.718814;
      val[1665 * nCulm + 4] = -22.590454;
      val[1665 * nCulm + 5] = 2.384765;
      val[1666 * nCulm + 0] = 2.041013;
      val[1666 * nCulm + 1] = -2.263160;
      val[1666 * nCulm + 2] = -8.856573;
      val[1666 * nCulm + 3] = -10.604402;
      val[1666 * nCulm + 4] = 1.500146;
      val[1666 * nCulm + 5] = -40.370366;
      val[1667 * nCulm + 0] = -42.535410;
      val[1667 * nCulm + 1] = 17.597880;
      val[1667 * nCulm + 2] = -47.779513;
      val[1667 * nCulm + 3] = -49.000267;
      val[1667 * nCulm + 4] = 29.532920;
      val[1667 * nCulm + 5] = -4.802959;
      val[1668 * nCulm + 0] = 40.741981;
      val[1668 * nCulm + 1] = 46.635578;
      val[1668 * nCulm + 2] = -7.582977;
      val[1668 * nCulm + 3] = -22.698604;
      val[1668 * nCulm + 4] = 4.164890;
      val[1668 * nCulm + 5] = 27.434001;
      val[1669 * nCulm + 0] = -49.444228;
      val[1669 * nCulm + 1] = 0.647972;
      val[1669 * nCulm + 2] = -25.030053;
      val[1669 * nCulm + 3] = 30.773414;
      val[1669 * nCulm + 4] = -38.339869;
      val[1669 * nCulm + 5] = -3.649197;
      val[1670 * nCulm + 0] = -33.024833;
      val[1670 * nCulm + 1] = -16.152862;
      val[1670 * nCulm + 2] = 22.677509;
      val[1670 * nCulm + 3] = -6.843894;
      val[1670 * nCulm + 4] = 21.576346;
      val[1670 * nCulm + 5] = -4.814937;
      val[1671 * nCulm + 0] = -35.395710;
      val[1671 * nCulm + 1] = -43.112723;
      val[1671 * nCulm + 2] = 10.184739;
      val[1671 * nCulm + 3] = 25.528495;
      val[1671 * nCulm + 4] = 33.178496;
      val[1671 * nCulm + 5] = -2.278613;
      val[1672 * nCulm + 0] = -36.956463;
      val[1672 * nCulm + 1] = -21.358443;
      val[1672 * nCulm + 2] = 26.087940;
      val[1672 * nCulm + 3] = 5.817332;
      val[1672 * nCulm + 4] = 43.250473;
      val[1672 * nCulm + 5] = -1.470820;
      val[1673 * nCulm + 0] = 21.160272;
      val[1673 * nCulm + 1] = 33.436732;
      val[1673 * nCulm + 2] = -31.660250;
      val[1673 * nCulm + 3] = 22.873361;
      val[1673 * nCulm + 4] = 20.452117;
      val[1673 * nCulm + 5] = 13.262120;
      val[1674 * nCulm + 0] = 31.227456;
      val[1674 * nCulm + 1] = 40.905989;
      val[1674 * nCulm + 2] = 19.693073;
      val[1674 * nCulm + 3] = -34.734591;
      val[1674 * nCulm + 4] = 46.769782;
      val[1674 * nCulm + 5] = 0.854576;
      val[1675 * nCulm + 0] = -44.727614;
      val[1675 * nCulm + 1] = 25.663083;
      val[1675 * nCulm + 2] = -30.385754;
      val[1675 * nCulm + 3] = -17.084653;
      val[1675 * nCulm + 4] = 4.572463;
      val[1675 * nCulm + 5] = 9.110240;
      val[1676 * nCulm + 0] = -29.599910;
      val[1676 * nCulm + 1] = 44.088131;
      val[1676 * nCulm + 2] = -16.645715;
      val[1676 * nCulm + 3] = 28.148316;
      val[1676 * nCulm + 4] = -22.619760;
      val[1676 * nCulm + 5] = -14.885951;
      val[1677 * nCulm + 0] = 39.727479;
      val[1677 * nCulm + 1] = 43.231192;
      val[1677 * nCulm + 2] = 7.632982;
      val[1677 * nCulm + 3] = -27.535450;
      val[1677 * nCulm + 4] = -47.531646;
      val[1677 * nCulm + 5] = -1.333026;
      val[1678 * nCulm + 0] = -19.221786;
      val[1678 * nCulm + 1] = -48.750100;
      val[1678 * nCulm + 2] = 7.415390;
      val[1678 * nCulm + 3] = -3.856752;
      val[1678 * nCulm + 4] = -4.318136;
      val[1678 * nCulm + 5] = 57.895109;
      val[1679 * nCulm + 0] = 11.630437;
      val[1679 * nCulm + 1] = -16.261993;
      val[1679 * nCulm + 2] = -8.492028;
      val[1679 * nCulm + 3] = -32.823784;
      val[1679 * nCulm + 4] = -49.903952;
      val[1679 * nCulm + 5] = 4.885730;
      val[1680 * nCulm + 0] = 10.544202;
      val[1680 * nCulm + 1] = 38.788581;
      val[1680 * nCulm + 2] = 24.790594;
      val[1680 * nCulm + 3] = 14.340341;
      val[1680 * nCulm + 4] = 5.735723;
      val[1680 * nCulm + 5] = 44.073977;
      val[1681 * nCulm + 0] = 45.804825;
      val[1681 * nCulm + 1] = -2.120675;
      val[1681 * nCulm + 2] = 33.002999;
      val[1681 * nCulm + 3] = 48.924306;
      val[1681 * nCulm + 4] = 10.006919;
      val[1681 * nCulm + 5] = 22.368400;
      val[1682 * nCulm + 0] = -21.513511;
      val[1682 * nCulm + 1] = -10.240207;
      val[1682 * nCulm + 2] = -9.882165;
      val[1682 * nCulm + 3] = 24.557961;
      val[1682 * nCulm + 4] = -46.013355;
      val[1682 * nCulm + 5] = -1.242849;
      val[1683 * nCulm + 0] = -23.898264;
      val[1683 * nCulm + 1] = -34.370728;
      val[1683 * nCulm + 2] = 15.084795;
      val[1683 * nCulm + 3] = -9.850174;
      val[1683 * nCulm + 4] = 12.497262;
      val[1683 * nCulm + 5] = -16.518650;
      val[1684 * nCulm + 0] = 48.244382;
      val[1684 * nCulm + 1] = 34.301975;
      val[1684 * nCulm + 2] = -15.221364;
      val[1684 * nCulm + 3] = -11.578374;
      val[1684 * nCulm + 4] = 23.158117;
      val[1684 * nCulm + 5] = 4.874522;
      val[1685 * nCulm + 0] = 33.764626;
      val[1685 * nCulm + 1] = -47.363159;
      val[1685 * nCulm + 2] = -38.777277;
      val[1685 * nCulm + 3] = -8.971729;
      val[1685 * nCulm + 4] = 33.344211;
      val[1685 * nCulm + 5] = -7.766944;
      val[1686 * nCulm + 0] = -7.137098;
      val[1686 * nCulm + 1] = -31.868664;
      val[1686 * nCulm + 2] = 33.748545;
      val[1686 * nCulm + 3] = -12.838094;
      val[1686 * nCulm + 4] = 1.681114;
      val[1686 * nCulm + 5] = -125.646037;
      val[1687 * nCulm + 0] = -3.703156;
      val[1687 * nCulm + 1] = 48.018494;
      val[1687 * nCulm + 2] = -43.380517;
      val[1687 * nCulm + 3] = 20.936552;
      val[1687 * nCulm + 4] = -46.376901;
      val[1687 * nCulm + 5] = -6.807711;
      val[1688 * nCulm + 0] = -40.674466;
      val[1688 * nCulm + 1] = 20.258661;
      val[1688 * nCulm + 2] = -25.777212;
      val[1688 * nCulm + 3] = -34.957650;
      val[1688 * nCulm + 4] = -10.802659;
      val[1688 * nCulm + 5] = 6.670564;
      val[1689 * nCulm + 0] = -44.116406;
      val[1689 * nCulm + 1] = -33.113932;
      val[1689 * nCulm + 2] = 37.651446;
      val[1689 * nCulm + 3] = -16.467312;
      val[1689 * nCulm + 4] = -23.916981;
      val[1689 * nCulm + 5] = 10.042466;
      val[1690 * nCulm + 0] = 3.471413;
      val[1690 * nCulm + 1] = 12.315921;
      val[1690 * nCulm + 2] = -33.221218;
      val[1690 * nCulm + 3] = -0.321135;
      val[1690 * nCulm + 4] = -35.068071;
      val[1690 * nCulm + 5] = -1.389003;
      val[1691 * nCulm + 0] = 42.360637;
      val[1691 * nCulm + 1] = -38.168104;
      val[1691 * nCulm + 2] = 22.293411;
      val[1691 * nCulm + 3] = -31.216159;
      val[1691 * nCulm + 4] = -44.861764;
      val[1691 * nCulm + 5] = 7.550685;
      val[1692 * nCulm + 0] = -24.301279;
      val[1692 * nCulm + 1] = 21.792753;
      val[1692 * nCulm + 2] = -4.725288;
      val[1692 * nCulm + 3] = 2.358285;
      val[1692 * nCulm + 4] = -45.548228;
      val[1692 * nCulm + 5] = -2.279755;
      val[1693 * nCulm + 0] = 23.394434;
      val[1693 * nCulm + 1] = 16.708913;
      val[1693 * nCulm + 2] = 26.077377;
      val[1693 * nCulm + 3] = -49.796147;
      val[1693 * nCulm + 4] = -35.628025;
      val[1693 * nCulm + 5] = 4.625779;
      val[1694 * nCulm + 0] = -42.243448;
      val[1694 * nCulm + 1] = -28.484199;
      val[1694 * nCulm + 2] = -19.287606;
      val[1694 * nCulm + 3] = -22.779847;
      val[1694 * nCulm + 4] = -6.538170;
      val[1694 * nCulm + 5] = 37.342803;
      val[1695 * nCulm + 0] = 40.947672;
      val[1695 * nCulm + 1] = 30.531749;
      val[1695 * nCulm + 2] = -24.355255;
      val[1695 * nCulm + 3] = -40.008837;
      val[1695 * nCulm + 4] = 8.687068;
      val[1695 * nCulm + 5] = -4.933792;
      val[1696 * nCulm + 0] = -36.634554;
      val[1696 * nCulm + 1] = 6.102037;
      val[1696 * nCulm + 2] = 27.211168;
      val[1696 * nCulm + 3] = -45.792565;
      val[1696 * nCulm + 4] = -1.607416;
      val[1696 * nCulm + 5] = 117.106061;
      val[1697 * nCulm + 0] = 42.621864;
      val[1697 * nCulm + 1] = 20.160330;
      val[1697 * nCulm + 2] = 2.261373;
      val[1697 * nCulm + 3] = -13.523349;
      val[1697 * nCulm + 4] = -30.472224;
      val[1697 * nCulm + 5] = -0.800940;
      val[1698 * nCulm + 0] = 2.977453;
      val[1698 * nCulm + 1] = 35.038976;
      val[1698 * nCulm + 2] = 22.372055;
      val[1698 * nCulm + 3] = 31.062369;
      val[1698 * nCulm + 4] = -30.878582;
      val[1698 * nCulm + 5] = -9.902580;
      val[1699 * nCulm + 0] = 29.006777;
      val[1699 * nCulm + 1] = -22.401044;
      val[1699 * nCulm + 2] = -16.791245;
      val[1699 * nCulm + 3] = 41.038884;
      val[1699 * nCulm + 4] = 9.181041;
      val[1699 * nCulm + 5] = 9.838835;
      val[1700 * nCulm + 0] = -14.402422;
      val[1700 * nCulm + 1] = -38.306770;
      val[1700 * nCulm + 2] = 29.278224;
      val[1700 * nCulm + 3] = 4.349410;
      val[1700 * nCulm + 4] = 35.629402;
      val[1700 * nCulm + 5] = -4.281204;
      val[1701 * nCulm + 0] = 11.886906;
      val[1701 * nCulm + 1] = -35.696045;
      val[1701 * nCulm + 2] = 25.000147;
      val[1701 * nCulm + 3] = 1.537366;
      val[1701 * nCulm + 4] = 43.449602;
      val[1701 * nCulm + 5] = -3.491194;
      val[1702 * nCulm + 0] = -12.936162;
      val[1702 * nCulm + 1] = -29.166957;
      val[1702 * nCulm + 2] = -48.131525;
      val[1702 * nCulm + 3] = -35.931623;
      val[1702 * nCulm + 4] = 41.061781;
      val[1702 * nCulm + 5] = -7.274138;
      val[1703 * nCulm + 0] = -40.441331;
      val[1703 * nCulm + 1] = -12.860992;
      val[1703 * nCulm + 2] = -40.018046;
      val[1703 * nCulm + 3] = -1.451143;
      val[1703 * nCulm + 4] = 20.961939;
      val[1703 * nCulm + 5] = -3.001767;
      val[1704 * nCulm + 0] = -5.960507;
      val[1704 * nCulm + 1] = 5.657228;
      val[1704 * nCulm + 2] = -44.354722;
      val[1704 * nCulm + 3] = 43.587730;
      val[1704 * nCulm + 4] = -35.866874;
      val[1704 * nCulm + 5] = -6.268832;
      val[1705 * nCulm + 0] = -16.087129;
      val[1705 * nCulm + 1] = 42.339251;
      val[1705 * nCulm + 2] = 33.758853;
      val[1705 * nCulm + 3] = -7.598827;
      val[1705 * nCulm + 4] = -39.532035;
      val[1705 * nCulm + 5] = -3.929614;
      val[1706 * nCulm + 0] = -49.855080;
      val[1706 * nCulm + 1] = 46.771185;
      val[1706 * nCulm + 2] = -35.413067;
      val[1706 * nCulm + 3] = -44.909212;
      val[1706 * nCulm + 4] = 29.645259;
      val[1706 * nCulm + 5] = 0.527293;
      val[1707 * nCulm + 0] = -28.446619;
      val[1707 * nCulm + 1] = -33.925255;
      val[1707 * nCulm + 2] = -33.332426;
      val[1707 * nCulm + 3] = 32.584955;
      val[1707 * nCulm + 4] = 18.264230;
      val[1707 * nCulm + 5] = -0.117351;
      val[1708 * nCulm + 0] = -0.516336;
      val[1708 * nCulm + 1] = 1.729691;
      val[1708 * nCulm + 2] = 40.542706;
      val[1708 * nCulm + 3] = 2.190363;
      val[1708 * nCulm + 4] = 25.276425;
      val[1708 * nCulm + 5] = 0.964080;
      val[1709 * nCulm + 0] = 1.233602;
      val[1709 * nCulm + 1] = 12.399445;
      val[1709 * nCulm + 2] = 46.835583;
      val[1709 * nCulm + 3] = -45.171952;
      val[1709 * nCulm + 4] = -13.452332;
      val[1709 * nCulm + 5] = 11.761324;
      val[1710 * nCulm + 0] = 23.425753;
      val[1710 * nCulm + 1] = -30.713573;
      val[1710 * nCulm + 2] = 19.148799;
      val[1710 * nCulm + 3] = 41.827989;
      val[1710 * nCulm + 4] = 47.034533;
      val[1710 * nCulm + 5] = 1.348502;
      val[1711 * nCulm + 0] = -27.635652;
      val[1711 * nCulm + 1] = -46.182149;
      val[1711 * nCulm + 2] = -10.212742;
      val[1711 * nCulm + 3] = 31.144241;
      val[1711 * nCulm + 4] = 9.435814;
      val[1711 * nCulm + 5] = -7.313539;
      val[1712 * nCulm + 0] = 42.374391;
      val[1712 * nCulm + 1] = 16.913320;
      val[1712 * nCulm + 2] = 36.382912;
      val[1712 * nCulm + 3] = 8.404292;
      val[1712 * nCulm + 4] = 21.420334;
      val[1712 * nCulm + 5] = 5.824530;
      val[1713 * nCulm + 0] = 0.447341;
      val[1713 * nCulm + 1] = 31.849175;
      val[1713 * nCulm + 2] = 14.572826;
      val[1713 * nCulm + 3] = 22.620901;
      val[1713 * nCulm + 4] = 28.324794;
      val[1713 * nCulm + 5] = 9.332450;
      val[1714 * nCulm + 0] = 23.748893;
      val[1714 * nCulm + 1] = -16.533470;
      val[1714 * nCulm + 2] = 22.241560;
      val[1714 * nCulm + 3] = 5.060817;
      val[1714 * nCulm + 4] = -3.957185;
      val[1714 * nCulm + 5] = 13.952858;
      val[1715 * nCulm + 0] = 42.888180;
      val[1715 * nCulm + 1] = 36.658262;
      val[1715 * nCulm + 2] = 33.966621;
      val[1715 * nCulm + 3] = 18.188728;
      val[1715 * nCulm + 4] = 33.295775;
      val[1715 * nCulm + 5] = 8.027058;
      val[1716 * nCulm + 0] = 42.581084;
      val[1716 * nCulm + 1] = -23.623146;
      val[1716 * nCulm + 2] = 9.477643;
      val[1716 * nCulm + 3] = 13.814913;
      val[1716 * nCulm + 4] = 25.977994;
      val[1716 * nCulm + 5] = -1.557114;
      val[1717 * nCulm + 0] = 41.168916;
      val[1717 * nCulm + 1] = 24.134942;
      val[1717 * nCulm + 2] = -37.275935;
      val[1717 * nCulm + 3] = -20.006609;
      val[1717 * nCulm + 4] = -47.957906;
      val[1717 * nCulm + 5] = -0.177457;
      val[1718 * nCulm + 0] = 5.233849;
      val[1718 * nCulm + 1] = -34.536399;
      val[1718 * nCulm + 2] = -3.032085;
      val[1718 * nCulm + 3] = 19.516244;
      val[1718 * nCulm + 4] = -20.231820;
      val[1718 * nCulm + 5] = 3.744039;
      val[1719 * nCulm + 0] = -2.575567;
      val[1719 * nCulm + 1] = -23.381049;
      val[1719 * nCulm + 2] = -7.718812;
      val[1719 * nCulm + 3] = 27.576186;
      val[1719 * nCulm + 4] = 44.714104;
      val[1719 * nCulm + 5] = 0.674088;
      val[1720 * nCulm + 0] = -40.838802;
      val[1720 * nCulm + 1] = 27.619872;
      val[1720 * nCulm + 2] = -46.285570;
      val[1720 * nCulm + 3] = 37.074892;
      val[1720 * nCulm + 4] = -22.784011;
      val[1720 * nCulm + 5] = -13.210210;
      val[1721 * nCulm + 0] = 1.419459;
      val[1721 * nCulm + 1] = 12.743670;
      val[1721 * nCulm + 2] = 41.218841;
      val[1721 * nCulm + 3] = -0.967551;
      val[1721 * nCulm + 4] = -36.951401;
      val[1721 * nCulm + 5] = -1.278476;
      val[1722 * nCulm + 0] = 23.646504;
      val[1722 * nCulm + 1] = 36.151259;
      val[1722 * nCulm + 2] = -31.498231;
      val[1722 * nCulm + 3] = 13.160828;
      val[1722 * nCulm + 4] = -16.253474;
      val[1722 * nCulm + 5] = -14.130656;
      val[1723 * nCulm + 0] = -32.062687;
      val[1723 * nCulm + 1] = -1.227828;
      val[1723 * nCulm + 2] = -34.016300;
      val[1723 * nCulm + 3] = -37.134874;
      val[1723 * nCulm + 4] = -3.910044;
      val[1723 * nCulm + 5] = 46.670256;
      val[1724 * nCulm + 0] = -17.269608;
      val[1724 * nCulm + 1] = -19.955958;
      val[1724 * nCulm + 2] = 31.764835;
      val[1724 * nCulm + 3] = 26.223967;
      val[1724 * nCulm + 4] = -46.185222;
      val[1724 * nCulm + 5] = -0.412383;
      val[1725 * nCulm + 0] = 39.881664;
      val[1725 * nCulm + 1] = -15.218547;
      val[1725 * nCulm + 2] = -19.368561;
      val[1725 * nCulm + 3] = -21.422429;
      val[1725 * nCulm + 4] = 5.496495;
      val[1725 * nCulm + 5] = -31.323552;
      val[1726 * nCulm + 0] = 33.427696;
      val[1726 * nCulm + 1] = 31.117529;
      val[1726 * nCulm + 2] = -28.965203;
      val[1726 * nCulm + 3] = 29.795464;
      val[1726 * nCulm + 4] = 45.828257;
      val[1726 * nCulm + 5] = 6.521348;
      val[1727 * nCulm + 0] = -4.107207;
      val[1727 * nCulm + 1] = -25.107944;
      val[1727 * nCulm + 2] = -12.462944;
      val[1727 * nCulm + 3] = -46.443447;
      val[1727 * nCulm + 4] = 48.071134;
      val[1727 * nCulm + 5] = -6.815321;
      val[1728 * nCulm + 0] = -48.368746;
      val[1728 * nCulm + 1] = 19.690458;
      val[1728 * nCulm + 2] = 7.645375;
      val[1728 * nCulm + 3] = -9.727260;
      val[1728 * nCulm + 4] = -12.486717;
      val[1728 * nCulm + 5] = -3.546744;
      val[1729 * nCulm + 0] = 39.664132;
      val[1729 * nCulm + 1] = -48.251004;
      val[1729 * nCulm + 2] = -18.909844;
      val[1729 * nCulm + 3] = 19.362658;
      val[1729 * nCulm + 4] = 13.932379;
      val[1729 * nCulm + 5] = -9.584417;
      val[1730 * nCulm + 0] = 30.837771;
      val[1730 * nCulm + 1] = 6.387084;
      val[1730 * nCulm + 2] = 44.406980;
      val[1730 * nCulm + 3] = 16.566727;
      val[1730 * nCulm + 4] = 37.261188;
      val[1730 * nCulm + 5] = 3.145850;
      val[1731 * nCulm + 0] = -13.894830;
      val[1731 * nCulm + 1] = 23.608337;
      val[1731 * nCulm + 2] = 0.479209;
      val[1731 * nCulm + 3] = -4.797713;
      val[1731 * nCulm + 4] = 28.760285;
      val[1731 * nCulm + 5] = 3.325830;
      val[1732 * nCulm + 0] = 27.249444;
      val[1732 * nCulm + 1] = -4.715179;
      val[1732 * nCulm + 2] = 48.105504;
      val[1732 * nCulm + 3] = 6.107972;
      val[1732 * nCulm + 4] = -14.380003;
      val[1732 * nCulm + 5] = -0.228453;
      val[1733 * nCulm + 0] = 28.959397;
      val[1733 * nCulm + 1] = 36.436134;
      val[1733 * nCulm + 2] = -40.134233;
      val[1733 * nCulm + 3] = -45.936568;
      val[1733 * nCulm + 4] = 29.150234;
      val[1733 * nCulm + 5] = -1.312654;
      val[1734 * nCulm + 0] = -2.148618;
      val[1734 * nCulm + 1] = -43.153773;
      val[1734 * nCulm + 2] = -16.876476;
      val[1734 * nCulm + 3] = 21.820910;
      val[1734 * nCulm + 4] = 7.430354;
      val[1734 * nCulm + 5] = -13.359602;
      val[1735 * nCulm + 0] = 37.642744;
      val[1735 * nCulm + 1] = 23.757040;
      val[1735 * nCulm + 2] = 20.303475;
      val[1735 * nCulm + 3] = 7.338368;
      val[1735 * nCulm + 4] = -48.054353;
      val[1735 * nCulm + 5] = -2.832884;
      val[1736 * nCulm + 0] = -14.101405;
      val[1736 * nCulm + 1] = 5.786441;
      val[1736 * nCulm + 2] = -28.068415;
      val[1736 * nCulm + 3] = 49.822535;
      val[1736 * nCulm + 4] = 20.546687;
      val[1736 * nCulm + 5] = 13.040621;
      val[1737 * nCulm + 0] = -44.720304;
      val[1737 * nCulm + 1] = -32.009313;
      val[1737 * nCulm + 2] = 19.318101;
      val[1737 * nCulm + 3] = -4.291671;
      val[1737 * nCulm + 4] = 40.903004;
      val[1737 * nCulm + 5] = -3.970783;
      val[1738 * nCulm + 0] = 30.799415;
      val[1738 * nCulm + 1] = -37.374708;
      val[1738 * nCulm + 2] = 42.556938;
      val[1738 * nCulm + 3] = 39.804087;
      val[1738 * nCulm + 4] = 16.994805;
      val[1738 * nCulm + 5] = 0.906622;
      val[1739 * nCulm + 0] = 31.311943;
      val[1739 * nCulm + 1] = -37.829502;
      val[1739 * nCulm + 2] = 30.925619;
      val[1739 * nCulm + 3] = 12.539878;
      val[1739 * nCulm + 4] = 15.670494;
      val[1739 * nCulm + 5] = -7.408829;
      val[1740 * nCulm + 0] = 23.445110;
      val[1740 * nCulm + 1] = -45.515031;
      val[1740 * nCulm + 2] = 48.785917;
      val[1740 * nCulm + 3] = -38.434450;
      val[1740 * nCulm + 4] = -43.767739;
      val[1740 * nCulm + 5] = 9.308853;
      val[1741 * nCulm + 0] = -20.580630;
      val[1741 * nCulm + 1] = 7.999162;
      val[1741 * nCulm + 2] = -10.135722;
      val[1741 * nCulm + 3] = 43.243252;
      val[1741 * nCulm + 4] = -36.289941;
      val[1741 * nCulm + 5] = -6.453599;
      val[1742 * nCulm + 0] = -36.428705;
      val[1742 * nCulm + 1] = 0.549694;
      val[1742 * nCulm + 2] = -44.368680;
      val[1742 * nCulm + 3] = -14.756809;
      val[1742 * nCulm + 4] = -46.000060;
      val[1742 * nCulm + 5] = 1.691890;
      val[1743 * nCulm + 0] = -42.493101;
      val[1743 * nCulm + 1] = -26.981003;
      val[1743 * nCulm + 2] = 3.276512;
      val[1743 * nCulm + 3] = 3.938874;
      val[1743 * nCulm + 4] = 21.672231;
      val[1743 * nCulm + 5] = -4.802527;
      val[1744 * nCulm + 0] = 9.633967;
      val[1744 * nCulm + 1] = -21.246190;
      val[1744 * nCulm + 2] = -41.057595;
      val[1744 * nCulm + 3] = 28.502049;
      val[1744 * nCulm + 4] = -43.917152;
      val[1744 * nCulm + 5] = -0.552027;
      val[1745 * nCulm + 0] = 13.598123;
      val[1745 * nCulm + 1] = -11.619427;
      val[1745 * nCulm + 2] = -33.779076;
      val[1745 * nCulm + 3] = -12.411687;
      val[1745 * nCulm + 4] = 23.351300;
      val[1745 * nCulm + 5] = -4.641132;
      val[1746 * nCulm + 0] = -24.430974;
      val[1746 * nCulm + 1] = -36.377452;
      val[1746 * nCulm + 2] = -7.080310;
      val[1746 * nCulm + 3] = 0.509750;
      val[1746 * nCulm + 4] = 27.359794;
      val[1746 * nCulm + 5] = -5.975229;
      val[1747 * nCulm + 0] = 5.259600;
      val[1747 * nCulm + 1] = 25.121822;
      val[1747 * nCulm + 2] = -41.244558;
      val[1747 * nCulm + 3] = 17.160611;
      val[1747 * nCulm + 4] = 34.919078;
      val[1747 * nCulm + 5] = 5.961447;
      val[1748 * nCulm + 0] = -17.279313;
      val[1748 * nCulm + 1] = -30.478064;
      val[1748 * nCulm + 2] = -3.705445;
      val[1748 * nCulm + 3] = -35.616393;
      val[1748 * nCulm + 4] = 3.581911;
      val[1748 * nCulm + 5] = -87.110826;
      val[1749 * nCulm + 0] = -35.479859;
      val[1749 * nCulm + 1] = 44.839633;
      val[1749 * nCulm + 2] = -41.365211;
      val[1749 * nCulm + 3] = -20.571660;
      val[1749 * nCulm + 4] = 43.468025;
      val[1749 * nCulm + 5] = 2.872595;
      val[1750 * nCulm + 0] = -47.226536;
      val[1750 * nCulm + 1] = 3.544123;
      val[1750 * nCulm + 2] = 43.811823;
      val[1750 * nCulm + 3] = -9.641917;
      val[1750 * nCulm + 4] = -38.859978;
      val[1750 * nCulm + 5] = 0.972741;
      val[1751 * nCulm + 0] = 47.878461;
      val[1751 * nCulm + 1] = -11.167468;
      val[1751 * nCulm + 2] = 1.522619;
      val[1751 * nCulm + 3] = -1.229646;
      val[1751 * nCulm + 4] = -30.388302;
      val[1751 * nCulm + 5] = 2.160996;
      val[1752 * nCulm + 0] = -22.843713;
      val[1752 * nCulm + 1] = 39.599693;
      val[1752 * nCulm + 2] = -13.178721;
      val[1752 * nCulm + 3] = -37.054137;
      val[1752 * nCulm + 4] = 16.105540;
      val[1752 * nCulm + 5] = 0.978126;
      val[1753 * nCulm + 0] = -39.542080;
      val[1753 * nCulm + 1] = 8.294601;
      val[1753 * nCulm + 2] = 40.779641;
      val[1753 * nCulm + 3] = -8.528688;
      val[1753 * nCulm + 4] = -15.427464;
      val[1753 * nCulm + 5] = 0.301821;
      val[1754 * nCulm + 0] = -19.303950;
      val[1754 * nCulm + 1] = 48.182029;
      val[1754 * nCulm + 2] = -17.767889;
      val[1754 * nCulm + 3] = 14.265634;
      val[1754 * nCulm + 4] = -8.451164;
      val[1754 * nCulm + 5] = -34.745726;
      val[1755 * nCulm + 0] = 21.309552;
      val[1755 * nCulm + 1] = 9.282342;
      val[1755 * nCulm + 2] = -21.250995;
      val[1755 * nCulm + 3] = -49.016827;
      val[1755 * nCulm + 4] = -22.188282;
      val[1755 * nCulm + 5] = 8.706391;
      val[1756 * nCulm + 0] = 33.393132;
      val[1756 * nCulm + 1] = 12.275293;
      val[1756 * nCulm + 2] = -19.366213;
      val[1756 * nCulm + 3] = 2.890472;
      val[1756 * nCulm + 4] = 25.780105;
      val[1756 * nCulm + 5] = 3.014497;
      val[1757 * nCulm + 0] = -19.331842;
      val[1757 * nCulm + 1] = 18.381993;
      val[1757 * nCulm + 2] = 6.283198;
      val[1757 * nCulm + 3] = 0.920993;
      val[1757 * nCulm + 4] = -42.083538;
      val[1757 * nCulm + 5] = -1.941098;
      val[1758 * nCulm + 0] = -6.274259;
      val[1758 * nCulm + 1] = -4.639559;
      val[1758 * nCulm + 2] = 33.037455;
      val[1758 * nCulm + 3] = 15.263169;
      val[1758 * nCulm + 4] = 12.340897;
      val[1758 * nCulm + 5] = 4.304670;
      val[1759 * nCulm + 0] = 2.646891;
      val[1759 * nCulm + 1] = 29.873357;
      val[1759 * nCulm + 2] = -16.477170;
      val[1759 * nCulm + 3] = 28.848544;
      val[1759 * nCulm + 4] = 1.674856;
      val[1759 * nCulm + 5] = 166.184769;
      val[1760 * nCulm + 0] = 13.467342;
      val[1760 * nCulm + 1] = -7.749692;
      val[1760 * nCulm + 2] = 40.873919;
      val[1760 * nCulm + 3] = 29.640216;
      val[1760 * nCulm + 4] = 0.505308;
      val[1760 * nCulm + 5] = 205.283473;
      val[1761 * nCulm + 0] = -37.394398;
      val[1761 * nCulm + 1] = 29.279733;
      val[1761 * nCulm + 2] = 27.011784;
      val[1761 * nCulm + 3] = 37.396833;
      val[1761 * nCulm + 4] = -15.870021;
      val[1761 * nCulm + 5] = -19.656705;
      val[1762 * nCulm + 0] = 49.336122;
      val[1762 * nCulm + 1] = -6.834675;
      val[1762 * nCulm + 2] = 31.890119;
      val[1762 * nCulm + 3] = 0.447875;
      val[1762 * nCulm + 4] = 34.935662;
      val[1762 * nCulm + 5] = -0.635329;
      val[1763 * nCulm + 0] = 17.528514;
      val[1763 * nCulm + 1] = 13.828008;
      val[1763 * nCulm + 2] = 32.403780;
      val[1763 * nCulm + 3] = -9.379958;
      val[1763 * nCulm + 4] = -27.966582;
      val[1763 * nCulm + 5] = -0.522831;
      val[1764 * nCulm + 0] = 35.089103;
      val[1764 * nCulm + 1] = 39.000545;
      val[1764 * nCulm + 2] = 46.980410;
      val[1764 * nCulm + 3] = 40.226472;
      val[1764 * nCulm + 4] = -39.146955;
      val[1764 * nCulm + 5] = -9.349490;
      val[1765 * nCulm + 0] = -31.429392;
      val[1765 * nCulm + 1] = 47.857741;
      val[1765 * nCulm + 2] = 2.645674;
      val[1765 * nCulm + 3] = -15.736244;
      val[1765 * nCulm + 4] = -32.648278;
      val[1765 * nCulm + 5] = -4.426961;
      val[1766 * nCulm + 0] = 37.653848;
      val[1766 * nCulm + 1] = 20.951288;
      val[1766 * nCulm + 2] = 38.516069;
      val[1766 * nCulm + 3] = -14.148785;
      val[1766 * nCulm + 4] = 5.864580;
      val[1766 * nCulm + 5] = 5.720336;
      val[1767 * nCulm + 0] = -38.230689;
      val[1767 * nCulm + 1] = -40.870639;
      val[1767 * nCulm + 2] = -45.167438;
      val[1767 * nCulm + 3] = 1.496840;
      val[1767 * nCulm + 4] = -17.246159;
      val[1767 * nCulm + 5] = 11.036424;
      val[1768 * nCulm + 0] = 48.078178;
      val[1768 * nCulm + 1] = 24.167488;
      val[1768 * nCulm + 2] = 5.164308;
      val[1768 * nCulm + 3] = 30.410567;
      val[1768 * nCulm + 4] = -3.614512;
      val[1768 * nCulm + 5] = -71.241929;
      val[1769 * nCulm + 0] = -39.064481;
      val[1769 * nCulm + 1] = -46.325033;
      val[1769 * nCulm + 2] = 40.823709;
      val[1769 * nCulm + 3] = 14.482872;
      val[1769 * nCulm + 4] = -15.840632;
      val[1769 * nCulm + 5] = 9.744744;
      val[1770 * nCulm + 0] = -41.523646;
      val[1770 * nCulm + 1] = -11.228371;
      val[1770 * nCulm + 2] = -30.333745;
      val[1770 * nCulm + 3] = 47.205299;
      val[1770 * nCulm + 4] = 37.840506;
      val[1770 * nCulm + 5] = 4.730225;
      val[1771 * nCulm + 0] = -1.519727;
      val[1771 * nCulm + 1] = -0.848297;
      val[1771 * nCulm + 2] = 33.127845;
      val[1771 * nCulm + 3] = 3.184229;
      val[1771 * nCulm + 4] = 5.717256;
      val[1771 * nCulm + 5] = 2.163925;
      val[1772 * nCulm + 0] = 8.968114;
      val[1772 * nCulm + 1] = -34.399985;
      val[1772 * nCulm + 2] = -31.894836;
      val[1772 * nCulm + 3] = 27.760876;
      val[1772 * nCulm + 4] = -43.606887;
      val[1772 * nCulm + 5] = 0.950646;
      val[1773 * nCulm + 0] = -10.021319;
      val[1773 * nCulm + 1] = -33.872681;
      val[1773 * nCulm + 2] = -14.548499;
      val[1773 * nCulm + 3] = -39.508244;
      val[1773 * nCulm + 4] = 9.545628;
      val[1773 * nCulm + 5] = -36.156958;
      val[1774 * nCulm + 0] = 34.115834;
      val[1774 * nCulm + 1] = -17.130153;
      val[1774 * nCulm + 2] = -5.824227;
      val[1774 * nCulm + 3] = -46.260749;
      val[1774 * nCulm + 4] = 49.030715;
      val[1774 * nCulm + 5] = -5.889639;
      val[1775 * nCulm + 0] = 33.257689;
      val[1775 * nCulm + 1] = 44.530199;
      val[1775 * nCulm + 2] = -49.606705;
      val[1775 * nCulm + 3] = -33.916520;
      val[1775 * nCulm + 4] = 38.716176;
      val[1775 * nCulm + 5] = 1.527599;
      val[1776 * nCulm + 0] = 19.385756;
      val[1776 * nCulm + 1] = 47.365413;
      val[1776 * nCulm + 2] = -8.317192;
      val[1776 * nCulm + 3] = 8.878974;
      val[1776 * nCulm + 4] = 32.127094;
      val[1776 * nCulm + 5] = 8.516571;
      val[1777 * nCulm + 0] = -46.605373;
      val[1777 * nCulm + 1] = 38.830963;
      val[1777 * nCulm + 2] = -43.992262;
      val[1777 * nCulm + 3] = -24.139145;
      val[1777 * nCulm + 4] = 28.065552;
      val[1777 * nCulm + 5] = 2.707816;
      val[1778 * nCulm + 0] = 19.345353;
      val[1778 * nCulm + 1] = -0.175676;
      val[1778 * nCulm + 2] = -46.527538;
      val[1778 * nCulm + 3] = -26.515315;
      val[1778 * nCulm + 4] = -32.975902;
      val[1778 * nCulm + 5] = 4.061203;
      val[1779 * nCulm + 0] = -38.742738;
      val[1779 * nCulm + 1] = 28.155439;
      val[1779 * nCulm + 2] = 14.919490;
      val[1779 * nCulm + 3] = -3.700319;
      val[1779 * nCulm + 4] = 16.129969;
      val[1779 * nCulm + 5] = 7.406346;
      val[1780 * nCulm + 0] = -3.442478;
      val[1780 * nCulm + 1] = 14.464158;
      val[1780 * nCulm + 2] = 32.379498;
      val[1780 * nCulm + 3] = -28.708594;
      val[1780 * nCulm + 4] = 36.732200;
      val[1780 * nCulm + 5] = -1.605547;
      val[1781 * nCulm + 0] = -32.679220;
      val[1781 * nCulm + 1] = 20.686938;
      val[1781 * nCulm + 2] = 45.117726;
      val[1781 * nCulm + 3] = 32.159104;
      val[1781 * nCulm + 4] = -39.769988;
      val[1781 * nCulm + 5] = -6.059616;
      val[1782 * nCulm + 0] = 10.547077;
      val[1782 * nCulm + 1] = 26.866186;
      val[1782 * nCulm + 2] = -30.470018;
      val[1782 * nCulm + 3] = 7.310440;
      val[1782 * nCulm + 4] = -3.722989;
      val[1782 * nCulm + 5] = -43.221479;
      val[1783 * nCulm + 0] = 24.756067;
      val[1783 * nCulm + 1] = -22.409790;
      val[1783 * nCulm + 2] = 49.344502;
      val[1783 * nCulm + 3] = -17.984449;
      val[1783 * nCulm + 4] = -15.146812;
      val[1783 * nCulm + 5] = 12.853079;
      val[1784 * nCulm + 0] = -25.152791;
      val[1784 * nCulm + 1] = -11.820869;
      val[1784 * nCulm + 2] = -36.997158;
      val[1784 * nCulm + 3] = 13.551638;
      val[1784 * nCulm + 4] = 1.541532;
      val[1784 * nCulm + 5] = 5.544395;
      val[1785 * nCulm + 0] = -5.135633;
      val[1785 * nCulm + 1] = -28.157192;
      val[1785 * nCulm + 2] = -11.172164;
      val[1785 * nCulm + 3] = -29.213028;
      val[1785 * nCulm + 4] = 42.560659;
      val[1785 * nCulm + 5] = -6.150361;
      val[1786 * nCulm + 0] = 42.724766;
      val[1786 * nCulm + 1] = 32.145925;
      val[1786 * nCulm + 2] = 38.609990;
      val[1786 * nCulm + 3] = -39.753268;
      val[1786 * nCulm + 4] = -5.428698;
      val[1786 * nCulm + 5] = 6.862915;
      val[1787 * nCulm + 0] = 4.824318;
      val[1787 * nCulm + 1] = 33.517518;
      val[1787 * nCulm + 2] = 37.661011;
      val[1787 * nCulm + 3] = -23.303763;
      val[1787 * nCulm + 4] = -22.420439;
      val[1787 * nCulm + 5] = -1.926296;
      val[1788 * nCulm + 0] = -0.738635;
      val[1788 * nCulm + 1] = 5.563578;
      val[1788 * nCulm + 2] = 36.614824;
      val[1788 * nCulm + 3] = -34.550738;
      val[1788 * nCulm + 4] = -40.933286;
      val[1788 * nCulm + 5] = 3.581939;
      val[1789 * nCulm + 0] = -15.876743;
      val[1789 * nCulm + 1] = 1.353830;
      val[1789 * nCulm + 2] = -1.827666;
      val[1789 * nCulm + 3] = 34.278323;
      val[1789 * nCulm + 4] = -33.825938;
      val[1789 * nCulm + 5] = -4.756081;
      val[1790 * nCulm + 0] = 47.604871;
      val[1790 * nCulm + 1] = -38.496741;
      val[1790 * nCulm + 2] = -47.498582;
      val[1790 * nCulm + 3] = 36.546567;
      val[1790 * nCulm + 4] = 30.756388;
      val[1790 * nCulm + 5] = -0.070127;
      val[1791 * nCulm + 0] = -47.295001;
      val[1791 * nCulm + 1] = -38.517334;
      val[1791 * nCulm + 2] = 37.521853;
      val[1791 * nCulm + 3] = -10.873166;
      val[1791 * nCulm + 4] = 40.668196;
      val[1791 * nCulm + 5] = -5.518514;
      val[1792 * nCulm + 0] = -37.525793;
      val[1792 * nCulm + 1] = -32.715325;
      val[1792 * nCulm + 2] = -44.492706;
      val[1792 * nCulm + 3] = 37.686692;
      val[1792 * nCulm + 4] = 22.810031;
      val[1792 * nCulm + 5] = 1.261613;
      val[1793 * nCulm + 0] = 18.085433;
      val[1793 * nCulm + 1] = 22.982583;
      val[1793 * nCulm + 2] = 30.038342;
      val[1793 * nCulm + 3] = -40.046500;
      val[1793 * nCulm + 4] = 38.258438;
      val[1793 * nCulm + 5] = -1.881148;
      val[1794 * nCulm + 0] = -13.257048;
      val[1794 * nCulm + 1] = 5.790351;
      val[1794 * nCulm + 2] = -13.169234;
      val[1794 * nCulm + 3] = 6.881842;
      val[1794 * nCulm + 4] = -27.175282;
      val[1794 * nCulm + 5] = -1.977216;
      val[1795 * nCulm + 0] = 21.659278;
      val[1795 * nCulm + 1] = 32.017666;
      val[1795 * nCulm + 2] = 37.459716;
      val[1795 * nCulm + 3] = -29.674642;
      val[1795 * nCulm + 4] = -22.307764;
      val[1795 * nCulm + 5] = -0.267151;
      val[1796 * nCulm + 0] = 5.129687;
      val[1796 * nCulm + 1] = 40.013033;
      val[1796 * nCulm + 2] = -31.017555;
      val[1796 * nCulm + 3] = 39.234378;
      val[1796 * nCulm + 4] = 20.163940;
      val[1796 * nCulm + 5] = 18.832734;
      val[1797 * nCulm + 0] = -11.453333;
      val[1797 * nCulm + 1] = 39.815654;
      val[1797 * nCulm + 2] = -25.599970;
      val[1797 * nCulm + 3] = -48.404970;
      val[1797 * nCulm + 4] = 6.373282;
      val[1797 * nCulm + 5] = -6.149145;
      val[1798 * nCulm + 0] = -18.575172;
      val[1798 * nCulm + 1] = 31.319114;
      val[1798 * nCulm + 2] = 11.399710;
      val[1798 * nCulm + 3] = 2.865159;
      val[1798 * nCulm + 4] = 36.386792;
      val[1798 * nCulm + 5] = 4.676821;
      val[1799 * nCulm + 0] = -18.593045;
      val[1799 * nCulm + 1] = 30.970403;
      val[1799 * nCulm + 2] = -13.138939;
      val[1799 * nCulm + 3] = 14.848023;
      val[1799 * nCulm + 4] = 45.795964;
      val[1799 * nCulm + 5] = 4.965655;
      val[1800 * nCulm + 0] = 12.364172;
      val[1800 * nCulm + 1] = 33.270177;
      val[1800 * nCulm + 2] = -15.018263;
      val[1800 * nCulm + 3] = 9.307033;
      val[1800 * nCulm + 4] = 5.130520;
      val[1800 * nCulm + 5] = 39.511033;
      val[1801 * nCulm + 0] = 10.095907;
      val[1801 * nCulm + 1] = 0.605797;
      val[1801 * nCulm + 2] = -12.096004;
      val[1801 * nCulm + 3] = -5.951819;
      val[1801 * nCulm + 4] = -0.087584;
      val[1801 * nCulm + 5] = 289.147277;
      val[1802 * nCulm + 0] = 23.095783;
      val[1802 * nCulm + 1] = -27.103666;
      val[1802 * nCulm + 2] = 30.723903;
      val[1802 * nCulm + 3] = 30.600012;
      val[1802 * nCulm + 4] = -47.475065;
      val[1802 * nCulm + 5] = -0.118591;
      val[1803 * nCulm + 0] = -4.781140;
      val[1803 * nCulm + 1] = 24.390526;
      val[1803 * nCulm + 2] = 32.068401;
      val[1803 * nCulm + 3] = 4.279934;
      val[1803 * nCulm + 4] = -15.042532;
      val[1803 * nCulm + 5] = -8.791543;
      val[1804 * nCulm + 0] = 33.192751;
      val[1804 * nCulm + 1] = -16.585015;
      val[1804 * nCulm + 2] = -30.430239;
      val[1804 * nCulm + 3] = -31.597265;
      val[1804 * nCulm + 4] = -31.371082;
      val[1804 * nCulm + 5] = 7.499841;
      val[1805 * nCulm + 0] = -16.038350;
      val[1805 * nCulm + 1] = -47.144655;
      val[1805 * nCulm + 2] = -40.615596;
      val[1805 * nCulm + 3] = 32.180436;
      val[1805 * nCulm + 4] = 23.611168;
      val[1805 * nCulm + 5] = -2.769878;
      val[1806 * nCulm + 0] = 39.944244;
      val[1806 * nCulm + 1] = -28.071528;
      val[1806 * nCulm + 2] = -46.623676;
      val[1806 * nCulm + 3] = -20.206872;
      val[1806 * nCulm + 4] = -49.177584;
      val[1806 * nCulm + 5] = 4.876787;
      val[1807 * nCulm + 0] = 27.849550;
      val[1807 * nCulm + 1] = 46.290074;
      val[1807 * nCulm + 2] = -41.031558;
      val[1807 * nCulm + 3] = -21.410744;
      val[1807 * nCulm + 4] = -7.956854;
      val[1807 * nCulm + 5] = -14.570090;
      val[1808 * nCulm + 0] = -22.058453;
      val[1808 * nCulm + 1] = 43.152426;
      val[1808 * nCulm + 2] = 30.869380;
      val[1808 * nCulm + 3] = -21.285456;
      val[1808 * nCulm + 4] = -45.198487;
      val[1808 * nCulm + 5] = -2.059981;
      val[1809 * nCulm + 0] = -46.831336;
      val[1809 * nCulm + 1] = 17.888733;
      val[1809 * nCulm + 2] = 0.874370;
      val[1809 * nCulm + 3] = -8.431787;
      val[1809 * nCulm + 4] = 33.505131;
      val[1809 * nCulm + 5] = 1.566001;
      val[1810 * nCulm + 0] = -6.208645;
      val[1810 * nCulm + 1] = -9.819486;
      val[1810 * nCulm + 2] = -16.304688;
      val[1810 * nCulm + 3] = -49.720800;
      val[1810 * nCulm + 4] = -0.073261;
      val[1810 * nCulm + 5] = 3847.087103;
      val[1811 * nCulm + 0] = 14.166474;
      val[1811 * nCulm + 1] = 28.973491;
      val[1811 * nCulm + 2] = -20.748481;
      val[1811 * nCulm + 3] = 42.984078;
      val[1811 * nCulm + 4] = 35.160775;
      val[1811 * nCulm + 5] = 9.916907;
      val[1812 * nCulm + 0] = -44.037937;
      val[1812 * nCulm + 1] = 15.852922;
      val[1812 * nCulm + 2] = -49.722900;
      val[1812 * nCulm + 3] = 5.557637;
      val[1812 * nCulm + 4] = -32.346148;
      val[1812 * nCulm + 5] = -2.903087;
      val[1813 * nCulm + 0] = -48.178704;
      val[1813 * nCulm + 1] = 20.401405;
      val[1813 * nCulm + 2] = 38.039618;
      val[1813 * nCulm + 3] = -25.560356;
      val[1813 * nCulm + 4] = -24.851930;
      val[1813 * nCulm + 5] = 1.212581;
      val[1814 * nCulm + 0] = 35.881115;
      val[1814 * nCulm + 1] = 33.300315;
      val[1814 * nCulm + 2] = -24.930710;
      val[1814 * nCulm + 3] = -19.823746;
      val[1814 * nCulm + 4] = -31.672316;
      val[1814 * nCulm + 5] = -1.784033;
      val[1815 * nCulm + 0] = 41.077773;
      val[1815 * nCulm + 1] = 44.012190;
      val[1815 * nCulm + 2] = 8.261860;
      val[1815 * nCulm + 3] = -15.878597;
      val[1815 * nCulm + 4] = -40.007873;
      val[1815 * nCulm + 5] = -3.098487;
      val[1816 * nCulm + 0] = -45.768062;
      val[1816 * nCulm + 1] = -19.141337;
      val[1816 * nCulm + 2] = -24.922348;
      val[1816 * nCulm + 3] = 29.867871;
      val[1816 * nCulm + 4] = 18.810069;
      val[1816 * nCulm + 5] = 2.929206;
      val[1817 * nCulm + 0] = 41.881283;
      val[1817 * nCulm + 1] = -40.865057;
      val[1817 * nCulm + 2] = 48.301108;
      val[1817 * nCulm + 3] = -26.369450;
      val[1817 * nCulm + 4] = -8.960824;
      val[1817 * nCulm + 5] = 35.744964;
      val[1818 * nCulm + 0] = 36.611216;
      val[1818 * nCulm + 1] = 39.012625;
      val[1818 * nCulm + 2] = -35.344718;
      val[1818 * nCulm + 3] = 5.249432;
      val[1818 * nCulm + 4] = -8.738082;
      val[1818 * nCulm + 5] = -23.746323;
      val[1819 * nCulm + 0] = -16.542939;
      val[1819 * nCulm + 1] = -40.245752;
      val[1819 * nCulm + 2] = 13.830498;
      val[1819 * nCulm + 3] = -46.390416;
      val[1819 * nCulm + 4] = 20.229795;
      val[1819 * nCulm + 5] = -20.040984;
      val[1820 * nCulm + 0] = -16.291958;
      val[1820 * nCulm + 1] = 3.385174;
      val[1820 * nCulm + 2] = 46.358499;
      val[1820 * nCulm + 3] = -34.747196;
      val[1820 * nCulm + 4] = -45.839957;
      val[1820 * nCulm + 5] = 3.468374;
      val[1821 * nCulm + 0] = 29.554953;
      val[1821 * nCulm + 1] = 45.032256;
      val[1821 * nCulm + 2] = 41.462158;
      val[1821 * nCulm + 3] = -26.537458;
      val[1821 * nCulm + 4] = 38.407584;
      val[1821 * nCulm + 5] = 2.509291;
      val[1822 * nCulm + 0] = 9.181973;
      val[1822 * nCulm + 1] = -12.873758;
      val[1822 * nCulm + 2] = 44.640746;
      val[1822 * nCulm + 3] = -37.617867;
      val[1822 * nCulm + 4] = -0.832365;
      val[1822 * nCulm + 5] = 287.356001;
      val[1823 * nCulm + 0] = -43.298327;
      val[1823 * nCulm + 1] = 23.860169;
      val[1823 * nCulm + 2] = 33.449326;
      val[1823 * nCulm + 3] = -18.231438;
      val[1823 * nCulm + 4] = -44.456558;
      val[1823 * nCulm + 5] = -0.369296;
      val[1824 * nCulm + 0] = -45.107913;
      val[1824 * nCulm + 1] = 5.544653;
      val[1824 * nCulm + 2] = -6.281962;
      val[1824 * nCulm + 3] = -4.384639;
      val[1824 * nCulm + 4] = -1.246417;
      val[1824 * nCulm + 5] = -4.175213;
      val[1825 * nCulm + 0] = 18.215112;
      val[1825 * nCulm + 1] = 18.167238;
      val[1825 * nCulm + 2] = -18.120001;
      val[1825 * nCulm + 3] = -45.862499;
      val[1825 * nCulm + 4] = 4.796980;
      val[1825 * nCulm + 5] = -27.097798;
      val[1826 * nCulm + 0] = 26.715575;
      val[1826 * nCulm + 1] = 17.317355;
      val[1826 * nCulm + 2] = 39.630127;
      val[1826 * nCulm + 3] = 1.307365;
      val[1826 * nCulm + 4] = 49.358868;
      val[1826 * nCulm + 5] = 2.016042;
      val[1827 * nCulm + 0] = 10.506337;
      val[1827 * nCulm + 1] = 38.228841;
      val[1827 * nCulm + 2] = -43.461967;
      val[1827 * nCulm + 3] = -13.250133;
      val[1827 * nCulm + 4] = -19.285749;
      val[1827 * nCulm + 5] = -5.900566;
      val[1828 * nCulm + 0] = -9.457711;
      val[1828 * nCulm + 1] = 40.137015;
      val[1828 * nCulm + 2] = 31.099009;
      val[1828 * nCulm + 3] = -49.809421;
      val[1828 * nCulm + 4] = -0.462579;
      val[1828 * nCulm + 5] = 99.202797;
      val[1829 * nCulm + 0] = -23.239272;
      val[1829 * nCulm + 1] = 22.003480;
      val[1829 * nCulm + 2] = -1.485620;
      val[1829 * nCulm + 3] = -15.012619;
      val[1829 * nCulm + 4] = 35.072905;
      val[1829 * nCulm + 5] = 1.173465;
      val[1830 * nCulm + 0] = 2.583658;
      val[1830 * nCulm + 1] = 41.359905;
      val[1830 * nCulm + 2] = -10.050221;
      val[1830 * nCulm + 3] = -18.214799;
      val[1830 * nCulm + 4] = 44.200997;
      val[1830 * nCulm + 5] = 2.708530;
      val[1831 * nCulm + 0] = -3.489144;
      val[1831 * nCulm + 1] = 45.426642;
      val[1831 * nCulm + 2] = 5.552848;
      val[1831 * nCulm + 3] = -27.318946;
      val[1831 * nCulm + 4] = 7.979762;
      val[1831 * nCulm + 5] = 10.970892;
      val[1832 * nCulm + 0] = 47.835726;
      val[1832 * nCulm + 1] = -27.104612;
      val[1832 * nCulm + 2] = -49.570100;
      val[1832 * nCulm + 3] = 23.163205;
      val[1832 * nCulm + 4] = 39.611581;
      val[1832 * nCulm + 5] = -0.240973;
      val[1833 * nCulm + 0] = 34.616703;
      val[1833 * nCulm + 1] = 32.920499;
      val[1833 * nCulm + 2] = -40.601511;
      val[1833 * nCulm + 3] = 28.170582;
      val[1833 * nCulm + 4] = 14.538351;
      val[1833 * nCulm + 5] = 20.119769;
      val[1834 * nCulm + 0] = -26.676218;
      val[1834 * nCulm + 1] = -32.279985;
      val[1834 * nCulm + 2] = -33.422690;
      val[1834 * nCulm + 3] = -21.593303;
      val[1834 * nCulm + 4] = -20.963016;
      val[1834 * nCulm + 5] = 12.394291;
      val[1835 * nCulm + 0] = 5.000399;
      val[1835 * nCulm + 1] = 49.616200;
      val[1835 * nCulm + 2] = 10.481093;
      val[1835 * nCulm + 3] = 0.787310;
      val[1835 * nCulm + 4] = -7.071502;
      val[1835 * nCulm + 5] = -33.507757;
      val[1836 * nCulm + 0] = 0.178543;
      val[1836 * nCulm + 1] = -21.798081;
      val[1836 * nCulm + 2] = -46.881808;
      val[1836 * nCulm + 3] = -2.794661;
      val[1836 * nCulm + 4] = 10.832807;
      val[1836 * nCulm + 5] = -10.515659;
      val[1837 * nCulm + 0] = 37.718710;
      val[1837 * nCulm + 1] = -9.393785;
      val[1837 * nCulm + 2] = -11.141904;
      val[1837 * nCulm + 3] = -48.867079;
      val[1837 * nCulm + 4] = 37.067853;
      val[1837 * nCulm + 5] = -7.209548;
      val[1838 * nCulm + 0] = 13.159415;
      val[1838 * nCulm + 1] = -42.006454;
      val[1838 * nCulm + 2] = -23.977896;
      val[1838 * nCulm + 3] = 48.982151;
      val[1838 * nCulm + 4] = 0.903197;
      val[1838 * nCulm + 5] = 36.787156;
      val[1839 * nCulm + 0] = -7.003767;
      val[1839 * nCulm + 1] = 15.593732;
      val[1839 * nCulm + 2] = -43.224619;
      val[1839 * nCulm + 3] = 10.327968;
      val[1839 * nCulm + 4] = 18.810723;
      val[1839 * nCulm + 5] = 6.752665;
      val[1840 * nCulm + 0] = -41.655920;
      val[1840 * nCulm + 1] = 0.555152;
      val[1840 * nCulm + 2] = -10.014908;
      val[1840 * nCulm + 3] = -30.656283;
      val[1840 * nCulm + 4] = -25.572887;
      val[1840 * nCulm + 5] = 5.801475;
      val[1841 * nCulm + 0] = 16.186176;
      val[1841 * nCulm + 1] = -45.039164;
      val[1841 * nCulm + 2] = 3.732500;
      val[1841 * nCulm + 3] = -17.555809;
      val[1841 * nCulm + 4] = 37.231948;
      val[1841 * nCulm + 5] = -7.727759;
      val[1842 * nCulm + 0] = 24.735903;
      val[1842 * nCulm + 1] = 3.912226;
      val[1842 * nCulm + 2] = 28.999019;
      val[1842 * nCulm + 3] = -37.994965;
      val[1842 * nCulm + 4] = -3.217581;
      val[1842 * nCulm + 5] = 50.368589;
      val[1843 * nCulm + 0] = -14.352727;
      val[1843 * nCulm + 1] = -21.502139;
      val[1843 * nCulm + 2] = 32.713218;
      val[1843 * nCulm + 3] = -29.725483;
      val[1843 * nCulm + 4] = 19.855599;
      val[1843 * nCulm + 5] = -11.982042;
      val[1844 * nCulm + 0] = -38.666837;
      val[1844 * nCulm + 1] = -31.975151;
      val[1844 * nCulm + 2] = -15.888625;
      val[1844 * nCulm + 3] = -3.622956;
      val[1844 * nCulm + 4] = -22.513041;
      val[1844 * nCulm + 5] = 7.714449;
      val[1845 * nCulm + 0] = -34.633456;
      val[1845 * nCulm + 1] = -17.363477;
      val[1845 * nCulm + 2] = -36.513219;
      val[1845 * nCulm + 3] = -17.250958;
      val[1845 * nCulm + 4] = 43.247501;
      val[1845 * nCulm + 5] = -3.558465;
      val[1846 * nCulm + 0] = 13.745821;
      val[1846 * nCulm + 1] = -7.058388;
      val[1846 * nCulm + 2] = 30.549860;
      val[1846 * nCulm + 3] = -2.744341;
      val[1846 * nCulm + 4] = -2.083886;
      val[1846 * nCulm + 5] = 22.495890;
      val[1847 * nCulm + 0] = -15.915135;
      val[1847 * nCulm + 1] = -6.816813;
      val[1847 * nCulm + 2] = 6.237727;
      val[1847 * nCulm + 3] = -0.797037;
      val[1847 * nCulm + 4] = 44.017380;
      val[1847 * nCulm + 5] = -0.588742;
      val[1848 * nCulm + 0] = 9.833806;
      val[1848 * nCulm + 1] = -44.218243;
      val[1848 * nCulm + 2] = -15.848769;
      val[1848 * nCulm + 3] = 11.635007;
      val[1848 * nCulm + 4] = 43.327407;
      val[1848 * nCulm + 5] = -3.329579;
      val[1849 * nCulm + 0] = -9.612681;
      val[1849 * nCulm + 1] = 4.952976;
      val[1849 * nCulm + 2] = -25.544027;
      val[1849 * nCulm + 3] = -8.650264;
      val[1849 * nCulm + 4] = -10.336959;
      val[1849 * nCulm + 5] = 1.923002;
      val[1850 * nCulm + 0] = -22.267544;
      val[1850 * nCulm + 1] = 7.838641;
      val[1850 * nCulm + 2] = -32.643632;
      val[1850 * nCulm + 3] = 6.878683;
      val[1850 * nCulm + 4] = -28.896811;
      val[1850 * nCulm + 5] = -2.180716;
      val[1851 * nCulm + 0] = 38.345103;
      val[1851 * nCulm + 1] = 3.166757;
      val[1851 * nCulm + 2] = 1.001711;
      val[1851 * nCulm + 3] = 44.933751;
      val[1851 * nCulm + 4] = 34.222634;
      val[1851 * nCulm + 5] = 6.882782;
      val[1852 * nCulm + 0] = 40.966757;
      val[1852 * nCulm + 1] = 38.856218;
      val[1852 * nCulm + 2] = 42.478452;
      val[1852 * nCulm + 3] = -44.966835;
      val[1852 * nCulm + 4] = -18.201677;
      val[1852 * nCulm + 5] = 1.819062;
      val[1853 * nCulm + 0] = -43.398003;
      val[1853 * nCulm + 1] = -18.374556;
      val[1853 * nCulm + 2] = 13.636236;
      val[1853 * nCulm + 3] = 26.691776;
      val[1853 * nCulm + 4] = 29.075907;
      val[1853 * nCulm + 5] = 1.583979;
      val[1854 * nCulm + 0] = 42.969033;
      val[1854 * nCulm + 1] = -49.531980;
      val[1854 * nCulm + 2] = 24.755361;
      val[1854 * nCulm + 3] = -1.199694;
      val[1854 * nCulm + 4] = 43.135944;
      val[1854 * nCulm + 5] = -5.336817;
      val[1855 * nCulm + 0] = -10.954831;
      val[1855 * nCulm + 1] = -11.542733;
      val[1855 * nCulm + 2] = -47.018098;
      val[1855 * nCulm + 3] = 16.942133;
      val[1855 * nCulm + 4] = 33.729322;
      val[1855 * nCulm + 5] = 0.987713;
      val[1856 * nCulm + 0] = -40.275093;
      val[1856 * nCulm + 1] = -48.521465;
      val[1856 * nCulm + 2] = -12.444839;
      val[1856 * nCulm + 3] = -3.147177;
      val[1856 * nCulm + 4] = 43.199809;
      val[1856 * nCulm + 5] = -5.431250;
      val[1857 * nCulm + 0] = -11.937728;
      val[1857 * nCulm + 1] = 32.545659;
      val[1857 * nCulm + 2] = -11.576470;
      val[1857 * nCulm + 3] = -48.994698;
      val[1857 * nCulm + 4] = 46.322111;
      val[1857 * nCulm + 5] = -1.450813;
      val[1858 * nCulm + 0] = 31.890936;
      val[1858 * nCulm + 1] = -25.173380;
      val[1858 * nCulm + 2] = -9.762836;
      val[1858 * nCulm + 3] = -48.816563;
      val[1858 * nCulm + 4] = -47.266914;
      val[1858 * nCulm + 5] = 7.639391;
      val[1859 * nCulm + 0] = 15.278090;
      val[1859 * nCulm + 1] = -40.694260;
      val[1859 * nCulm + 2] = 49.428333;
      val[1859 * nCulm + 3] = -3.413058;
      val[1859 * nCulm + 4] = 45.412283;
      val[1859 * nCulm + 5] = -4.367317;
      val[1860 * nCulm + 0] = 49.188490;
      val[1860 * nCulm + 1] = -0.824759;
      val[1860 * nCulm + 2] = 4.923111;
      val[1860 * nCulm + 3] = -47.885258;
      val[1860 * nCulm + 4] = -47.145909;
      val[1860 * nCulm + 5] = 5.120366;
      val[1861 * nCulm + 0] = 15.916203;
      val[1861 * nCulm + 1] = 45.463622;
      val[1861 * nCulm + 2] = 24.267526;
      val[1861 * nCulm + 3] = 32.334519;
      val[1861 * nCulm + 4] = 45.075991;
      val[1861 * nCulm + 5] = 8.399416;
      val[1862 * nCulm + 0] = -29.466009;
      val[1862 * nCulm + 1] = -15.178483;
      val[1862 * nCulm + 2] = 21.462515;
      val[1862 * nCulm + 3] = 35.940710;
      val[1862 * nCulm + 4] = -16.983296;
      val[1862 * nCulm + 5] = -5.556541;
      val[1863 * nCulm + 0] = 24.112632;
      val[1863 * nCulm + 1] = -7.575396;
      val[1863 * nCulm + 2] = -31.627192;
      val[1863 * nCulm + 3] = 3.718358;
      val[1863 * nCulm + 4] = 23.520053;
      val[1863 * nCulm + 5] = -0.546216;
      val[1864 * nCulm + 0] = 36.117561;
      val[1864 * nCulm + 1] = -4.431847;
      val[1864 * nCulm + 2] = 41.012030;
      val[1864 * nCulm + 3] = 16.810352;
      val[1864 * nCulm + 4] = 43.457026;
      val[1864 * nCulm + 5] = 1.578265;
      val[1865 * nCulm + 0] = 37.634185;
      val[1865 * nCulm + 1] = 21.951431;
      val[1865 * nCulm + 2] = -40.439294;
      val[1865 * nCulm + 3] = 42.920284;
      val[1865 * nCulm + 4] = 37.915896;
      val[1865 * nCulm + 5] = 8.328436;
      val[1866 * nCulm + 0] = -42.246432;
      val[1866 * nCulm + 1] = 49.066926;
      val[1866 * nCulm + 2] = -1.241101;
      val[1866 * nCulm + 3] = -5.657363;
      val[1866 * nCulm + 4] = 32.073846;
      val[1866 * nCulm + 5] = 6.636214;
      val[1867 * nCulm + 0] = -12.134587;
      val[1867 * nCulm + 1] = -21.091064;
      val[1867 * nCulm + 2] = -6.777122;
      val[1867 * nCulm + 3] = -34.556156;
      val[1867 * nCulm + 4] = -36.678905;
      val[1867 * nCulm + 5] = 7.411153;
      val[1868 * nCulm + 0] = -11.450633;
      val[1868 * nCulm + 1] = -48.200562;
      val[1868 * nCulm + 2] = 30.407670;
      val[1868 * nCulm + 3] = 11.002937;
      val[1868 * nCulm + 4] = 42.055758;
      val[1868 * nCulm + 5] = -3.956555;
      val[1869 * nCulm + 0] = 42.229901;
      val[1869 * nCulm + 1] = -34.904668;
      val[1869 * nCulm + 2] = 1.048371;
      val[1869 * nCulm + 3] = -39.400291;
      val[1869 * nCulm + 4] = -9.693255;
      val[1869 * nCulm + 5] = 36.514009;
      val[1870 * nCulm + 0] = 22.645467;
      val[1870 * nCulm + 1] = 37.703314;
      val[1870 * nCulm + 2] = -25.487731;
      val[1870 * nCulm + 3] = 49.071570;
      val[1870 * nCulm + 4] = -10.506548;
      val[1870 * nCulm + 5] = -38.863188;
      val[1871 * nCulm + 0] = 4.505992;
      val[1871 * nCulm + 1] = 23.335896;
      val[1871 * nCulm + 2] = 21.583533;
      val[1871 * nCulm + 3] = -4.574594;
      val[1871 * nCulm + 4] = -47.053234;
      val[1871 * nCulm + 5] = -1.657298;
      val[1872 * nCulm + 0] = -11.340808;
      val[1872 * nCulm + 1] = -15.229428;
      val[1872 * nCulm + 2] = -11.082363;
      val[1872 * nCulm + 3] = -24.556253;
      val[1872 * nCulm + 4] = -9.464756;
      val[1872 * nCulm + 5] = 20.126856;
      val[1873 * nCulm + 0] = 13.425636;
      val[1873 * nCulm + 1] = 24.861131;
      val[1873 * nCulm + 2] = 18.418205;
      val[1873 * nCulm + 3] = -26.943246;
      val[1873 * nCulm + 4] = -3.424473;
      val[1873 * nCulm + 5] = 3.107917;
      val[1874 * nCulm + 0] = 26.776361;
      val[1874 * nCulm + 1] = 19.715124;
      val[1874 * nCulm + 2] = 30.687715;
      val[1874 * nCulm + 3] = 42.002643;
      val[1874 * nCulm + 4] = -5.835186;
      val[1874 * nCulm + 5] = -49.833663;
      val[1875 * nCulm + 0] = -12.170189;
      val[1875 * nCulm + 1] = -0.174660;
      val[1875 * nCulm + 2] = -15.143907;
      val[1875 * nCulm + 3] = 27.736982;
      val[1875 * nCulm + 4] = -22.735633;
      val[1875 * nCulm + 5] = -5.508202;
      val[1876 * nCulm + 0] = 5.727792;
      val[1876 * nCulm + 1] = 15.011378;
      val[1876 * nCulm + 2] = 9.717136;
      val[1876 * nCulm + 3] = -31.535685;
      val[1876 * nCulm + 4] = 15.875248;
      val[1876 * nCulm + 5] = -4.696856;
      val[1877 * nCulm + 0] = 45.623920;
      val[1877 * nCulm + 1] = -9.806149;
      val[1877 * nCulm + 2] = -17.439234;
      val[1877 * nCulm + 3] = 18.976967;
      val[1877 * nCulm + 4] = -45.506045;
      val[1877 * nCulm + 5] = -0.723907;
      val[1878 * nCulm + 0] = -13.660203;
      val[1878 * nCulm + 1] = -42.451333;
      val[1878 * nCulm + 2] = -13.788400;
      val[1878 * nCulm + 3] = 23.274080;
      val[1878 * nCulm + 4] = -38.172149;
      val[1878 * nCulm + 5] = 2.607973;
      val[1879 * nCulm + 0] = 44.639031;
      val[1879 * nCulm + 1] = 3.531824;
      val[1879 * nCulm + 2] = 42.479323;
      val[1879 * nCulm + 3] = -36.424447;
      val[1879 * nCulm + 4] = 1.204693;
      val[1879 * nCulm + 5] = -129.007714;
      val[1880 * nCulm + 0] = 47.143167;
      val[1880 * nCulm + 1] = 16.478398;
      val[1880 * nCulm + 2] = -42.556128;
      val[1880 * nCulm + 3] = 6.588933;
      val[1880 * nCulm + 4] = -49.159815;
      val[1880 * nCulm + 5] = -1.991029;
      val[1881 * nCulm + 0] = 18.478671;
      val[1881 * nCulm + 1] = -47.017779;
      val[1881 * nCulm + 2] = 12.826210;
      val[1881 * nCulm + 3] = -47.243355;
      val[1881 * nCulm + 4] = 29.102760;
      val[1881 * nCulm + 5] = -15.100826;
      val[1882 * nCulm + 0] = 36.178249;
      val[1882 * nCulm + 1] = 37.255175;
      val[1882 * nCulm + 2] = -6.680147;
      val[1882 * nCulm + 3] = -30.177978;
      val[1882 * nCulm + 4] = 17.148799;
      val[1882 * nCulm + 5] = 2.183415;
      val[1883 * nCulm + 0] = 18.495842;
      val[1883 * nCulm + 1] = -15.679442;
      val[1883 * nCulm + 2] = -1.126457;
      val[1883 * nCulm + 3] = 19.926052;
      val[1883 * nCulm + 4] = 3.893600;
      val[1883 * nCulm + 5] = 5.392478;
      val[1884 * nCulm + 0] = 48.962254;
      val[1884 * nCulm + 1] = -30.076958;
      val[1884 * nCulm + 2] = 2.601419;
      val[1884 * nCulm + 3] = -33.588333;
      val[1884 * nCulm + 4] = 23.763685;
      val[1884 * nCulm + 5] = -12.451074;
      val[1885 * nCulm + 0] = 30.569821;
      val[1885 * nCulm + 1] = 3.818619;
      val[1885 * nCulm + 2] = 29.290099;
      val[1885 * nCulm + 3] = -14.488599;
      val[1885 * nCulm + 4] = 42.407052;
      val[1885 * nCulm + 5] = -0.960947;
      val[1886 * nCulm + 0] = -4.220680;
      val[1886 * nCulm + 1] = -16.465901;
      val[1886 * nCulm + 2] = 26.550370;
      val[1886 * nCulm + 3] = 45.693467;
      val[1886 * nCulm + 4] = 25.541061;
      val[1886 * nCulm + 5] = 5.646526;
      val[1887 * nCulm + 0] = -15.306344;
      val[1887 * nCulm + 1] = 40.514927;
      val[1887 * nCulm + 2] = 27.265429;
      val[1887 * nCulm + 3] = 5.567991;
      val[1887 * nCulm + 4] = 21.436568;
      val[1887 * nCulm + 5] = 10.405407;
      val[1888 * nCulm + 0] = -4.750296;
      val[1888 * nCulm + 1] = -15.964839;
      val[1888 * nCulm + 2] = 26.307663;
      val[1888 * nCulm + 3] = -17.546858;
      val[1888 * nCulm + 4] = -27.447422;
      val[1888 * nCulm + 5] = 6.009123;
      val[1889 * nCulm + 0] = 18.074151;
      val[1889 * nCulm + 1] = 11.160538;
      val[1889 * nCulm + 2] = -22.884838;
      val[1889 * nCulm + 3] = -20.832114;
      val[1889 * nCulm + 4] = 4.780508;
      val[1889 * nCulm + 5] = -9.346135;
      val[1890 * nCulm + 0] = -9.108341;
      val[1890 * nCulm + 1] = 47.172798;
      val[1890 * nCulm + 2] = 3.864017;
      val[1890 * nCulm + 3] = 3.853510;
      val[1890 * nCulm + 4] = -30.974372;
      val[1890 * nCulm + 5] = -7.567560;
      val[1891 * nCulm + 0] = 17.601064;
      val[1891 * nCulm + 1] = 31.364707;
      val[1891 * nCulm + 2] = 19.309160;
      val[1891 * nCulm + 3] = -23.509661;
      val[1891 * nCulm + 4] = 10.272470;
      val[1891 * nCulm + 5] = 3.849437;
      val[1892 * nCulm + 0] = -13.936605;
      val[1892 * nCulm + 1] = 38.973427;
      val[1892 * nCulm + 2] = -14.451874;
      val[1892 * nCulm + 3] = -37.688883;
      val[1892 * nCulm + 4] = 41.121391;
      val[1892 * nCulm + 5] = 0.377859;
      val[1893 * nCulm + 0] = 29.206333;
      val[1893 * nCulm + 1] = 4.699407;
      val[1893 * nCulm + 2] = -40.128690;
      val[1893 * nCulm + 3] = 8.596248;
      val[1893 * nCulm + 4] = 33.698896;
      val[1893 * nCulm + 5] = 2.097502;
      val[1894 * nCulm + 0] = 34.536257;
      val[1894 * nCulm + 1] = 16.721081;
      val[1894 * nCulm + 2] = -41.210595;
      val[1894 * nCulm + 3] = -25.528601;
      val[1894 * nCulm + 4] = 36.006653;
      val[1894 * nCulm + 5] = -0.927812;
      val[1895 * nCulm + 0] = 0.476848;
      val[1895 * nCulm + 1] = 28.889345;
      val[1895 * nCulm + 2] = -41.457054;
      val[1895 * nCulm + 3] = 49.056023;
      val[1895 * nCulm + 4] = -0.863391;
      val[1895 * nCulm + 5] = -427.086818;
      val[1896 * nCulm + 0] = 7.471751;
      val[1896 * nCulm + 1] = -18.525094;
      val[1896 * nCulm + 2] = 20.489637;
      val[1896 * nCulm + 3] = 19.266102;
      val[1896 * nCulm + 4] = 4.305521;
      val[1896 * nCulm + 5] = 1.044637;
      val[1897 * nCulm + 0] = 45.082499;
      val[1897 * nCulm + 1] = -49.278789;
      val[1897 * nCulm + 2] = -33.831825;
      val[1897 * nCulm + 3] = -16.987314;
      val[1897 * nCulm + 4] = 20.180668;
      val[1897 * nCulm + 5] = -15.312575;
      val[1898 * nCulm + 0] = -8.407808;
      val[1898 * nCulm + 1] = -47.598389;
      val[1898 * nCulm + 2] = 23.250226;
      val[1898 * nCulm + 3] = -49.835874;
      val[1898 * nCulm + 4] = -25.967414;
      val[1898 * nCulm + 5] = 17.990292;
      val[1899 * nCulm + 0] = 9.972230;
      val[1899 * nCulm + 1] = -25.557404;
      val[1899 * nCulm + 2] = 46.832312;
      val[1899 * nCulm + 3] = 15.190868;
      val[1899 * nCulm + 4] = -13.891015;
      val[1899 * nCulm + 5] = 3.762375;
      val[1900 * nCulm + 0] = -13.028534;
      val[1900 * nCulm + 1] = -0.226860;
      val[1900 * nCulm + 2] = -45.495237;
      val[1900 * nCulm + 3] = -8.098741;
      val[1900 * nCulm + 4] = -42.138898;
      val[1900 * nCulm + 5] = 1.165189;
      val[1901 * nCulm + 0] = -23.150458;
      val[1901 * nCulm + 1] = -36.614372;
      val[1901 * nCulm + 2] = 44.473636;
      val[1901 * nCulm + 3] = 48.549023;
      val[1901 * nCulm + 4] = -24.437315;
      val[1901 * nCulm + 5] = -2.081657;
      val[1902 * nCulm + 0] = 27.529133;
      val[1902 * nCulm + 1] = -14.064838;
      val[1902 * nCulm + 2] = -38.661840;
      val[1902 * nCulm + 3] = -19.479255;
      val[1902 * nCulm + 4] = -49.100518;
      val[1902 * nCulm + 5] = 3.463680;
      val[1903 * nCulm + 0] = -33.689665;
      val[1903 * nCulm + 1] = 21.865020;
      val[1903 * nCulm + 2] = 3.874484;
      val[1903 * nCulm + 3] = -32.746496;
      val[1903 * nCulm + 4] = 24.482958;
      val[1903 * nCulm + 5] = -1.873735;
      val[1904 * nCulm + 0] = 31.766413;
      val[1904 * nCulm + 1] = 37.626747;
      val[1904 * nCulm + 2] = -35.580892;
      val[1904 * nCulm + 3] = 5.322666;
      val[1904 * nCulm + 4] = 7.183143;
      val[1904 * nCulm + 5] = 28.531524;
      val[1905 * nCulm + 0] = -0.628081;
      val[1905 * nCulm + 1] = 41.731871;
      val[1905 * nCulm + 2] = -4.049602;
      val[1905 * nCulm + 3] = -23.475765;
      val[1905 * nCulm + 4] = 16.169599;
      val[1905 * nCulm + 5] = 5.574117;
      val[1906 * nCulm + 0] = -35.446651;
      val[1906 * nCulm + 1] = -3.524717;
      val[1906 * nCulm + 2] = -20.912999;
      val[1906 * nCulm + 3] = -37.190435;
      val[1906 * nCulm + 4] = -22.315946;
      val[1906 * nCulm + 5] = 8.865905;
      val[1907 * nCulm + 0] = -36.734576;
      val[1907 * nCulm + 1] = 47.593824;
      val[1907 * nCulm + 2] = -25.476911;
      val[1907 * nCulm + 3] = 38.747922;
      val[1907 * nCulm + 4] = -29.764567;
      val[1907 * nCulm + 5] = -13.500563;
      val[1908 * nCulm + 0] = 23.882968;
      val[1908 * nCulm + 1] = -28.736922;
      val[1908 * nCulm + 2] = -16.099775;
      val[1908 * nCulm + 3] = 26.486551;
      val[1908 * nCulm + 4] = 38.129031;
      val[1908 * nCulm + 5] = -0.049361;
      val[1909 * nCulm + 0] = -48.548403;
      val[1909 * nCulm + 1] = 26.379867;
      val[1909 * nCulm + 2] = -7.602690;
      val[1909 * nCulm + 3] = 44.608747;
      val[1909 * nCulm + 4] = -24.927909;
      val[1909 * nCulm + 5] = -13.249380;
      val[1910 * nCulm + 0] = -31.568836;
      val[1910 * nCulm + 1] = 26.008847;
      val[1910 * nCulm + 2] = -32.147421;
      val[1910 * nCulm + 3] = 11.078737;
      val[1910 * nCulm + 4] = -0.349131;
      val[1910 * nCulm + 5] = -502.583881;
      val[1911 * nCulm + 0] = -28.166517;
      val[1911 * nCulm + 1] = 13.026885;
      val[1911 * nCulm + 2] = 40.804680;
      val[1911 * nCulm + 3] = -0.434470;
      val[1911 * nCulm + 4] = 35.047077;
      val[1911 * nCulm + 5] = 1.930687;
      val[1912 * nCulm + 0] = -25.029903;
      val[1912 * nCulm + 1] = 31.761690;
      val[1912 * nCulm + 2] = 49.027110;
      val[1912 * nCulm + 3] = 43.373602;
      val[1912 * nCulm + 4] = -37.651526;
      val[1912 * nCulm + 5] = -9.215577;
      val[1913 * nCulm + 0] = 29.363998;
      val[1913 * nCulm + 1] = 41.851634;
      val[1913 * nCulm + 2] = -34.792708;
      val[1913 * nCulm + 3] = 32.562764;
      val[1913 * nCulm + 4] = -35.186966;
      val[1913 * nCulm + 5] = -9.780188;
      val[1914 * nCulm + 0] = 37.115025;
      val[1914 * nCulm + 1] = -30.603027;
      val[1914 * nCulm + 2] = 13.497717;
      val[1914 * nCulm + 3] = 22.171073;
      val[1914 * nCulm + 4] = -20.786416;
      val[1914 * nCulm + 5] = 2.150064;
      val[1915 * nCulm + 0] = 14.876611;
      val[1915 * nCulm + 1] = 40.373180;
      val[1915 * nCulm + 2] = -10.402957;
      val[1915 * nCulm + 3] = -28.293446;
      val[1915 * nCulm + 4] = -17.705612;
      val[1915 * nCulm + 5] = -2.999338;
      val[1916 * nCulm + 0] = -18.850633;
      val[1916 * nCulm + 1] = -44.840762;
      val[1916 * nCulm + 2] = 16.735269;
      val[1916 * nCulm + 3] = -47.448342;
      val[1916 * nCulm + 4] = -27.718767;
      val[1916 * nCulm + 5] = 15.989543;
      val[1917 * nCulm + 0] = 41.787874;
      val[1917 * nCulm + 1] = -36.367054;
      val[1917 * nCulm + 2] = 38.146391;
      val[1917 * nCulm + 3] = 14.125665;
      val[1917 * nCulm + 4] = 11.407049;
      val[1917 * nCulm + 5] = -8.999023;
      val[1918 * nCulm + 0] = -42.392814;
      val[1918 * nCulm + 1] = -26.117702;
      val[1918 * nCulm + 2] = -37.933280;
      val[1918 * nCulm + 3] = 25.933215;
      val[1918 * nCulm + 4] = 19.968183;
      val[1918 * nCulm + 5] = 0.186269;
      val[1919 * nCulm + 0] = 42.607060;
      val[1919 * nCulm + 1] = -26.816366;
      val[1919 * nCulm + 2] = -25.118146;
      val[1919 * nCulm + 3] = 18.953300;
      val[1919 * nCulm + 4] = -16.648859;
      val[1919 * nCulm + 5] = 2.465499;
      val[1920 * nCulm + 0] = 12.425865;
      val[1920 * nCulm + 1] = 29.307076;
      val[1920 * nCulm + 2] = -30.677150;
      val[1920 * nCulm + 3] = 38.723971;
      val[1920 * nCulm + 4] = -14.072012;
      val[1920 * nCulm + 5] = -22.653267;
      val[1921 * nCulm + 0] = -36.393078;
      val[1921 * nCulm + 1] = -9.861400;
      val[1921 * nCulm + 2] = -5.561982;
      val[1921 * nCulm + 3] = -28.864410;
      val[1921 * nCulm + 4] = 13.890674;
      val[1921 * nCulm + 5] = -12.966060;
      val[1922 * nCulm + 0] = -47.470090;
      val[1922 * nCulm + 1] = 20.574364;
      val[1922 * nCulm + 2] = 23.417002;
      val[1922 * nCulm + 3] = 39.155165;
      val[1922 * nCulm + 4] = -10.296565;
      val[1922 * nCulm + 5] = -27.227678;
      val[1923 * nCulm + 0] = -25.544149;
      val[1923 * nCulm + 1] = -39.084647;
      val[1923 * nCulm + 2] = 15.151541;
      val[1923 * nCulm + 3] = -34.873766;
      val[1923 * nCulm + 4] = 45.819236;
      val[1923 * nCulm + 5] = -7.410237;
      val[1924 * nCulm + 0] = -18.351616;
      val[1924 * nCulm + 1] = -36.875356;
      val[1924 * nCulm + 2] = 35.525606;
      val[1924 * nCulm + 3] = -2.964007;
      val[1924 * nCulm + 4] = 19.771715;
      val[1924 * nCulm + 5] = -9.307513;
      val[1925 * nCulm + 0] = 28.792202;
      val[1925 * nCulm + 1] = -15.970962;
      val[1925 * nCulm + 2] = -27.313797;
      val[1925 * nCulm + 3] = 37.920977;
      val[1925 * nCulm + 4] = 42.905658;
      val[1925 * nCulm + 5] = 2.651516;
      val[1926 * nCulm + 0] = 39.986268;
      val[1926 * nCulm + 1] = 14.054324;
      val[1926 * nCulm + 2] = -13.091584;
      val[1926 * nCulm + 3] = -8.485463;
      val[1926 * nCulm + 4] = -5.845024;
      val[1926 * nCulm + 5] = -4.279695;
      val[1927 * nCulm + 0] = -28.901926;
      val[1927 * nCulm + 1] = 49.054915;
      val[1927 * nCulm + 2] = -19.520512;
      val[1927 * nCulm + 3] = 35.354108;
      val[1927 * nCulm + 4] = 28.237455;
      val[1927 * nCulm + 5] = 14.379152;
      val[1928 * nCulm + 0] = 48.211333;
      val[1928 * nCulm + 1] = -26.120830;
      val[1928 * nCulm + 2] = -25.574922;
      val[1928 * nCulm + 3] = 23.066435;
      val[1928 * nCulm + 4] = 28.683566;
      val[1928 * nCulm + 5] = -0.274033;
      val[1929 * nCulm + 0] = -40.723029;
      val[1929 * nCulm + 1] = -15.954211;
      val[1929 * nCulm + 2] = 22.106362;
      val[1929 * nCulm + 3] = -19.017763;
      val[1929 * nCulm + 4] = -19.305280;
      val[1929 * nCulm + 5] = 8.804546;
      val[1930 * nCulm + 0] = 13.570638;
      val[1930 * nCulm + 1] = 32.538494;
      val[1930 * nCulm + 2] = -19.566969;
      val[1930 * nCulm + 3] = -26.383475;
      val[1930 * nCulm + 4] = -34.114253;
      val[1930 * nCulm + 5] = -0.624005;
      val[1931 * nCulm + 0] = -48.714651;
      val[1931 * nCulm + 1] = -48.030554;
      val[1931 * nCulm + 2] = -40.333397;
      val[1931 * nCulm + 3] = -14.195566;
      val[1931 * nCulm + 4] = 23.889163;
      val[1931 * nCulm + 5] = -12.099313;
      val[1932 * nCulm + 0] = -17.160033;
      val[1932 * nCulm + 1] = -31.096294;
      val[1932 * nCulm + 2] = 18.660430;
      val[1932 * nCulm + 3] = -34.686712;
      val[1932 * nCulm + 4] = -13.199814;
      val[1932 * nCulm + 5] = 23.819188;
      val[1933 * nCulm + 0] = -20.804322;
      val[1933 * nCulm + 1] = 8.434855;
      val[1933 * nCulm + 2] = -32.210086;
      val[1933 * nCulm + 3] = 10.491953;
      val[1933 * nCulm + 4] = 3.808923;
      val[1933 * nCulm + 5] = 23.750265;
      val[1934 * nCulm + 0] = -1.963040;
      val[1934 * nCulm + 1] = -18.770596;
      val[1934 * nCulm + 2] = 3.025989;
      val[1934 * nCulm + 3] = 17.544573;
      val[1934 * nCulm + 4] = 4.518016;
      val[1934 * nCulm + 5] = -1.054452;
      val[1935 * nCulm + 0] = -18.116484;
      val[1935 * nCulm + 1] = 31.737003;
      val[1935 * nCulm + 2] = 36.721299;
      val[1935 * nCulm + 3] = 1.778986;
      val[1935 * nCulm + 4] = -21.948490;
      val[1935 * nCulm + 5] = -6.997939;
      val[1936 * nCulm + 0] = 43.002464;
      val[1936 * nCulm + 1] = -28.915671;
      val[1936 * nCulm + 2] = 20.180533;
      val[1936 * nCulm + 3] = 30.190439;
      val[1936 * nCulm + 4] = -4.482965;
      val[1936 * nCulm + 5] = -1.115963;
      val[1937 * nCulm + 0] = 27.441256;
      val[1937 * nCulm + 1] = -20.185851;
      val[1937 * nCulm + 2] = 21.380737;
      val[1937 * nCulm + 3] = 49.354504;
      val[1937 * nCulm + 4] = 9.398210;
      val[1937 * nCulm + 5] = 14.920560;
      val[1938 * nCulm + 0] = -21.258586;
      val[1938 * nCulm + 1] = -11.263879;
      val[1938 * nCulm + 2] = -4.225118;
      val[1938 * nCulm + 3] = -41.902803;
      val[1938 * nCulm + 4] = -31.775849;
      val[1938 * nCulm + 5] = 8.149714;
      val[1939 * nCulm + 0] = 26.231969;
      val[1939 * nCulm + 1] = 7.450843;
      val[1939 * nCulm + 2] = 10.374901;
      val[1939 * nCulm + 3] = 19.582446;
      val[1939 * nCulm + 4] = 18.473902;
      val[1939 * nCulm + 5] = 7.156396;
      val[1940 * nCulm + 0] = -15.460468;
      val[1940 * nCulm + 1] = 26.773319;
      val[1940 * nCulm + 2] = -24.135887;
      val[1940 * nCulm + 3] = 5.533568;
      val[1940 * nCulm + 4] = 47.364597;
      val[1940 * nCulm + 5] = 3.458556;
      val[1941 * nCulm + 0] = 30.159954;
      val[1941 * nCulm + 1] = 15.923263;
      val[1941 * nCulm + 2] = -40.750897;
      val[1941 * nCulm + 3] = 38.078830;
      val[1941 * nCulm + 4] = 36.873426;
      val[1941 * nCulm + 5] = 7.162090;
      val[1942 * nCulm + 0] = 42.518233;
      val[1942 * nCulm + 1] = 9.728033;
      val[1942 * nCulm + 2] = 0.991520;
      val[1942 * nCulm + 3] = -9.718040;
      val[1942 * nCulm + 4] = -24.502681;
      val[1942 * nCulm + 5] = 0.228070;
      val[1943 * nCulm + 0] = 49.770204;
      val[1943 * nCulm + 1] = -29.139273;
      val[1943 * nCulm + 2] = 31.734550;
      val[1943 * nCulm + 3] = -44.799607;
      val[1943 * nCulm + 4] = 5.801284;
      val[1943 * nCulm + 5] = -60.097566;
      val[1944 * nCulm + 0] = -10.502706;
      val[1944 * nCulm + 1] = 28.335521;
      val[1944 * nCulm + 2] = 11.482182;
      val[1944 * nCulm + 3] = -35.248172;
      val[1944 * nCulm + 4] = 30.622124;
      val[1944 * nCulm + 5] = -0.838505;
      val[1945 * nCulm + 0] = 35.632578;
      val[1945 * nCulm + 1] = 9.396952;
      val[1945 * nCulm + 2] = -26.082285;
      val[1945 * nCulm + 3] = -26.854283;
      val[1945 * nCulm + 4] = -24.917255;
      val[1945 * nCulm + 5] = 3.546231;
      val[1946 * nCulm + 0] = -35.075478;
      val[1946 * nCulm + 1] = 25.243922;
      val[1946 * nCulm + 2] = -21.512418;
      val[1946 * nCulm + 3] = -45.769367;
      val[1946 * nCulm + 4] = -29.146574;
      val[1946 * nCulm + 5] = 3.563283;
      val[1947 * nCulm + 0] = -10.314373;
      val[1947 * nCulm + 1] = 17.108097;
      val[1947 * nCulm + 2] = 17.836966;
      val[1947 * nCulm + 3] = -3.476312;
      val[1947 * nCulm + 4] = -5.670466;
      val[1947 * nCulm + 5] = -11.148921;
      val[1948 * nCulm + 0] = 11.178675;
      val[1948 * nCulm + 1] = 7.955117;
      val[1948 * nCulm + 2] = -5.794767;
      val[1948 * nCulm + 3] = 22.765098;
      val[1948 * nCulm + 4] = 23.259114;
      val[1948 * nCulm + 5] = 6.481701;
      val[1949 * nCulm + 0] = -4.460729;
      val[1949 * nCulm + 1] = 5.185650;
      val[1949 * nCulm + 2] = -23.451059;
      val[1949 * nCulm + 3] = -9.386137;
      val[1949 * nCulm + 4] = 9.988354;
      val[1949 * nCulm + 5] = -1.760549;
      val[1950 * nCulm + 0] = -41.266475;
      val[1950 * nCulm + 1] = -1.406556;
      val[1950 * nCulm + 2] = 25.897337;
      val[1950 * nCulm + 3] = -20.524768;
      val[1950 * nCulm + 4] = 29.989286;
      val[1950 * nCulm + 5] = -3.231512;
      val[1951 * nCulm + 0] = -44.522982;
      val[1951 * nCulm + 1] = 4.339007;
      val[1951 * nCulm + 2] = -43.110820;
      val[1951 * nCulm + 3] = 36.442404;
      val[1951 * nCulm + 4] = -9.329010;
      val[1951 * nCulm + 5] = -20.461587;
      val[1952 * nCulm + 0] = -2.046624;
      val[1952 * nCulm + 1] = -22.786317;
      val[1952 * nCulm + 2] = -33.308476;
      val[1952 * nCulm + 3] = -12.981166;
      val[1952 * nCulm + 4] = 7.954459;
      val[1952 * nCulm + 5] = -21.053587;
      val[1953 * nCulm + 0] = 45.931280;
      val[1953 * nCulm + 1] = 8.143888;
      val[1953 * nCulm + 2] = -28.131687;
      val[1953 * nCulm + 3] = 32.867618;
      val[1953 * nCulm + 4] = -25.127504;
      val[1953 * nCulm + 5] = -7.495444;
      val[1954 * nCulm + 0] = 19.995517;
      val[1954 * nCulm + 1] = 4.802449;
      val[1954 * nCulm + 2] = -29.274313;
      val[1954 * nCulm + 3] = -30.108035;
      val[1954 * nCulm + 4] = 9.171628;
      val[1954 * nCulm + 5] = -12.829816;
      val[1955 * nCulm + 0] = 32.675344;
      val[1955 * nCulm + 1] = -43.560390;
      val[1955 * nCulm + 2] = -18.815116;
      val[1955 * nCulm + 3] = -5.430443;
      val[1955 * nCulm + 4] = -20.037061;
      val[1955 * nCulm + 5] = 11.803051;
      val[1956 * nCulm + 0] = -27.119667;
      val[1956 * nCulm + 1] = -22.413993;
      val[1956 * nCulm + 2] = 30.563084;
      val[1956 * nCulm + 3] = 27.145333;
      val[1956 * nCulm + 4] = 46.416255;
      val[1956 * nCulm + 5] = 0.712482;
      val[1957 * nCulm + 0] = 12.125470;
      val[1957 * nCulm + 1] = 23.449243;
      val[1957 * nCulm + 2] = 1.078025;
      val[1957 * nCulm + 3] = -5.487746;
      val[1957 * nCulm + 4] = 24.983212;
      val[1957 * nCulm + 5] = 3.632995;
      val[1958 * nCulm + 0] = -48.920177;
      val[1958 * nCulm + 1] = 28.086311;
      val[1958 * nCulm + 2] = 12.201669;
      val[1958 * nCulm + 3] = -27.627372;
      val[1958 * nCulm + 4] = -23.515157;
      val[1958 * nCulm + 5] = 0.137621;
      val[1959 * nCulm + 0] = -34.447971;
      val[1959 * nCulm + 1] = -7.609481;
      val[1959 * nCulm + 2] = -29.657443;
      val[1959 * nCulm + 3] = 7.365464;
      val[1959 * nCulm + 4] = -32.246025;
      val[1959 * nCulm + 5] = 0.265819;
      val[1960 * nCulm + 0] = -5.067451;
      val[1960 * nCulm + 1] = 27.427431;
      val[1960 * nCulm + 2] = -40.834168;
      val[1960 * nCulm + 3] = 30.147081;
      val[1960 * nCulm + 4] = 3.250664;
      val[1960 * nCulm + 5] = 84.064982;
      val[1961 * nCulm + 0] = 39.414969;
      val[1961 * nCulm + 1] = 31.620288;
      val[1961 * nCulm + 2] = -13.971866;
      val[1961 * nCulm + 3] = 13.820576;
      val[1961 * nCulm + 4] = -12.421084;
      val[1961 * nCulm + 5] = -17.086263;
      val[1962 * nCulm + 0] = -6.133194;
      val[1962 * nCulm + 1] = -36.824965;
      val[1962 * nCulm + 2] = 36.421609;
      val[1962 * nCulm + 3] = 28.843804;
      val[1962 * nCulm + 4] = 24.995579;
      val[1962 * nCulm + 5] = -1.281367;
      val[1963 * nCulm + 0] = 16.344416;
      val[1963 * nCulm + 1] = 13.718499;
      val[1963 * nCulm + 2] = 12.864934;
      val[1963 * nCulm + 3] = 5.363824;
      val[1963 * nCulm + 4] = 5.378886;
      val[1963 * nCulm + 5] = 17.022137;
      val[1964 * nCulm + 0] = 4.402345;
      val[1964 * nCulm + 1] = -8.608834;
      val[1964 * nCulm + 2] = 10.719364;
      val[1964 * nCulm + 3] = -3.070975;
      val[1964 * nCulm + 4] = 8.722065;
      val[1964 * nCulm + 5] = -6.108457;
      val[1965 * nCulm + 0] = -11.872904;
      val[1965 * nCulm + 1] = -19.065665;
      val[1965 * nCulm + 2] = 10.984032;
      val[1965 * nCulm + 3] = -10.141668;
      val[1965 * nCulm + 4] = 47.138261;
      val[1965 * nCulm + 5] = -2.702820;
      val[1966 * nCulm + 0] = -12.818277;
      val[1966 * nCulm + 1] = 27.052489;
      val[1966 * nCulm + 2] = -49.586379;
      val[1966 * nCulm + 3] = 7.606620;
      val[1966 * nCulm + 4] = 45.248471;
      val[1966 * nCulm + 5] = 3.855606;
      val[1967 * nCulm + 0] = -18.223848;
      val[1967 * nCulm + 1] = 36.621103;
      val[1967 * nCulm + 2] = 26.094295;
      val[1967 * nCulm + 3] = -27.694391;
      val[1967 * nCulm + 4] = 22.401494;
      val[1967 * nCulm + 5] = 2.116174;
      val[1968 * nCulm + 0] = 12.462952;
      val[1968 * nCulm + 1] = -19.521122;
      val[1968 * nCulm + 2] = -1.102101;
      val[1968 * nCulm + 3] = -19.701788;
      val[1968 * nCulm + 4] = 25.634699;
      val[1968 * nCulm + 5] = -7.012336;
      val[1969 * nCulm + 0] = -37.299321;
      val[1969 * nCulm + 1] = 16.188453;
      val[1969 * nCulm + 2] = 39.047390;
      val[1969 * nCulm + 3] = 20.658367;
      val[1969 * nCulm + 4] = -25.475588;
      val[1969 * nCulm + 5] = -6.616094;
      val[1970 * nCulm + 0] = -48.767950;
      val[1970 * nCulm + 1] = -34.966039;
      val[1970 * nCulm + 2] = 22.681706;
      val[1970 * nCulm + 3] = 36.102343;
      val[1970 * nCulm + 4] = -20.384789;
      val[1970 * nCulm + 5] = -0.033849;
      val[1971 * nCulm + 0] = -41.914995;
      val[1971 * nCulm + 1] = -7.785301;
      val[1971 * nCulm + 2] = 0.013690;
      val[1971 * nCulm + 3] = -0.373485;
      val[1971 * nCulm + 4] = -19.010687;
      val[1971 * nCulm + 5] = 2.261397;
      val[1972 * nCulm + 0] = -4.974926;
      val[1972 * nCulm + 1] = 35.228854;
      val[1972 * nCulm + 2] = -0.247848;
      val[1972 * nCulm + 3] = 10.773943;
      val[1972 * nCulm + 4] = 24.884009;
      val[1972 * nCulm + 5] = 8.980462;
      val[1973 * nCulm + 0] = -42.999529;
      val[1973 * nCulm + 1] = 10.155850;
      val[1973 * nCulm + 2] = 10.934939;
      val[1973 * nCulm + 3] = 31.463278;
      val[1973 * nCulm + 4] = -34.337914;
      val[1973 * nCulm + 5] = -5.507017;
      val[1974 * nCulm + 0] = -20.084981;
      val[1974 * nCulm + 1] = -49.248377;
      val[1974 * nCulm + 2] = -10.046861;
      val[1974 * nCulm + 3] = 44.051309;
      val[1974 * nCulm + 4] = -7.056689;
      val[1974 * nCulm + 5] = 3.715977;
      val[1975 * nCulm + 0] = 46.014627;
      val[1975 * nCulm + 1] = 17.799878;
      val[1975 * nCulm + 2] = -21.102979;
      val[1975 * nCulm + 3] = -35.925058;
      val[1975 * nCulm + 4] = -35.106039;
      val[1975 * nCulm + 5] = 2.673811;
      val[1976 * nCulm + 0] = 43.238324;
      val[1976 * nCulm + 1] = -35.728465;
      val[1976 * nCulm + 2] = -47.064157;
      val[1976 * nCulm + 3] = -9.012823;
      val[1976 * nCulm + 4] = 23.556266;
      val[1976 * nCulm + 5] = -8.760195;
      val[1977 * nCulm + 0] = -9.640864;
      val[1977 * nCulm + 1] = 22.884486;
      val[1977 * nCulm + 2] = -0.571659;
      val[1977 * nCulm + 3] = -24.065614;
      val[1977 * nCulm + 4] = -1.529486;
      val[1977 * nCulm + 5] = 3.885262;
      val[1978 * nCulm + 0] = -37.995636;
      val[1978 * nCulm + 1] = -41.673957;
      val[1978 * nCulm + 2] = -16.118493;
      val[1978 * nCulm + 3] = -35.805958;
      val[1978 * nCulm + 4] = 1.548174;
      val[1978 * nCulm + 5] = -236.654394;
      val[1979 * nCulm + 0] = 36.530907;
      val[1979 * nCulm + 1] = -6.641896;
      val[1979 * nCulm + 2] = 1.662650;
      val[1979 * nCulm + 3] = -46.381177;
      val[1979 * nCulm + 4] = 24.266202;
      val[1979 * nCulm + 5] = -10.112610;
      val[1980 * nCulm + 0] = -26.130360;
      val[1980 * nCulm + 1] = 40.654062;
      val[1980 * nCulm + 2] = 8.183747;
      val[1980 * nCulm + 3] = 49.292008;
      val[1980 * nCulm + 4] = 13.482657;
      val[1980 * nCulm + 5] = 31.807213;
      val[1981 * nCulm + 0] = 33.495358;
      val[1981 * nCulm + 1] = -13.073180;
      val[1981 * nCulm + 2] = -6.656534;
      val[1981 * nCulm + 3] = 20.273315;
      val[1981 * nCulm + 4] = 3.978025;
      val[1981 * nCulm + 5] = 8.797226;
      val[1982 * nCulm + 0] = -17.405770;
      val[1982 * nCulm + 1] = 38.208199;
      val[1982 * nCulm + 2] = -5.846342;
      val[1982 * nCulm + 3] = 43.674955;
      val[1982 * nCulm + 4] = 48.146695;
      val[1982 * nCulm + 5] = 8.279987;
      val[1983 * nCulm + 0] = -43.240403;
      val[1983 * nCulm + 1] = 18.142426;
      val[1983 * nCulm + 2] = 49.217557;
      val[1983 * nCulm + 3] = -5.901512;
      val[1983 * nCulm + 4] = -44.491696;
      val[1983 * nCulm + 5] = -1.072273;
      val[1984 * nCulm + 0] = 8.047071;
      val[1984 * nCulm + 1] = 13.998941;
      val[1984 * nCulm + 2] = -45.192649;
      val[1984 * nCulm + 3] = -44.004759;
      val[1984 * nCulm + 4] = -49.088698;
      val[1984 * nCulm + 5] = 3.123284;
      val[1985 * nCulm + 0] = 34.151389;
      val[1985 * nCulm + 1] = 47.136578;
      val[1985 * nCulm + 2] = -47.996692;
      val[1985 * nCulm + 3] = -3.146498;
      val[1985 * nCulm + 4] = 42.981475;
      val[1985 * nCulm + 5] = 5.074406;
      val[1986 * nCulm + 0] = 26.476955;
      val[1986 * nCulm + 1] = -20.738540;
      val[1986 * nCulm + 2] = 11.523348;
      val[1986 * nCulm + 3] = -45.208602;
      val[1986 * nCulm + 4] = -21.535588;
      val[1986 * nCulm + 5] = 14.724603;
      val[1987 * nCulm + 0] = 11.580714;
      val[1987 * nCulm + 1] = -46.770816;
      val[1987 * nCulm + 2] = -5.446246;
      val[1987 * nCulm + 3] = -21.737395;
      val[1987 * nCulm + 4] = -42.806247;
      val[1987 * nCulm + 5] = 7.805348;
      val[1988 * nCulm + 0] = 12.132551;
      val[1988 * nCulm + 1] = -7.434202;
      val[1988 * nCulm + 2] = 41.674336;
      val[1988 * nCulm + 3] = 26.945897;
      val[1988 * nCulm + 4] = 24.452282;
      val[1988 * nCulm + 5] = 4.006963;
      val[1989 * nCulm + 0] = 18.469834;
      val[1989 * nCulm + 1] = 30.865668;
      val[1989 * nCulm + 2] = 43.067383;
      val[1989 * nCulm + 3] = -16.317046;
      val[1989 * nCulm + 4] = 12.144673;
      val[1989 * nCulm + 5] = 5.900262;
      val[1990 * nCulm + 0] = -2.275764;
      val[1990 * nCulm + 1] = -6.165256;
      val[1990 * nCulm + 2] = -29.718589;
      val[1990 * nCulm + 3] = -41.902203;
      val[1990 * nCulm + 4] = 22.132700;
      val[1990 * nCulm + 5] = -10.049781;
      val[1991 * nCulm + 0] = 30.780241;
      val[1991 * nCulm + 1] = -29.502816;
      val[1991 * nCulm + 2] = -31.837498;
      val[1991 * nCulm + 3] = 15.144570;
      val[1991 * nCulm + 4] = 4.326418;
      val[1991 * nCulm + 5] = -15.478693;
      val[1992 * nCulm + 0] = 20.452307;
      val[1992 * nCulm + 1] = -11.152044;
      val[1992 * nCulm + 2] = -36.095799;
      val[1992 * nCulm + 3] = -47.922689;
      val[1992 * nCulm + 4] = -39.680346;
      val[1992 * nCulm + 5] = 7.276824;
      val[1993 * nCulm + 0] = 41.200288;
      val[1993 * nCulm + 1] = -38.956036;
      val[1993 * nCulm + 2] = 6.883342;
      val[1993 * nCulm + 3] = -38.997459;
      val[1993 * nCulm + 4] = 46.368480;
      val[1993 * nCulm + 5] = -7.727558;
      val[1994 * nCulm + 0] = 35.818648;
      val[1994 * nCulm + 1] = -39.882310;
      val[1994 * nCulm + 2] = -18.100462;
      val[1994 * nCulm + 3] = -40.599337;
      val[1994 * nCulm + 4] = -4.808476;
      val[1994 * nCulm + 5] = 79.453947;
      val[1995 * nCulm + 0] = -1.079134;
      val[1995 * nCulm + 1] = -47.890905;
      val[1995 * nCulm + 2] = 24.140958;
      val[1995 * nCulm + 3] = -0.124922;
      val[1995 * nCulm + 4] = -3.389022;
      val[1995 * nCulm + 5] = 67.292091;
      val[1996 * nCulm + 0] = -48.748254;
      val[1996 * nCulm + 1] = -17.756356;
      val[1996 * nCulm + 2] = -25.296763;
      val[1996 * nCulm + 3] = -7.656427;
      val[1996 * nCulm + 4] = 44.584127;
      val[1996 * nCulm + 5] = -2.467982;
      val[1997 * nCulm + 0] = -21.271498;
      val[1997 * nCulm + 1] = 17.546327;
      val[1997 * nCulm + 2] = 31.225111;
      val[1997 * nCulm + 3] = 14.781582;
      val[1997 * nCulm + 4] = 30.577863;
      val[1997 * nCulm + 5] = 5.234234;
      val[1998 * nCulm + 0] = -49.801135;
      val[1998 * nCulm + 1] = 21.075641;
      val[1998 * nCulm + 2] = 1.425204;
      val[1998 * nCulm + 3] = 29.691145;
      val[1998 * nCulm + 4] = -39.103713;
      val[1998 * nCulm + 5] = -5.915097;
      val[1999 * nCulm + 0] = -19.540852;
      val[1999 * nCulm + 1] = -30.754217;
      val[1999 * nCulm + 2] = -33.038078;
      val[1999 * nCulm + 3] = 43.181245;
      val[1999 * nCulm + 4] = 45.608553;
      val[1999 * nCulm + 5] = 1.519698;



      IntPtr TestData = Marshal.AllocHGlobal(sizeof(Double) * n * nCulm);
      Marshal.Copy(val, 0, TestData, n * nCulm);

      return TestData;
    }

    private static IntPtr GetTrainData(int indepLen, int depLen, int n) {
      int nCulm = indepLen + depLen;

      double[] val = new double[n * nCulm];

      val[0 * nCulm + 0] = -21.639789;
      val[0 * nCulm + 1] = -28.078086;
      val[0 * nCulm + 2] = 41.713222;
      val[0 * nCulm + 3] = 10.725847;
      val[0 * nCulm + 4] = -16.372946;
      val[0 * nCulm + 5] = 5.246442;
      val[1 * nCulm + 0] = 49.821839;
      val[1 * nCulm + 1] = 27.183868;
      val[1 * nCulm + 2] = -13.874773;
      val[1 * nCulm + 3] = 18.415933;
      val[1 * nCulm + 4] = 25.416896;
      val[1 * nCulm + 5] = 8.721952;
      val[2 * nCulm + 0] = -7.861182;
      val[2 * nCulm + 1] = 48.626631;
      val[2 * nCulm + 2] = 27.549726;
      val[2 * nCulm + 3] = 23.173792;
      val[2 * nCulm + 4] = 7.018672;
      val[2 * nCulm + 5] = 48.651598;
      val[3 * nCulm + 0] = -7.875011;
      val[3 * nCulm + 1] = 33.022808;
      val[3 * nCulm + 2] = -42.167314;
      val[3 * nCulm + 3] = -27.888553;
      val[3 * nCulm + 4] = 14.322524;
      val[3 * nCulm + 5] = 1.926778;
      val[4 * nCulm + 0] = 2.453036;
      val[4 * nCulm + 1] = -29.671108;
      val[4 * nCulm + 2] = 34.059408;
      val[4 * nCulm + 3] = -6.459488;
      val[4 * nCulm + 4] = -41.954837;
      val[4 * nCulm + 5] = 4.306244;
      val[5 * nCulm + 0] = 18.675992;
      val[5 * nCulm + 1] = 25.617428;
      val[5 * nCulm + 2] = 0.153721;
      val[5 * nCulm + 3] = 34.503576;
      val[5 * nCulm + 4] = 21.407313;
      val[5 * nCulm + 5] = 13.523250;
      val[6 * nCulm + 0] = -20.187300;
      val[6 * nCulm + 1] = 6.994981;
      val[6 * nCulm + 2] = -3.401957;
      val[6 * nCulm + 3] = -46.624527;
      val[6 * nCulm + 4] = -27.254819;
      val[6 * nCulm + 5] = 7.112447;
      val[7 * nCulm + 0] = 38.370660;
      val[7 * nCulm + 1] = 17.488568;
      val[7 * nCulm + 2] = -5.527242;
      val[7 * nCulm + 3] = 17.799555;
      val[7 * nCulm + 4] = 3.961027;
      val[7 * nCulm + 5] = 42.398465;
      val[8 * nCulm + 0] = -14.266651;
      val[8 * nCulm + 1] = -39.938616;
      val[8 * nCulm + 2] = 38.013487;
      val[8 * nCulm + 3] = -28.403790;
      val[8 * nCulm + 4] = 36.004745;
      val[8 * nCulm + 5] = -8.754577;
      val[9 * nCulm + 0] = 30.948622;
      val[9 * nCulm + 1] = -47.943454;
      val[9 * nCulm + 2] = 30.970309;
      val[9 * nCulm + 3] = 20.418247;
      val[9 * nCulm + 4] = -32.455894;
      val[9 * nCulm + 5] = 4.244247;
      val[10 * nCulm + 0] = -13.936659;
      val[10 * nCulm + 1] = -38.697351;
      val[10 * nCulm + 2] = 0.785206;
      val[10 * nCulm + 3] = 34.785158;
      val[10 * nCulm + 4] = -34.387979;
      val[10 * nCulm + 5] = 0.768494;
      val[11 * nCulm + 0] = -19.650230;
      val[11 * nCulm + 1] = 43.996940;
      val[11 * nCulm + 2] = -46.327543;
      val[11 * nCulm + 3] = 43.867408;
      val[11 * nCulm + 4] = -46.310906;
      val[11 * nCulm + 5] = -8.750417;
      val[12 * nCulm + 0] = 36.690440;
      val[12 * nCulm + 1] = 5.747139;
      val[12 * nCulm + 2] = -41.555913;
      val[12 * nCulm + 3] = -23.420287;
      val[12 * nCulm + 4] = -34.480656;
      val[12 * nCulm + 5] = 2.656082;
      val[13 * nCulm + 0] = -9.978066;
      val[13 * nCulm + 1] = 47.568559;
      val[13 * nCulm + 2] = -39.221353;
      val[13 * nCulm + 3] = -5.568600;
      val[13 * nCulm + 4] = 37.617327;
      val[13 * nCulm + 5] = 5.514794;
      val[14 * nCulm + 0] = -11.556172;
      val[14 * nCulm + 1] = -39.115491;
      val[14 * nCulm + 2] = 27.716042;
      val[14 * nCulm + 3] = 43.289950;
      val[14 * nCulm + 4] = -36.204064;
      val[14 * nCulm + 5] = -0.315770;
      val[15 * nCulm + 0] = -48.531087;
      val[15 * nCulm + 1] = -14.043241;
      val[15 * nCulm + 2] = 16.546614;
      val[15 * nCulm + 3] = -25.184800;
      val[15 * nCulm + 4] = 49.476302;
      val[15 * nCulm + 5] = -3.522895;
      val[16 * nCulm + 0] = -43.943755;
      val[16 * nCulm + 1] = -41.505513;
      val[16 * nCulm + 2] = -34.413326;
      val[16 * nCulm + 3] = 33.007688;
      val[16 * nCulm + 4] = 49.910032;
      val[16 * nCulm + 5] = -0.575911;
      val[17 * nCulm + 0] = -34.390878;
      val[17 * nCulm + 1] = -47.563521;
      val[17 * nCulm + 2] = 29.705234;
      val[17 * nCulm + 3] = 4.326070;
      val[17 * nCulm + 4] = 33.909866;
      val[17 * nCulm + 5] = -5.805331;
      val[18 * nCulm + 0] = -27.427145;
      val[18 * nCulm + 1] = -47.914824;
      val[18 * nCulm + 2] = -48.969430;
      val[18 * nCulm + 3] = 0.212677;
      val[18 * nCulm + 4] = -2.483620;
      val[18 * nCulm + 5] = 91.141734;
      val[19 * nCulm + 0] = -46.865316;
      val[19 * nCulm + 1] = -22.095598;
      val[19 * nCulm + 2] = -45.296294;
      val[19 * nCulm + 3] = 12.373731;
      val[19 * nCulm + 4] = -7.088740;
      val[19 * nCulm + 5] = 6.721540;
      val[20 * nCulm + 0] = 10.678629;
      val[20 * nCulm + 1] = 10.131870;
      val[20 * nCulm + 2] = -45.755898;
      val[20 * nCulm + 3] = -38.601034;
      val[20 * nCulm + 4] = -15.446805;
      val[20 * nCulm + 5] = 8.953749;
      val[21 * nCulm + 0] = -2.612848;
      val[21 * nCulm + 1] = -21.840514;
      val[21 * nCulm + 2] = 19.351421;
      val[21 * nCulm + 3] = -47.023412;
      val[21 * nCulm + 4] = -28.916682;
      val[21 * nCulm + 5] = 11.502245;
      val[22 * nCulm + 0] = 34.872927;
      val[22 * nCulm + 1] = 7.848129;
      val[22 * nCulm + 2] = -3.216654;
      val[22 * nCulm + 3] = 27.217195;
      val[22 * nCulm + 4] = 37.948511;
      val[22 * nCulm + 5] = 4.603712;
      val[23 * nCulm + 0] = 48.755791;
      val[23 * nCulm + 1] = 6.123460;
      val[23 * nCulm + 2] = -5.646605;
      val[23 * nCulm + 3] = -1.467923;
      val[23 * nCulm + 4] = 3.867234;
      val[23 * nCulm + 5] = 5.928184;
      val[24 * nCulm + 0] = -1.696169;
      val[24 * nCulm + 1] = -27.585694;
      val[24 * nCulm + 2] = 49.975305;
      val[24 * nCulm + 3] = 39.297959;
      val[24 * nCulm + 4] = -47.987957;
      val[24 * nCulm + 5] = -0.925249;
      val[25 * nCulm + 0] = -40.827795;
      val[25 * nCulm + 1] = 29.770397;
      val[25 * nCulm + 2] = 18.414433;
      val[25 * nCulm + 3] = 5.962366;
      val[25 * nCulm + 4] = -29.964533;
      val[25 * nCulm + 5] = -5.414509;
      val[26 * nCulm + 0] = -34.540434;
      val[26 * nCulm + 1] = 13.078456;
      val[26 * nCulm + 2] = 25.018113;
      val[26 * nCulm + 3] = 39.926208;
      val[26 * nCulm + 4] = -36.797200;
      val[26 * nCulm + 5] = -6.588148;
      val[27 * nCulm + 0] = -20.377869;
      val[27 * nCulm + 1] = 25.178500;
      val[27 * nCulm + 2] = 12.103377;
      val[27 * nCulm + 3] = 48.218568;
      val[27 * nCulm + 4] = -46.371914;
      val[27 * nCulm + 5] = -7.261879;
      val[28 * nCulm + 0] = -9.922767;
      val[28 * nCulm + 1] = 30.828812;
      val[28 * nCulm + 2] = 7.731789;
      val[28 * nCulm + 3] = -36.451202;
      val[28 * nCulm + 4] = 47.366478;
      val[28 * nCulm + 5] = -0.331846;
      val[29 * nCulm + 0] = 11.895450;
      val[29 * nCulm + 1] = 25.099919;
      val[29 * nCulm + 2] = 12.831645;
      val[29 * nCulm + 3] = -2.107199;
      val[29 * nCulm + 4] = 31.762643;
      val[29 * nCulm + 5] = 3.656422;
      val[30 * nCulm + 0] = 4.405313;
      val[30 * nCulm + 1] = 35.721082;
      val[30 * nCulm + 2] = -29.072920;
      val[30 * nCulm + 3] = 42.954735;
      val[30 * nCulm + 4] = -4.115971;
      val[30 * nCulm + 5] = -90.246557;
      val[31 * nCulm + 0] = -2.327290;
      val[31 * nCulm + 1] = -49.300842;
      val[31 * nCulm + 2] = -3.101383;
      val[31 * nCulm + 3] = 24.212449;
      val[31 * nCulm + 4] = 17.968408;
      val[31 * nCulm + 5] = -6.378918;
      val[32 * nCulm + 0] = -18.100553;
      val[32 * nCulm + 1] = 48.390838;
      val[32 * nCulm + 2] = -46.708913;
      val[32 * nCulm + 3] = -0.855032;
      val[32 * nCulm + 4] = -45.766385;
      val[32 * nCulm + 5] = -4.686334;
      val[33 * nCulm + 0] = 6.355709;
      val[33 * nCulm + 1] = -44.965093;
      val[33 * nCulm + 2] = 17.698002;
      val[33 * nCulm + 3] = -43.211200;
      val[33 * nCulm + 4] = -2.695860;
      val[33 * nCulm + 5] = 155.048071;
      val[34 * nCulm + 0] = -45.971859;
      val[34 * nCulm + 1] = 8.625900;
      val[34 * nCulm + 2] = -29.868821;
      val[34 * nCulm + 3] = -45.429359;
      val[34 * nCulm + 4] = -16.622542;
      val[34 * nCulm + 5] = 10.709928;
      val[35 * nCulm + 0] = -18.827414;
      val[35 * nCulm + 1] = 31.954530;
      val[35 * nCulm + 2] = 6.113889;
      val[35 * nCulm + 3] = 5.092410;
      val[35 * nCulm + 4] = 22.341408;
      val[35 * nCulm + 5] = 8.078902;
      val[36 * nCulm + 0] = 37.554250;
      val[36 * nCulm + 1] = 25.967428;
      val[36 * nCulm + 2] = 29.342300;
      val[36 * nCulm + 3] = 38.600812;
      val[36 * nCulm + 4] = 27.576804;
      val[36 * nCulm + 5] = 11.312611;
      val[37 * nCulm + 0] = -49.356168;
      val[37 * nCulm + 1] = 31.104619;
      val[37 * nCulm + 2] = -12.273411;
      val[37 * nCulm + 3] = 37.726555;
      val[37 * nCulm + 4] = -20.727820;
      val[37 * nCulm + 5] = -15.488049;
      val[38 * nCulm + 0] = -6.650628;
      val[38 * nCulm + 1] = -37.744260;
      val[38 * nCulm + 2] = 37.788389;
      val[38 * nCulm + 3] = -30.764962;
      val[38 * nCulm + 4] = 1.481237;
      val[38 * nCulm + 5] = -218.693034;
      val[39 * nCulm + 0] = -26.435794;
      val[39 * nCulm + 1] = 44.919920;
      val[39 * nCulm + 2] = -15.471132;
      val[39 * nCulm + 3] = -48.563680;
      val[39 * nCulm + 4] = 29.746486;
      val[39 * nCulm + 5] = -0.349804;
      val[40 * nCulm + 0] = -37.643247;
      val[40 * nCulm + 1] = -42.140839;
      val[40 * nCulm + 2] = 8.138976;
      val[40 * nCulm + 3] = 23.414355;
      val[40 * nCulm + 4] = 42.791490;
      val[40 * nCulm + 5] = -1.841409;
      val[41 * nCulm + 0] = -4.777036;
      val[41 * nCulm + 1] = -2.039914;
      val[41 * nCulm + 2] = -2.290911;
      val[41 * nCulm + 3] = 12.606977;
      val[41 * nCulm + 4] = 2.465067;
      val[41 * nCulm + 5] = 20.520491;
      val[42 * nCulm + 0] = 3.755029;
      val[42 * nCulm + 1] = -7.222938;
      val[42 * nCulm + 2] = 42.918122;
      val[42 * nCulm + 3] = 36.915754;
      val[42 * nCulm + 4] = 32.262733;
      val[42 * nCulm + 5] = 4.586296;
      val[43 * nCulm + 0] = 5.454078;
      val[43 * nCulm + 1] = -33.504194;
      val[43 * nCulm + 2] = -32.776984;
      val[43 * nCulm + 3] = -18.482937;
      val[43 * nCulm + 4] = 36.295479;
      val[43 * nCulm + 5] = -6.549699;
      val[44 * nCulm + 0] = 26.018485;
      val[44 * nCulm + 1] = 13.823961;
      val[44 * nCulm + 2] = -44.487930;
      val[44 * nCulm + 3] = 44.669018;
      val[44 * nCulm + 4] = -49.773147;
      val[44 * nCulm + 5] = -5.332573;
      val[45 * nCulm + 0] = 8.245304;
      val[45 * nCulm + 1] = 32.272648;
      val[45 * nCulm + 2] = -9.229625;
      val[45 * nCulm + 3] = 19.117970;
      val[45 * nCulm + 4] = -37.541231;
      val[45 * nCulm + 5] = -6.249514;
      val[46 * nCulm + 0] = -17.019353;
      val[46 * nCulm + 1] = 34.731715;
      val[46 * nCulm + 2] = -26.468247;
      val[46 * nCulm + 3] = -1.810787;
      val[46 * nCulm + 4] = 4.680643;
      val[46 * nCulm + 5] = 33.521523;
      val[47 * nCulm + 0] = -12.259562;
      val[47 * nCulm + 1] = 9.462884;
      val[47 * nCulm + 2] = -4.352696;
      val[47 * nCulm + 3] = -29.325683;
      val[47 * nCulm + 4] = 28.727563;
      val[47 * nCulm + 5] = -3.042719;
      val[48 * nCulm + 0] = 28.506142;
      val[48 * nCulm + 1] = -44.040785;
      val[48 * nCulm + 2] = -1.720922;
      val[48 * nCulm + 3] = -27.976557;
      val[48 * nCulm + 4] = -40.815239;
      val[48 * nCulm + 5] = 8.581833;
      val[49 * nCulm + 0] = -49.384284;
      val[49 * nCulm + 1] = 26.688981;
      val[49 * nCulm + 2] = -41.439788;
      val[49 * nCulm + 3] = 46.249481;
      val[49 * nCulm + 4] = 13.268060;
      val[49 * nCulm + 5] = 26.250537;
      val[50 * nCulm + 0] = -46.075423;
      val[50 * nCulm + 1] = 17.763285;
      val[50 * nCulm + 2] = 20.420482;
      val[50 * nCulm + 3] = -42.317464;
      val[50 * nCulm + 4] = -49.131494;
      val[50 * nCulm + 5] = 2.595552;
      val[51 * nCulm + 0] = 33.839990;
      val[51 * nCulm + 1] = 7.295914;
      val[51 * nCulm + 2] = -6.885581;
      val[51 * nCulm + 3] = -7.103600;
      val[51 * nCulm + 4] = -14.977752;
      val[51 * nCulm + 5] = 0.169224;
      val[52 * nCulm + 0] = 32.089725;
      val[52 * nCulm + 1] = -46.188425;
      val[52 * nCulm + 2] = 36.494679;
      val[52 * nCulm + 3] = -27.749897;
      val[52 * nCulm + 4] = 29.286040;
      val[52 * nCulm + 5] = -11.720224;
      val[53 * nCulm + 0] = 16.379904;
      val[53 * nCulm + 1] = 30.802798;
      val[53 * nCulm + 2] = 0.664821;
      val[53 * nCulm + 3] = 40.148568;
      val[53 * nCulm + 4] = -18.566908;
      val[53 * nCulm + 5] = -17.857905;
      val[54 * nCulm + 0] = 35.986424;
      val[54 * nCulm + 1] = -15.811675;
      val[54 * nCulm + 2] = 28.154285;
      val[54 * nCulm + 3] = 2.356335;
      val[54 * nCulm + 4] = 46.131906;
      val[54 * nCulm + 5] = -1.150576;
      val[55 * nCulm + 0] = -41.404668;
      val[55 * nCulm + 1] = -36.756782;
      val[55 * nCulm + 2] = 46.045699;
      val[55 * nCulm + 3] = 35.139243;
      val[55 * nCulm + 4] = 33.392841;
      val[55 * nCulm + 5] = 0.000719;
      val[56 * nCulm + 0] = 35.589308;
      val[56 * nCulm + 1] = -30.386664;
      val[56 * nCulm + 2] = 1.372870;
      val[56 * nCulm + 3] = -27.224863;
      val[56 * nCulm + 4] = 2.625389;
      val[56 * nCulm + 5] = -103.638239;
      val[57 * nCulm + 0] = 39.673612;
      val[57 * nCulm + 1] = 0.422236;
      val[57 * nCulm + 2] = 9.519154;
      val[57 * nCulm + 3] = 26.335403;
      val[57 * nCulm + 4] = -38.715675;
      val[57 * nCulm + 5] = -3.041358;
      val[58 * nCulm + 0] = 35.508026;
      val[58 * nCulm + 1] = -20.334790;
      val[58 * nCulm + 2] = 23.725236;
      val[58 * nCulm + 3] = -5.085248;
      val[58 * nCulm + 4] = 18.293470;
      val[58 * nCulm + 5] = -6.347293;
      val[59 * nCulm + 0] = 6.823488;
      val[59 * nCulm + 1] = 47.953346;
      val[59 * nCulm + 2] = -7.003259;
      val[59 * nCulm + 3] = 9.269243;
      val[59 * nCulm + 4] = 39.387647;
      val[59 * nCulm + 5] = 7.106613;
      val[60 * nCulm + 0] = 5.167902;
      val[60 * nCulm + 1] = -22.401212;
      val[60 * nCulm + 2] = -18.473773;
      val[60 * nCulm + 3] = -37.972861;
      val[60 * nCulm + 4] = -25.064487;
      val[60 * nCulm + 5] = 11.631415;
      val[61 * nCulm + 0] = -24.180189;
      val[61 * nCulm + 1] = -22.196911;
      val[61 * nCulm + 2] = -19.114419;
      val[61 * nCulm + 3] = 5.759389;
      val[61 * nCulm + 4] = -49.434341;
      val[61 * nCulm + 5] = 1.803891;
      val[62 * nCulm + 0] = -30.679967;
      val[62 * nCulm + 1] = 43.447486;
      val[62 * nCulm + 2] = 14.845310;
      val[62 * nCulm + 3] = 41.309163;
      val[62 * nCulm + 4] = 2.548706;
      val[62 * nCulm + 5] = 157.635963;
      val[63 * nCulm + 0] = 14.863608;
      val[63 * nCulm + 1] = 40.563711;
      val[63 * nCulm + 2] = -5.667498;
      val[63 * nCulm + 3] = -42.748496;
      val[63 * nCulm + 4] = -23.929186;
      val[63 * nCulm + 5] = 0.662163;
      val[64 * nCulm + 0] = 4.413728;
      val[64 * nCulm + 1] = 42.937505;
      val[64 * nCulm + 2] = 46.715144;
      val[64 * nCulm + 3] = 15.545918;
      val[64 * nCulm + 4] = 30.158345;
      val[64 * nCulm + 5] = 9.408937;
      val[65 * nCulm + 0] = 34.102357;
      val[65 * nCulm + 1] = 17.179344;
      val[65 * nCulm + 2] = 45.845479;
      val[65 * nCulm + 3] = 43.237587;
      val[65 * nCulm + 4] = -22.463784;
      val[65 * nCulm + 5] = -12.500423;
      val[66 * nCulm + 0] = -25.000367;
      val[66 * nCulm + 1] = -23.917106;
      val[66 * nCulm + 2] = -13.701707;
      val[66 * nCulm + 3] = -44.644434;
      val[66 * nCulm + 4] = 49.757040;
      val[66 * nCulm + 5] = -6.292185;
      val[67 * nCulm + 0] = 14.664890;
      val[67 * nCulm + 1] = 27.408905;
      val[67 * nCulm + 2] = 42.561653;
      val[67 * nCulm + 3] = 45.849780;
      val[67 * nCulm + 4] = -6.772809;
      val[67 * nCulm + 5] = -50.968518;
      val[68 * nCulm + 0] = 37.977177;
      val[68 * nCulm + 1] = 41.901318;
      val[68 * nCulm + 2] = 30.233654;
      val[68 * nCulm + 3] = -21.998667;
      val[68 * nCulm + 4] = -30.690948;
      val[68 * nCulm + 5] = -2.839501;
      val[69 * nCulm + 0] = 27.039796;
      val[69 * nCulm + 1] = 23.966576;
      val[69 * nCulm + 2] = 20.525873;
      val[69 * nCulm + 3] = 47.304672;
      val[69 * nCulm + 4] = -32.185461;
      val[69 * nCulm + 5] = -10.251458;
      val[70 * nCulm + 0] = -41.163520;
      val[70 * nCulm + 1] = 3.840771;
      val[70 * nCulm + 2] = -15.700801;
      val[70 * nCulm + 3] = -37.606413;
      val[70 * nCulm + 4] = 12.976638;
      val[70 * nCulm + 5] = -12.086290;
      val[71 * nCulm + 0] = -13.013413;
      val[71 * nCulm + 1] = 47.224073;
      val[71 * nCulm + 2] = -46.878760;
      val[71 * nCulm + 3] = 33.072982;
      val[71 * nCulm + 4] = 10.208667;
      val[71 * nCulm + 5] = 37.460397;
      val[72 * nCulm + 0] = 2.369995;
      val[72 * nCulm + 1] = 32.244116;
      val[72 * nCulm + 2] = -17.958382;
      val[72 * nCulm + 3] = 45.632015;
      val[72 * nCulm + 4] = -27.080885;
      val[72 * nCulm + 5] = -13.381582;
      val[73 * nCulm + 0] = 45.144362;
      val[73 * nCulm + 1] = -7.185377;
      val[73 * nCulm + 2] = 1.048126;
      val[73 * nCulm + 3] = -33.186711;
      val[73 * nCulm + 4] = -21.715179;
      val[73 * nCulm + 5] = 9.030045;
      val[74 * nCulm + 0] = -6.555770;
      val[74 * nCulm + 1] = -40.837166;
      val[74 * nCulm + 2] = -6.986562;
      val[74 * nCulm + 3] = 46.414695;
      val[74 * nCulm + 4] = -5.074612;
      val[74 * nCulm + 5] = -4.972427;
      val[75 * nCulm + 0] = 44.866033;
      val[75 * nCulm + 1] = 46.729913;
      val[75 * nCulm + 2] = -36.690391;
      val[75 * nCulm + 3] = -13.353945;
      val[75 * nCulm + 4] = -33.114401;
      val[75 * nCulm + 5] = -4.540721;
      val[76 * nCulm + 0] = -43.541994;
      val[76 * nCulm + 1] = -25.887809;
      val[76 * nCulm + 2] = -45.820706;
      val[76 * nCulm + 3] = 2.085203;
      val[76 * nCulm + 4] = 19.782033;
      val[76 * nCulm + 5] = -5.465353;
      val[77 * nCulm + 0] = 30.547953;
      val[77 * nCulm + 1] = -4.997539;
      val[77 * nCulm + 2] = 10.786063;
      val[77 * nCulm + 3] = 42.834053;
      val[77 * nCulm + 4] = 15.484168;
      val[77 * nCulm + 5] = 11.796190;
      val[78 * nCulm + 0] = -18.110363;
      val[78 * nCulm + 1] = -47.822688;
      val[78 * nCulm + 2] = 36.923691;
      val[78 * nCulm + 3] = -44.592965;
      val[78 * nCulm + 4] = 36.962334;
      val[78 * nCulm + 5] = -11.604590;
      val[79 * nCulm + 0] = 23.099201;
      val[79 * nCulm + 1] = -36.008165;
      val[79 * nCulm + 2] = 36.657714;
      val[79 * nCulm + 3] = -25.419040;
      val[79 * nCulm + 4] = 48.764729;
      val[79 * nCulm + 5] = -5.732413;
      val[80 * nCulm + 0] = -47.757332;
      val[80 * nCulm + 1] = -43.810608;
      val[80 * nCulm + 2] = -25.609949;
      val[80 * nCulm + 3] = 16.635457;
      val[80 * nCulm + 4] = -39.659628;
      val[80 * nCulm + 5] = 3.473325;
      val[81 * nCulm + 0] = 17.316704;
      val[81 * nCulm + 1] = 10.354469;
      val[81 * nCulm + 2] = 0.991751;
      val[81 * nCulm + 3] = 21.406698;
      val[81 * nCulm + 4] = -33.846821;
      val[81 * nCulm + 5] = -4.211664;
      val[82 * nCulm + 0] = 21.751495;
      val[82 * nCulm + 1] = -5.467112;
      val[82 * nCulm + 2] = -43.900580;
      val[82 * nCulm + 3] = -45.714215;
      val[82 * nCulm + 4] = -22.188778;
      val[82 * nCulm + 5] = 11.148054;
      val[83 * nCulm + 0] = -48.855129;
      val[83 * nCulm + 1] = 34.102702;
      val[83 * nCulm + 2] = -4.185458;
      val[83 * nCulm + 3] = -3.489187;
      val[83 * nCulm + 4] = -10.280352;
      val[83 * nCulm + 5] = -13.865234;
      val[84 * nCulm + 0] = -21.079370;
      val[84 * nCulm + 1] = -11.368468;
      val[84 * nCulm + 2] = 2.014562;
      val[84 * nCulm + 3] = 42.725920;
      val[84 * nCulm + 4] = -13.916643;
      val[84 * nCulm + 5] = -10.435307;
      val[85 * nCulm + 0] = -35.388664;
      val[85 * nCulm + 1] = -25.579564;
      val[85 * nCulm + 2] = 26.694396;
      val[85 * nCulm + 3] = 1.246265;
      val[85 * nCulm + 4] = -8.746104;
      val[85 * nCulm + 5] = 13.399020;
      val[86 * nCulm + 0] = 29.909987;
      val[86 * nCulm + 1] = -15.456558;
      val[86 * nCulm + 2] = 27.659020;
      val[86 * nCulm + 3] = -6.898219;
      val[86 * nCulm + 4] = 28.340102;
      val[86 * nCulm + 5] = -3.503671;
      val[87 * nCulm + 0] = 39.656059;
      val[87 * nCulm + 1] = 40.791774;
      val[87 * nCulm + 2] = -28.771072;
      val[87 * nCulm + 3] = -27.162041;
      val[87 * nCulm + 4] = 27.157088;
      val[87 * nCulm + 5] = 2.605589;
      val[88 * nCulm + 0] = 15.206514;
      val[88 * nCulm + 1] = 12.498748;
      val[88 * nCulm + 2] = 2.983190;
      val[88 * nCulm + 3] = 4.828058;
      val[88 * nCulm + 4] = -44.915678;
      val[88 * nCulm + 5] = -1.595945;
      val[89 * nCulm + 0] = 19.751295;
      val[89 * nCulm + 1] = -26.899606;
      val[89 * nCulm + 2] = -11.567238;
      val[89 * nCulm + 3] = 6.044887;
      val[89 * nCulm + 4] = -23.217886;
      val[89 * nCulm + 5] = 4.481564;
      val[90 * nCulm + 0] = -22.687408;
      val[90 * nCulm + 1] = 11.564896;
      val[90 * nCulm + 2] = 9.933571;
      val[90 * nCulm + 3] = 27.322644;
      val[90 * nCulm + 4] = -18.182506;
      val[90 * nCulm + 5] = -9.893340;
      val[91 * nCulm + 0] = -14.247861;
      val[91 * nCulm + 1] = -26.370653;
      val[91 * nCulm + 2] = -33.020270;
      val[91 * nCulm + 3] = -23.393490;
      val[91 * nCulm + 4] = 22.015330;
      val[91 * nCulm + 5] = -10.469375;
      val[92 * nCulm + 0] = -47.110073;
      val[92 * nCulm + 1] = 19.927467;
      val[92 * nCulm + 2] = 28.029487;
      val[92 * nCulm + 3] = -24.085282;
      val[92 * nCulm + 4] = -22.240936;
      val[92 * nCulm + 5] = 1.114869;
      val[93 * nCulm + 0] = -28.264215;
      val[93 * nCulm + 1] = 0.317513;
      val[93 * nCulm + 2] = -9.767377;
      val[93 * nCulm + 3] = 29.157817;
      val[93 * nCulm + 4] = 8.298178;
      val[93 * nCulm + 5] = 17.042915;
      val[94 * nCulm + 0] = -9.469245;
      val[94 * nCulm + 1] = -19.341670;
      val[94 * nCulm + 2] = 39.267217;
      val[94 * nCulm + 3] = -4.265161;
      val[94 * nCulm + 4] = -48.726958;
      val[94 * nCulm + 5] = 2.523166;
      val[95 * nCulm + 0] = 9.945595;
      val[95 * nCulm + 1] = 40.432931;
      val[95 * nCulm + 2] = 7.406348;
      val[95 * nCulm + 3] = 1.068445;
      val[95 * nCulm + 4] = 39.356973;
      val[95 * nCulm + 5] = 5.221234;
      val[96 * nCulm + 0] = 16.772719;
      val[96 * nCulm + 1] = 24.154760;
      val[96 * nCulm + 2] = -9.947414;
      val[96 * nCulm + 3] = -11.298465;
      val[96 * nCulm + 4] = 36.590565;
      val[96 * nCulm + 5] = 1.893083;
      val[97 * nCulm + 0] = -21.346752;
      val[97 * nCulm + 1] = -27.981912;
      val[97 * nCulm + 2] = 32.437036;
      val[97 * nCulm + 3] = 43.976774;
      val[97 * nCulm + 4] = -20.848693;
      val[97 * nCulm + 5] = -3.401355;
      val[98 * nCulm + 0] = -32.064547;
      val[98 * nCulm + 1] = 12.763543;
      val[98 * nCulm + 2] = 28.599167;
      val[98 * nCulm + 3] = 26.904224;
      val[98 * nCulm + 4] = 31.922313;
      val[98 * nCulm + 5] = 6.111803;
      val[99 * nCulm + 0] = -29.512921;
      val[99 * nCulm + 1] = -16.511792;
      val[99 * nCulm + 2] = -10.045655;
      val[99 * nCulm + 3] = -42.863735;
      val[99 * nCulm + 4] = 14.726661;
      val[99 * nCulm + 5] = -18.854039;
      val[100 * nCulm + 0] = -41.780961;
      val[100 * nCulm + 1] = -16.793993;
      val[100 * nCulm + 2] = 34.530480;
      val[100 * nCulm + 3] = 32.886299;
      val[100 * nCulm + 4] = 43.577268;
      val[100 * nCulm + 5] = 1.977935;
      val[101 * nCulm + 0] = -30.615078;
      val[101 * nCulm + 1] = -20.968772;
      val[101 * nCulm + 2] = -16.859673;
      val[101 * nCulm + 3] = 49.784939;
      val[101 * nCulm + 4] = -14.735545;
      val[101 * nCulm + 5] = -9.026293;
      val[102 * nCulm + 0] = -19.908654;
      val[102 * nCulm + 1] = 29.910002;
      val[102 * nCulm + 2] = 35.047896;
      val[102 * nCulm + 3] = 13.744767;
      val[102 * nCulm + 4] = 6.334966;
      val[102 * nCulm + 5] = 32.847785;
      val[103 * nCulm + 0] = -2.874864;
      val[103 * nCulm + 1] = 16.805344;
      val[103 * nCulm + 2] = -6.216302;
      val[103 * nCulm + 3] = -24.732335;
      val[103 * nCulm + 4] = 5.387153;
      val[103 * nCulm + 5] = -6.734920;
      val[104 * nCulm + 0] = 38.349744;
      val[104 * nCulm + 1] = 27.272499;
      val[104 * nCulm + 2] = -15.632505;
      val[104 * nCulm + 3] = 3.613341;
      val[104 * nCulm + 4] = -37.682508;
      val[104 * nCulm + 5] = -3.649598;
      val[105 * nCulm + 0] = 11.861679;
      val[105 * nCulm + 1] = 22.244450;
      val[105 * nCulm + 2] = 9.697826;
      val[105 * nCulm + 3] = -21.888514;
      val[105 * nCulm + 4] = 45.913012;
      val[105 * nCulm + 5] = 0.266695;
      val[106 * nCulm + 0] = 5.048843;
      val[106 * nCulm + 1] = -31.629183;
      val[106 * nCulm + 2] = -19.410627;
      val[106 * nCulm + 3] = 36.862176;
      val[106 * nCulm + 4] = -31.329354;
      val[106 * nCulm + 5] = -0.560616;
      val[107 * nCulm + 0] = 27.207970;
      val[107 * nCulm + 1] = -42.979107;
      val[107 * nCulm + 2] = 30.547337;
      val[107 * nCulm + 3] = -13.863370;
      val[107 * nCulm + 4] = 28.854112;
      val[107 * nCulm + 5] = -9.094646;
      val[108 * nCulm + 0] = 7.535995;
      val[108 * nCulm + 1] = -32.815949;
      val[108 * nCulm + 2] = -24.880422;
      val[108 * nCulm + 3] = 49.863424;
      val[108 * nCulm + 4] = -34.814225;
      val[108 * nCulm + 5] = -2.087770;
      val[109 * nCulm + 0] = 35.750197;
      val[109 * nCulm + 1] = -12.388133;
      val[109 * nCulm + 2] = 32.665644;
      val[109 * nCulm + 3] = -40.515279;
      val[109 * nCulm + 4] = -17.989064;
      val[109 * nCulm + 5] = 14.150095;
      val[110 * nCulm + 0] = 2.628380;
      val[110 * nCulm + 1] = 25.164568;
      val[110 * nCulm + 2] = -41.910965;
      val[110 * nCulm + 3] = -1.989949;
      val[110 * nCulm + 4] = 37.998369;
      val[110 * nCulm + 5] = 3.116787;
      val[111 * nCulm + 0] = -42.659463;
      val[111 * nCulm + 1] = -37.122995;
      val[111 * nCulm + 2] = 10.978821;
      val[111 * nCulm + 3] = -16.165552;
      val[111 * nCulm + 4] = 43.557127;
      val[111 * nCulm + 5] = -5.560842;
      val[112 * nCulm + 0] = -21.492678;
      val[112 * nCulm + 1] = 12.699448;
      val[112 * nCulm + 2] = 20.942235;
      val[112 * nCulm + 3] = -2.702075;
      val[112 * nCulm + 4] = -34.225276;
      val[112 * nCulm + 5] = -1.152630;
      val[113 * nCulm + 0] = 40.399031;
      val[113 * nCulm + 1] = -22.758571;
      val[113 * nCulm + 2] = 40.362146;
      val[113 * nCulm + 3] = 38.675787;
      val[113 * nCulm + 4] = 21.629573;
      val[113 * nCulm + 5] = 3.713263;
      val[114 * nCulm + 0] = 21.378259;
      val[114 * nCulm + 1] = 2.399368;
      val[114 * nCulm + 2] = -38.321593;
      val[114 * nCulm + 3] = 32.932409;
      val[114 * nCulm + 4] = -20.197644;
      val[114 * nCulm + 5] = -8.050029;
      val[115 * nCulm + 0] = -10.891656;
      val[115 * nCulm + 1] = -6.197675;
      val[115 * nCulm + 2] = -1.146561;
      val[115 * nCulm + 3] = 35.541921;
      val[115 * nCulm + 4] = 2.926660;
      val[115 * nCulm + 5] = 47.688915;
      val[116 * nCulm + 0] = -19.713304;
      val[116 * nCulm + 1] = 37.954752;
      val[116 * nCulm + 2] = -11.860859;
      val[116 * nCulm + 3] = -17.599381;
      val[116 * nCulm + 4] = 28.735401;
      val[116 * nCulm + 5] = 3.582964;
      val[117 * nCulm + 0] = -12.774464;
      val[117 * nCulm + 1] = -30.857966;
      val[117 * nCulm + 2] = -29.985029;
      val[117 * nCulm + 3] = 0.243958;
      val[117 * nCulm + 4] = 16.747720;
      val[117 * nCulm + 5] = -8.422301;
      val[118 * nCulm + 0] = 28.392403;
      val[118 * nCulm + 1] = 2.243450;
      val[118 * nCulm + 2] = 38.116871;
      val[118 * nCulm + 3] = 23.022680;
      val[118 * nCulm + 4] = 44.743422;
      val[118 * nCulm + 5] = 2.902863;
      val[119 * nCulm + 0] = 29.380828;
      val[119 * nCulm + 1] = 24.992975;
      val[119 * nCulm + 2] = -3.180091;
      val[119 * nCulm + 3] = 43.070585;
      val[119 * nCulm + 4] = 25.605786;
      val[119 * nCulm + 5] = 12.811825;
      val[120 * nCulm + 0] = -30.025972;
      val[120 * nCulm + 1] = -6.727380;
      val[120 * nCulm + 2] = 13.155407;
      val[120 * nCulm + 3] = 47.703875;
      val[120 * nCulm + 4] = 35.500006;
      val[120 * nCulm + 5] = 5.693532;
      val[121 * nCulm + 0] = 31.988738;
      val[121 * nCulm + 1] = 21.827021;
      val[121 * nCulm + 2] = -21.882749;
      val[121 * nCulm + 3] = 36.586803;
      val[121 * nCulm + 4] = 19.122127;
      val[121 * nCulm + 5] = 14.689276;
      val[122 * nCulm + 0] = 3.287501;
      val[122 * nCulm + 1] = -20.523166;
      val[122 * nCulm + 2] = -6.950970;
      val[122 * nCulm + 3] = 15.161044;
      val[122 * nCulm + 4] = -21.973455;
      val[122 * nCulm + 5] = 1.385062;
      val[123 * nCulm + 0] = -1.350413;
      val[123 * nCulm + 1] = -46.581771;
      val[123 * nCulm + 2] = 11.447870;
      val[123 * nCulm + 3] = 25.666427;
      val[123 * nCulm + 4] = 1.516301;
      val[123 * nCulm + 5] = -65.059990;
      val[124 * nCulm + 0] = -6.300335;
      val[124 * nCulm + 1] = 4.323345;
      val[124 * nCulm + 2] = 9.939527;
      val[124 * nCulm + 3] = 41.859289;
      val[124 * nCulm + 4] = 11.673457;
      val[124 * nCulm + 5] = 18.956055;
      val[125 * nCulm + 0] = 6.410646;
      val[125 * nCulm + 1] = 26.716111;
      val[125 * nCulm + 2] = -34.570326;
      val[125 * nCulm + 3] = 7.315479;
      val[125 * nCulm + 4] = 31.283481;
      val[125 * nCulm + 5] = 5.379135;
      val[126 * nCulm + 0] = -3.338248;
      val[126 * nCulm + 1] = 41.118146;
      val[126 * nCulm + 2] = -21.115341;
      val[126 * nCulm + 3] = -22.012577;
      val[126 * nCulm + 4] = -17.602163;
      val[126 * nCulm + 5] = -4.907609;
      val[127 * nCulm + 0] = -33.454806;
      val[127 * nCulm + 1] = 17.039328;
      val[127 * nCulm + 2] = 2.731814;
      val[127 * nCulm + 3] = 2.139343;
      val[127 * nCulm + 4] = 39.412666;
      val[127 * nCulm + 5] = 2.533296;
      val[128 * nCulm + 0] = 4.423600;
      val[128 * nCulm + 1] = -10.441531;
      val[128 * nCulm + 2] = -33.344519;
      val[128 * nCulm + 3] = -39.067202;
      val[128 * nCulm + 4] = 3.635591;
      val[128 * nCulm + 5] = -64.227558;
      val[129 * nCulm + 0] = -39.187007;
      val[129 * nCulm + 1] = 0.375722;
      val[129 * nCulm + 2] = 30.658737;
      val[129 * nCulm + 3] = -45.072582;
      val[129 * nCulm + 4] = 34.743399;
      val[129 * nCulm + 5] = -5.859362;
      val[130 * nCulm + 0] = -15.094182;
      val[130 * nCulm + 1] = -27.349200;
      val[130 * nCulm + 2] = 47.834221;
      val[130 * nCulm + 3] = -41.485447;
      val[130 * nCulm + 4] = -44.917500;
      val[130 * nCulm + 5] = 7.483683;
      val[131 * nCulm + 0] = 24.597542;
      val[131 * nCulm + 1] = 19.629309;
      val[131 * nCulm + 2] = -44.154626;
      val[131 * nCulm + 3] = 41.850601;
      val[131 * nCulm + 4] = 45.787666;
      val[131 * nCulm + 5] = 6.585530;
      val[132 * nCulm + 0] = -4.428778;
      val[132 * nCulm + 1] = -41.553926;
      val[132 * nCulm + 2] = 45.833938;
      val[132 * nCulm + 3] = -24.113423;
      val[132 * nCulm + 4] = -44.150231;
      val[132 * nCulm + 5] = 7.270177;
      val[133 * nCulm + 0] = 30.791099;
      val[133 * nCulm + 1] = -40.903870;
      val[133 * nCulm + 2] = 23.652774;
      val[133 * nCulm + 3] = -21.153661;
      val[133 * nCulm + 4] = -27.564077;
      val[133 * nCulm + 5] = 10.886587;
      val[134 * nCulm + 0] = -36.762573;
      val[134 * nCulm + 1] = -9.899696;
      val[134 * nCulm + 2] = -11.213337;
      val[134 * nCulm + 3] = 49.811227;
      val[134 * nCulm + 4] = -33.031961;
      val[134 * nCulm + 5] = -5.489145;
      val[135 * nCulm + 0] = 18.821452;
      val[135 * nCulm + 1] = 4.252784;
      val[135 * nCulm + 2] = -1.215800;
      val[135 * nCulm + 3] = 28.201212;
      val[135 * nCulm + 4] = -11.929490;
      val[135 * nCulm + 5] = -12.646962;
      val[136 * nCulm + 0] = -5.718298;
      val[136 * nCulm + 1] = 35.202634;
      val[136 * nCulm + 2] = -32.377908;
      val[136 * nCulm + 3] = -42.291746;
      val[136 * nCulm + 4] = -38.920498;
      val[136 * nCulm + 5] = 1.092145;
      val[137 * nCulm + 0] = -19.085379;
      val[137 * nCulm + 1] = -46.237913;
      val[137 * nCulm + 2] = -16.132532;
      val[137 * nCulm + 3] = -40.360643;
      val[137 * nCulm + 4] = 49.689376;
      val[137 * nCulm + 5] = -8.019245;
      val[138 * nCulm + 0] = -21.177770;
      val[138 * nCulm + 1] = -3.579155;
      val[138 * nCulm + 2] = 5.328770;
      val[138 * nCulm + 3] = -18.642891;
      val[138 * nCulm + 4] = -31.663234;
      val[138 * nCulm + 5] = 3.551971;
      val[139 * nCulm + 0] = -43.659368;
      val[139 * nCulm + 1] = 26.635785;
      val[139 * nCulm + 2] = 8.656211;
      val[139 * nCulm + 3] = -33.303488;
      val[139 * nCulm + 4] = -24.548994;
      val[139 * nCulm + 5] = 1.515611;
      val[140 * nCulm + 0] = -23.092927;
      val[140 * nCulm + 1] = 48.762645;
      val[140 * nCulm + 2] = -5.611420;
      val[140 * nCulm + 3] = -42.185611;
      val[140 * nCulm + 4] = -10.752852;
      val[140 * nCulm + 5] = -2.665167;
      val[141 * nCulm + 0] = -9.967249;
      val[141 * nCulm + 1] = 36.013041;
      val[141 * nCulm + 2] = -10.981268;
      val[141 * nCulm + 3] = -0.212071;
      val[141 * nCulm + 4] = 45.035876;
      val[141 * nCulm + 5] = 3.992732;
      val[142 * nCulm + 0] = -17.372106;
      val[142 * nCulm + 1] = 7.391155;
      val[142 * nCulm + 2] = -25.455760;
      val[142 * nCulm + 3] = 43.366000;
      val[142 * nCulm + 4] = -18.149830;
      val[142 * nCulm + 5] = -13.007068;
      val[143 * nCulm + 0] = 5.959778;
      val[143 * nCulm + 1] = 25.911376;
      val[143 * nCulm + 2] = 39.957249;
      val[143 * nCulm + 3] = -22.400576;
      val[143 * nCulm + 4] = 19.883740;
      val[143 * nCulm + 5] = 1.065747;
      val[144 * nCulm + 0] = -34.350042;
      val[144 * nCulm + 1] = -6.006602;
      val[144 * nCulm + 2] = -24.462095;
      val[144 * nCulm + 3] = 33.436052;
      val[144 * nCulm + 4] = -44.081708;
      val[144 * nCulm + 5] = -2.715274;
      val[145 * nCulm + 0] = -41.534352;
      val[145 * nCulm + 1] = -18.810122;
      val[145 * nCulm + 2] = 30.121325;
      val[145 * nCulm + 3] = 8.166445;
      val[145 * nCulm + 4] = -26.395347;
      val[145 * nCulm + 5] = 2.138672;
      val[146 * nCulm + 0] = -43.722311;
      val[146 * nCulm + 1] = -21.381448;
      val[146 * nCulm + 2] = 31.187535;
      val[146 * nCulm + 3] = 32.660323;
      val[146 * nCulm + 4] = -11.658100;
      val[146 * nCulm + 5] = -4.349363;
      val[147 * nCulm + 0] = -16.008147;
      val[147 * nCulm + 1] = -4.049815;
      val[147 * nCulm + 2] = -6.781370;
      val[147 * nCulm + 3] = 34.814242;
      val[147 * nCulm + 4] = -24.664374;
      val[147 * nCulm + 5] = -5.673993;
      val[148 * nCulm + 0] = -19.841169;
      val[148 * nCulm + 1] = 42.360617;
      val[148 * nCulm + 2] = 37.920309;
      val[148 * nCulm + 3] = -34.290746;
      val[148 * nCulm + 4] = 42.761707;
      val[148 * nCulm + 5] = 1.123262;
      val[149 * nCulm + 0] = 37.485784;
      val[149 * nCulm + 1] = -0.637075;
      val[149 * nCulm + 2] = -8.649725;
      val[149 * nCulm + 3] = -9.225592;
      val[149 * nCulm + 4] = -1.835280;
      val[149 * nCulm + 5] = 25.666606;
      val[150 * nCulm + 0] = 20.955146;
      val[150 * nCulm + 1] = -1.565077;
      val[150 * nCulm + 2] = 1.252423;
      val[150 * nCulm + 3] = -8.127362;
      val[150 * nCulm + 4] = -13.013595;
      val[150 * nCulm + 5] = 3.755355;
      val[151 * nCulm + 0] = 37.945387;
      val[151 * nCulm + 1] = -29.535822;
      val[151 * nCulm + 2] = -9.004122;
      val[151 * nCulm + 3] = -35.625670;
      val[151 * nCulm + 4] = -7.054832;
      val[151 * nCulm + 5] = 43.949120;
      val[152 * nCulm + 0] = 25.391771;
      val[152 * nCulm + 1] = -10.139197;
      val[152 * nCulm + 2] = 26.824017;
      val[152 * nCulm + 3] = -31.365390;
      val[152 * nCulm + 4] = -40.337840;
      val[152 * nCulm + 5] = 5.100242;
      val[153 * nCulm + 0] = 2.811617;
      val[153 * nCulm + 1] = -5.127368;
      val[153 * nCulm + 2] = -36.178240;
      val[153 * nCulm + 3] = -31.122083;
      val[153 * nCulm + 4] = -13.220706;
      val[153 * nCulm + 5] = 13.208183;
      val[154 * nCulm + 0] = 39.099313;
      val[154 * nCulm + 1] = -38.630120;
      val[154 * nCulm + 2] = -28.917630;
      val[154 * nCulm + 3] = -36.746054;
      val[154 * nCulm + 4] = -49.095991;
      val[154 * nCulm + 5] = 7.497000;
      val[155 * nCulm + 0] = 41.319279;
      val[155 * nCulm + 1] = -19.809560;
      val[155 * nCulm + 2] = 47.605409;
      val[155 * nCulm + 3] = 28.010822;
      val[155 * nCulm + 4] = -0.837593;
      val[155 * nCulm + 5] = -46.116257;
      val[156 * nCulm + 0] = -12.289032;
      val[156 * nCulm + 1] = -16.837602;
      val[156 * nCulm + 2] = 16.437041;
      val[156 * nCulm + 3] = -37.954124;
      val[156 * nCulm + 4] = -13.976109;
      val[156 * nCulm + 5] = 18.786488;
      val[157 * nCulm + 0] = -9.859694;
      val[157 * nCulm + 1] = -13.913825;
      val[157 * nCulm + 2] = -6.110783;
      val[157 * nCulm + 3] = -26.907436;
      val[157 * nCulm + 4] = -3.852356;
      val[157 * nCulm + 5] = 50.386484;
      val[158 * nCulm + 0] = -17.615491;
      val[158 * nCulm + 1] = -47.155531;
      val[158 * nCulm + 2] = 6.030985;
      val[158 * nCulm + 3] = 19.454363;
      val[158 * nCulm + 4] = -35.000913;
      val[158 * nCulm + 5] = 3.976155;
      val[159 * nCulm + 0] = -27.905950;
      val[159 * nCulm + 1] = 32.885522;
      val[159 * nCulm + 2] = 5.666864;
      val[159 * nCulm + 3] = 24.117420;
      val[159 * nCulm + 4] = 10.032840;
      val[159 * nCulm + 5] = 27.123076;
      val[160 * nCulm + 0] = 28.932864;
      val[160 * nCulm + 1] = 29.592724;
      val[160 * nCulm + 2] = -30.522783;
      val[160 * nCulm + 3] = -0.031238;
      val[160 * nCulm + 4] = 2.899685;
      val[160 * nCulm + 5] = 48.485022;
      val[161 * nCulm + 0] = -17.974307;
      val[161 * nCulm + 1] = 16.608662;
      val[161 * nCulm + 2] = -18.972601;
      val[161 * nCulm + 3] = 35.067131;
      val[161 * nCulm + 4] = 15.159869;
      val[161 * nCulm + 5] = 16.364622;
      val[162 * nCulm + 0] = 3.961692;
      val[162 * nCulm + 1] = -21.071880;
      val[162 * nCulm + 2] = -25.922924;
      val[162 * nCulm + 3] = -44.503919;
      val[162 * nCulm + 4] = 14.893140;
      val[162 * nCulm + 5] = -20.611281;
      val[163 * nCulm + 0] = 37.726555;
      val[163 * nCulm + 1] = 2.328491;
      val[163 * nCulm + 2] = 18.940804;
      val[163 * nCulm + 3] = -21.472741;
      val[163 * nCulm + 4] = -19.470011;
      val[163 * nCulm + 5] = 4.884138;
      val[164 * nCulm + 0] = 19.581398;
      val[164 * nCulm + 1] = 41.747454;
      val[164 * nCulm + 2] = 37.465013;
      val[164 * nCulm + 3] = 19.124186;
      val[164 * nCulm + 4] = 42.387583;
      val[164 * nCulm + 5] = 7.027410;
      val[165 * nCulm + 0] = -10.393902;
      val[165 * nCulm + 1] = -15.694470;
      val[165 * nCulm + 2] = 14.016854;
      val[165 * nCulm + 3] = 21.164498;
      val[165 * nCulm + 4] = -31.610926;
      val[165 * nCulm + 5] = -0.589067;
      val[166 * nCulm + 0] = 5.647839;
      val[166 * nCulm + 1] = -15.938699;
      val[166 * nCulm + 2] = 1.802431;
      val[166 * nCulm + 3] = -39.220031;
      val[166 * nCulm + 4] = -46.530177;
      val[166 * nCulm + 5] = 5.841082;
      val[167 * nCulm + 0] = -9.939795;
      val[167 * nCulm + 1] = 9.756693;
      val[167 * nCulm + 2] = -1.244629;
      val[167 * nCulm + 3] = 25.130746;
      val[167 * nCulm + 4] = 0.773182;
      val[167 * nCulm + 5] = 213.806915;
      val[168 * nCulm + 0] = -11.448642;
      val[168 * nCulm + 1] = -6.643570;
      val[168 * nCulm + 2] = -40.629989;
      val[168 * nCulm + 3] = -19.158857;
      val[168 * nCulm + 4] = 48.046671;
      val[168 * nCulm + 5] = -2.311934;
      val[169 * nCulm + 0] = -17.647276;
      val[169 * nCulm + 1] = 11.659971;
      val[169 * nCulm + 2] = -41.691503;
      val[169 * nCulm + 3] = -4.932440;
      val[169 * nCulm + 4] = 42.081403;
      val[169 * nCulm + 5] = 0.986715;
      val[170 * nCulm + 0] = 20.876882;
      val[170 * nCulm + 1] = 44.726682;
      val[170 * nCulm + 2] = 3.542376;
      val[170 * nCulm + 3] = -43.024323;
      val[170 * nCulm + 4] = 46.514964;
      val[170 * nCulm + 5] = 0.403231;
      val[171 * nCulm + 0] = -15.611378;
      val[171 * nCulm + 1] = 45.668679;
      val[171 * nCulm + 2] = 32.659977;
      val[171 * nCulm + 3] = -45.011179;
      val[171 * nCulm + 4] = 39.562516;
      val[171 * nCulm + 5] = 0.308665;
      val[172 * nCulm + 0] = -22.302493;
      val[172 * nCulm + 1] = 1.112464;
      val[172 * nCulm + 2] = 0.587710;
      val[172 * nCulm + 3] = -14.311684;
      val[172 * nCulm + 4] = 45.357869;
      val[172 * nCulm + 5] = -1.147408;
      val[173 * nCulm + 0] = -18.986729;
      val[173 * nCulm + 1] = -41.955071;
      val[173 * nCulm + 2] = 26.833147;
      val[173 * nCulm + 3] = 33.192403;
      val[173 * nCulm + 4] = 11.487655;
      val[173 * nCulm + 5] = -3.380539;
      val[174 * nCulm + 0] = 19.070012;
      val[174 * nCulm + 1] = 22.356625;
      val[174 * nCulm + 2] = -8.014310;
      val[174 * nCulm + 3] = -49.223174;
      val[174 * nCulm + 4] = 43.937441;
      val[174 * nCulm + 5] = -2.664304;
      val[175 * nCulm + 0] = 3.303975;
      val[175 * nCulm + 1] = -20.863032;
      val[175 * nCulm + 2] = 21.486430;
      val[175 * nCulm + 3] = -33.822937;
      val[175 * nCulm + 4] = -0.018694;
      val[175 * nCulm + 5] = 13846.925885;
      val[176 * nCulm + 0] = 30.473586;
      val[176 * nCulm + 1] = 32.718710;
      val[176 * nCulm + 2] = 27.717459;
      val[176 * nCulm + 3] = 16.530719;
      val[176 * nCulm + 4] = -24.477467;
      val[176 * nCulm + 5] = -9.293615;
      val[177 * nCulm + 0] = -21.811727;
      val[177 * nCulm + 1] = -1.446114;
      val[177 * nCulm + 2] = -36.384147;
      val[177 * nCulm + 3] = 18.262923;
      val[177 * nCulm + 4] = 4.791099;
      val[177 * nCulm + 5] = 16.844050;
      val[178 * nCulm + 0] = 34.223007;
      val[178 * nCulm + 1] = -21.708184;
      val[178 * nCulm + 2] = -8.810087;
      val[178 * nCulm + 3] = 44.121902;
      val[178 * nCulm + 4] = -36.157501;
      val[178 * nCulm + 5] = -2.704152;
      val[179 * nCulm + 0] = -13.725070;
      val[179 * nCulm + 1] = -46.856386;
      val[179 * nCulm + 2] = -2.818518;
      val[179 * nCulm + 3] = 36.075855;
      val[179 * nCulm + 4] = 0.441347;
      val[179 * nCulm + 5] = -115.388412;
      val[180 * nCulm + 0] = 10.344426;
      val[180 * nCulm + 1] = -24.391051;
      val[180 * nCulm + 2] = -11.893031;
      val[180 * nCulm + 3] = -5.384901;
      val[180 * nCulm + 4] = -15.885113;
      val[180 * nCulm + 5] = 9.102427;
      val[181 * nCulm + 0] = 38.153902;
      val[181 * nCulm + 1] = -32.624930;
      val[181 * nCulm + 2] = 37.565739;
      val[181 * nCulm + 3] = -5.856018;
      val[181 * nCulm + 4] = 48.565555;
      val[181 * nCulm + 5] = -3.520460;
      val[182 * nCulm + 0] = 14.758953;
      val[182 * nCulm + 1] = 27.074856;
      val[182 * nCulm + 2] = -34.767523;
      val[182 * nCulm + 3] = 32.226688;
      val[182 * nCulm + 4] = 20.444050;
      val[182 * nCulm + 5] = 13.959861;
      val[183 * nCulm + 0] = 22.414870;
      val[183 * nCulm + 1] = -38.501543;
      val[183 * nCulm + 2] = 22.955624;
      val[183 * nCulm + 3] = -45.739521;
      val[183 * nCulm + 4] = -34.778968;
      val[183 * nCulm + 5] = 11.695005;
      val[184 * nCulm + 0] = 21.967900;
      val[184 * nCulm + 1] = 7.476123;
      val[184 * nCulm + 2] = -0.392993;
      val[184 * nCulm + 3] = -24.530471;
      val[184 * nCulm + 4] = 16.983302;
      val[184 * nCulm + 5] = -4.523134;
      val[185 * nCulm + 0] = -44.914276;
      val[185 * nCulm + 1] = -15.414633;
      val[185 * nCulm + 2] = 9.496228;
      val[185 * nCulm + 3] = 17.535046;
      val[185 * nCulm + 4] = 16.344452;
      val[185 * nCulm + 5] = 0.844069;
      val[186 * nCulm + 0] = 21.391292;
      val[186 * nCulm + 1] = 22.008946;
      val[186 * nCulm + 2] = 29.890023;
      val[186 * nCulm + 3] = -37.249434;
      val[186 * nCulm + 4] = -45.708447;
      val[186 * nCulm + 5] = 1.808227;
      val[187 * nCulm + 0] = 39.071525;
      val[187 * nCulm + 1] = 3.422793;
      val[187 * nCulm + 2] = -19.150598;
      val[187 * nCulm + 3] = -43.126007;
      val[187 * nCulm + 4] = -4.605577;
      val[187 * nCulm + 5] = 41.034556;
      val[188 * nCulm + 0] = 29.008340;
      val[188 * nCulm + 1] = -21.396621;
      val[188 * nCulm + 2] = 37.100812;
      val[188 * nCulm + 3] = 40.646332;
      val[188 * nCulm + 4] = -17.338042;
      val[188 * nCulm + 5] = -5.025224;
      val[189 * nCulm + 0] = -15.363557;
      val[189 * nCulm + 1] = -6.961582;
      val[189 * nCulm + 2] = -45.054784;
      val[189 * nCulm + 3] = 10.722770;
      val[189 * nCulm + 4] = -15.513562;
      val[189 * nCulm + 5] = -0.917574;
      val[190 * nCulm + 0] = 26.785532;
      val[190 * nCulm + 1] = 47.510264;
      val[190 * nCulm + 2] = -34.889694;
      val[190 * nCulm + 3] = -31.751722;
      val[190 * nCulm + 4] = 5.728507;
      val[190 * nCulm + 5] = 13.250919;
      val[191 * nCulm + 0] = -35.073235;
      val[191 * nCulm + 1] = -24.477207;
      val[191 * nCulm + 2] = -30.084018;
      val[191 * nCulm + 3] = 34.755391;
      val[191 * nCulm + 4] = -11.938715;
      val[191 * nCulm + 5] = -3.844984;
      val[192 * nCulm + 0] = -3.738945;
      val[192 * nCulm + 1] = 22.615996;
      val[192 * nCulm + 2] = -13.324037;
      val[192 * nCulm + 3] = -23.953697;
      val[192 * nCulm + 4] = -0.457915;
      val[192 * nCulm + 5] = 14.057423;
      val[193 * nCulm + 0] = -11.598247;
      val[193 * nCulm + 1] = 41.565777;
      val[193 * nCulm + 2] = 20.706761;
      val[193 * nCulm + 3] = 38.584748;
      val[193 * nCulm + 4] = -41.322596;
      val[193 * nCulm + 5] = -8.950913;
      val[194 * nCulm + 0] = 4.288226;
      val[194 * nCulm + 1] = -10.384373;
      val[194 * nCulm + 2] = -29.404632;
      val[194 * nCulm + 3] = 19.721696;
      val[194 * nCulm + 4] = -0.189228;
      val[194 * nCulm + 5] = -233.332625;
      val[195 * nCulm + 0] = 11.201869;
      val[195 * nCulm + 1] = -13.900790;
      val[195 * nCulm + 2] = 32.691378;
      val[195 * nCulm + 3] = -0.804415;
      val[195 * nCulm + 4] = -20.973521;
      val[195 * nCulm + 5] = 3.548691;
      val[196 * nCulm + 0] = -14.566574;
      val[196 * nCulm + 1] = 44.713316;
      val[196 * nCulm + 2] = 39.901910;
      val[196 * nCulm + 3] = -20.642194;
      val[196 * nCulm + 4] = 20.700763;
      val[196 * nCulm + 5] = 5.733983;
      val[197 * nCulm + 0] = 11.190295;
      val[197 * nCulm + 1] = -39.748400;
      val[197 * nCulm + 2] = -11.691824;
      val[197 * nCulm + 3] = 30.071969;
      val[197 * nCulm + 4] = 30.090670;
      val[197 * nCulm + 5] = -1.292126;
      val[198 * nCulm + 0] = -7.957548;
      val[198 * nCulm + 1] = 47.381457;
      val[198 * nCulm + 2] = 0.431692;
      val[198 * nCulm + 3] = 10.652419;
      val[198 * nCulm + 4] = -45.220539;
      val[198 * nCulm + 5] = -5.844534;
      val[199 * nCulm + 0] = -31.628042;
      val[199 * nCulm + 1] = -1.079781;
      val[199 * nCulm + 2] = -12.192071;
      val[199 * nCulm + 3] = -39.357040;
      val[199 * nCulm + 4] = -31.886431;
      val[199 * nCulm + 5] = 6.232583;


      IntPtr TrainData = Marshal.AllocHGlobal(sizeof(Double) * n * nCulm);
      Marshal.Copy(val, 0, TrainData, n * nCulm);

      return TrainData;
    }
  }
}
